package androidx.constraintlayout.core.motion.utils;

import java.util.Arrays;

/* loaded from: classes.dex */
public class Oscillator {
    public static final int BOUNCE = 6;
    public static final int COS_WAVE = 5;
    public static final int CUSTOM = 7;
    public static final int REVERSE_SAW_WAVE = 4;
    public static final int SAW_WAVE = 3;
    public static final int SIN_WAVE = 0;
    public static final int SQUARE_WAVE = 1;
    public static String TAG = "Oscillator";
    public static final int TRIANGLE_WAVE = 2;
    double[] mArea;
    MonotonicCurveFit mCustomCurve;
    String mCustomType;
    int mType;
    float[] mPeriod = new float[0];
    double[] mPosition = new double[0];
    double PI2 = 6.283185307179586d;
    private boolean mNormalized = false;

    public String toString() {
        return "pos =" + Arrays.toString(this.mPosition) + " period=" + Arrays.toString(this.mPeriod);
    }

    public void setType(int i2, String str) {
        this.mType = i2;
        this.mCustomType = str;
        if (str != null) {
            this.mCustomCurve = MonotonicCurveFit.buildWave(str);
        }
    }

    public void addPoint(double d2, float f2) {
        int length = this.mPeriod.length + 1;
        int binarySearch = Arrays.binarySearch(this.mPosition, d2);
        if (binarySearch < 0) {
            binarySearch = (-binarySearch) - 1;
        }
        this.mPosition = Arrays.copyOf(this.mPosition, length);
        this.mPeriod = Arrays.copyOf(this.mPeriod, length);
        this.mArea = new double[length];
        double[] dArr = this.mPosition;
        System.arraycopy(dArr, binarySearch, dArr, binarySearch + 1, (length - binarySearch) - 1);
        this.mPosition[binarySearch] = d2;
        this.mPeriod[binarySearch] = f2;
        this.mNormalized = false;
    }

    public void normalize() {
        double d2 = 0.0d;
        int i2 = 0;
        while (true) {
            if (i2 >= this.mPeriod.length) {
                break;
            }
            d2 += r7[i2];
            i2++;
        }
        double d3 = 0.0d;
        int i3 = 1;
        while (true) {
            float[] fArr = this.mPeriod;
            if (i3 >= fArr.length) {
                break;
            }
            int i4 = i3 - 1;
            float f2 = (fArr[i4] + fArr[i3]) / 2.0f;
            double[] dArr = this.mPosition;
            d3 += (dArr[i3] - dArr[i4]) * f2;
            i3++;
        }
        int i5 = 0;
        while (true) {
            float[] fArr2 = this.mPeriod;
            if (i5 >= fArr2.length) {
                break;
            }
            fArr2[i5] = (float) (fArr2[i5] * (d2 / d3));
            i5++;
        }
        this.mArea[0] = 0.0d;
        int i6 = 1;
        while (true) {
            float[] fArr3 = this.mPeriod;
            if (i6 < fArr3.length) {
                int i7 = i6 - 1;
                float f3 = (fArr3[i7] + fArr3[i6]) / 2.0f;
                double[] dArr2 = this.mPosition;
                double d4 = dArr2[i6] - dArr2[i7];
                double[] dArr3 = this.mArea;
                dArr3[i6] = dArr3[i7] + (d4 * f3);
                i6++;
            } else {
                this.mNormalized = true;
                return;
            }
        }
    }

    double getP(double d2) {
        if (d2 < com.yucheng.smarthealthpro.customchart.utils.Utils.DOUBLE_EPSILON) {
            d2 = 0.0d;
        } else if (d2 > 1.0d) {
            d2 = 1.0d;
        }
        int binarySearch = Arrays.binarySearch(this.mPosition, d2);
        if (binarySearch > 0) {
            return 1.0d;
        }
        if (binarySearch == 0) {
            return com.yucheng.smarthealthpro.customchart.utils.Utils.DOUBLE_EPSILON;
        }
        int i2 = (-binarySearch) - 1;
        float[] fArr = this.mPeriod;
        float f2 = fArr[i2];
        int i3 = i2 - 1;
        float f3 = fArr[i3];
        double d3 = f2 - f3;
        double[] dArr = this.mPosition;
        double d4 = dArr[i2];
        double d5 = dArr[i3];
        double d6 = d3 / (d4 - d5);
        return this.mArea[i3] + ((f3 - (d6 * d5)) * (d2 - d5)) + ((d6 * ((d2 * d2) - (d5 * d5))) / 2.0d);
    }

    public double getValue(double d2, double d3) {
        double abs;
        double p = getP(d2) + d3;
        switch (this.mType) {
            case 1:
                return Math.signum(0.5d - (p % 1.0d));
            case 2:
                abs = Math.abs((((p * 4.0d) + 1.0d) % 4.0d) - 2.0d);
                break;
            case 3:
                return (((p * 2.0d) + 1.0d) % 2.0d) - 1.0d;
            case 4:
                abs = ((p * 2.0d) + 1.0d) % 2.0d;
                break;
            case 5:
                return Math.cos(this.PI2 * (d3 + p));
            case 6:
                double abs2 = 1.0d - Math.abs(((p * 4.0d) % 4.0d) - 2.0d);
                abs = abs2 * abs2;
                break;
            case 7:
                return this.mCustomCurve.getPos(p % 1.0d, 0);
            default:
                return Math.sin(this.PI2 * p);
        }
        return 1.0d - abs;
    }

    double getDP(double d2) {
        if (d2 <= com.yucheng.smarthealthpro.customchart.utils.Utils.DOUBLE_EPSILON) {
            d2 = 1.0E-5d;
        } else if (d2 >= 1.0d) {
            d2 = 0.999999d;
        }
        int binarySearch = Arrays.binarySearch(this.mPosition, d2);
        if (binarySearch > 0 || binarySearch == 0) {
            return com.yucheng.smarthealthpro.customchart.utils.Utils.DOUBLE_EPSILON;
        }
        int i2 = (-binarySearch) - 1;
        float[] fArr = this.mPeriod;
        float f2 = fArr[i2];
        int i3 = i2 - 1;
        float f3 = fArr[i3];
        double d3 = f2 - f3;
        double[] dArr = this.mPosition;
        double d4 = dArr[i2];
        double d5 = dArr[i3];
        double d6 = d3 / (d4 - d5);
        return (f3 - (d6 * d5)) + (d2 * d6);
    }

    public double getSlope(double d2, double d3, double d4) {
        double p = d3 + getP(d2);
        double dp = getDP(d2) + d4;
        switch (this.mType) {
            case 1:
                return com.yucheng.smarthealthpro.customchart.utils.Utils.DOUBLE_EPSILON;
            case 2:
                return dp * 4.0d * Math.signum((((p * 4.0d) + 3.0d) % 4.0d) - 2.0d);
            case 3:
                return dp * 2.0d;
            case 4:
                return (-dp) * 2.0d;
            case 5:
                double d5 = this.PI2;
                return (-d5) * dp * Math.sin(d5 * p);
            case 6:
                return dp * 4.0d * ((((p * 4.0d) + 2.0d) % 4.0d) - 2.0d);
            case 7:
                return this.mCustomCurve.getSlope(p % 1.0d, 0);
            default:
                double d6 = this.PI2;
                return dp * d6 * Math.cos(d6 * p);
        }
    }
}
