package cn.addapp.pickers.common;

import android.R;
import android.app.Activity;
import android.text.TextUtils;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;
import androidx.core.view.ViewCompat;
import cn.addapp.pickers.util.ConvertUtils;
import cn.addapp.pickers.widget.WheelListView;

/* loaded from: classes.dex */
public abstract class ConfirmDialog<V extends View> extends BaseDialog<View> {
    protected int backgroundColor;
    private TextView cancelButton;
    protected CharSequence cancelText;
    protected int cancelTextColor;
    protected int cancelTextSize;
    protected boolean cancelVisible;
    protected int pressedTextColor;
    private TextView submitButton;
    protected CharSequence submitText;
    protected int submitTextColor;
    protected int submitTextSize;
    protected CharSequence titleText;
    protected int titleTextColor;
    protected int titleTextSize;
    private View titleView;
    protected int topBackgroundColor;
    protected int topHeight;
    protected int topLineColor;
    protected int topLineHeight;
    protected boolean topLineVisible;
    protected int topPadding;

    protected abstract V makeCenterView();

    protected View makeFooterView() {
        return null;
    }

    protected void onCancel() {
    }

    protected void onSubmit() {
    }

    public ConfirmDialog(Activity activity) {
        super(activity);
        this.topLineVisible = true;
        this.topLineColor = -2236963;
        this.topLineHeight = 1;
        this.topBackgroundColor = -1;
        this.topHeight = 40;
        this.topPadding = 15;
        this.cancelVisible = true;
        this.cancelText = "";
        this.submitText = "";
        this.titleText = "";
        this.cancelTextColor = ViewCompat.MEASURED_STATE_MASK;
        this.submitTextColor = ViewCompat.MEASURED_STATE_MASK;
        this.titleTextColor = ViewCompat.MEASURED_STATE_MASK;
        this.pressedTextColor = WheelListView.TEXT_COLOR_FOCUS;
        this.cancelTextSize = 0;
        this.submitTextSize = 0;
        this.titleTextSize = 0;
        this.backgroundColor = -1;
        this.cancelText = activity.getString(R.string.cancel);
        this.submitText = activity.getString(R.string.ok);
    }

    public void setTopLineColor(int i2) {
        this.topLineColor = i2;
    }

    public void setTopLineHeight(int i2) {
        this.topLineHeight = i2;
    }

    public void setTopBackgroundColor(int i2) {
        this.topBackgroundColor = i2;
    }

    public void setTopHeight(int i2) {
        this.topHeight = i2;
    }

    public void setTopPadding(int i2) {
        this.topPadding = i2;
    }

    public void setTopLineVisible(boolean z) {
        this.topLineVisible = z;
    }

    public void setCancelVisible(boolean z) {
        TextView textView = this.cancelButton;
        if (textView != null) {
            textView.setVisibility(z ? 0 : 8);
        } else {
            this.cancelVisible = z;
        }
    }

    public void setCancelText(CharSequence charSequence) {
        TextView textView = this.cancelButton;
        if (textView != null) {
            textView.setText(charSequence);
        } else {
            this.cancelText = charSequence;
        }
    }

    public void setCancelText(int i2) {
        setCancelText(this.activity.getString(i2));
    }

    public void setSubmitText(CharSequence charSequence) {
        TextView textView = this.submitButton;
        if (textView != null) {
            textView.setText(charSequence);
        } else {
            this.submitText = charSequence;
        }
    }

    public void setSubmitText(int i2) {
        setSubmitText(this.activity.getString(i2));
    }

    public void setTitleText(CharSequence charSequence) {
        View view = this.titleView;
        if (view != null && (view instanceof TextView)) {
            ((TextView) view).setText(charSequence);
        } else {
            this.titleText = charSequence;
        }
    }

    public void setTitleText(int i2) {
        setTitleText(this.activity.getString(i2));
    }

    public void setCancelTextColor(int i2) {
        TextView textView = this.cancelButton;
        if (textView != null) {
            textView.setTextColor(i2);
        } else {
            this.cancelTextColor = i2;
        }
    }

    public void setSubmitTextColor(int i2) {
        TextView textView = this.submitButton;
        if (textView != null) {
            textView.setTextColor(i2);
        } else {
            this.submitTextColor = i2;
        }
    }

    public void setTitleTextColor(int i2) {
        View view = this.titleView;
        if (view != null && (view instanceof TextView)) {
            ((TextView) view).setTextColor(i2);
        } else {
            this.titleTextColor = i2;
        }
    }

    public void setPressedTextColor(int i2) {
        this.pressedTextColor = i2;
    }

    public void setCancelTextSize(int i2) {
        this.cancelTextSize = i2;
    }

    public void setSubmitTextSize(int i2) {
        this.submitTextSize = i2;
    }

    public void setTitleTextSize(int i2) {
        this.titleTextSize = i2;
    }

    public void setBackgroundColor(int i2) {
        this.backgroundColor = i2;
    }

    public void setTitleView(View view) {
        this.titleView = view;
    }

    public View getTitleView() {
        View view = this.titleView;
        if (view != null) {
            return view;
        }
        throw new NullPointerException("please call show at first");
    }

    public TextView getCancelButton() {
        TextView textView = this.cancelButton;
        if (textView != null) {
            return textView;
        }
        throw new NullPointerException("please call show at first");
    }

    public TextView getSubmitButton() {
        TextView textView = this.submitButton;
        if (textView != null) {
            return textView;
        }
        throw new NullPointerException("please call show at first");
    }

    @Override // cn.addapp.pickers.common.BaseDialog
    protected final View makeContentView() {
        LinearLayout linearLayout = new LinearLayout(this.activity);
        linearLayout.setLayoutParams(new LinearLayout.LayoutParams(-1, -1));
        linearLayout.setBackgroundColor(this.backgroundColor);
        linearLayout.setOrientation(1);
        linearLayout.setGravity(17);
        linearLayout.setPadding(0, 0, 0, 0);
        linearLayout.setClipToPadding(false);
        View makeHeaderView = makeHeaderView();
        if (makeHeaderView != null) {
            linearLayout.addView(makeHeaderView);
        }
        if (this.topLineVisible) {
            View view = new View(this.activity);
            view.setLayoutParams(new LinearLayout.LayoutParams(-1, ConvertUtils.toPx(this.activity, this.topLineHeight)));
            view.setBackgroundColor(this.topLineColor);
            linearLayout.addView(view);
        }
        LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(-1, 0, 1.0f);
        layoutParams.setMargins(0, 15, 0, 15);
        linearLayout.addView(makeCenterView(), layoutParams);
        View makeFooterView = makeFooterView();
        if (makeFooterView != null) {
            linearLayout.addView(makeFooterView);
        }
        return linearLayout;
    }

    protected View makeHeaderView() {
        RelativeLayout relativeLayout = new RelativeLayout(this.activity);
        relativeLayout.setLayoutParams(new RelativeLayout.LayoutParams(-1, ConvertUtils.toPx(this.activity, this.topHeight)));
        relativeLayout.setBackgroundColor(this.topBackgroundColor);
        relativeLayout.setGravity(16);
        TextView textView = new TextView(this.activity);
        this.cancelButton = textView;
        textView.setVisibility(this.cancelVisible ? 0 : 8);
        RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(-2, -1);
        layoutParams.addRule(9, -1);
        layoutParams.addRule(15, -1);
        this.cancelButton.setLayoutParams(layoutParams);
        this.cancelButton.setBackgroundColor(0);
        this.cancelButton.setGravity(17);
        int px = ConvertUtils.toPx(this.activity, this.topPadding);
        this.cancelButton.setPadding(px, 0, px, 0);
        if (!TextUtils.isEmpty(this.cancelText)) {
            this.cancelButton.setText(this.cancelText);
        }
        this.cancelButton.setTextColor(ConvertUtils.toColorStateList(this.cancelTextColor, this.pressedTextColor));
        int i2 = this.cancelTextSize;
        if (i2 != 0) {
            this.cancelButton.setTextSize(i2);
        }
        this.cancelButton.setOnClickListener(new View.OnClickListener() { // from class: cn.addapp.pickers.common.ConfirmDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                ConfirmDialog.this.dismiss();
                ConfirmDialog.this.onCancel();
            }
        });
        relativeLayout.addView(this.cancelButton);
        if (this.titleView == null) {
            TextView textView2 = new TextView(this.activity);
            RelativeLayout.LayoutParams layoutParams2 = new RelativeLayout.LayoutParams(-2, -2);
            int px2 = ConvertUtils.toPx(this.activity, this.topPadding);
            layoutParams2.leftMargin = px2;
            layoutParams2.rightMargin = px2;
            layoutParams2.addRule(14, -1);
            layoutParams2.addRule(15, -1);
            textView2.setLayoutParams(layoutParams2);
            textView2.setGravity(17);
            if (!TextUtils.isEmpty(this.titleText)) {
                textView2.setText(this.titleText);
            }
            textView2.setTextColor(this.titleTextColor);
            int i3 = this.titleTextSize;
            if (i3 != 0) {
                textView2.setTextSize(i3);
            }
            this.titleView = textView2;
        }
        relativeLayout.addView(this.titleView);
        this.submitButton = new TextView(this.activity);
        RelativeLayout.LayoutParams layoutParams3 = new RelativeLayout.LayoutParams(-2, -1);
        layoutParams3.addRule(11, -1);
        layoutParams3.addRule(15, -1);
        this.submitButton.setLayoutParams(layoutParams3);
        this.submitButton.setBackgroundColor(0);
        this.submitButton.setGravity(17);
        this.submitButton.setPadding(px, 0, px, 0);
        if (!TextUtils.isEmpty(this.submitText)) {
            this.submitButton.setText(this.submitText);
        }
        this.submitButton.setTextColor(ConvertUtils.toColorStateList(this.submitTextColor, this.pressedTextColor));
        int i4 = this.submitTextSize;
        if (i4 != 0) {
            this.submitButton.setTextSize(i4);
        }
        this.submitButton.setOnClickListener(new View.OnClickListener() { // from class: cn.addapp.pickers.common.ConfirmDialog.2
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                ConfirmDialog.this.dismiss();
                ConfirmDialog.this.onSubmit();
            }
        });
        relativeLayout.addView(this.submitButton);
        return relativeLayout;
    }
}
