package cn.addapp.pickers.picker;

import android.app.Activity;
import android.text.TextUtils;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;
import cn.addapp.pickers.adapter.ArrayWheelAdapter;
import cn.addapp.pickers.common.LineConfig;
import cn.addapp.pickers.listeners.OnItemPickListener;
import cn.addapp.pickers.util.DateUtils;
import cn.addapp.pickers.util.LogUtils;
import cn.addapp.pickers.widget.WheelListView;
import cn.addapp.pickers.widget.WheelView;
import com.autonavi.base.amap.mapcore.tools.GLMapStaticValue;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Comparator;
import java.util.Locale;

/* loaded from: classes.dex */
public class DateTimePicker extends WheelPicker {
    public static final int HOUR_12 = 4;
    public static final int HOUR_24 = 3;
    public static final int MONTH_DAY = 2;
    public static final int NONE = -1;
    public static final int YEAR_MONTH = 1;
    public static final int YEAR_MONTH_DAY = 0;
    private int dateMode;
    private String dayLabel;
    private ArrayList<String> days;
    private int endDay;
    private int endHour;
    private int endMinute;
    private int endMonth;
    private int endYear;
    private String hourLabel;
    private ArrayList<String> hours;
    private String minuteLabel;
    private ArrayList<String> minutes;
    private String monthLabel;
    private ArrayList<String> months;
    private OnDateTimePickListener onDateTimePickListener;
    private OnWheelListener onWheelListener;
    private int selectedDayIndex;
    private String selectedHour;
    private int selectedHourIndex;
    private String selectedMinute;
    private int selectedMinuteIndex;
    private int selectedMonthIndex;
    private int selectedYearIndex;
    private int startDay;
    private int startHour;
    private int startMinute;
    private int startMonth;
    private int startYear;
    private int timeMode;
    private String yearLabel;
    private ArrayList<String> years;

    @Retention(RetentionPolicy.SOURCE)
    public @interface DateMode {
    }

    protected interface OnDateTimePickListener {
    }

    public interface OnMonthDayTimePickListener extends OnDateTimePickListener {
        void onDateTimePicked(String str, String str2, String str3, String str4);
    }

    public interface OnTimePickListener extends OnDateTimePickListener {
        void onDateTimePicked(String str, String str2);
    }

    public interface OnWheelListener {
        void onDayWheeled(int i2, String str);

        void onHourWheeled(int i2, String str);

        void onMinuteWheeled(int i2, String str);

        void onMonthWheeled(int i2, String str);

        void onYearWheeled(int i2, String str);
    }

    public interface OnYearMonthDayTimePickListener extends OnDateTimePickListener {
        void onDateTimePicked(String str, String str2, String str3, String str4, String str5);
    }

    public interface OnYearMonthTimePickListener extends OnDateTimePickListener {
        void onDateTimePicked(String str, String str2, String str3, String str4);
    }

    @Retention(RetentionPolicy.SOURCE)
    public @interface TimeMode {
    }

    public DateTimePicker(Activity activity, int i2) {
        this(activity, 0, i2);
    }

    public DateTimePicker(Activity activity, int i2, int i3) {
        super(activity);
        this.years = new ArrayList<>();
        this.months = new ArrayList<>();
        this.days = new ArrayList<>();
        this.hours = new ArrayList<>();
        this.minutes = new ArrayList<>();
        this.yearLabel = "年";
        this.monthLabel = "月";
        this.dayLabel = "日";
        this.hourLabel = "时";
        this.minuteLabel = "分";
        this.selectedYearIndex = 0;
        this.selectedMonthIndex = 0;
        this.selectedDayIndex = 0;
        this.selectedHourIndex = 0;
        this.selectedMinuteIndex = 0;
        this.selectedHour = "";
        this.selectedMinute = "";
        this.dateMode = 0;
        this.timeMode = 3;
        this.startYear = GLMapStaticValue.MAP_PARAMETERNAME_TRAFFIC;
        this.startMonth = 1;
        this.startDay = 1;
        this.endYear = 2020;
        this.endMonth = 12;
        this.endDay = 31;
        this.startMinute = 0;
        this.endMinute = 59;
        if (i2 == -1 && i3 == -1) {
            throw new IllegalArgumentException("The modes are NONE at the same time");
        }
        if (i2 == 0 && i3 != -1) {
            if (this.screenWidthPixels < 720) {
                this.textSize = 14;
            } else if (this.screenWidthPixels < 480) {
                this.textSize = 12;
            }
        }
        this.dateMode = i2;
        if (i3 == 4) {
            this.startHour = 1;
            this.endHour = 12;
        } else {
            this.startHour = 0;
            this.endHour = 23;
        }
        this.timeMode = i3;
    }

    public void setDateRangeStart(int i2, int i3, int i4) {
        if (this.dateMode == -1) {
            throw new IllegalArgumentException("Date mode invalid");
        }
        this.startYear = i2;
        this.startMonth = i3;
        this.startDay = i4;
    }

    public void setDateRangeEnd(int i2, int i3, int i4) {
        if (this.dateMode == -1) {
            throw new IllegalArgumentException("Date mode invalid");
        }
        this.endYear = i2;
        this.endMonth = i3;
        this.endDay = i4;
        initYearData();
    }

    public void setDateRangeStart(int i2, int i3) {
        int i4 = this.dateMode;
        if (i4 == -1) {
            throw new IllegalArgumentException("Date mode invalid");
        }
        if (i4 == 0) {
            throw new IllegalArgumentException("Not support year/month/day mode");
        }
        if (i4 == 1) {
            this.startYear = i2;
            this.startMonth = i3;
        } else if (i4 == 2) {
            int i5 = Calendar.getInstance(Locale.CHINA).get(1);
            this.endYear = i5;
            this.startYear = i5;
            this.startMonth = i2;
            this.startDay = i3;
        }
    }

    public void setDateRangeEnd(int i2, int i3) {
        int i4 = this.dateMode;
        if (i4 == -1) {
            throw new IllegalArgumentException("Date mode invalid");
        }
        if (i4 == 0) {
            throw new IllegalArgumentException("Not support year/month/day mode");
        }
        if (i4 == 1) {
            this.endYear = i2;
            this.endMonth = i3;
        } else if (i4 == 2) {
            this.endMonth = i2;
            this.endDay = i3;
        }
        initYearData();
    }

    public void setTimeRangeStart(int i2, int i3) {
        int i4 = this.timeMode;
        if (i4 == -1) {
            throw new IllegalArgumentException("Time mode invalid");
        }
        boolean z = i2 < 0 || i3 < 0 || i3 > 59;
        if (i4 == 4 && (i2 == 0 || i2 > 12)) {
            z = true;
        }
        if ((i4 != 3 || i2 < 24) ? z : true) {
            throw new IllegalArgumentException("Time out of range");
        }
        this.startHour = i2;
        this.startMinute = i3;
    }

    public void setTimeRangeEnd(int i2, int i3) {
        int i4 = this.timeMode;
        if (i4 == -1) {
            throw new IllegalArgumentException("Time mode invalid");
        }
        boolean z = i2 < 0 || i3 < 0 || i3 > 59;
        if (i4 == 4 && (i2 == 0 || i2 > 12)) {
            z = true;
        }
        if ((i4 != 3 || i2 < 24) ? z : true) {
            throw new IllegalArgumentException("Time out of range");
        }
        this.endHour = i2;
        this.endMinute = i3;
        initHourData();
    }

    public void setLabel(String str, String str2, String str3, String str4, String str5) {
        this.yearLabel = str;
        this.monthLabel = str2;
        this.dayLabel = str3;
        this.hourLabel = str4;
        this.minuteLabel = str5;
    }

    public void setSelectedItem(int i2, int i3, int i4, int i5, int i6) {
        if (this.dateMode != 0) {
            throw new IllegalArgumentException("Date mode invalid");
        }
        LogUtils.verbose(this, "change months and days while set selected");
        changeMonthData(i2);
        changeDayData(i2, i3);
        this.selectedYearIndex = findItemIndex(this.years, i2);
        this.selectedMonthIndex = findItemIndex(this.months, i3);
        this.selectedDayIndex = findItemIndex(this.days, i4);
        if (this.timeMode != -1) {
            this.selectedHour = DateUtils.fillZero(i5);
            this.selectedMinute = DateUtils.fillZero(i6);
        }
    }

    public void setSelectedItem(int i2, int i3, int i4, int i5) {
        int i6 = this.dateMode;
        if (i6 == 0) {
            throw new IllegalArgumentException("Date mode invalid");
        }
        if (i6 == 2) {
            LogUtils.verbose(this, "change months and days while set selected");
            int i7 = Calendar.getInstance(Locale.CHINA).get(1);
            this.endYear = i7;
            this.startYear = i7;
            changeMonthData(i7);
            changeDayData(i7, i2);
            this.selectedMonthIndex = findItemIndex(this.months, i2);
            this.selectedDayIndex = findItemIndex(this.days, i3);
        } else if (i6 == 1) {
            LogUtils.verbose(this, "change months while set selected");
            changeMonthData(i2);
            this.selectedYearIndex = findItemIndex(this.years, i2);
            this.selectedMonthIndex = findItemIndex(this.months, i3);
        }
        if (this.timeMode != -1) {
            this.selectedHour = DateUtils.fillZero(i4);
            this.selectedMinute = DateUtils.fillZero(i5);
        }
    }

    public void setOnWheelListener(OnWheelListener onWheelListener) {
        this.onWheelListener = onWheelListener;
    }

    public void setOnDateTimePickListener(OnDateTimePickListener onDateTimePickListener) {
        this.onDateTimePickListener = onDateTimePickListener;
    }

    public String getSelectedYear() {
        int i2 = this.dateMode;
        if (i2 != 0 && i2 != 1) {
            return "";
        }
        if (this.years.size() <= this.selectedYearIndex) {
            this.selectedYearIndex = this.years.size() - 1;
        }
        return this.years.get(this.selectedYearIndex);
    }

    public String getSelectedMonth() {
        if (this.dateMode == -1) {
            return "";
        }
        if (this.months.size() <= this.selectedMonthIndex) {
            this.selectedMonthIndex = this.months.size() - 1;
        }
        return this.months.get(this.selectedMonthIndex);
    }

    public String getSelectedDay() {
        int i2 = this.dateMode;
        if (i2 != 0 && i2 != 2) {
            return "";
        }
        if (this.days.size() <= this.selectedDayIndex) {
            this.selectedDayIndex = this.days.size() - 1;
        }
        return this.days.get(this.selectedDayIndex);
    }

    public String getSelectedHour() {
        return this.timeMode != -1 ? this.selectedHour : "";
    }

    public String getSelectedMinute() {
        return this.timeMode != -1 ? this.selectedMinute : "";
    }

    @Override // cn.addapp.pickers.common.ConfirmDialog
    protected View makeCenterView() {
        int i2;
        LinearLayout.LayoutParams layoutParams;
        int i3 = this.dateMode;
        if ((i3 == 0 || i3 == 1) && this.years.size() == 0) {
            LogUtils.verbose(this, "init years before make view");
            initYearData();
        }
        if (this.dateMode != -1 && this.months.size() == 0) {
            LogUtils.verbose(this, "init months before make view");
            changeMonthData(DateUtils.trimZero(getSelectedYear()));
        }
        int i4 = this.dateMode;
        if ((i4 == 0 || i4 == 2) && this.days.size() == 0) {
            LogUtils.verbose(this, "init days before make view");
            if (this.dateMode == 0) {
                i2 = DateUtils.trimZero(getSelectedYear());
            } else {
                i2 = Calendar.getInstance(Locale.CHINA).get(1);
            }
            changeDayData(i2, DateUtils.trimZero(getSelectedMonth()));
        }
        if (this.timeMode != -1 && this.hours.size() == 0) {
            LogUtils.verbose(this, "init hours before make view");
            initHourData();
        }
        if (this.timeMode != -1 && this.minutes.size() == 0) {
            LogUtils.verbose(this, "init minutes before make view");
            changeMinuteData(DateUtils.trimZero(this.selectedHour));
        }
        LinearLayout linearLayout = new LinearLayout(this.activity);
        linearLayout.setOrientation(0);
        linearLayout.setGravity(17);
        linearLayout.setWeightSum(5.0f);
        if (this.weightEnable) {
            layoutParams = new LinearLayout.LayoutParams(0, -2);
            layoutParams.weight = 1.0f;
        } else {
            layoutParams = new LinearLayout.LayoutParams(-2, -2);
        }
        LinearLayout.LayoutParams layoutParams2 = new LinearLayout.LayoutParams(-2, -2);
        if (this.wheelModeEnable) {
            WheelView wheelView = new WheelView(this.activity);
            final WheelView wheelView2 = new WheelView(this.activity);
            final WheelView wheelView3 = new WheelView(this.activity);
            WheelView wheelView4 = new WheelView(this.activity);
            final WheelView wheelView5 = new WheelView(this.activity);
            int i5 = this.dateMode;
            if (i5 == 0 || i5 == 1) {
                wheelView.setCanLoop(this.canLoop);
                wheelView.setTextSize(this.textSize);
                wheelView.setSelectedTextColor(this.textColorFocus);
                wheelView.setUnSelectedTextColor(this.textColorNormal);
                wheelView.setAdapter(new ArrayWheelAdapter(this.years));
                wheelView.setCurrentItem(this.selectedYearIndex);
                wheelView.setDividerType(LineConfig.DividerType.FILL);
                wheelView.setLayoutParams(layoutParams);
                wheelView.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.DateTimePicker.1
                    @Override // cn.addapp.pickers.listeners.OnItemPickListener
                    public void onItemPicked(int i6, String str) {
                        DateTimePicker.this.selectedYearIndex = i6;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onYearWheeled(DateTimePicker.this.selectedYearIndex, str);
                        }
                        LogUtils.verbose(this, "change months after year wheeled");
                        DateTimePicker.this.selectedMonthIndex = 0;
                        DateTimePicker.this.selectedDayIndex = 0;
                        int trimZero = DateUtils.trimZero(str);
                        DateTimePicker.this.changeMonthData(trimZero);
                        wheelView2.setAdapter(new ArrayWheelAdapter(DateTimePicker.this.months));
                        wheelView2.setCurrentItem(DateTimePicker.this.selectedMonthIndex);
                        DateTimePicker dateTimePicker = DateTimePicker.this;
                        dateTimePicker.changeDayData(trimZero, DateUtils.trimZero((String) dateTimePicker.months.get(DateTimePicker.this.selectedMonthIndex)));
                        wheelView3.setAdapter(new ArrayWheelAdapter(DateTimePicker.this.days));
                        wheelView3.setCurrentItem(DateTimePicker.this.selectedDayIndex);
                    }
                });
                linearLayout.addView(wheelView);
                if (!TextUtils.isEmpty(this.yearLabel)) {
                    TextView textView = new TextView(this.activity);
                    textView.setLayoutParams(layoutParams2);
                    textView.setTextColor(this.textColorFocus);
                    textView.setTextSize(this.textSize);
                    textView.setText(this.yearLabel);
                    linearLayout.addView(textView);
                }
            }
            if (this.dateMode != -1) {
                wheelView2.setCanLoop(this.canLoop);
                wheelView2.setTextSize(this.textSize);
                wheelView2.setSelectedTextColor(this.textColorFocus);
                wheelView2.setUnSelectedTextColor(this.textColorNormal);
                wheelView2.setAdapter(new ArrayWheelAdapter(this.months));
                wheelView2.setCurrentItem(this.selectedMonthIndex);
                wheelView2.setDividerType(LineConfig.DividerType.FILL);
                wheelView2.setLayoutParams(layoutParams);
                wheelView2.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.DateTimePicker.2
                    @Override // cn.addapp.pickers.listeners.OnItemPickListener
                    public void onItemPicked(int i6, String str) {
                        int i7;
                        DateTimePicker.this.selectedMonthIndex = i6;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onMonthWheeled(DateTimePicker.this.selectedMonthIndex, str);
                        }
                        if (DateTimePicker.this.dateMode == 0 || DateTimePicker.this.dateMode == 2) {
                            LogUtils.verbose(this, "change days after month wheeled");
                            DateTimePicker.this.selectedDayIndex = 0;
                            if (DateTimePicker.this.dateMode == 0) {
                                i7 = DateUtils.trimZero(DateTimePicker.this.getSelectedYear());
                            } else {
                                i7 = Calendar.getInstance(Locale.CHINA).get(1);
                            }
                            DateTimePicker.this.changeDayData(i7, DateUtils.trimZero(str));
                            wheelView3.setAdapter(new ArrayWheelAdapter(DateTimePicker.this.days));
                            wheelView3.setCurrentItem(DateTimePicker.this.selectedDayIndex);
                        }
                    }
                });
                linearLayout.addView(wheelView2);
                if (!TextUtils.isEmpty(this.monthLabel)) {
                    TextView textView2 = new TextView(this.activity);
                    textView2.setLayoutParams(layoutParams2);
                    textView2.setTextColor(this.textColorFocus);
                    textView2.setTextSize(this.textSize);
                    textView2.setText(this.monthLabel);
                    linearLayout.addView(textView2);
                }
            }
            int i6 = this.dateMode;
            if (i6 == 0 || i6 == 2) {
                wheelView3.setCanLoop(this.canLoop);
                wheelView3.setTextSize(this.textSize);
                wheelView3.setSelectedTextColor(this.textColorFocus);
                wheelView3.setUnSelectedTextColor(this.textColorNormal);
                wheelView3.setAdapter(new ArrayWheelAdapter(this.days));
                wheelView3.setCurrentItem(this.selectedDayIndex);
                wheelView3.setDividerType(LineConfig.DividerType.FILL);
                wheelView3.setLayoutParams(layoutParams);
                wheelView3.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.DateTimePicker.3
                    @Override // cn.addapp.pickers.listeners.OnItemPickListener
                    public void onItemPicked(int i7, String str) {
                        DateTimePicker.this.selectedDayIndex = i7;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onDayWheeled(i7, str);
                        }
                    }
                });
                linearLayout.addView(wheelView3);
                if (!TextUtils.isEmpty(this.dayLabel)) {
                    TextView textView3 = new TextView(this.activity);
                    textView3.setLayoutParams(layoutParams2);
                    textView3.setTextColor(this.textColorFocus);
                    textView3.setTextSize(this.textSize);
                    textView3.setText(this.dayLabel);
                    linearLayout.addView(textView3);
                }
            }
            if (this.timeMode != -1) {
                wheelView4.setCanLoop(this.canLoop);
                wheelView4.setTextSize(this.textSize);
                wheelView4.setSelectedTextColor(this.textColorFocus);
                wheelView4.setUnSelectedTextColor(this.textColorNormal);
                wheelView4.setDividerType(LineConfig.DividerType.FILL);
                wheelView4.setAdapter(new ArrayWheelAdapter(this.hours));
                wheelView4.setCurrentItem(this.selectedHourIndex);
                wheelView4.setLayoutParams(layoutParams);
                wheelView4.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.DateTimePicker.4
                    @Override // cn.addapp.pickers.listeners.OnItemPickListener
                    public void onItemPicked(int i7, String str) {
                        DateTimePicker.this.selectedHourIndex = i7;
                        DateTimePicker.this.selectedMinuteIndex = 0;
                        DateTimePicker.this.selectedHour = str;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onHourWheeled(i7, str);
                        }
                        DateTimePicker.this.changeMinuteData(DateUtils.trimZero(str));
                        wheelView5.setAdapter(new ArrayWheelAdapter(DateTimePicker.this.minutes));
                        wheelView5.setCurrentItem(DateTimePicker.this.selectedMinuteIndex);
                    }
                });
                linearLayout.addView(wheelView4);
                if (!TextUtils.isEmpty(this.hourLabel)) {
                    TextView textView4 = new TextView(this.activity);
                    textView4.setLayoutParams(layoutParams2);
                    textView4.setTextColor(this.textColorFocus);
                    textView4.setTextSize(this.textSize);
                    textView4.setText(this.hourLabel);
                    linearLayout.addView(textView4);
                }
                wheelView5.setCanLoop(this.canLoop);
                wheelView5.setTextSize(this.textSize);
                wheelView5.setSelectedTextColor(this.textColorFocus);
                wheelView5.setUnSelectedTextColor(this.textColorNormal);
                wheelView5.setAdapter(new ArrayWheelAdapter(this.minutes));
                wheelView5.setCurrentItem(this.selectedMinuteIndex);
                wheelView5.setDividerType(LineConfig.DividerType.FILL);
                wheelView5.setLayoutParams(layoutParams);
                linearLayout.addView(wheelView5);
                wheelView5.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.DateTimePicker.5
                    @Override // cn.addapp.pickers.listeners.OnItemPickListener
                    public void onItemPicked(int i7, String str) {
                        DateTimePicker.this.selectedMinuteIndex = i7;
                        DateTimePicker.this.selectedMinute = str;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onMinuteWheeled(i7, str);
                        }
                    }
                });
                if (!TextUtils.isEmpty(this.minuteLabel)) {
                    TextView textView5 = new TextView(this.activity);
                    textView5.setLayoutParams(layoutParams2);
                    textView5.setTextColor(this.textColorFocus);
                    textView5.setTextSize(this.textSize);
                    textView5.setText(this.minuteLabel);
                    linearLayout.addView(textView5);
                }
            }
        } else {
            WheelListView wheelListView = new WheelListView(this.activity);
            final WheelListView wheelListView2 = new WheelListView(this.activity);
            final WheelListView wheelListView3 = new WheelListView(this.activity);
            WheelListView wheelListView4 = new WheelListView(this.activity);
            final WheelListView wheelListView5 = new WheelListView(this.activity);
            int i7 = this.dateMode;
            if (i7 == 0 || i7 == 1) {
                wheelListView.setLayoutParams(layoutParams);
                wheelListView.setTextSize(this.textSize);
                wheelListView.setSelectedTextColor(this.textColorFocus);
                wheelListView.setUnSelectedTextColor(this.textColorNormal);
                wheelListView.setLineConfig(this.lineConfig);
                wheelListView.setOffset(this.offset);
                wheelListView.setCanLoop(this.canLoop);
                wheelListView.setItems(this.years, this.selectedYearIndex);
                wheelListView.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.DateTimePicker.6
                    @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
                    public void onItemSelected(boolean z, int i8, String str) {
                        DateTimePicker.this.selectedYearIndex = i8;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onYearWheeled(DateTimePicker.this.selectedYearIndex, str);
                        }
                        if (z) {
                            LogUtils.verbose(this, "change months after year wheeled");
                            DateTimePicker.this.selectedMonthIndex = 0;
                            DateTimePicker.this.selectedDayIndex = 0;
                            int trimZero = DateUtils.trimZero(str);
                            DateTimePicker.this.changeMonthData(trimZero);
                            wheelListView2.setItems(DateTimePicker.this.months, DateTimePicker.this.selectedMonthIndex);
                            DateTimePicker dateTimePicker = DateTimePicker.this;
                            dateTimePicker.changeDayData(trimZero, DateUtils.trimZero((String) dateTimePicker.months.get(DateTimePicker.this.selectedMonthIndex)));
                            wheelListView3.setItems(DateTimePicker.this.days, DateTimePicker.this.selectedDayIndex);
                        }
                    }
                });
                linearLayout.addView(wheelListView);
                if (!TextUtils.isEmpty(this.yearLabel)) {
                    TextView textView6 = new TextView(this.activity);
                    textView6.setLayoutParams(layoutParams2);
                    textView6.setTextSize(this.textSize);
                    textView6.setTextColor(this.textColorFocus);
                    textView6.setText(this.yearLabel);
                    linearLayout.addView(textView6);
                }
            }
            if (this.dateMode != -1) {
                wheelListView2.setLayoutParams(layoutParams);
                wheelListView2.setTextSize(this.textSize);
                wheelListView2.setSelectedTextColor(this.textColorFocus);
                wheelListView2.setUnSelectedTextColor(this.textColorNormal);
                wheelListView2.setLineConfig(this.lineConfig);
                wheelListView2.setOffset(this.offset);
                wheelListView2.setCanLoop(this.canLoop);
                wheelListView2.setItems(this.months, this.selectedMonthIndex);
                wheelListView2.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.DateTimePicker.7
                    @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
                    public void onItemSelected(boolean z, int i8, String str) {
                        int i9;
                        DateTimePicker.this.selectedMonthIndex = i8;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onMonthWheeled(DateTimePicker.this.selectedMonthIndex, str);
                        }
                        if (z) {
                            if (DateTimePicker.this.dateMode == 0 || DateTimePicker.this.dateMode == 2) {
                                LogUtils.verbose(this, "change days after month wheeled");
                                DateTimePicker.this.selectedDayIndex = 0;
                                if (DateTimePicker.this.dateMode == 0) {
                                    i9 = DateUtils.trimZero(DateTimePicker.this.getSelectedYear());
                                } else {
                                    i9 = Calendar.getInstance(Locale.CHINA).get(1);
                                }
                                DateTimePicker.this.changeDayData(i9, DateUtils.trimZero(str));
                                wheelListView3.setItems(DateTimePicker.this.days, DateTimePicker.this.selectedDayIndex);
                            }
                        }
                    }
                });
                linearLayout.addView(wheelListView2);
                if (!TextUtils.isEmpty(this.monthLabel)) {
                    TextView textView7 = new TextView(this.activity);
                    textView7.setLayoutParams(layoutParams2);
                    textView7.setTextSize(this.textSize);
                    textView7.setTextColor(this.textColorFocus);
                    textView7.setText(this.monthLabel);
                    linearLayout.addView(textView7);
                }
            }
            int i8 = this.dateMode;
            if (i8 == 0 || i8 == 2) {
                wheelListView3.setLayoutParams(layoutParams);
                wheelListView3.setTextSize(this.textSize);
                wheelListView3.setSelectedTextColor(this.textColorFocus);
                wheelListView3.setUnSelectedTextColor(this.textColorNormal);
                wheelListView3.setLineConfig(this.lineConfig);
                wheelListView3.setOffset(this.offset);
                wheelListView3.setCanLoop(this.canLoop);
                wheelListView3.setItems(this.days, this.selectedDayIndex);
                wheelListView3.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.DateTimePicker.8
                    @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
                    public void onItemSelected(boolean z, int i9, String str) {
                        DateTimePicker.this.selectedDayIndex = i9;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onDayWheeled(DateTimePicker.this.selectedDayIndex, str);
                        }
                    }
                });
                linearLayout.addView(wheelListView3);
                if (!TextUtils.isEmpty(this.dayLabel)) {
                    TextView textView8 = new TextView(this.activity);
                    textView8.setLayoutParams(layoutParams2);
                    textView8.setTextSize(this.textSize);
                    textView8.setTextColor(this.textColorFocus);
                    textView8.setText(this.dayLabel);
                    linearLayout.addView(textView8);
                }
            }
            if (this.timeMode != -1) {
                wheelListView4.setLayoutParams(layoutParams);
                wheelListView4.setTextSize(this.textSize);
                wheelListView4.setSelectedTextColor(this.textColorFocus);
                wheelListView4.setUnSelectedTextColor(this.textColorNormal);
                wheelListView4.setLineConfig(this.lineConfig);
                wheelListView4.setCanLoop(this.canLoop);
                wheelListView4.setItems(this.hours, this.selectedHour);
                wheelListView4.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.DateTimePicker.9
                    @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
                    public void onItemSelected(boolean z, int i9, String str) {
                        DateTimePicker.this.selectedHourIndex = i9;
                        DateTimePicker.this.selectedMinuteIndex = 0;
                        DateTimePicker.this.selectedHour = str;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onHourWheeled(i9, str);
                        }
                        if (z) {
                            LogUtils.verbose(this, "change minutes after hour wheeled");
                            DateTimePicker.this.changeMinuteData(DateUtils.trimZero(str));
                            wheelListView5.setItems(DateTimePicker.this.minutes, DateTimePicker.this.selectedMinuteIndex);
                        }
                    }
                });
                linearLayout.addView(wheelListView4);
                if (!TextUtils.isEmpty(this.hourLabel)) {
                    TextView textView9 = new TextView(this.activity);
                    textView9.setLayoutParams(layoutParams2);
                    textView9.setTextSize(this.textSize);
                    textView9.setTextColor(this.textColorFocus);
                    textView9.setText(this.hourLabel);
                    linearLayout.addView(textView9);
                }
                wheelListView5.setLayoutParams(layoutParams);
                wheelListView5.setTextSize(this.textSize);
                wheelListView5.setSelectedTextColor(this.textColorFocus);
                wheelListView5.setUnSelectedTextColor(this.textColorNormal);
                wheelListView5.setLineConfig(this.lineConfig);
                wheelListView5.setOffset(this.offset);
                wheelListView5.setCanLoop(this.canLoop);
                wheelListView5.setItems(this.minutes, this.selectedMinute);
                wheelListView5.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.DateTimePicker.10
                    @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
                    public void onItemSelected(boolean z, int i9, String str) {
                        DateTimePicker.this.selectedMinuteIndex = i9;
                        DateTimePicker.this.selectedMinute = str;
                        if (DateTimePicker.this.onWheelListener != null) {
                            DateTimePicker.this.onWheelListener.onMinuteWheeled(i9, str);
                        }
                    }
                });
                linearLayout.addView(wheelListView5);
                if (!TextUtils.isEmpty(this.minuteLabel)) {
                    TextView textView10 = new TextView(this.activity);
                    textView10.setLayoutParams(layoutParams2);
                    textView10.setTextSize(this.textSize);
                    textView10.setTextColor(this.textColorFocus);
                    textView10.setText(this.minuteLabel);
                    linearLayout.addView(textView10);
                }
            }
        }
        return linearLayout;
    }

    @Override // cn.addapp.pickers.common.ConfirmDialog
    protected void onSubmit() {
        if (this.onDateTimePickListener == null) {
            return;
        }
        String selectedYear = getSelectedYear();
        String selectedMonth = getSelectedMonth();
        String selectedDay = getSelectedDay();
        String selectedHour = getSelectedHour();
        String selectedMinute = getSelectedMinute();
        int i2 = this.dateMode;
        if (i2 == -1) {
            ((OnTimePickListener) this.onDateTimePickListener).onDateTimePicked(selectedHour, selectedMinute);
            return;
        }
        if (i2 == 0) {
            ((OnYearMonthDayTimePickListener) this.onDateTimePickListener).onDateTimePicked(selectedYear, selectedMonth, selectedDay, selectedHour, selectedMinute);
        } else if (i2 == 1) {
            ((OnYearMonthTimePickListener) this.onDateTimePickListener).onDateTimePicked(selectedYear, selectedMonth, selectedHour, selectedMinute);
        } else {
            if (i2 != 2) {
                return;
            }
            ((OnMonthDayTimePickListener) this.onDateTimePickListener).onDateTimePicked(selectedMonth, selectedDay, selectedHour, selectedMinute);
        }
    }

    private int findItemIndex(ArrayList<String> arrayList, int i2) {
        int binarySearch = Collections.binarySearch(arrayList, Integer.valueOf(i2), new Comparator<Object>() { // from class: cn.addapp.pickers.picker.DateTimePicker.11
            @Override // java.util.Comparator
            public int compare(Object obj, Object obj2) {
                String obj3 = obj.toString();
                String obj4 = obj2.toString();
                if (obj3.startsWith("0")) {
                    obj3 = obj3.substring(1);
                }
                if (obj4.startsWith("0")) {
                    obj4 = obj4.substring(1);
                }
                return Integer.parseInt(obj3) - Integer.parseInt(obj4);
            }
        });
        if (binarySearch >= 0) {
            return binarySearch;
        }
        throw new IllegalArgumentException("Item[" + i2 + "] out of range");
    }

    private void initYearData() {
        this.years.clear();
        int i2 = this.startYear;
        int i3 = this.endYear;
        if (i2 == i3) {
            this.years.add(String.valueOf(i2));
            return;
        }
        if (i2 < i3) {
            while (i2 <= this.endYear) {
                this.years.add(String.valueOf(i2));
                i2++;
            }
        } else {
            while (i2 >= this.endYear) {
                this.years.add(String.valueOf(i2));
                i2--;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void changeMonthData(int i2) {
        int i3;
        this.months.clear();
        int i4 = this.startMonth;
        int i5 = 1;
        if (i4 < 1 || (i3 = this.endMonth) < 1 || i4 > 12 || i3 > 12) {
            throw new IllegalArgumentException("Month out of range [1-12]");
        }
        int i6 = this.startYear;
        int i7 = this.endYear;
        if (i6 == i7) {
            if (i4 > i3) {
                while (i3 >= this.startMonth) {
                    this.months.add(DateUtils.fillZero(i3));
                    i3--;
                }
                return;
            } else {
                while (i4 <= this.endMonth) {
                    this.months.add(DateUtils.fillZero(i4));
                    i4++;
                }
                return;
            }
        }
        if (i2 == i6) {
            while (i4 <= 12) {
                this.months.add(DateUtils.fillZero(i4));
                i4++;
            }
        } else if (i2 == i7) {
            while (i5 <= this.endMonth) {
                this.months.add(DateUtils.fillZero(i5));
                i5++;
            }
        } else {
            while (i5 <= 12) {
                this.months.add(DateUtils.fillZero(i5));
                i5++;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void changeDayData(int i2, int i3) {
        int calculateDaysInMonth = DateUtils.calculateDaysInMonth(i2, i3);
        this.days.clear();
        int i4 = this.startYear;
        if (i2 == i4 && i3 == this.startMonth && i2 == this.endYear && i3 == this.endMonth) {
            for (int i5 = this.startDay; i5 <= this.endDay; i5++) {
                this.days.add(DateUtils.fillZero(i5));
            }
            return;
        }
        if (i2 == i4 && i3 == this.startMonth) {
            for (int i6 = this.startDay; i6 <= calculateDaysInMonth; i6++) {
                this.days.add(DateUtils.fillZero(i6));
            }
            return;
        }
        int i7 = 1;
        if (i2 == this.endYear && i3 == this.endMonth) {
            while (i7 <= this.endDay) {
                this.days.add(DateUtils.fillZero(i7));
                i7++;
            }
        } else {
            while (i7 <= calculateDaysInMonth) {
                this.days.add(DateUtils.fillZero(i7));
                i7++;
            }
        }
    }

    private void initHourData() {
        for (int i2 = this.startHour; i2 <= this.endHour; i2++) {
            this.hours.add(DateUtils.fillZero(i2));
        }
        if (this.hours.indexOf(this.selectedHour) == -1) {
            this.selectedHour = this.hours.get(0);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void changeMinuteData(int i2) {
        int i3 = this.startHour;
        int i4 = this.endHour;
        if (i3 == i4) {
            int i5 = this.startMinute;
            int i6 = this.endMinute;
            if (i5 > i6) {
                this.startMinute = i6;
                this.endMinute = i5;
            }
            for (int i7 = this.startMinute; i7 <= this.endMinute; i7++) {
                this.minutes.add(DateUtils.fillZero(i7));
            }
        } else if (i2 == i3) {
            for (int i8 = this.startMinute; i8 <= 59; i8++) {
                this.minutes.add(DateUtils.fillZero(i8));
            }
        } else if (i2 == i4) {
            for (int i9 = 0; i9 <= this.endMinute; i9++) {
                this.minutes.add(DateUtils.fillZero(i9));
            }
        } else {
            for (int i10 = 0; i10 <= 59; i10++) {
                this.minutes.add(DateUtils.fillZero(i10));
            }
        }
        if (this.minutes.indexOf(this.selectedMinute) == -1) {
            this.selectedMinute = this.minutes.get(0);
        }
    }
}
