package cn.addapp.pickers.picker;

import android.app.Activity;
import android.text.TextUtils;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;
import cn.addapp.pickers.adapter.ArrayWheelAdapter;
import cn.addapp.pickers.common.LineConfig;
import cn.addapp.pickers.listeners.OnItemPickListener;
import cn.addapp.pickers.listeners.OnMoreItemPickListener;
import cn.addapp.pickers.listeners.OnMoreWheelListener;
import cn.addapp.pickers.util.LogUtils;
import cn.addapp.pickers.widget.WheelListView;
import cn.addapp.pickers.widget.WheelView;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

/* loaded from: classes.dex */
public class LinkagePicker extends WheelPicker {
    private float firstColumnWeight;
    protected String firstLabel;
    private OnMoreItemPickListener onMoreItemPickListener;
    private OnMoreWheelListener onMoreWheelListener;
    protected DataProvider provider;
    private float secondColumnWeight;
    protected String secondLabel;
    protected int selectedFirstIndex;
    protected String selectedFirstItem;
    protected int selectedSecondIndex;
    protected String selectedSecondItem;
    protected int selectedThirdIndex;
    protected String selectedThirdItem;
    private float thirdColumnWeight;
    protected String thirdLabel;

    public interface DataProvider {
        boolean isOnlyTwo();

        List<String> provideFirstData();

        List<String> provideSecondData(int i2);

        List<String> provideThirdData(int i2, int i3);
    }

    public LinkagePicker(Activity activity) {
        super(activity);
        this.selectedFirstItem = "";
        this.selectedSecondItem = "";
        this.selectedThirdItem = "";
        this.firstLabel = "";
        this.secondLabel = "";
        this.thirdLabel = "";
        this.selectedFirstIndex = 0;
        this.selectedSecondIndex = 0;
        this.selectedThirdIndex = 0;
        this.firstColumnWeight = 0.0f;
        this.secondColumnWeight = 0.0f;
        this.thirdColumnWeight = 0.0f;
    }

    public LinkagePicker(Activity activity, DataProvider dataProvider) {
        super(activity);
        this.selectedFirstItem = "";
        this.selectedSecondItem = "";
        this.selectedThirdItem = "";
        this.firstLabel = "";
        this.secondLabel = "";
        this.thirdLabel = "";
        this.selectedFirstIndex = 0;
        this.selectedSecondIndex = 0;
        this.selectedThirdIndex = 0;
        this.firstColumnWeight = 0.0f;
        this.secondColumnWeight = 0.0f;
        this.thirdColumnWeight = 0.0f;
        this.provider = dataProvider;
    }

    protected void setProvider(DataProvider dataProvider) {
        this.provider = dataProvider;
    }

    public void setSelectedIndex(int i2, int i3) {
        setSelectedIndex(i2, i3, 0);
    }

    public void setSelectedIndex(int i2, int i3, int i4) {
        this.selectedFirstIndex = i2;
        this.selectedSecondIndex = i3;
        this.selectedThirdIndex = i4;
    }

    public void setSelectedItem(String str, String str2) {
        setSelectedItem(str, str2, "");
    }

    public void setSelectedItem(String str, String str2, String str3) {
        DataProvider dataProvider = this.provider;
        if (dataProvider == null) {
            throw new IllegalArgumentException("please set data provider at first");
        }
        List<String> provideFirstData = dataProvider.provideFirstData();
        int i2 = 0;
        while (true) {
            if (i2 >= provideFirstData.size()) {
                break;
            }
            String str4 = provideFirstData.get(i2);
            if (str4.contains(str)) {
                this.selectedFirstIndex = i2;
                LogUtils.verbose("init select first text: " + str4 + ", index:" + this.selectedFirstIndex);
                break;
            }
            i2++;
        }
        List<String> provideSecondData = this.provider.provideSecondData(this.selectedFirstIndex);
        int i3 = 0;
        while (true) {
            if (i3 >= provideSecondData.size()) {
                break;
            }
            String str5 = provideSecondData.get(i3);
            if (str5.contains(str2)) {
                this.selectedSecondIndex = i3;
                LogUtils.verbose("init select second text: " + str5 + ", index:" + this.selectedSecondIndex);
                break;
            }
            i3++;
        }
        if (this.provider.isOnlyTwo()) {
            return;
        }
        List<String> provideThirdData = this.provider.provideThirdData(this.selectedFirstIndex, this.selectedSecondIndex);
        for (int i4 = 0; i4 < provideThirdData.size(); i4++) {
            String str6 = provideThirdData.get(i4);
            if (str6.contains(str3)) {
                this.selectedThirdIndex = i4;
                LogUtils.verbose("init select third text: " + str6 + ", index:" + this.selectedThirdIndex);
                return;
            }
        }
    }

    public void setLabel(String str, String str2) {
        setLabel(str, str2, "");
    }

    public void setLabel(String str, String str2, String str3) {
        this.firstLabel = str;
        this.secondLabel = str2;
        this.thirdLabel = str3;
    }

    public String getSelectedFirstItem() {
        String str = this.provider.provideFirstData().get(this.selectedFirstIndex);
        this.selectedFirstItem = str;
        return str;
    }

    public String getSelectedSecondItem() {
        String str = this.provider.provideSecondData(this.selectedFirstIndex).get(this.selectedSecondIndex);
        this.selectedSecondItem = str;
        return str;
    }

    public String getSelectedThirdItem() {
        String str = this.provider.provideThirdData(this.selectedFirstIndex, this.selectedSecondIndex).get(this.selectedThirdIndex);
        this.selectedThirdItem = str;
        return str;
    }

    public int getSelectedFirstIndex() {
        return this.selectedFirstIndex;
    }

    public int getSelectedSecondIndex() {
        return this.selectedSecondIndex;
    }

    public int getSelectedThirdIndex() {
        return this.selectedThirdIndex;
    }

    public void setColumnWeight(float f2, float f3, float f4) {
        this.firstColumnWeight = f2;
        this.secondColumnWeight = f3;
        this.thirdColumnWeight = f4;
    }

    public void setColumnWeight(float f2, float f3) {
        this.firstColumnWeight = f2;
        this.secondColumnWeight = f3;
        this.thirdColumnWeight = 0.0f;
    }

    public void setOnMoreWheelListener(OnMoreWheelListener onMoreWheelListener) {
        this.onMoreWheelListener = onMoreWheelListener;
    }

    public void setOnMoreItemPickListener(OnMoreItemPickListener onMoreItemPickListener) {
        this.onMoreItemPickListener = onMoreItemPickListener;
    }

    protected int[] getColumnWidths(boolean z) {
        LogUtils.verbose(this, String.format(Locale.CHINA, "column weight is: %f-%f-%f", Float.valueOf(this.firstColumnWeight), Float.valueOf(this.secondColumnWeight), Float.valueOf(this.thirdColumnWeight)));
        int[] iArr = new int[3];
        if (((int) this.firstColumnWeight) != 0 || ((int) this.secondColumnWeight) != 0 || ((int) this.thirdColumnWeight) != 0) {
            iArr[0] = (int) (this.screenWidthPixels * this.firstColumnWeight);
            iArr[1] = (int) (this.screenWidthPixels * this.secondColumnWeight);
            iArr[2] = (int) (this.screenWidthPixels * this.thirdColumnWeight);
        } else if (z) {
            int i2 = this.screenWidthPixels / 2;
            iArr[0] = i2;
            iArr[1] = i2;
            iArr[2] = 0;
        } else {
            int i3 = this.screenWidthPixels / 3;
            iArr[0] = i3;
            iArr[1] = i3;
            iArr[2] = i3;
        }
        return iArr;
    }

    @Override // cn.addapp.pickers.common.ConfirmDialog
    protected View makeCenterView() {
        DataProvider dataProvider = this.provider;
        if (dataProvider == null) {
            throw new IllegalArgumentException("please set data provider before make view");
        }
        int[] columnWidths = getColumnWidths(dataProvider.isOnlyTwo());
        LinearLayout linearLayout = new LinearLayout(this.activity);
        linearLayout.setOrientation(0);
        linearLayout.setGravity(17);
        linearLayout.setWeightSum(3.0f);
        LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(columnWidths[0], -2);
        LinearLayout.LayoutParams layoutParams2 = new LinearLayout.LayoutParams(columnWidths[1], -2);
        LinearLayout.LayoutParams layoutParams3 = new LinearLayout.LayoutParams(columnWidths[2], -2);
        if (this.weightEnable) {
            layoutParams.weight = this.firstColumnWeight;
            layoutParams2.weight = this.secondColumnWeight;
            layoutParams3.weight = this.thirdColumnWeight;
        }
        if (this.wheelModeEnable) {
            WheelView wheelView = new WheelView(this.activity);
            wheelView.setCanLoop(this.canLoop);
            wheelView.setTextSize(this.textSize);
            wheelView.setSelectedTextColor(this.textColorFocus);
            wheelView.setUnSelectedTextColor(this.textColorNormal);
            wheelView.setLineConfig(this.lineConfig);
            wheelView.setDividerType(LineConfig.DividerType.WRAP);
            wheelView.setAdapter(new ArrayWheelAdapter(this.provider.provideFirstData()));
            wheelView.setCurrentItem(this.selectedFirstIndex);
            if (TextUtils.isEmpty(this.firstLabel)) {
                wheelView.setLayoutParams(layoutParams);
            } else {
                wheelView.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                TextView textView = new TextView(this.activity);
                textView.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                textView.setTextSize(this.textSize);
                textView.setTextColor(this.textColorFocus);
                textView.setText(this.firstLabel);
                linearLayout.addView(textView);
            }
            linearLayout.addView(wheelView);
            final WheelView wheelView2 = new WheelView(this.activity);
            wheelView2.setCanLoop(this.canLoop);
            wheelView2.setTextSize(this.textSize);
            wheelView2.setSelectedTextColor(this.textColorFocus);
            wheelView2.setUnSelectedTextColor(this.textColorNormal);
            wheelView2.setLineConfig(this.lineConfig);
            wheelView2.setDividerType(LineConfig.DividerType.WRAP);
            wheelView2.setAdapter(new ArrayWheelAdapter(this.provider.provideSecondData(this.selectedFirstIndex)));
            wheelView2.setCurrentItem(this.selectedSecondIndex);
            if (TextUtils.isEmpty(this.secondLabel)) {
                wheelView2.setLayoutParams(layoutParams2);
            } else {
                wheelView2.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                TextView textView2 = new TextView(this.activity);
                textView2.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                textView2.setTextSize(this.textSize);
                textView2.setTextColor(this.textColorFocus);
                textView2.setText(this.secondLabel);
                linearLayout.addView(textView2);
            }
            linearLayout.addView(wheelView2);
            final WheelView wheelView3 = new WheelView(this.activity);
            if (!this.provider.isOnlyTwo()) {
                wheelView3.setCanLoop(this.canLoop);
                wheelView3.setTextSize(this.textSize);
                wheelView3.setSelectedTextColor(this.textColorFocus);
                wheelView3.setUnSelectedTextColor(this.textColorNormal);
                wheelView3.setLineConfig(this.lineConfig);
                wheelView3.setDividerType(LineConfig.DividerType.WRAP);
                wheelView3.setAdapter(new ArrayWheelAdapter(this.provider.provideThirdData(this.selectedFirstIndex, this.selectedSecondIndex)));
                wheelView3.setCurrentItem(this.selectedThirdIndex);
                if (TextUtils.isEmpty(this.thirdLabel)) {
                    wheelView3.setLayoutParams(layoutParams3);
                } else {
                    wheelView3.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                    TextView textView3 = new TextView(this.activity);
                    textView3.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                    textView3.setTextSize(this.textSize);
                    textView3.setTextColor(this.textColorFocus);
                    textView3.setText(this.thirdLabel);
                    linearLayout.addView(textView3);
                }
                linearLayout.addView(wheelView3);
            }
            wheelView.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.LinkagePicker.1
                @Override // cn.addapp.pickers.listeners.OnItemPickListener
                public void onItemPicked(int i2, String str) {
                    LinkagePicker.this.selectedFirstIndex = i2;
                    LinkagePicker.this.selectedFirstItem = str;
                    LinkagePicker.this.selectedSecondIndex = 0;
                    LinkagePicker.this.selectedThirdIndex = 0;
                    if (LinkagePicker.this.onMoreWheelListener != null) {
                        LinkagePicker.this.onMoreWheelListener.onFirstWheeled(LinkagePicker.this.selectedFirstIndex, LinkagePicker.this.selectedFirstItem);
                    }
                    LogUtils.error(this, "change second data after first wheeled");
                    wheelView2.setAdapter(new ArrayWheelAdapter(LinkagePicker.this.provider.provideSecondData(LinkagePicker.this.selectedFirstIndex)));
                    wheelView2.setCurrentItem(LinkagePicker.this.selectedSecondIndex);
                    if (LinkagePicker.this.provider.isOnlyTwo()) {
                        return;
                    }
                    wheelView3.setAdapter(new ArrayWheelAdapter(LinkagePicker.this.provider.provideThirdData(LinkagePicker.this.selectedFirstIndex, LinkagePicker.this.selectedSecondIndex)));
                    wheelView3.setCurrentItem(LinkagePicker.this.selectedThirdIndex);
                }
            });
            wheelView2.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.LinkagePicker.2
                @Override // cn.addapp.pickers.listeners.OnItemPickListener
                public void onItemPicked(int i2, String str) {
                    LinkagePicker.this.selectedSecondItem = str;
                    LinkagePicker.this.selectedSecondIndex = i2;
                    LinkagePicker.this.selectedThirdIndex = 0;
                    if (LinkagePicker.this.onMoreWheelListener != null) {
                        LinkagePicker.this.onMoreWheelListener.onSecondWheeled(LinkagePicker.this.selectedSecondIndex, LinkagePicker.this.selectedSecondItem);
                    }
                    if (LinkagePicker.this.provider.isOnlyTwo()) {
                        return;
                    }
                    LogUtils.error(this, "change third data after second wheeled");
                    wheelView3.setAdapter(new ArrayWheelAdapter(LinkagePicker.this.provider.provideThirdData(LinkagePicker.this.selectedFirstIndex, LinkagePicker.this.selectedSecondIndex)));
                    wheelView3.setCurrentItem(LinkagePicker.this.selectedThirdIndex);
                }
            });
            if (this.provider.isOnlyTwo()) {
                return linearLayout;
            }
            wheelView3.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.LinkagePicker.3
                @Override // cn.addapp.pickers.listeners.OnItemPickListener
                public void onItemPicked(int i2, String str) {
                    LinkagePicker.this.selectedThirdItem = str;
                    LinkagePicker.this.selectedThirdIndex = i2;
                    if (LinkagePicker.this.onMoreWheelListener != null) {
                        LinkagePicker.this.onMoreWheelListener.onThirdWheeled(LinkagePicker.this.selectedThirdIndex, LinkagePicker.this.selectedThirdItem);
                    }
                }
            });
            return linearLayout;
        }
        WheelListView wheelListView = new WheelListView(this.activity);
        wheelListView.setTextSize(this.textSize);
        wheelListView.setSelectedTextColor(this.textColorFocus);
        wheelListView.setUnSelectedTextColor(this.textColorNormal);
        wheelListView.setLineConfig(this.lineConfig);
        wheelListView.setOffset(this.offset);
        wheelListView.setCanLoop(this.canLoop);
        linearLayout.addView(wheelListView);
        if (TextUtils.isEmpty(this.firstLabel)) {
            wheelListView.setLayoutParams(layoutParams);
        } else {
            wheelListView.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
            TextView textView4 = new TextView(this.activity);
            textView4.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
            textView4.setTextSize(this.textSize);
            textView4.setTextColor(this.textColorFocus);
            textView4.setText(this.firstLabel);
            linearLayout.addView(textView4);
        }
        final WheelListView wheelListView2 = new WheelListView(this.activity);
        wheelListView2.setTextSize(this.textSize);
        wheelListView2.setSelectedTextColor(this.textColorFocus);
        wheelListView2.setUnSelectedTextColor(this.textColorNormal);
        wheelListView2.setLineConfig(this.lineConfig);
        wheelListView2.setOffset(this.offset);
        wheelListView2.setCanLoop(this.canLoop);
        linearLayout.addView(wheelListView2);
        if (TextUtils.isEmpty(this.secondLabel)) {
            wheelListView2.setLayoutParams(layoutParams2);
        } else {
            wheelListView2.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
            TextView textView5 = new TextView(this.activity);
            textView5.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
            textView5.setTextSize(this.textSize);
            textView5.setTextColor(this.textColorFocus);
            textView5.setText(this.secondLabel);
            linearLayout.addView(textView5);
        }
        final WheelListView wheelListView3 = new WheelListView(this.activity);
        if (!this.provider.isOnlyTwo()) {
            wheelListView3.setTextSize(this.textSize);
            wheelListView3.setSelectedTextColor(this.textColorFocus);
            wheelListView3.setUnSelectedTextColor(this.textColorNormal);
            wheelListView3.setLineConfig(this.lineConfig);
            wheelListView3.setOffset(this.offset);
            wheelListView3.setCanLoop(this.canLoop);
            linearLayout.addView(wheelListView3);
            if (TextUtils.isEmpty(this.thirdLabel)) {
                wheelListView3.setLayoutParams(layoutParams3);
            } else {
                wheelListView3.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                TextView textView6 = new TextView(this.activity);
                textView6.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                textView6.setTextSize(this.textSize);
                textView6.setTextColor(this.textColorFocus);
                textView6.setText(this.thirdLabel);
                linearLayout.addView(textView6);
            }
        }
        wheelListView.setItems(this.provider.provideFirstData(), this.selectedFirstIndex);
        wheelListView.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.LinkagePicker.4
            @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
            public void onItemSelected(boolean z, int i2, String str) {
                LinkagePicker.this.selectedFirstItem = str;
                LinkagePicker.this.selectedFirstIndex = i2;
                LinkagePicker.this.selectedSecondIndex = 0;
                LinkagePicker.this.selectedThirdIndex = 0;
                if (LinkagePicker.this.onMoreWheelListener != null) {
                    LinkagePicker.this.onMoreWheelListener.onFirstWheeled(LinkagePicker.this.selectedFirstIndex, LinkagePicker.this.selectedFirstItem);
                }
                if (z) {
                    LogUtils.verbose(this, "change second data after first wheeled");
                    wheelListView2.setItems(LinkagePicker.this.provider.provideSecondData(LinkagePicker.this.selectedFirstIndex), LinkagePicker.this.selectedSecondIndex);
                    if (LinkagePicker.this.provider.isOnlyTwo()) {
                        return;
                    }
                    wheelListView3.setItems(LinkagePicker.this.provider.provideThirdData(LinkagePicker.this.selectedFirstIndex, LinkagePicker.this.selectedSecondIndex), LinkagePicker.this.selectedThirdIndex);
                }
            }
        });
        wheelListView2.setItems(this.provider.provideSecondData(this.selectedFirstIndex), this.selectedSecondIndex);
        wheelListView2.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.LinkagePicker.5
            @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
            public void onItemSelected(boolean z, int i2, String str) {
                LinkagePicker.this.selectedSecondItem = str;
                LinkagePicker.this.selectedSecondIndex = i2;
                LinkagePicker.this.selectedThirdIndex = 0;
                if (LinkagePicker.this.onMoreWheelListener != null) {
                    LinkagePicker.this.onMoreWheelListener.onSecondWheeled(LinkagePicker.this.selectedSecondIndex, LinkagePicker.this.selectedSecondItem);
                }
                if (z && !LinkagePicker.this.provider.isOnlyTwo()) {
                    LogUtils.verbose(this, "change third data after second wheeled");
                    wheelListView3.setItems(LinkagePicker.this.provider.provideThirdData(LinkagePicker.this.selectedFirstIndex, LinkagePicker.this.selectedSecondIndex), LinkagePicker.this.selectedThirdIndex);
                }
            }
        });
        if (this.provider.isOnlyTwo()) {
            return linearLayout;
        }
        wheelListView3.setItems(this.provider.provideThirdData(this.selectedFirstIndex, this.selectedSecondIndex), this.selectedThirdIndex);
        wheelListView3.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.LinkagePicker.6
            @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
            public void onItemSelected(boolean z, int i2, String str) {
                LinkagePicker.this.selectedThirdItem = str;
                LinkagePicker.this.selectedThirdIndex = i2;
                if (LinkagePicker.this.onMoreWheelListener != null) {
                    LinkagePicker.this.onMoreWheelListener.onThirdWheeled(LinkagePicker.this.selectedThirdIndex, LinkagePicker.this.selectedThirdItem);
                }
            }
        });
        return linearLayout;
    }

    @Override // cn.addapp.pickers.common.ConfirmDialog
    public void onSubmit() {
        if (this.onMoreItemPickListener == null) {
            return;
        }
        this.selectedFirstItem = this.provider.provideFirstData().get(this.selectedFirstIndex);
        this.selectedSecondItem = this.provider.provideSecondData(this.selectedFirstIndex).get(this.selectedSecondIndex);
        if (this.provider.isOnlyTwo()) {
            this.onMoreItemPickListener.onItemPicked(this.selectedFirstItem, this.selectedSecondItem, null);
            return;
        }
        String str = this.provider.provideThirdData(this.selectedFirstIndex, this.selectedSecondIndex).get(this.selectedThirdIndex);
        this.selectedThirdItem = str;
        this.onMoreItemPickListener.onItemPicked(this.selectedFirstItem, this.selectedSecondItem, str);
    }

    public static class DefaultDataProvider implements DataProvider {
        private List<String> firstList;
        private boolean onlyTwo;
        private List<List<String>> secondList;
        private List<List<List<String>>> thirdList;

        public DefaultDataProvider(List<String> list, List<List<String>> list2, List<List<List<String>>> list3) {
            this.firstList = new ArrayList();
            this.secondList = new ArrayList();
            this.thirdList = new ArrayList();
            this.onlyTwo = false;
            this.firstList = list;
            this.secondList = list2;
            if (list3 == null || list3.size() == 0) {
                this.onlyTwo = true;
            } else {
                this.thirdList = list3;
            }
        }

        @Override // cn.addapp.pickers.picker.LinkagePicker.DataProvider
        public boolean isOnlyTwo() {
            return this.onlyTwo;
        }

        @Override // cn.addapp.pickers.picker.LinkagePicker.DataProvider
        public List<String> provideFirstData() {
            return this.firstList;
        }

        @Override // cn.addapp.pickers.picker.LinkagePicker.DataProvider
        public List<String> provideSecondData(int i2) {
            return this.secondList.get(i2);
        }

        @Override // cn.addapp.pickers.picker.LinkagePicker.DataProvider
        public List<String> provideThirdData(int i2, int i3) {
            if (this.onlyTwo) {
                return new ArrayList();
            }
            return this.thirdList.get(i2).get(i3);
        }
    }
}
