package cn.addapp.pickers.picker;

import android.app.Activity;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.TextView;
import cn.addapp.pickers.adapter.ArrayWheelAdapter;
import cn.addapp.pickers.common.LineConfig;
import cn.addapp.pickers.listeners.OnItemPickListener;
import cn.addapp.pickers.listeners.OnSingleWheelListener;
import cn.addapp.pickers.util.ConvertUtils;
import cn.addapp.pickers.widget.WheelListView;
import cn.addapp.pickers.widget.WheelView;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

/* loaded from: classes.dex */
public class SinglePicker<T> extends WheelPicker {
    private static final int ITEM_WIDTH_UNKNOWN = -99;
    private List<String> itemStrings;
    private int itemWidth;
    private List<T> items;
    private String label;
    private OnItemPickListener<T> onItemPickListener;
    private OnSingleWheelListener onSingleWheelListener;
    private String selectedItem;
    private int selectedItemIndex;
    private float weightWidth;
    private WheelListView wheelListView;
    private WheelView wheelView;

    public SinglePicker(Activity activity, T[] tArr) {
        this(activity, Arrays.asList(tArr));
    }

    public SinglePicker(Activity activity, List<T> list) {
        super(activity);
        this.items = new ArrayList();
        this.itemStrings = new ArrayList();
        this.weightWidth = 0.0f;
        this.selectedItemIndex = 0;
        this.selectedItem = "";
        this.label = "";
        this.itemWidth = -99;
        setItems(list);
    }

    public void addItem(T t) {
        this.items.add(t);
        this.itemStrings.add(formatToString(t));
    }

    public void removeItem(T t) {
        this.items.remove(t);
        this.itemStrings.remove(formatToString(t));
    }

    public void setItems(T[] tArr) {
        setItems(Arrays.asList(tArr));
    }

    public void setItems(List<T> list) {
        if (list == null || list.size() == 0) {
            return;
        }
        this.items = list;
        Iterator<T> it2 = list.iterator();
        while (it2.hasNext()) {
            this.itemStrings.add(formatToString(it2.next()));
        }
        if (this.wheelModeEnable) {
            WheelView wheelView = this.wheelView;
            if (wheelView != null) {
                wheelView.setAdapter(new ArrayWheelAdapter(this.itemStrings));
                this.wheelView.setCurrentItem(this.selectedItemIndex);
                return;
            }
            return;
        }
        WheelListView wheelListView = this.wheelListView;
        if (wheelListView != null) {
            wheelListView.setItems(this.itemStrings, this.selectedItemIndex);
        }
    }

    public void setLabel(String str) {
        this.label = str;
    }

    public void setSelectedIndex(int i2) {
        if (i2 < 0 || i2 >= this.items.size()) {
            return;
        }
        this.selectedItemIndex = i2;
    }

    public void setSelectedItem(T t) {
        setSelectedIndex(this.itemStrings.indexOf(formatToString(t)));
    }

    public void setWeightWidth(float f2) {
        if (f2 < 0.0f) {
            f2 = 0.0f;
        }
        if (!TextUtils.isEmpty(this.label) && f2 >= 1.0f) {
            f2 = 0.5f;
        }
        this.weightWidth = f2;
    }

    public void setItemWidth(int i2) {
        if (this.wheelModeEnable) {
            if (this.wheelView != null) {
                this.wheelView.setLayoutParams(new LinearLayout.LayoutParams(ConvertUtils.toPx(this.activity, i2), this.wheelListView.getLayoutParams().height));
                return;
            } else {
                this.itemWidth = i2;
                return;
            }
        }
        if (this.wheelListView != null) {
            this.wheelListView.setLayoutParams(new LinearLayout.LayoutParams(ConvertUtils.toPx(this.activity, i2), this.wheelListView.getLayoutParams().height));
        } else {
            this.itemWidth = i2;
        }
    }

    public void setOnSingleWheelListener(OnSingleWheelListener onSingleWheelListener) {
        this.onSingleWheelListener = onSingleWheelListener;
    }

    public void setOnItemPickListener(OnItemPickListener<T> onItemPickListener) {
        this.onItemPickListener = onItemPickListener;
    }

    @Override // cn.addapp.pickers.common.ConfirmDialog
    protected View makeCenterView() {
        if (this.items.size() == 0) {
            throw new IllegalArgumentException("please initial items at first, can't be empty");
        }
        LinearLayout linearLayout = new LinearLayout(this.activity);
        linearLayout.setLayoutParams(new ViewGroup.LayoutParams(-1, -2));
        linearLayout.setOrientation(0);
        linearLayout.setGravity(17);
        LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(-2, -2);
        if (this.weightEnable) {
            linearLayout.setWeightSum(1.0f);
            layoutParams.weight = this.weightWidth;
        }
        if (this.wheelModeEnable) {
            WheelView wheelView = new WheelView(this.activity);
            this.wheelView = wheelView;
            wheelView.setAdapter(new ArrayWheelAdapter(this.itemStrings));
            this.wheelView.setCurrentItem(this.selectedItemIndex);
            this.wheelView.setCanLoop(this.canLoop);
            this.wheelView.setLineConfig(this.lineConfig);
            this.wheelView.setDividerType(LineConfig.DividerType.FILL);
            this.wheelView.setOnItemPickListener(new OnItemPickListener<String>() { // from class: cn.addapp.pickers.picker.SinglePicker.1
                @Override // cn.addapp.pickers.listeners.OnItemPickListener
                public void onItemPicked(int i2, String str) {
                    SinglePicker.this.selectedItem = str;
                    SinglePicker.this.selectedItemIndex = i2;
                    if (SinglePicker.this.onSingleWheelListener != null) {
                        SinglePicker.this.onSingleWheelListener.onWheeled(SinglePicker.this.selectedItemIndex, SinglePicker.this.selectedItem);
                    }
                }
            });
            if (TextUtils.isEmpty(this.label)) {
                this.wheelView.setLayoutParams(layoutParams);
                linearLayout.addView(this.wheelView);
            } else {
                this.wheelView.setLayoutParams(layoutParams);
                linearLayout.addView(this.wheelView);
                TextView textView = new TextView(this.activity);
                textView.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                textView.setTextColor(this.textColorFocus);
                textView.setTextSize(this.textSize);
                textView.setText(this.label);
                linearLayout.addView(textView);
            }
            if (this.itemWidth != -99) {
                this.wheelView.setLayoutParams(new LinearLayout.LayoutParams(ConvertUtils.toPx(this.activity, this.itemWidth), this.wheelView.getLayoutParams().height));
            }
        } else {
            WheelListView wheelListView = new WheelListView(this.activity);
            this.wheelListView = wheelListView;
            wheelListView.setTextSize(this.textSize);
            this.wheelListView.setSelectedTextColor(this.textColorFocus);
            this.wheelListView.setUnSelectedTextColor(this.textColorNormal);
            this.wheelListView.setLineConfig(this.lineConfig);
            this.wheelListView.setOffset(this.offset);
            this.wheelListView.setCanLoop(this.canLoop);
            this.wheelListView.setItems(this.itemStrings, this.selectedItemIndex);
            this.wheelListView.setOnWheelChangeListener(new WheelListView.OnWheelChangeListener() { // from class: cn.addapp.pickers.picker.SinglePicker.2
                @Override // cn.addapp.pickers.widget.WheelListView.OnWheelChangeListener
                public void onItemSelected(boolean z, int i2, String str) {
                    SinglePicker.this.selectedItemIndex = i2;
                    SinglePicker.this.selectedItem = str;
                    if (SinglePicker.this.onSingleWheelListener != null) {
                        SinglePicker.this.onSingleWheelListener.onWheeled(SinglePicker.this.selectedItemIndex, str);
                    }
                }
            });
            if (TextUtils.isEmpty(this.label)) {
                this.wheelListView.setLayoutParams(layoutParams);
                linearLayout.addView(this.wheelListView);
            } else {
                this.wheelListView.setLayoutParams(layoutParams);
                linearLayout.addView(this.wheelListView);
                TextView textView2 = new TextView(this.activity);
                textView2.setLayoutParams(new LinearLayout.LayoutParams(-2, -2));
                textView2.setTextColor(this.textColorFocus);
                textView2.setTextSize(this.textSize);
                textView2.setText(this.label);
                linearLayout.addView(textView2);
            }
            if (this.itemWidth != -99) {
                this.wheelListView.setLayoutParams(new LinearLayout.LayoutParams(ConvertUtils.toPx(this.activity, this.itemWidth), this.wheelListView.getLayoutParams().height));
            }
        }
        return linearLayout;
    }

    private String formatToString(T t) {
        if ((t instanceof Float) || (t instanceof Double)) {
            return new DecimalFormat("0.00").format(t);
        }
        return t.toString();
    }

    @Override // cn.addapp.pickers.common.ConfirmDialog
    public void onSubmit() {
        OnItemPickListener<T> onItemPickListener = this.onItemPickListener;
        if (onItemPickListener != null) {
            onItemPickListener.onItemPicked(getSelectedIndex(), getSelectedItem());
        }
    }

    private T getSelectedItem() {
        return this.items.get(this.selectedItemIndex);
    }

    public int getSelectedIndex() {
        return this.selectedItemIndex;
    }
}
