package cn.addapp.pickers.util;

import com.tencent.connect.common.Constants;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Locale;

/* loaded from: classes.dex */
public class DateUtils extends android.text.format.DateUtils {
    public static final int Day = 3;
    public static final int Hour = 2;
    public static final int Minute = 1;
    public static final int Second = 0;

    @Retention(RetentionPolicy.SOURCE)
    public @interface DifferenceMode {
    }

    public static long calculateDifferentSecond(Date date, Date date2) {
        return calculateDifference(date, date2, 0);
    }

    public static long calculateDifferentMinute(Date date, Date date2) {
        return calculateDifference(date, date2, 1);
    }

    public static long calculateDifferentHour(Date date, Date date2) {
        return calculateDifference(date, date2, 2);
    }

    public static long calculateDifferentDay(Date date, Date date2) {
        return calculateDifference(date, date2, 3);
    }

    public static long calculateDifferentSecond(long j2, long j3) {
        return calculateDifference(j2, j3, 0);
    }

    public static long calculateDifferentMinute(long j2, long j3) {
        return calculateDifference(j2, j3, 1);
    }

    public static long calculateDifferentHour(long j2, long j3) {
        return calculateDifference(j2, j3, 2);
    }

    public static long calculateDifferentDay(long j2, long j3) {
        return calculateDifference(j2, j3, 3);
    }

    public static long calculateDifference(long j2, long j3, int i2) {
        return calculateDifference(new Date(j2), new Date(j3), i2);
    }

    public static long calculateDifference(Date date, Date date2, int i2) {
        long[] calculateDifference = calculateDifference(date, date2);
        if (i2 == 1) {
            return calculateDifference[2];
        }
        if (i2 == 2) {
            return calculateDifference[1];
        }
        if (i2 == 3) {
            return calculateDifference[0];
        }
        return calculateDifference[3];
    }

    private static long[] calculateDifference(Date date, Date date2) {
        return calculateDifference(date2.getTime() - date.getTime());
    }

    private static long[] calculateDifference(long j2) {
        long j3 = j2 / org.apache.commons.lang3.time.DateUtils.MILLIS_PER_DAY;
        long j4 = j2 % org.apache.commons.lang3.time.DateUtils.MILLIS_PER_DAY;
        long j5 = j4 / org.apache.commons.lang3.time.DateUtils.MILLIS_PER_HOUR;
        long j6 = j4 % org.apache.commons.lang3.time.DateUtils.MILLIS_PER_HOUR;
        long j7 = j6 / org.apache.commons.lang3.time.DateUtils.MILLIS_PER_MINUTE;
        long j8 = j6 % org.apache.commons.lang3.time.DateUtils.MILLIS_PER_MINUTE;
        long j9 = j8 / 1000;
        LogUtils.verbose(String.format(Locale.CHINA, "different: %d ms, %d days, %d hours, %d minutes, %d seconds", Long.valueOf(j8), Long.valueOf(j3), Long.valueOf(j5), Long.valueOf(j7), Long.valueOf(j9)));
        return new long[]{j3, j5, j7, j9};
    }

    public static int calculateDaysInMonth(int i2) {
        return calculateDaysInMonth(0, i2);
    }

    public static int calculateDaysInMonth(int i2, int i3) {
        String[] strArr = {"1", "3", "5", "7", Constants.VIA_SHARE_TYPE_PUBLISHVIDEO, Constants.VIA_REPORT_TYPE_SHARE_TO_QQ, Constants.VIA_REPORT_TYPE_SET_AVATAR};
        String[] strArr2 = {Constants.VIA_TO_TYPE_QZONE, Constants.VIA_SHARE_TYPE_INFO, Constants.VIA_SHARE_TYPE_MINI_PROGRAM, Constants.VIA_REPORT_TYPE_SHARE_TO_QZONE};
        List asList = Arrays.asList(strArr);
        List asList2 = Arrays.asList(strArr2);
        if (asList.contains(String.valueOf(i3))) {
            return 31;
        }
        if (asList2.contains(String.valueOf(i3))) {
            return 30;
        }
        if (i2 <= 0) {
            return 29;
        }
        return ((i2 % 4 != 0 || i2 % 100 == 0) && i2 % 400 != 0) ? 28 : 29;
    }

    public static String fillZero(int i2) {
        StringBuilder sb = i2 < 10 ? new StringBuilder("0") : new StringBuilder("");
        sb.append(i2);
        return sb.toString();
    }

    public static int trimZero(String str) {
        try {
            if (str.startsWith("0")) {
                str = str.substring(1);
            }
            return Integer.parseInt(str);
        } catch (NumberFormatException e2) {
            LogUtils.warn(e2);
            return 0;
        }
    }

    public static boolean isSameDay(Date date) {
        if (date == null) {
            throw new IllegalArgumentException("date is null");
        }
        Calendar calendar = Calendar.getInstance();
        Calendar calendar2 = Calendar.getInstance();
        calendar2.setTime(date);
        return calendar.get(0) == calendar2.get(0) && calendar.get(1) == calendar2.get(1) && calendar.get(6) == calendar2.get(6);
    }

    public static Date parseDate(String str, String str2) {
        try {
            return new Date(new SimpleDateFormat(str2, Locale.PRC).parse(str).getTime());
        } catch (ParseException e2) {
            LogUtils.warn(e2);
            return null;
        }
    }

    public static Date parseDate(String str) {
        return parseDate(str, "yyyy-MM-dd HH:mm:ss");
    }

    public static String formatDate(Date date, String str) {
        return new SimpleDateFormat(str, Locale.PRC).format(date);
    }

    public static String formatDate(String str) {
        return formatDate(Calendar.getInstance(Locale.CHINA).getTime(), str);
    }
}
