package cn.addapp.pickers.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.Typeface;
import android.os.Handler;
import android.os.Message;
import android.util.AttributeSet;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import cn.addapp.pickers.util.ConvertUtils;
import cn.addapp.pickers.wheelpicker.R;
import java.util.List;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.TimeUnit;

@Deprecated
/* loaded from: classes.dex */
public class LoopView extends View {
    public static final int MSG_INVALIDATE = 1000;
    public static final int MSG_SCROLL_LOOP = 2000;
    public static final int MSG_SELECTED_ITEM = 3000;
    private static final String TAG = "LoopView";
    private float lineSpacingMultiplier;
    private int mBottomLineY;
    private boolean mCanLoop;
    private int mCenterLineColor;
    private Paint mCenterLinePaint;
    private int mCenterTextColor;
    private Paint mCenterTextPaint;
    private Paint mCenterTopBottomTextPaint;
    private int mCircularDiameter;
    private int mCircularRadius;
    private Context mContext;
    private int mCurrentIndex;
    private List<String> mDataList;
    private int mDrawItemsCount;
    private ScheduledExecutorService mExecutor;
    private GestureDetector mGestureDetector;
    public Handler mHandler;
    private int mInitPosition;
    private float mItemHeight;
    private LoopScrollListener mLoopListener;
    private int mMaxTextHeight;
    private int mMaxTextWidth;
    private GestureDetector.SimpleOnGestureListener mOnGestureListener;
    private int mPaddingTopBottom;
    private ScheduledFuture<?> mScheduledFuture;
    private int mSelectedPosition;
    private int mTextPaddingLeftRight;
    private int mTextSize;
    private int mTopBottomTextColor;
    private Paint mTopBottomTextPaint;
    private int mTopLineY;
    private int mTotalScrollY;
    private int mWidgetHeight;
    private int mWidgetWidth;

    public interface LoopScrollListener {
        void onItemSelected(int i2, String str);
    }

    public LoopView(Context context) {
        this(context, null);
    }

    public LoopView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public LoopView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mExecutor = Executors.newSingleThreadScheduledExecutor();
        this.mTextPaddingLeftRight = 100;
        this.mHandler = new Handler(new Handler.Callback() { // from class: cn.addapp.pickers.widget.LoopView.1
            @Override // android.os.Handler.Callback
            public boolean handleMessage(Message message) {
                if (message.what == 1000) {
                    LoopView.this.invalidate();
                }
                if (message.what == 2000) {
                    LoopView.this.startSmoothScrollTo();
                    return false;
                }
                if (message.what != 3000) {
                    return false;
                }
                LoopView.this.itemSelected();
                return false;
            }
        });
        initView(context, attributeSet);
    }

    public LoopView(Context context, AttributeSet attributeSet, int i2, int i3) {
        super(context, attributeSet, i2, i3);
        this.mExecutor = Executors.newSingleThreadScheduledExecutor();
        this.mTextPaddingLeftRight = 100;
        this.mHandler = new Handler(new Handler.Callback() { // from class: cn.addapp.pickers.widget.LoopView.1
            @Override // android.os.Handler.Callback
            public boolean handleMessage(Message message) {
                if (message.what == 1000) {
                    LoopView.this.invalidate();
                }
                if (message.what == 2000) {
                    LoopView.this.startSmoothScrollTo();
                    return false;
                }
                if (message.what != 3000) {
                    return false;
                }
                LoopView.this.itemSelected();
                return false;
            }
        });
        initView(context, attributeSet);
    }

    private void initView(Context context, AttributeSet attributeSet) {
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.LoopView);
        if (obtainStyledAttributes != null) {
            this.mTopBottomTextColor = obtainStyledAttributes.getColor(R.styleable.LoopView_topBottomTextColor, -5263441);
            this.mCenterTextColor = obtainStyledAttributes.getColor(R.styleable.LoopView_centerTextColor, -13553359);
            this.mCenterLineColor = obtainStyledAttributes.getColor(R.styleable.LoopView_lineColor, -3815995);
            this.mCanLoop = obtainStyledAttributes.getBoolean(R.styleable.LoopView_canLoop, true);
            this.mInitPosition = obtainStyledAttributes.getInt(R.styleable.LoopView_initPosition, -1);
            this.mTextSize = obtainStyledAttributes.getDimensionPixelSize(R.styleable.LoopView_textSize, sp2px(context, 16.0f));
            int i2 = obtainStyledAttributes.getInt(R.styleable.LoopView_drawItemCount, 7);
            this.mDrawItemsCount = i2;
            if (i2 % 2 == 0) {
                if (i2 >= 10) {
                    this.mDrawItemsCount = i2 - 1;
                } else {
                    this.mDrawItemsCount = i2 + 1;
                }
            }
            if (this.mDrawItemsCount < 3) {
                this.mDrawItemsCount = 3;
            }
            obtainStyledAttributes.recycle();
        }
        this.lineSpacingMultiplier = 2.0f;
        this.mContext = context;
        this.mTextPaddingLeftRight = ConvertUtils.toDp(context, this.mTextPaddingLeftRight);
        this.mOnGestureListener = new LoopViewGestureListener();
        this.mCenterTopBottomTextPaint = new Paint();
        this.mTopBottomTextPaint = new Paint();
        this.mCenterTextPaint = new Paint();
        this.mCenterLinePaint = new Paint();
        setLayerType(1, null);
        GestureDetector gestureDetector = new GestureDetector(context, this.mOnGestureListener);
        this.mGestureDetector = gestureDetector;
        gestureDetector.setIsLongpressEnabled(false);
    }

    private void initData() {
        if (this.mDataList == null) {
            throw new IllegalArgumentException("data list must not be null!");
        }
        this.mTopBottomTextPaint.setColor(this.mTopBottomTextColor);
        this.mTopBottomTextPaint.setAntiAlias(true);
        this.mTopBottomTextPaint.setAlpha(150);
        this.mTopBottomTextPaint.setTypeface(Typeface.MONOSPACE);
        this.mTopBottomTextPaint.setTextSize(this.mTextSize);
        this.mCenterTopBottomTextPaint.setColor(this.mTopBottomTextColor);
        this.mCenterTopBottomTextPaint.setAntiAlias(true);
        this.mCenterTopBottomTextPaint.setTypeface(Typeface.MONOSPACE);
        this.mCenterTopBottomTextPaint.setTextSize(this.mTextSize);
        this.mCenterTextPaint.setColor(this.mCenterTextColor);
        this.mCenterTextPaint.setAntiAlias(true);
        this.mCenterTextPaint.setTypeface(Typeface.MONOSPACE);
        this.mCenterTextPaint.setTextSize(this.mTextSize);
        this.mCenterLinePaint.setColor(this.mCenterLineColor);
        this.mCenterLinePaint.setAntiAlias(true);
        this.mCenterLinePaint.setTypeface(Typeface.MONOSPACE);
        this.mCenterLinePaint.setTextSize(this.mTextSize);
        measureTextWidthHeight();
        int i2 = (int) (this.mMaxTextHeight * this.lineSpacingMultiplier * (this.mDrawItemsCount - 1));
        this.mCircularDiameter = (int) ((i2 * 2) / 3.141592653589793d);
        this.mCircularRadius = (int) (i2 / 3.141592653589793d);
        if (this.mInitPosition == -1) {
            if (this.mCanLoop) {
                this.mInitPosition = (this.mDataList.size() + 1) / 2;
            } else {
                this.mInitPosition = 0;
            }
        }
        this.mCurrentIndex = this.mInitPosition;
        invalidate();
    }

    private void measureTextWidthHeight() {
        Rect rect = new Rect();
        for (int i2 = 0; i2 < this.mDataList.size(); i2++) {
            String trim = this.mDataList.get(i2).trim();
            this.mCenterTextPaint.getTextBounds(trim, 0, trim.length(), rect);
            int width = rect.width();
            if (width > this.mMaxTextWidth) {
                this.mMaxTextWidth = width;
            }
            int height = rect.height() + 10;
            if (height > this.mMaxTextHeight) {
                this.mMaxTextHeight = height;
            }
        }
    }

    private Rect getRect(Paint paint, String str) {
        Rect rect = new Rect();
        paint.getTextBounds(str, 0, str.length(), rect);
        return rect;
    }

    private int measureTextWidth(String str) {
        int width = getRect(this.mCenterTextPaint, str).width();
        if (width > this.mMaxTextWidth) {
            this.mMaxTextWidth = width;
        }
        return width;
    }

    private int getPaddingLeftRight(String str) {
        return ((this.mWidgetWidth - measureTextWidth(str)) / 2) - 4;
    }

    @Override // android.view.View
    protected void onMeasure(int i2, int i3) {
        int size = View.MeasureSpec.getSize(i2);
        int size2 = View.MeasureSpec.getSize(i3);
        int mode = View.MeasureSpec.getMode(i2);
        int mode2 = View.MeasureSpec.getMode(i3);
        float f2 = this.lineSpacingMultiplier * this.mMaxTextHeight;
        this.mItemHeight = f2;
        int i4 = (int) f2;
        this.mPaddingTopBottom = i4;
        int i5 = this.mCircularDiameter;
        this.mTopLineY = ((int) ((i5 - f2) / 2.0f)) + i4;
        this.mBottomLineY = ((int) ((i5 + f2) / 2.0f)) + i4;
        int i6 = this.mMaxTextWidth + this.mTextPaddingLeftRight;
        this.mWidgetWidth = i6;
        this.mWidgetHeight = i5 + (i4 * 2);
        this.mWidgetWidth = i6 + getPaddingLeft() + getPaddingRight();
        this.mWidgetHeight += getPaddingTop() + getPaddingBottom();
        this.mWidgetWidth = measureSize(mode, size, this.mWidgetWidth);
        this.mWidgetHeight = measureSize(mode2, size2, this.mWidgetHeight);
        setMeasuredDimension(this.mWidgetWidth, this.mCircularDiameter + (this.mPaddingTopBottom * 2));
    }

    private int measureSize(int i2, int i3, int i4) {
        return i2 == 1073741824 ? i3 : i2 == Integer.MIN_VALUE ? Math.min(i4, i3) : i4;
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        String[] strArr;
        if (this.mDataList == null) {
            super.onDraw(canvas);
            return;
        }
        super.onDraw(canvas);
        int size = this.mInitPosition + (((int) (this.mTotalScrollY / this.mItemHeight)) % this.mDataList.size());
        this.mCurrentIndex = size;
        if (!this.mCanLoop) {
            if (size < 0) {
                this.mCurrentIndex = 0;
            }
            if (this.mCurrentIndex > this.mDataList.size() - 1) {
                this.mCurrentIndex = this.mDataList.size() - 1;
            }
        } else {
            if (size < 0) {
                this.mCurrentIndex = this.mDataList.size() + this.mCurrentIndex;
            }
            if (this.mCurrentIndex > this.mDataList.size() - 1) {
                this.mCurrentIndex -= this.mDataList.size();
            }
        }
        String[] strArr2 = new String[this.mDrawItemsCount];
        int i2 = 0;
        while (true) {
            int i3 = this.mDrawItemsCount;
            if (i2 >= i3) {
                break;
            }
            int i4 = this.mCurrentIndex - ((i3 / 2) - i2);
            if (this.mCanLoop) {
                if (i4 < 0) {
                    i4 += this.mDataList.size();
                }
                if (i4 > this.mDataList.size() - 1) {
                    i4 -= this.mDataList.size();
                }
                if (i4 >= this.mDataList.size()) {
                    i4 = 0;
                }
                strArr2[i2] = this.mDataList.get(i4);
            } else if (i4 < 0) {
                strArr2[i2] = "";
            } else if (i4 > this.mDataList.size() - 1) {
                strArr2[i2] = "";
            } else {
                strArr2[i2] = this.mDataList.get(i4);
            }
            i2++;
        }
        float f2 = (this.mWidgetWidth - this.mMaxTextWidth) / 2;
        int i5 = this.mTopLineY;
        canvas.drawLine(f2, i5, r2 + r10, i5, this.mCenterLinePaint);
        int i6 = this.mBottomLineY;
        canvas.drawLine(f2, i6, r10 + this.mMaxTextWidth, i6, this.mCenterLinePaint);
        int i7 = (int) (this.mTotalScrollY % this.mItemHeight);
        int i8 = 0;
        while (i8 < this.mDrawItemsCount) {
            canvas.save();
            float f3 = this.mMaxTextHeight * this.lineSpacingMultiplier;
            double d2 = ((i8 * f3) - i7) / this.mCircularRadius;
            float f4 = (float) (90.0d - ((d2 / 3.141592653589793d) * 180.0d));
            if (f4 >= 90.0f || f4 <= -90.0f) {
                strArr = strArr2;
                canvas.restore();
            } else {
                Paint.FontMetricsInt fontMetricsInt = this.mCenterTextPaint.getFontMetricsInt();
                int i9 = ((this.mMaxTextHeight / 2) + ((fontMetricsInt.bottom - fontMetricsInt.top) / 2)) - fontMetricsInt.bottom;
                strArr = strArr2;
                int cos = ((int) ((this.mCircularRadius - (Math.cos(d2) * this.mCircularRadius)) - ((Math.sin(d2) * this.mMaxTextHeight) / 2.0d))) + this.mPaddingTopBottom;
                float f5 = cos;
                canvas.translate(0.0f, f5);
                canvas.scale(1.0f, (float) Math.sin(d2));
                int i10 = this.mTopLineY;
                if (cos <= i10) {
                    if (f5 <= i10 - f3) {
                        canvas.save();
                        canvas.clipRect(0.0f, 0.0f, this.mWidgetWidth, this.mTopLineY - f3);
                        canvas.drawText(strArr[i8], getPaddingLeftRight(r4), i9, this.mTopBottomTextPaint);
                        canvas.restore();
                    } else {
                        canvas.save();
                        canvas.clipRect(0, 0, this.mWidgetWidth, this.mTopLineY - cos);
                        canvas.drawText(strArr[i8], getPaddingLeftRight(r4), i9, this.mCenterTopBottomTextPaint);
                        canvas.restore();
                    }
                    canvas.save();
                    canvas.clipRect(0, this.mTopLineY - cos, this.mWidgetWidth, (int) f3);
                    canvas.drawText(strArr[i8], getPaddingLeftRight(r3), i9, this.mCenterTextPaint);
                    canvas.restore();
                } else {
                    int i11 = this.mMaxTextHeight;
                    int i12 = i11 + cos;
                    int i13 = this.mBottomLineY;
                    if (i12 >= i13) {
                        canvas.save();
                        canvas.clipRect(0, 0, this.mWidgetWidth, this.mBottomLineY - cos);
                        float f6 = i9;
                        canvas.drawText(strArr[i8], getPaddingLeftRight(r4), f6, this.mCenterTextPaint);
                        canvas.restore();
                        if (this.mMaxTextHeight + cos >= this.mBottomLineY + f3) {
                            canvas.save();
                            int i14 = this.mBottomLineY;
                            canvas.clipRect(0.0f, i14 - (f5 + f3), this.mWidgetWidth, i14 + (f3 * 2.0f));
                            canvas.drawText(strArr[i8], getPaddingLeftRight(r3), f6, this.mTopBottomTextPaint);
                            canvas.restore();
                        } else {
                            canvas.save();
                            canvas.clipRect(0, this.mBottomLineY - cos, this.mWidgetWidth, (int) f3);
                            canvas.drawText(strArr[i8], getPaddingLeftRight(r3), f6, this.mCenterTopBottomTextPaint);
                            canvas.restore();
                        }
                    } else if (cos >= i10 && i11 + cos <= i13) {
                        canvas.save();
                        int i15 = this.mMaxTextHeight;
                        canvas.clipRect(0.0f, (-i15) / 2, this.mWidgetWidth, f3 - (i15 / 2));
                        canvas.drawText(strArr[i8], getPaddingLeftRight(r3), i9, this.mCenterTextPaint);
                        this.mSelectedPosition = this.mDataList.indexOf(strArr[i8]);
                        canvas.restore();
                    }
                    canvas.restore();
                }
                canvas.restore();
            }
            i8++;
            strArr2 = strArr;
        }
    }

    @Override // android.view.View
    public boolean onTouchEvent(MotionEvent motionEvent) {
        motionEvent.getAction();
        if (this.mGestureDetector.onTouchEvent(motionEvent)) {
            return true;
        }
        startSmoothScrollTo();
        return true;
    }

    public int getDrawItemsCount() {
        return this.mDrawItemsCount;
    }

    public void setDrawItemsCount(int i2) {
        this.mDrawItemsCount = i2;
    }

    public final void setCanLoop(boolean z) {
        this.mCanLoop = z;
        invalidate();
    }

    public final void setTextSize(float f2) {
        if (f2 > 0.0f) {
            this.mTextSize = sp2px(this.mContext, f2);
        }
    }

    public void setUnSelectedTextColor(int i2) {
        this.mTopBottomTextColor = i2;
    }

    public void setSelectedTextColor(int i2) {
        this.mCenterTextColor = i2;
    }

    public void setCenterLineColor(int i2) {
        this.mCenterLineColor = i2;
    }

    public void setInitPosition(int i2) {
        this.mInitPosition = i2;
        invalidate();
    }

    public void setInitPosition(String str) {
        this.mInitPosition = this.mDataList.indexOf(str);
        invalidate();
    }

    public void setLoopListener(LoopScrollListener loopScrollListener) {
        this.mLoopListener = loopScrollListener;
    }

    public final void setDataList(List<String> list) {
        this.mDataList = list;
        initData();
    }

    public int getSelectedPosition() {
        return this.mSelectedPosition;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void itemSelected() {
        if (this.mLoopListener != null) {
            postDelayed(new SelectedRunnable(), 200L);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void cancelSchedule() {
        ScheduledFuture<?> scheduledFuture = this.mScheduledFuture;
        if (scheduledFuture == null || scheduledFuture.isCancelled()) {
            return;
        }
        this.mScheduledFuture.cancel(true);
        this.mScheduledFuture = null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void startSmoothScrollTo() {
        int i2 = (int) (this.mTotalScrollY % this.mItemHeight);
        cancelSchedule();
        this.mScheduledFuture = this.mExecutor.scheduleWithFixedDelay(new HalfHeightRunnable(i2), 0L, 10, TimeUnit.MILLISECONDS);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void startSmoothScrollTo(float f2) {
        cancelSchedule();
        this.mScheduledFuture = this.mExecutor.scheduleWithFixedDelay(new FlingRunnable(f2), 0L, 10, TimeUnit.MILLISECONDS);
    }

    class LoopViewGestureListener extends GestureDetector.SimpleOnGestureListener {
        LoopViewGestureListener() {
        }

        @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
        public final boolean onDown(MotionEvent motionEvent) {
            LoopView.this.cancelSchedule();
            return true;
        }

        @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
        public final boolean onFling(MotionEvent motionEvent, MotionEvent motionEvent2, float f2, float f3) {
            LoopView.this.startSmoothScrollTo(f3);
            return true;
        }

        @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
        public boolean onScroll(MotionEvent motionEvent, MotionEvent motionEvent2, float f2, float f3) {
            LoopView.this.mTotalScrollY = (int) (r1.mTotalScrollY + f3);
            if (!LoopView.this.mCanLoop) {
                int i2 = ((int) (LoopView.this.mInitPosition * LoopView.this.mItemHeight)) * (-1);
                if (LoopView.this.mTotalScrollY < i2) {
                    LoopView.this.mTotalScrollY = i2;
                }
                int size = (int) (((LoopView.this.mDataList.size() - 1) - LoopView.this.mInitPosition) * LoopView.this.mItemHeight);
                if (LoopView.this.mTotalScrollY >= size) {
                    LoopView.this.mTotalScrollY = size;
                }
            }
            LoopView.this.invalidate();
            return true;
        }
    }

    public int sp2px(Context context, float f2) {
        return (int) ((f2 * context.getResources().getDisplayMetrics().scaledDensity) + 0.5f);
    }

    class SelectedRunnable implements Runnable {
        SelectedRunnable() {
        }

        @Override // java.lang.Runnable
        public final void run() {
            LoopScrollListener loopScrollListener = LoopView.this.mLoopListener;
            int selectedPosition = LoopView.this.getSelectedPosition();
            loopScrollListener.onItemSelected(selectedPosition, (String) LoopView.this.mDataList.get(selectedPosition));
        }
    }

    class HalfHeightRunnable implements Runnable {
        int offset;
        int realTotalOffset = Integer.MAX_VALUE;
        int realOffset = 0;

        public HalfHeightRunnable(int i2) {
            this.offset = i2;
        }

        @Override // java.lang.Runnable
        public void run() {
            if (this.realTotalOffset == Integer.MAX_VALUE) {
                if (this.offset > LoopView.this.mItemHeight / 2.0f) {
                    this.realTotalOffset = (int) (LoopView.this.mItemHeight - this.offset);
                } else {
                    this.realTotalOffset = -this.offset;
                }
            }
            int i2 = this.realTotalOffset;
            int i3 = (int) (i2 * 0.1f);
            this.realOffset = i3;
            if (i3 == 0) {
                if (i2 < 0) {
                    this.realOffset = -1;
                } else {
                    this.realOffset = 1;
                }
            }
            if (Math.abs(i2) <= 0) {
                LoopView.this.cancelSchedule();
                LoopView.this.mHandler.sendEmptyMessage(3000);
            } else {
                LoopView.this.mTotalScrollY += this.realOffset;
                LoopView.this.mHandler.sendEmptyMessage(1000);
                this.realTotalOffset -= this.realOffset;
            }
        }
    }

    class FlingRunnable implements Runnable {
        float velocity = 2.1474836E9f;
        final float velocityY;

        FlingRunnable(float f2) {
            this.velocityY = f2;
        }

        @Override // java.lang.Runnable
        public void run() {
            if (this.velocity == 2.1474836E9f) {
                if (Math.abs(this.velocityY) <= 2000.0f) {
                    this.velocity = this.velocityY;
                } else if (this.velocityY > 0.0f) {
                    this.velocity = 2000.0f;
                } else {
                    this.velocity = -2000.0f;
                }
            }
            if (Math.abs(this.velocity) >= 0.0f && Math.abs(this.velocity) <= 20.0f) {
                LoopView.this.cancelSchedule();
                LoopView.this.mHandler.sendEmptyMessage(2000);
                return;
            }
            LoopView.this.mTotalScrollY -= (int) ((this.velocity * 10.0f) / 1000.0f);
            if (!LoopView.this.mCanLoop) {
                float f2 = LoopView.this.lineSpacingMultiplier * LoopView.this.mMaxTextHeight;
                if (LoopView.this.mTotalScrollY > ((int) ((-LoopView.this.mInitPosition) * f2))) {
                    if (LoopView.this.mTotalScrollY >= ((int) (((LoopView.this.mDataList.size() - 1) - LoopView.this.mInitPosition) * f2))) {
                        LoopView.this.mTotalScrollY = (int) (((r3.mDataList.size() - 1) - LoopView.this.mInitPosition) * f2);
                        this.velocity = -40.0f;
                    }
                } else {
                    this.velocity = 40.0f;
                    LoopView.this.mTotalScrollY = (int) ((-r3.mInitPosition) * f2);
                }
            }
            float f3 = this.velocity;
            if (f3 < 0.0f) {
                this.velocity = f3 + 20.0f;
            } else {
                this.velocity = f3 - 20.0f;
            }
            LoopView.this.mHandler.sendEmptyMessage(1000);
        }
    }
}
