package cn.bingoogolapple.qrcode.core;

import android.graphics.Bitmap;
import android.hardware.Camera;
import android.os.AsyncTask;
import android.text.TextUtils;
import java.lang.ref.WeakReference;

/* loaded from: classes.dex */
class ProcessDataTask extends AsyncTask<Void, Void, ScanResult> {
    private static long sLastStartTime;
    private Bitmap mBitmap;
    private Camera mCamera;
    private byte[] mData;
    private boolean mIsPortrait;
    private String mPicturePath;
    private WeakReference<QRCodeView> mQRCodeViewRef;

    ProcessDataTask(Camera camera, byte[] bArr, QRCodeView qRCodeView, boolean z) {
        this.mCamera = camera;
        this.mData = bArr;
        this.mQRCodeViewRef = new WeakReference<>(qRCodeView);
        this.mIsPortrait = z;
    }

    ProcessDataTask(String str, QRCodeView qRCodeView) {
        this.mPicturePath = str;
        this.mQRCodeViewRef = new WeakReference<>(qRCodeView);
    }

    ProcessDataTask(Bitmap bitmap, QRCodeView qRCodeView) {
        this.mBitmap = bitmap;
        this.mQRCodeViewRef = new WeakReference<>(qRCodeView);
    }

    ProcessDataTask perform() {
        executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
        return this;
    }

    void cancelTask() {
        if (getStatus() != AsyncTask.Status.FINISHED) {
            cancel(true);
        }
    }

    @Override // android.os.AsyncTask
    protected void onCancelled() {
        super.onCancelled();
        this.mQRCodeViewRef.clear();
        this.mBitmap = null;
        this.mData = null;
    }

    private ScanResult processData(QRCodeView qRCodeView) {
        int i2;
        Exception e2;
        int i3;
        byte[] bArr = this.mData;
        if (bArr == null) {
            return null;
        }
        try {
            Camera.Size previewSize = this.mCamera.getParameters().getPreviewSize();
            i2 = previewSize.width;
            try {
                i3 = previewSize.height;
                try {
                    if (this.mIsPortrait) {
                        bArr = new byte[this.mData.length];
                        for (int i4 = 0; i4 < i3; i4++) {
                            for (int i5 = 0; i5 < i2; i5++) {
                                bArr[(((i5 * i3) + i3) - i4) - 1] = this.mData[(i4 * i2) + i5];
                            }
                        }
                        i2 = i3;
                        i3 = i2;
                    }
                    return qRCodeView.processData(bArr, i2, i3, false);
                } catch (Exception e3) {
                    e2 = e3;
                    e2.printStackTrace();
                    if (i2 != 0 && i3 != 0) {
                        try {
                            BGAQRCodeUtil.d("识别失败重试");
                            return qRCodeView.processData(bArr, i2, i3, true);
                        } catch (Exception e4) {
                            e4.printStackTrace();
                            return null;
                        }
                    }
                    return null;
                }
            } catch (Exception e5) {
                i3 = 0;
                e2 = e5;
            }
        } catch (Exception e6) {
            i2 = 0;
            e2 = e6;
            i3 = 0;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // android.os.AsyncTask
    public ScanResult doInBackground(Void... voidArr) {
        QRCodeView qRCodeView = this.mQRCodeViewRef.get();
        if (qRCodeView == null) {
            return null;
        }
        String str = this.mPicturePath;
        if (str != null) {
            return qRCodeView.processBitmapData(BGAQRCodeUtil.getDecodeAbleBitmap(str));
        }
        Bitmap bitmap = this.mBitmap;
        if (bitmap != null) {
            ScanResult processBitmapData = qRCodeView.processBitmapData(bitmap);
            this.mBitmap = null;
            return processBitmapData;
        }
        if (BGAQRCodeUtil.isDebug()) {
            BGAQRCodeUtil.d("两次任务执行的时间间隔：" + (System.currentTimeMillis() - sLastStartTime));
            sLastStartTime = System.currentTimeMillis();
        }
        long currentTimeMillis = System.currentTimeMillis();
        ScanResult processData = processData(qRCodeView);
        if (BGAQRCodeUtil.isDebug()) {
            long currentTimeMillis2 = System.currentTimeMillis() - currentTimeMillis;
            if (processData != null && !TextUtils.isEmpty(processData.result)) {
                BGAQRCodeUtil.d("识别成功时间为：" + currentTimeMillis2);
            } else {
                BGAQRCodeUtil.e("识别失败时间为：" + currentTimeMillis2);
            }
        }
        return processData;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // android.os.AsyncTask
    public void onPostExecute(ScanResult scanResult) {
        QRCodeView qRCodeView = this.mQRCodeViewRef.get();
        if (qRCodeView == null) {
            return;
        }
        if (this.mPicturePath != null || this.mBitmap != null) {
            this.mBitmap = null;
            qRCodeView.onPostParseBitmapOrPicture(scanResult);
        } else {
            qRCodeView.onPostParseData(scanResult);
        }
    }
}
