package cn.bingoogolapple.qrcode.core;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.text.Layout;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.View;

/* loaded from: classes.dex */
public class ScanBoxView extends View {
    private int mAnimDelayTime;
    private int mAnimTime;
    private String mBarCodeTipText;
    private int mBarcodeRectHeight;
    private int mBorderColor;
    private int mBorderSize;
    private int mCornerColor;
    private int mCornerDisplayType;
    private int mCornerLength;
    private int mCornerSize;
    private Drawable mCustomGridScanLineDrawable;
    private Drawable mCustomScanLineDrawable;
    private Rect mFramingRect;
    private Bitmap mGridScanLineBitmap;
    private float mGridScanLineBottom;
    private float mGridScanLineRight;
    private float mHalfCornerSize;
    private boolean mIsAutoZoom;
    private boolean mIsBarcode;
    private boolean mIsOnlyDecodeScanBoxArea;
    private boolean mIsScanLineReverse;
    private boolean mIsShowDefaultGridScanLineDrawable;
    private boolean mIsShowDefaultScanLineDrawable;
    private boolean mIsShowLocationPoint;
    private boolean mIsShowTipBackground;
    private boolean mIsShowTipTextAsSingleLine;
    private boolean mIsTipTextBelowRect;
    private int mMaskColor;
    private int mMoveStepDistance;
    private Bitmap mOriginBarCodeGridScanLineBitmap;
    private Bitmap mOriginBarCodeScanLineBitmap;
    private Bitmap mOriginQRCodeGridScanLineBitmap;
    private Bitmap mOriginQRCodeScanLineBitmap;
    private Paint mPaint;
    private String mQRCodeTipText;
    private QRCodeView mQRCodeView;
    private int mRectHeight;
    private int mRectWidth;
    private Bitmap mScanLineBitmap;
    private int mScanLineColor;
    private float mScanLineLeft;
    private int mScanLineMargin;
    private int mScanLineSize;
    private float mScanLineTop;
    private int mTipBackgroundColor;
    private int mTipBackgroundRadius;
    private TextPaint mTipPaint;
    private String mTipText;
    private int mTipTextColor;
    private int mTipTextMargin;
    private int mTipTextSize;
    private StaticLayout mTipTextSl;
    private int mToolbarHeight;
    private int mTopOffset;
    private float mVerticalBias;

    public ScanBoxView(Context context) {
        super(context);
        Paint paint = new Paint();
        this.mPaint = paint;
        paint.setAntiAlias(true);
        this.mMaskColor = Color.parseColor("#33FFFFFF");
        this.mCornerColor = -1;
        this.mCornerLength = BGAQRCodeUtil.dp2px(context, 20.0f);
        this.mCornerSize = BGAQRCodeUtil.dp2px(context, 3.0f);
        this.mScanLineSize = BGAQRCodeUtil.dp2px(context, 1.0f);
        this.mScanLineColor = -1;
        this.mTopOffset = BGAQRCodeUtil.dp2px(context, 90.0f);
        this.mRectWidth = BGAQRCodeUtil.dp2px(context, 200.0f);
        this.mBarcodeRectHeight = BGAQRCodeUtil.dp2px(context, 140.0f);
        this.mScanLineMargin = 0;
        this.mIsShowDefaultScanLineDrawable = false;
        this.mCustomScanLineDrawable = null;
        this.mScanLineBitmap = null;
        this.mBorderSize = BGAQRCodeUtil.dp2px(context, 1.0f);
        this.mBorderColor = -1;
        this.mAnimTime = 1000;
        this.mVerticalBias = -1.0f;
        this.mCornerDisplayType = 1;
        this.mToolbarHeight = 0;
        this.mIsBarcode = false;
        this.mMoveStepDistance = BGAQRCodeUtil.dp2px(context, 2.0f);
        this.mTipText = null;
        this.mTipTextSize = BGAQRCodeUtil.sp2px(context, 14.0f);
        this.mTipTextColor = -1;
        this.mIsTipTextBelowRect = false;
        this.mTipTextMargin = BGAQRCodeUtil.dp2px(context, 20.0f);
        this.mIsShowTipTextAsSingleLine = false;
        this.mTipBackgroundColor = Color.parseColor("#22000000");
        this.mIsShowTipBackground = false;
        this.mIsScanLineReverse = false;
        this.mIsShowDefaultGridScanLineDrawable = false;
        TextPaint textPaint = new TextPaint();
        this.mTipPaint = textPaint;
        textPaint.setAntiAlias(true);
        this.mTipBackgroundRadius = BGAQRCodeUtil.dp2px(context, 4.0f);
        this.mIsOnlyDecodeScanBoxArea = false;
        this.mIsShowLocationPoint = false;
        this.mIsAutoZoom = false;
    }

    void init(QRCodeView qRCodeView, AttributeSet attributeSet) {
        this.mQRCodeView = qRCodeView;
        TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attributeSet, R.styleable.QRCodeView);
        int indexCount = obtainStyledAttributes.getIndexCount();
        for (int i2 = 0; i2 < indexCount; i2++) {
            initCustomAttr(obtainStyledAttributes.getIndex(i2), obtainStyledAttributes);
        }
        obtainStyledAttributes.recycle();
        afterInitCustomAttrs();
    }

    private void initCustomAttr(int i2, TypedArray typedArray) {
        if (i2 == R.styleable.QRCodeView_qrcv_topOffset) {
            this.mTopOffset = typedArray.getDimensionPixelSize(i2, this.mTopOffset);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_cornerSize) {
            this.mCornerSize = typedArray.getDimensionPixelSize(i2, this.mCornerSize);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_cornerLength) {
            this.mCornerLength = typedArray.getDimensionPixelSize(i2, this.mCornerLength);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_scanLineSize) {
            this.mScanLineSize = typedArray.getDimensionPixelSize(i2, this.mScanLineSize);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_rectWidth) {
            this.mRectWidth = typedArray.getDimensionPixelSize(i2, this.mRectWidth);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_maskColor) {
            this.mMaskColor = typedArray.getColor(i2, this.mMaskColor);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_cornerColor) {
            this.mCornerColor = typedArray.getColor(i2, this.mCornerColor);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_scanLineColor) {
            this.mScanLineColor = typedArray.getColor(i2, this.mScanLineColor);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_scanLineMargin) {
            this.mScanLineMargin = typedArray.getDimensionPixelSize(i2, this.mScanLineMargin);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_isShowDefaultScanLineDrawable) {
            this.mIsShowDefaultScanLineDrawable = typedArray.getBoolean(i2, this.mIsShowDefaultScanLineDrawable);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_customScanLineDrawable) {
            this.mCustomScanLineDrawable = typedArray.getDrawable(i2);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_borderSize) {
            this.mBorderSize = typedArray.getDimensionPixelSize(i2, this.mBorderSize);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_borderColor) {
            this.mBorderColor = typedArray.getColor(i2, this.mBorderColor);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_animTime) {
            this.mAnimTime = typedArray.getInteger(i2, this.mAnimTime);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_verticalBias) {
            this.mVerticalBias = typedArray.getFloat(i2, this.mVerticalBias);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_cornerDisplayType) {
            this.mCornerDisplayType = typedArray.getInteger(i2, this.mCornerDisplayType);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_toolbarHeight) {
            this.mToolbarHeight = typedArray.getDimensionPixelSize(i2, this.mToolbarHeight);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_barcodeRectHeight) {
            this.mBarcodeRectHeight = typedArray.getDimensionPixelSize(i2, this.mBarcodeRectHeight);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_isBarcode) {
            this.mIsBarcode = typedArray.getBoolean(i2, this.mIsBarcode);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_barCodeTipText) {
            this.mBarCodeTipText = typedArray.getString(i2);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_qrCodeTipText) {
            this.mQRCodeTipText = typedArray.getString(i2);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_tipTextSize) {
            this.mTipTextSize = typedArray.getDimensionPixelSize(i2, this.mTipTextSize);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_tipTextColor) {
            this.mTipTextColor = typedArray.getColor(i2, this.mTipTextColor);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_isTipTextBelowRect) {
            this.mIsTipTextBelowRect = typedArray.getBoolean(i2, this.mIsTipTextBelowRect);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_tipTextMargin) {
            this.mTipTextMargin = typedArray.getDimensionPixelSize(i2, this.mTipTextMargin);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_isShowTipTextAsSingleLine) {
            this.mIsShowTipTextAsSingleLine = typedArray.getBoolean(i2, this.mIsShowTipTextAsSingleLine);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_isShowTipBackground) {
            this.mIsShowTipBackground = typedArray.getBoolean(i2, this.mIsShowTipBackground);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_tipBackgroundColor) {
            this.mTipBackgroundColor = typedArray.getColor(i2, this.mTipBackgroundColor);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_isScanLineReverse) {
            this.mIsScanLineReverse = typedArray.getBoolean(i2, this.mIsScanLineReverse);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_isShowDefaultGridScanLineDrawable) {
            this.mIsShowDefaultGridScanLineDrawable = typedArray.getBoolean(i2, this.mIsShowDefaultGridScanLineDrawable);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_customGridScanLineDrawable) {
            this.mCustomGridScanLineDrawable = typedArray.getDrawable(i2);
            return;
        }
        if (i2 == R.styleable.QRCodeView_qrcv_isOnlyDecodeScanBoxArea) {
            this.mIsOnlyDecodeScanBoxArea = typedArray.getBoolean(i2, this.mIsOnlyDecodeScanBoxArea);
        } else if (i2 == R.styleable.QRCodeView_qrcv_isShowLocationPoint) {
            this.mIsShowLocationPoint = typedArray.getBoolean(i2, this.mIsShowLocationPoint);
        } else if (i2 == R.styleable.QRCodeView_qrcv_isAutoZoom) {
            this.mIsAutoZoom = typedArray.getBoolean(i2, this.mIsAutoZoom);
        }
    }

    private void afterInitCustomAttrs() {
        Drawable drawable = this.mCustomGridScanLineDrawable;
        if (drawable != null) {
            this.mOriginQRCodeGridScanLineBitmap = ((BitmapDrawable) drawable).getBitmap();
        }
        if (this.mOriginQRCodeGridScanLineBitmap == null) {
            Bitmap decodeResource = BitmapFactory.decodeResource(getResources(), R.mipmap.qrcode_default_grid_scan_line);
            this.mOriginQRCodeGridScanLineBitmap = decodeResource;
            this.mOriginQRCodeGridScanLineBitmap = BGAQRCodeUtil.makeTintBitmap(decodeResource, this.mScanLineColor);
        }
        Bitmap adjustPhotoRotation = BGAQRCodeUtil.adjustPhotoRotation(this.mOriginQRCodeGridScanLineBitmap, 90);
        this.mOriginBarCodeGridScanLineBitmap = adjustPhotoRotation;
        Bitmap adjustPhotoRotation2 = BGAQRCodeUtil.adjustPhotoRotation(adjustPhotoRotation, 90);
        this.mOriginBarCodeGridScanLineBitmap = adjustPhotoRotation2;
        this.mOriginBarCodeGridScanLineBitmap = BGAQRCodeUtil.adjustPhotoRotation(adjustPhotoRotation2, 90);
        Drawable drawable2 = this.mCustomScanLineDrawable;
        if (drawable2 != null) {
            this.mOriginQRCodeScanLineBitmap = ((BitmapDrawable) drawable2).getBitmap();
        }
        if (this.mOriginQRCodeScanLineBitmap == null) {
            Bitmap decodeResource2 = BitmapFactory.decodeResource(getResources(), R.mipmap.qrcode_default_scan_line);
            this.mOriginQRCodeScanLineBitmap = decodeResource2;
            this.mOriginQRCodeScanLineBitmap = BGAQRCodeUtil.makeTintBitmap(decodeResource2, this.mScanLineColor);
        }
        this.mOriginBarCodeScanLineBitmap = BGAQRCodeUtil.adjustPhotoRotation(this.mOriginQRCodeScanLineBitmap, 90);
        this.mTopOffset += this.mToolbarHeight;
        this.mHalfCornerSize = (this.mCornerSize * 1.0f) / 2.0f;
        this.mTipPaint.setTextSize(this.mTipTextSize);
        this.mTipPaint.setColor(this.mTipTextColor);
        setIsBarcode(this.mIsBarcode);
    }

    @Override // android.view.View
    public void onDraw(Canvas canvas) {
        if (this.mFramingRect == null) {
            return;
        }
        drawMask(canvas);
        drawBorderLine(canvas);
        drawCornerLine(canvas);
        drawScanLine(canvas);
        drawTipText(canvas);
        moveScanLine();
    }

    private void drawMask(Canvas canvas) {
        int width = canvas.getWidth();
        int height = canvas.getHeight();
        if (this.mMaskColor != 0) {
            this.mPaint.setStyle(Paint.Style.FILL);
            this.mPaint.setColor(this.mMaskColor);
            float f2 = width;
            canvas.drawRect(0.0f, 0.0f, f2, this.mFramingRect.top, this.mPaint);
            canvas.drawRect(0.0f, this.mFramingRect.top, this.mFramingRect.left, this.mFramingRect.bottom + 1, this.mPaint);
            canvas.drawRect(this.mFramingRect.right + 1, this.mFramingRect.top, f2, this.mFramingRect.bottom + 1, this.mPaint);
            canvas.drawRect(0.0f, this.mFramingRect.bottom + 1, f2, height, this.mPaint);
        }
    }

    private void drawBorderLine(Canvas canvas) {
        if (this.mBorderSize > 0) {
            this.mPaint.setStyle(Paint.Style.STROKE);
            this.mPaint.setColor(this.mBorderColor);
            this.mPaint.setStrokeWidth(this.mBorderSize);
            canvas.drawRect(this.mFramingRect, this.mPaint);
        }
    }

    private void drawCornerLine(Canvas canvas) {
        if (this.mHalfCornerSize > 0.0f) {
            this.mPaint.setStyle(Paint.Style.STROKE);
            this.mPaint.setColor(this.mCornerColor);
            this.mPaint.setStrokeWidth(this.mCornerSize);
            int i2 = this.mCornerDisplayType;
            if (i2 == 1) {
                canvas.drawLine(this.mFramingRect.left - this.mHalfCornerSize, this.mFramingRect.top, (this.mFramingRect.left - this.mHalfCornerSize) + this.mCornerLength, this.mFramingRect.top, this.mPaint);
                canvas.drawLine(this.mFramingRect.left, this.mFramingRect.top - this.mHalfCornerSize, this.mFramingRect.left, (this.mFramingRect.top - this.mHalfCornerSize) + this.mCornerLength, this.mPaint);
                canvas.drawLine(this.mFramingRect.right + this.mHalfCornerSize, this.mFramingRect.top, (this.mFramingRect.right + this.mHalfCornerSize) - this.mCornerLength, this.mFramingRect.top, this.mPaint);
                canvas.drawLine(this.mFramingRect.right, this.mFramingRect.top - this.mHalfCornerSize, this.mFramingRect.right, (this.mFramingRect.top - this.mHalfCornerSize) + this.mCornerLength, this.mPaint);
                canvas.drawLine(this.mFramingRect.left - this.mHalfCornerSize, this.mFramingRect.bottom, (this.mFramingRect.left - this.mHalfCornerSize) + this.mCornerLength, this.mFramingRect.bottom, this.mPaint);
                canvas.drawLine(this.mFramingRect.left, this.mFramingRect.bottom + this.mHalfCornerSize, this.mFramingRect.left, (this.mFramingRect.bottom + this.mHalfCornerSize) - this.mCornerLength, this.mPaint);
                canvas.drawLine(this.mFramingRect.right + this.mHalfCornerSize, this.mFramingRect.bottom, (this.mFramingRect.right + this.mHalfCornerSize) - this.mCornerLength, this.mFramingRect.bottom, this.mPaint);
                canvas.drawLine(this.mFramingRect.right, this.mFramingRect.bottom + this.mHalfCornerSize, this.mFramingRect.right, (this.mFramingRect.bottom + this.mHalfCornerSize) - this.mCornerLength, this.mPaint);
                return;
            }
            if (i2 == 2) {
                canvas.drawLine(this.mFramingRect.left, this.mFramingRect.top + this.mHalfCornerSize, this.mFramingRect.left + this.mCornerLength, this.mFramingRect.top + this.mHalfCornerSize, this.mPaint);
                canvas.drawLine(this.mFramingRect.left + this.mHalfCornerSize, this.mFramingRect.top, this.mFramingRect.left + this.mHalfCornerSize, this.mFramingRect.top + this.mCornerLength, this.mPaint);
                canvas.drawLine(this.mFramingRect.right, this.mFramingRect.top + this.mHalfCornerSize, this.mFramingRect.right - this.mCornerLength, this.mFramingRect.top + this.mHalfCornerSize, this.mPaint);
                canvas.drawLine(this.mFramingRect.right - this.mHalfCornerSize, this.mFramingRect.top, this.mFramingRect.right - this.mHalfCornerSize, this.mFramingRect.top + this.mCornerLength, this.mPaint);
                canvas.drawLine(this.mFramingRect.left, this.mFramingRect.bottom - this.mHalfCornerSize, this.mFramingRect.left + this.mCornerLength, this.mFramingRect.bottom - this.mHalfCornerSize, this.mPaint);
                canvas.drawLine(this.mFramingRect.left + this.mHalfCornerSize, this.mFramingRect.bottom, this.mFramingRect.left + this.mHalfCornerSize, this.mFramingRect.bottom - this.mCornerLength, this.mPaint);
                canvas.drawLine(this.mFramingRect.right, this.mFramingRect.bottom - this.mHalfCornerSize, this.mFramingRect.right - this.mCornerLength, this.mFramingRect.bottom - this.mHalfCornerSize, this.mPaint);
                canvas.drawLine(this.mFramingRect.right - this.mHalfCornerSize, this.mFramingRect.bottom, this.mFramingRect.right - this.mHalfCornerSize, this.mFramingRect.bottom - this.mCornerLength, this.mPaint);
            }
        }
    }

    private void drawScanLine(Canvas canvas) {
        if (this.mIsBarcode) {
            if (this.mGridScanLineBitmap != null) {
                RectF rectF = new RectF(this.mFramingRect.left + this.mHalfCornerSize + 0.5f, this.mFramingRect.top + this.mHalfCornerSize + this.mScanLineMargin, this.mGridScanLineRight, (this.mFramingRect.bottom - this.mHalfCornerSize) - this.mScanLineMargin);
                Rect rect = new Rect((int) (this.mGridScanLineBitmap.getWidth() - rectF.width()), 0, this.mGridScanLineBitmap.getWidth(), this.mGridScanLineBitmap.getHeight());
                if (rect.left < 0) {
                    rect.left = 0;
                    rectF.left = rectF.right - rect.width();
                }
                canvas.drawBitmap(this.mGridScanLineBitmap, rect, rectF, this.mPaint);
                return;
            }
            if (this.mScanLineBitmap != null) {
                canvas.drawBitmap(this.mScanLineBitmap, (Rect) null, new RectF(this.mScanLineLeft, this.mFramingRect.top + this.mHalfCornerSize + this.mScanLineMargin, this.mScanLineLeft + this.mScanLineBitmap.getWidth(), (this.mFramingRect.bottom - this.mHalfCornerSize) - this.mScanLineMargin), this.mPaint);
                return;
            } else {
                this.mPaint.setStyle(Paint.Style.FILL);
                this.mPaint.setColor(this.mScanLineColor);
                canvas.drawRect(this.mScanLineLeft, this.mFramingRect.top + this.mHalfCornerSize + this.mScanLineMargin, this.mScanLineLeft + this.mScanLineSize, (this.mFramingRect.bottom - this.mHalfCornerSize) - this.mScanLineMargin, this.mPaint);
                return;
            }
        }
        if (this.mGridScanLineBitmap != null) {
            RectF rectF2 = new RectF(this.mFramingRect.left + this.mHalfCornerSize + this.mScanLineMargin, this.mFramingRect.top + this.mHalfCornerSize + 0.5f, (this.mFramingRect.right - this.mHalfCornerSize) - this.mScanLineMargin, this.mGridScanLineBottom);
            Rect rect2 = new Rect(0, (int) (this.mGridScanLineBitmap.getHeight() - rectF2.height()), this.mGridScanLineBitmap.getWidth(), this.mGridScanLineBitmap.getHeight());
            if (rect2.top < 0) {
                rect2.top = 0;
                rectF2.top = rectF2.bottom - rect2.height();
            }
            canvas.drawBitmap(this.mGridScanLineBitmap, rect2, rectF2, this.mPaint);
            return;
        }
        if (this.mScanLineBitmap != null) {
            canvas.drawBitmap(this.mScanLineBitmap, (Rect) null, new RectF(this.mFramingRect.left + this.mHalfCornerSize + this.mScanLineMargin, this.mScanLineTop, (this.mFramingRect.right - this.mHalfCornerSize) - this.mScanLineMargin, this.mScanLineTop + this.mScanLineBitmap.getHeight()), this.mPaint);
        } else {
            this.mPaint.setStyle(Paint.Style.FILL);
            this.mPaint.setColor(this.mScanLineColor);
            canvas.drawRect(this.mFramingRect.left + this.mHalfCornerSize + this.mScanLineMargin, this.mScanLineTop, (this.mFramingRect.right - this.mHalfCornerSize) - this.mScanLineMargin, this.mScanLineTop + this.mScanLineSize, this.mPaint);
        }
    }

    private void drawTipText(Canvas canvas) {
        if (TextUtils.isEmpty(this.mTipText) || this.mTipTextSl == null) {
            return;
        }
        if (this.mIsTipTextBelowRect) {
            if (this.mIsShowTipBackground) {
                this.mPaint.setColor(this.mTipBackgroundColor);
                this.mPaint.setStyle(Paint.Style.FILL);
                if (this.mIsShowTipTextAsSingleLine) {
                    Rect rect = new Rect();
                    TextPaint textPaint = this.mTipPaint;
                    String str = this.mTipText;
                    textPaint.getTextBounds(str, 0, str.length(), rect);
                    float width = ((canvas.getWidth() - rect.width()) / 2) - this.mTipBackgroundRadius;
                    RectF rectF = new RectF(width, (this.mFramingRect.bottom + this.mTipTextMargin) - this.mTipBackgroundRadius, rect.width() + width + (this.mTipBackgroundRadius * 2), this.mFramingRect.bottom + this.mTipTextMargin + this.mTipTextSl.getHeight() + this.mTipBackgroundRadius);
                    int i2 = this.mTipBackgroundRadius;
                    canvas.drawRoundRect(rectF, i2, i2, this.mPaint);
                } else {
                    RectF rectF2 = new RectF(this.mFramingRect.left, (this.mFramingRect.bottom + this.mTipTextMargin) - this.mTipBackgroundRadius, this.mFramingRect.right, this.mFramingRect.bottom + this.mTipTextMargin + this.mTipTextSl.getHeight() + this.mTipBackgroundRadius);
                    int i3 = this.mTipBackgroundRadius;
                    canvas.drawRoundRect(rectF2, i3, i3, this.mPaint);
                }
            }
            canvas.save();
            if (this.mIsShowTipTextAsSingleLine) {
                canvas.translate(0.0f, this.mFramingRect.bottom + this.mTipTextMargin);
            } else {
                canvas.translate(this.mFramingRect.left + this.mTipBackgroundRadius, this.mFramingRect.bottom + this.mTipTextMargin);
            }
            this.mTipTextSl.draw(canvas);
            canvas.restore();
            return;
        }
        if (this.mIsShowTipBackground) {
            this.mPaint.setColor(this.mTipBackgroundColor);
            this.mPaint.setStyle(Paint.Style.FILL);
            if (this.mIsShowTipTextAsSingleLine) {
                Rect rect2 = new Rect();
                TextPaint textPaint2 = this.mTipPaint;
                String str2 = this.mTipText;
                textPaint2.getTextBounds(str2, 0, str2.length(), rect2);
                float width2 = ((canvas.getWidth() - rect2.width()) / 2) - this.mTipBackgroundRadius;
                RectF rectF3 = new RectF(width2, ((this.mFramingRect.top - this.mTipTextMargin) - this.mTipTextSl.getHeight()) - this.mTipBackgroundRadius, rect2.width() + width2 + (this.mTipBackgroundRadius * 2), (this.mFramingRect.top - this.mTipTextMargin) + this.mTipBackgroundRadius);
                int i4 = this.mTipBackgroundRadius;
                canvas.drawRoundRect(rectF3, i4, i4, this.mPaint);
            } else {
                RectF rectF4 = new RectF(this.mFramingRect.left, ((this.mFramingRect.top - this.mTipTextMargin) - this.mTipTextSl.getHeight()) - this.mTipBackgroundRadius, this.mFramingRect.right, (this.mFramingRect.top - this.mTipTextMargin) + this.mTipBackgroundRadius);
                int i5 = this.mTipBackgroundRadius;
                canvas.drawRoundRect(rectF4, i5, i5, this.mPaint);
            }
        }
        canvas.save();
        if (this.mIsShowTipTextAsSingleLine) {
            canvas.translate(0.0f, (this.mFramingRect.top - this.mTipTextMargin) - this.mTipTextSl.getHeight());
        } else {
            canvas.translate(this.mFramingRect.left + this.mTipBackgroundRadius, (this.mFramingRect.top - this.mTipTextMargin) - this.mTipTextSl.getHeight());
        }
        this.mTipTextSl.draw(canvas);
        canvas.restore();
    }

    private void moveScanLine() {
        if (this.mIsBarcode) {
            if (this.mGridScanLineBitmap == null) {
                this.mScanLineLeft += this.mMoveStepDistance;
                int i2 = this.mScanLineSize;
                Bitmap bitmap = this.mScanLineBitmap;
                if (bitmap != null) {
                    i2 = bitmap.getWidth();
                }
                if (this.mIsScanLineReverse) {
                    if (this.mScanLineLeft + i2 > this.mFramingRect.right - this.mHalfCornerSize || this.mScanLineLeft < this.mFramingRect.left + this.mHalfCornerSize) {
                        this.mMoveStepDistance = -this.mMoveStepDistance;
                    }
                } else if (this.mScanLineLeft + i2 > this.mFramingRect.right - this.mHalfCornerSize) {
                    this.mScanLineLeft = this.mFramingRect.left + this.mHalfCornerSize + 0.5f;
                }
            } else {
                float f2 = this.mGridScanLineRight + this.mMoveStepDistance;
                this.mGridScanLineRight = f2;
                if (f2 > this.mFramingRect.right - this.mHalfCornerSize) {
                    this.mGridScanLineRight = this.mFramingRect.left + this.mHalfCornerSize + 0.5f;
                }
            }
        } else if (this.mGridScanLineBitmap == null) {
            this.mScanLineTop += this.mMoveStepDistance;
            int i3 = this.mScanLineSize;
            Bitmap bitmap2 = this.mScanLineBitmap;
            if (bitmap2 != null) {
                i3 = bitmap2.getHeight();
            }
            if (this.mIsScanLineReverse) {
                if (this.mScanLineTop + i3 > this.mFramingRect.bottom - this.mHalfCornerSize || this.mScanLineTop < this.mFramingRect.top + this.mHalfCornerSize) {
                    this.mMoveStepDistance = -this.mMoveStepDistance;
                }
            } else if (this.mScanLineTop + i3 > this.mFramingRect.bottom - this.mHalfCornerSize) {
                this.mScanLineTop = this.mFramingRect.top + this.mHalfCornerSize + 0.5f;
            }
        } else {
            float f3 = this.mGridScanLineBottom + this.mMoveStepDistance;
            this.mGridScanLineBottom = f3;
            if (f3 > this.mFramingRect.bottom - this.mHalfCornerSize) {
                this.mGridScanLineBottom = this.mFramingRect.top + this.mHalfCornerSize + 0.5f;
            }
        }
        postInvalidateDelayed(this.mAnimDelayTime, this.mFramingRect.left, this.mFramingRect.top, this.mFramingRect.right, this.mFramingRect.bottom);
    }

    @Override // android.view.View
    protected void onSizeChanged(int i2, int i3, int i4, int i5) {
        super.onSizeChanged(i2, i3, i4, i5);
        calFramingRect();
    }

    private void calFramingRect() {
        int width = (getWidth() - this.mRectWidth) / 2;
        int i2 = this.mTopOffset;
        this.mFramingRect = new Rect(width, i2, this.mRectWidth + width, this.mRectHeight + i2);
        if (this.mIsBarcode) {
            float f2 = r1.left + this.mHalfCornerSize + 0.5f;
            this.mScanLineLeft = f2;
            this.mGridScanLineRight = f2;
        } else {
            float f3 = r1.top + this.mHalfCornerSize + 0.5f;
            this.mScanLineTop = f3;
            this.mGridScanLineBottom = f3;
        }
        if (this.mQRCodeView == null || !isOnlyDecodeScanBoxArea()) {
            return;
        }
        this.mQRCodeView.onScanBoxRectChanged(new Rect(this.mFramingRect));
    }

    public Rect getScanBoxAreaRect(int i2) {
        if (!this.mIsOnlyDecodeScanBoxArea || getVisibility() != 0) {
            return null;
        }
        Rect rect = new Rect(this.mFramingRect);
        float measuredHeight = (i2 * 1.0f) / getMeasuredHeight();
        float exactCenterX = rect.exactCenterX() * measuredHeight;
        float exactCenterY = rect.exactCenterY() * measuredHeight;
        float width = (rect.width() / 2.0f) * measuredHeight;
        float height = (rect.height() / 2.0f) * measuredHeight;
        rect.left = (int) (exactCenterX - width);
        rect.right = (int) (exactCenterX + width);
        rect.top = (int) (exactCenterY - height);
        rect.bottom = (int) (exactCenterY + height);
        return rect;
    }

    public void setIsBarcode(boolean z) {
        this.mIsBarcode = z;
        refreshScanBox();
    }

    private void refreshScanBox() {
        if (this.mCustomGridScanLineDrawable != null || this.mIsShowDefaultGridScanLineDrawable) {
            if (this.mIsBarcode) {
                this.mGridScanLineBitmap = this.mOriginBarCodeGridScanLineBitmap;
            } else {
                this.mGridScanLineBitmap = this.mOriginQRCodeGridScanLineBitmap;
            }
        } else if (this.mCustomScanLineDrawable != null || this.mIsShowDefaultScanLineDrawable) {
            if (this.mIsBarcode) {
                this.mScanLineBitmap = this.mOriginBarCodeScanLineBitmap;
            } else {
                this.mScanLineBitmap = this.mOriginQRCodeScanLineBitmap;
            }
        }
        if (this.mIsBarcode) {
            this.mTipText = this.mBarCodeTipText;
            this.mRectHeight = this.mBarcodeRectHeight;
            this.mAnimDelayTime = (int) (((this.mAnimTime * 1.0f) * this.mMoveStepDistance) / this.mRectWidth);
        } else {
            this.mTipText = this.mQRCodeTipText;
            int i2 = this.mRectWidth;
            this.mRectHeight = i2;
            this.mAnimDelayTime = (int) (((this.mAnimTime * 1.0f) * this.mMoveStepDistance) / i2);
        }
        if (!TextUtils.isEmpty(this.mTipText)) {
            if (this.mIsShowTipTextAsSingleLine) {
                this.mTipTextSl = new StaticLayout(this.mTipText, this.mTipPaint, BGAQRCodeUtil.getScreenResolution(getContext()).x, Layout.Alignment.ALIGN_CENTER, 1.0f, 0.0f, true);
            } else {
                this.mTipTextSl = new StaticLayout(this.mTipText, this.mTipPaint, this.mRectWidth - (this.mTipBackgroundRadius * 2), Layout.Alignment.ALIGN_CENTER, 1.0f, 0.0f, true);
            }
        }
        if (this.mVerticalBias != -1.0f) {
            int statusBarHeight = BGAQRCodeUtil.getScreenResolution(getContext()).y - BGAQRCodeUtil.getStatusBarHeight(getContext());
            int i3 = this.mToolbarHeight;
            if (i3 == 0) {
                this.mTopOffset = (int) ((statusBarHeight * this.mVerticalBias) - (this.mRectHeight / 2));
            } else {
                this.mTopOffset = i3 + ((int) (((statusBarHeight - i3) * this.mVerticalBias) - (this.mRectHeight / 2)));
            }
        }
        calFramingRect();
        postInvalidate();
    }

    public boolean getIsBarcode() {
        return this.mIsBarcode;
    }

    public int getMaskColor() {
        return this.mMaskColor;
    }

    public void setMaskColor(int i2) {
        this.mMaskColor = i2;
        refreshScanBox();
    }

    public int getCornerColor() {
        return this.mCornerColor;
    }

    public void setCornerColor(int i2) {
        this.mCornerColor = i2;
        refreshScanBox();
    }

    public int getCornerLength() {
        return this.mCornerLength;
    }

    public void setCornerLength(int i2) {
        this.mCornerLength = i2;
        refreshScanBox();
    }

    public int getCornerSize() {
        return this.mCornerSize;
    }

    public void setCornerSize(int i2) {
        this.mCornerSize = i2;
        refreshScanBox();
    }

    public int getRectWidth() {
        return this.mRectWidth;
    }

    public void setRectWidth(int i2) {
        this.mRectWidth = i2;
        refreshScanBox();
    }

    public int getRectHeight() {
        return this.mRectHeight;
    }

    public void setRectHeight(int i2) {
        this.mRectHeight = i2;
        refreshScanBox();
    }

    public int getBarcodeRectHeight() {
        return this.mBarcodeRectHeight;
    }

    public void setBarcodeRectHeight(int i2) {
        this.mBarcodeRectHeight = i2;
        refreshScanBox();
    }

    public int getTopOffset() {
        return this.mTopOffset;
    }

    public void setTopOffset(int i2) {
        this.mTopOffset = i2;
        refreshScanBox();
    }

    public int getScanLineSize() {
        return this.mScanLineSize;
    }

    public void setScanLineSize(int i2) {
        this.mScanLineSize = i2;
        refreshScanBox();
    }

    public int getScanLineColor() {
        return this.mScanLineColor;
    }

    public void setScanLineColor(int i2) {
        this.mScanLineColor = i2;
        refreshScanBox();
    }

    public int getScanLineMargin() {
        return this.mScanLineMargin;
    }

    public void setScanLineMargin(int i2) {
        this.mScanLineMargin = i2;
        refreshScanBox();
    }

    public boolean isShowDefaultScanLineDrawable() {
        return this.mIsShowDefaultScanLineDrawable;
    }

    public void setShowDefaultScanLineDrawable(boolean z) {
        this.mIsShowDefaultScanLineDrawable = z;
        refreshScanBox();
    }

    public Drawable getCustomScanLineDrawable() {
        return this.mCustomScanLineDrawable;
    }

    public void setCustomScanLineDrawable(Drawable drawable) {
        this.mCustomScanLineDrawable = drawable;
        refreshScanBox();
    }

    public Bitmap getScanLineBitmap() {
        return this.mScanLineBitmap;
    }

    public void setScanLineBitmap(Bitmap bitmap) {
        this.mScanLineBitmap = bitmap;
        refreshScanBox();
    }

    public int getBorderSize() {
        return this.mBorderSize;
    }

    public void setBorderSize(int i2) {
        this.mBorderSize = i2;
        refreshScanBox();
    }

    public int getBorderColor() {
        return this.mBorderColor;
    }

    public void setBorderColor(int i2) {
        this.mBorderColor = i2;
        refreshScanBox();
    }

    public int getAnimTime() {
        return this.mAnimTime;
    }

    public void setAnimTime(int i2) {
        this.mAnimTime = i2;
        refreshScanBox();
    }

    public float getVerticalBias() {
        return this.mVerticalBias;
    }

    public void setVerticalBias(float f2) {
        this.mVerticalBias = f2;
        refreshScanBox();
    }

    public int getToolbarHeight() {
        return this.mToolbarHeight;
    }

    public void setToolbarHeight(int i2) {
        this.mToolbarHeight = i2;
        refreshScanBox();
    }

    public String getQRCodeTipText() {
        return this.mQRCodeTipText;
    }

    public void setQRCodeTipText(String str) {
        this.mQRCodeTipText = str;
        refreshScanBox();
    }

    public String getBarCodeTipText() {
        return this.mBarCodeTipText;
    }

    public void setBarCodeTipText(String str) {
        this.mBarCodeTipText = str;
        refreshScanBox();
    }

    public String getTipText() {
        return this.mTipText;
    }

    public void setTipText(String str) {
        if (this.mIsBarcode) {
            this.mBarCodeTipText = str;
        } else {
            this.mQRCodeTipText = str;
        }
        refreshScanBox();
    }

    public int getTipTextColor() {
        return this.mTipTextColor;
    }

    public void setTipTextColor(int i2) {
        this.mTipTextColor = i2;
        this.mTipPaint.setColor(i2);
        refreshScanBox();
    }

    public int getTipTextSize() {
        return this.mTipTextSize;
    }

    public void setTipTextSize(int i2) {
        this.mTipTextSize = i2;
        this.mTipPaint.setTextSize(i2);
        refreshScanBox();
    }

    public boolean isTipTextBelowRect() {
        return this.mIsTipTextBelowRect;
    }

    public void setTipTextBelowRect(boolean z) {
        this.mIsTipTextBelowRect = z;
        refreshScanBox();
    }

    public int getTipTextMargin() {
        return this.mTipTextMargin;
    }

    public void setTipTextMargin(int i2) {
        this.mTipTextMargin = i2;
        refreshScanBox();
    }

    public boolean isShowTipTextAsSingleLine() {
        return this.mIsShowTipTextAsSingleLine;
    }

    public void setShowTipTextAsSingleLine(boolean z) {
        this.mIsShowTipTextAsSingleLine = z;
        refreshScanBox();
    }

    public boolean isShowTipBackground() {
        return this.mIsShowTipBackground;
    }

    public void setShowTipBackground(boolean z) {
        this.mIsShowTipBackground = z;
        refreshScanBox();
    }

    public int getTipBackgroundColor() {
        return this.mTipBackgroundColor;
    }

    public void setTipBackgroundColor(int i2) {
        this.mTipBackgroundColor = i2;
        refreshScanBox();
    }

    public boolean isScanLineReverse() {
        return this.mIsScanLineReverse;
    }

    public void setScanLineReverse(boolean z) {
        this.mIsScanLineReverse = z;
        refreshScanBox();
    }

    public boolean isShowDefaultGridScanLineDrawable() {
        return this.mIsShowDefaultGridScanLineDrawable;
    }

    public void setShowDefaultGridScanLineDrawable(boolean z) {
        this.mIsShowDefaultGridScanLineDrawable = z;
        refreshScanBox();
    }

    public float getHalfCornerSize() {
        return this.mHalfCornerSize;
    }

    public void setHalfCornerSize(float f2) {
        this.mHalfCornerSize = f2;
        refreshScanBox();
    }

    public StaticLayout getTipTextSl() {
        return this.mTipTextSl;
    }

    public void setTipTextSl(StaticLayout staticLayout) {
        this.mTipTextSl = staticLayout;
        refreshScanBox();
    }

    public int getTipBackgroundRadius() {
        return this.mTipBackgroundRadius;
    }

    public void setTipBackgroundRadius(int i2) {
        this.mTipBackgroundRadius = i2;
        refreshScanBox();
    }

    public boolean isOnlyDecodeScanBoxArea() {
        return this.mIsOnlyDecodeScanBoxArea;
    }

    public void setOnlyDecodeScanBoxArea(boolean z) {
        this.mIsOnlyDecodeScanBoxArea = z;
        calFramingRect();
    }

    public boolean isShowLocationPoint() {
        return this.mIsShowLocationPoint;
    }

    public void setShowLocationPoint(boolean z) {
        this.mIsShowLocationPoint = z;
    }

    public boolean isAutoZoom() {
        return this.mIsAutoZoom;
    }

    public void setAutoZoom(boolean z) {
        this.mIsAutoZoom = z;
    }
}
