package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.TypeUtils;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/* loaded from: classes.dex */
public class JavaBeanSerializer extends SerializeFilterable implements ObjectSerializer {
    protected final SerializeBeanInfo beanInfo;
    protected final FieldSerializer[] getters;
    private volatile transient long[] hashArray;
    private volatile transient short[] hashArrayMapping;
    protected final FieldSerializer[] sortedGetters;

    /* JADX WARN: 'this' call moved to the top of the method (can break code semantics) */
    public JavaBeanSerializer(Class<?> cls) {
        this(cls, (Map<String, String>) null);
    }

    public JavaBeanSerializer(Class<?> cls, String... strArr) {
        this(cls, createAliasMap(strArr));
    }

    static Map<String, String> createAliasMap(String... strArr) {
        HashMap hashMap = new HashMap();
        for (String str : strArr) {
            hashMap.put(str, str);
        }
        return hashMap;
    }

    public JSONType getJSONType() {
        return this.beanInfo.jsonType;
    }

    public Class<?> getType() {
        return this.beanInfo.beanType;
    }

    public JavaBeanSerializer(Class<?> cls, Map<String, String> map) {
        this(TypeUtils.buildBeanInfo(cls, map, null));
    }

    public JavaBeanSerializer(SerializeBeanInfo serializeBeanInfo) {
        boolean z;
        this.beanInfo = serializeBeanInfo;
        this.sortedGetters = new FieldSerializer[serializeBeanInfo.sortedFields.length];
        int i2 = 0;
        while (true) {
            FieldSerializer[] fieldSerializerArr = this.sortedGetters;
            if (i2 >= fieldSerializerArr.length) {
                break;
            }
            fieldSerializerArr[i2] = new FieldSerializer(serializeBeanInfo.beanType, serializeBeanInfo.sortedFields[i2]);
            i2++;
        }
        if (serializeBeanInfo.fields == serializeBeanInfo.sortedFields) {
            this.getters = this.sortedGetters;
        } else {
            this.getters = new FieldSerializer[serializeBeanInfo.fields.length];
            int i3 = 0;
            while (true) {
                if (i3 >= this.getters.length) {
                    z = false;
                    break;
                }
                FieldSerializer fieldSerializer = getFieldSerializer(serializeBeanInfo.fields[i3].name);
                if (fieldSerializer == null) {
                    z = true;
                    break;
                } else {
                    this.getters[i3] = fieldSerializer;
                    i3++;
                }
            }
            if (z) {
                FieldSerializer[] fieldSerializerArr2 = this.sortedGetters;
                System.arraycopy(fieldSerializerArr2, 0, this.getters, 0, fieldSerializerArr2.length);
            }
        }
        if (serializeBeanInfo.jsonType != null) {
            for (Class<? extends SerializeFilter> cls : serializeBeanInfo.jsonType.serialzeFilters()) {
                try {
                    addFilter(cls.getConstructor(new Class[0]).newInstance(new Object[0]));
                } catch (Exception unused) {
                }
            }
        }
    }

    public void writeDirectNonContext(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i2) throws IOException {
        write(jSONSerializer, obj, obj2, type, i2);
    }

    public void writeAsArray(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i2) throws IOException {
        write(jSONSerializer, obj, obj2, type, i2);
    }

    public void writeAsArrayNonContext(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i2) throws IOException {
        write(jSONSerializer, obj, obj2, type, i2);
    }

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public void write(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i2) throws IOException {
        write(jSONSerializer, obj, obj2, type, i2, false);
    }

    public void writeNoneASM(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i2) throws IOException {
        write(jSONSerializer, obj, obj2, type, i2, false);
    }

    /* JADX WARN: Code restructure failed: missing block: B:301:0x048c, code lost:
    
        if (r5 == 0) goto L336;
     */
    /* JADX WARN: Code restructure failed: missing block: B:393:0x0101, code lost:
    
        if (r13.fieldTransient != false) goto L105;
     */
    /* JADX WARN: Removed duplicated region for block: B:111:0x015b  */
    /* JADX WARN: Removed duplicated region for block: B:283:0x045f A[Catch: Exception -> 0x0495, all -> 0x04f3, TryCatch #2 {Exception -> 0x0495, blocks: (B:121:0x0194, B:124:0x019c, B:126:0x01a8, B:128:0x01b7, B:130:0x01c1, B:133:0x01cb, B:135:0x01d6, B:137:0x01da, B:142:0x01e1, B:144:0x01e5, B:145:0x01eb, B:147:0x01f0, B:149:0x01f7, B:152:0x0201, B:154:0x020c, B:156:0x0210, B:159:0x0217, B:162:0x021e, B:164:0x0223, B:167:0x022b, B:169:0x0233, B:171:0x023e, B:173:0x0242, B:176:0x0249, B:178:0x024d, B:179:0x0252, B:181:0x0257, B:183:0x025e, B:184:0x0263, B:186:0x026b, B:188:0x0276, B:190:0x027a, B:193:0x0281, B:195:0x0285, B:196:0x028a, B:198:0x028f, B:200:0x0296, B:202:0x029d, B:204:0x02a1, B:206:0x02ab, B:210:0x02b6, B:212:0x02ba, B:214:0x02c3, B:216:0x02ce, B:218:0x02d4, B:220:0x02d8, B:223:0x02e3, B:225:0x02e7, B:227:0x02eb, B:230:0x02f6, B:232:0x02fa, B:234:0x02fe, B:237:0x0309, B:239:0x030d, B:241:0x0311, B:244:0x031f, B:246:0x0323, B:248:0x0327, B:251:0x0334, B:253:0x0338, B:255:0x033c, B:258:0x034a, B:260:0x034e, B:262:0x0352, B:266:0x035e, B:268:0x0362, B:270:0x0366, B:272:0x0374, B:274:0x037f, B:278:0x0388, B:279:0x038e, B:281:0x045b, B:283:0x045f, B:285:0x0463, B:292:0x046d, B:294:0x0475, B:295:0x047d, B:297:0x0483, B:310:0x039c, B:311:0x039f, B:313:0x03a5, B:315:0x03b1, B:319:0x03c7, B:324:0x03d1, B:326:0x03e6, B:329:0x03f0, B:332:0x03fa, B:334:0x0402, B:335:0x040f, B:337:0x0418, B:339:0x041f, B:340:0x0423, B:342:0x042a, B:343:0x042e, B:344:0x0432, B:346:0x0437, B:347:0x043b, B:348:0x043f, B:350:0x0443, B:352:0x0447, B:356:0x0454, B:357:0x0458, B:358:0x03dc), top: B:120:0x0194 }] */
    /* JADX WARN: Removed duplicated region for block: B:289:0x0492  */
    /* JADX WARN: Removed duplicated region for block: B:291:0x04ac A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:292:0x046d A[Catch: Exception -> 0x0495, all -> 0x04f3, TryCatch #2 {Exception -> 0x0495, blocks: (B:121:0x0194, B:124:0x019c, B:126:0x01a8, B:128:0x01b7, B:130:0x01c1, B:133:0x01cb, B:135:0x01d6, B:137:0x01da, B:142:0x01e1, B:144:0x01e5, B:145:0x01eb, B:147:0x01f0, B:149:0x01f7, B:152:0x0201, B:154:0x020c, B:156:0x0210, B:159:0x0217, B:162:0x021e, B:164:0x0223, B:167:0x022b, B:169:0x0233, B:171:0x023e, B:173:0x0242, B:176:0x0249, B:178:0x024d, B:179:0x0252, B:181:0x0257, B:183:0x025e, B:184:0x0263, B:186:0x026b, B:188:0x0276, B:190:0x027a, B:193:0x0281, B:195:0x0285, B:196:0x028a, B:198:0x028f, B:200:0x0296, B:202:0x029d, B:204:0x02a1, B:206:0x02ab, B:210:0x02b6, B:212:0x02ba, B:214:0x02c3, B:216:0x02ce, B:218:0x02d4, B:220:0x02d8, B:223:0x02e3, B:225:0x02e7, B:227:0x02eb, B:230:0x02f6, B:232:0x02fa, B:234:0x02fe, B:237:0x0309, B:239:0x030d, B:241:0x0311, B:244:0x031f, B:246:0x0323, B:248:0x0327, B:251:0x0334, B:253:0x0338, B:255:0x033c, B:258:0x034a, B:260:0x034e, B:262:0x0352, B:266:0x035e, B:268:0x0362, B:270:0x0366, B:272:0x0374, B:274:0x037f, B:278:0x0388, B:279:0x038e, B:281:0x045b, B:283:0x045f, B:285:0x0463, B:292:0x046d, B:294:0x0475, B:295:0x047d, B:297:0x0483, B:310:0x039c, B:311:0x039f, B:313:0x03a5, B:315:0x03b1, B:319:0x03c7, B:324:0x03d1, B:326:0x03e6, B:329:0x03f0, B:332:0x03fa, B:334:0x0402, B:335:0x040f, B:337:0x0418, B:339:0x041f, B:340:0x0423, B:342:0x042a, B:343:0x042e, B:344:0x0432, B:346:0x0437, B:347:0x043b, B:348:0x043f, B:350:0x0443, B:352:0x0447, B:356:0x0454, B:357:0x0458, B:358:0x03dc), top: B:120:0x0194 }] */
    /* JADX WARN: Removed duplicated region for block: B:326:0x03e6 A[Catch: Exception -> 0x0495, all -> 0x04f3, TryCatch #2 {Exception -> 0x0495, blocks: (B:121:0x0194, B:124:0x019c, B:126:0x01a8, B:128:0x01b7, B:130:0x01c1, B:133:0x01cb, B:135:0x01d6, B:137:0x01da, B:142:0x01e1, B:144:0x01e5, B:145:0x01eb, B:147:0x01f0, B:149:0x01f7, B:152:0x0201, B:154:0x020c, B:156:0x0210, B:159:0x0217, B:162:0x021e, B:164:0x0223, B:167:0x022b, B:169:0x0233, B:171:0x023e, B:173:0x0242, B:176:0x0249, B:178:0x024d, B:179:0x0252, B:181:0x0257, B:183:0x025e, B:184:0x0263, B:186:0x026b, B:188:0x0276, B:190:0x027a, B:193:0x0281, B:195:0x0285, B:196:0x028a, B:198:0x028f, B:200:0x0296, B:202:0x029d, B:204:0x02a1, B:206:0x02ab, B:210:0x02b6, B:212:0x02ba, B:214:0x02c3, B:216:0x02ce, B:218:0x02d4, B:220:0x02d8, B:223:0x02e3, B:225:0x02e7, B:227:0x02eb, B:230:0x02f6, B:232:0x02fa, B:234:0x02fe, B:237:0x0309, B:239:0x030d, B:241:0x0311, B:244:0x031f, B:246:0x0323, B:248:0x0327, B:251:0x0334, B:253:0x0338, B:255:0x033c, B:258:0x034a, B:260:0x034e, B:262:0x0352, B:266:0x035e, B:268:0x0362, B:270:0x0366, B:272:0x0374, B:274:0x037f, B:278:0x0388, B:279:0x038e, B:281:0x045b, B:283:0x045f, B:285:0x0463, B:292:0x046d, B:294:0x0475, B:295:0x047d, B:297:0x0483, B:310:0x039c, B:311:0x039f, B:313:0x03a5, B:315:0x03b1, B:319:0x03c7, B:324:0x03d1, B:326:0x03e6, B:329:0x03f0, B:332:0x03fa, B:334:0x0402, B:335:0x040f, B:337:0x0418, B:339:0x041f, B:340:0x0423, B:342:0x042a, B:343:0x042e, B:344:0x0432, B:346:0x0437, B:347:0x043b, B:348:0x043f, B:350:0x0443, B:352:0x0447, B:356:0x0454, B:357:0x0458, B:358:0x03dc), top: B:120:0x0194 }] */
    /* JADX WARN: Removed duplicated region for block: B:357:0x0458 A[Catch: Exception -> 0x0495, all -> 0x04f3, TryCatch #2 {Exception -> 0x0495, blocks: (B:121:0x0194, B:124:0x019c, B:126:0x01a8, B:128:0x01b7, B:130:0x01c1, B:133:0x01cb, B:135:0x01d6, B:137:0x01da, B:142:0x01e1, B:144:0x01e5, B:145:0x01eb, B:147:0x01f0, B:149:0x01f7, B:152:0x0201, B:154:0x020c, B:156:0x0210, B:159:0x0217, B:162:0x021e, B:164:0x0223, B:167:0x022b, B:169:0x0233, B:171:0x023e, B:173:0x0242, B:176:0x0249, B:178:0x024d, B:179:0x0252, B:181:0x0257, B:183:0x025e, B:184:0x0263, B:186:0x026b, B:188:0x0276, B:190:0x027a, B:193:0x0281, B:195:0x0285, B:196:0x028a, B:198:0x028f, B:200:0x0296, B:202:0x029d, B:204:0x02a1, B:206:0x02ab, B:210:0x02b6, B:212:0x02ba, B:214:0x02c3, B:216:0x02ce, B:218:0x02d4, B:220:0x02d8, B:223:0x02e3, B:225:0x02e7, B:227:0x02eb, B:230:0x02f6, B:232:0x02fa, B:234:0x02fe, B:237:0x0309, B:239:0x030d, B:241:0x0311, B:244:0x031f, B:246:0x0323, B:248:0x0327, B:251:0x0334, B:253:0x0338, B:255:0x033c, B:258:0x034a, B:260:0x034e, B:262:0x0352, B:266:0x035e, B:268:0x0362, B:270:0x0366, B:272:0x0374, B:274:0x037f, B:278:0x0388, B:279:0x038e, B:281:0x045b, B:283:0x045f, B:285:0x0463, B:292:0x046d, B:294:0x0475, B:295:0x047d, B:297:0x0483, B:310:0x039c, B:311:0x039f, B:313:0x03a5, B:315:0x03b1, B:319:0x03c7, B:324:0x03d1, B:326:0x03e6, B:329:0x03f0, B:332:0x03fa, B:334:0x0402, B:335:0x040f, B:337:0x0418, B:339:0x041f, B:340:0x0423, B:342:0x042a, B:343:0x042e, B:344:0x0432, B:346:0x0437, B:347:0x043b, B:348:0x043f, B:350:0x0443, B:352:0x0447, B:356:0x0454, B:357:0x0458, B:358:0x03dc), top: B:120:0x0194 }] */
    /* JADX WARN: Removed duplicated region for block: B:35:0x054e A[Catch: all -> 0x05cf, TRY_ENTER, TryCatch #5 {all -> 0x05cf, blocks: (B:58:0x052c, B:35:0x054e, B:36:0x059e, B:38:0x05a4, B:39:0x05bc, B:41:0x05c0, B:44:0x05c9, B:45:0x05ce, B:51:0x0563, B:53:0x0567, B:55:0x056d, B:56:0x0588), top: B:57:0x052c }] */
    /* JADX WARN: Removed duplicated region for block: B:38:0x05a4 A[Catch: all -> 0x05cf, TryCatch #5 {all -> 0x05cf, blocks: (B:58:0x052c, B:35:0x054e, B:36:0x059e, B:38:0x05a4, B:39:0x05bc, B:41:0x05c0, B:44:0x05c9, B:45:0x05ce, B:51:0x0563, B:53:0x0567, B:55:0x056d, B:56:0x0588), top: B:57:0x052c }] */
    /* JADX WARN: Removed duplicated region for block: B:408:0x04d9  */
    /* JADX WARN: Removed duplicated region for block: B:413:0x0502 A[Catch: all -> 0x04f3, Exception -> 0x04f9, TRY_LEAVE, TryCatch #8 {all -> 0x04f3, blocks: (B:121:0x0194, B:124:0x019c, B:126:0x01a8, B:128:0x01b7, B:130:0x01c1, B:133:0x01cb, B:135:0x01d6, B:137:0x01da, B:142:0x01e1, B:144:0x01e5, B:145:0x01eb, B:147:0x01f0, B:149:0x01f7, B:152:0x0201, B:154:0x020c, B:156:0x0210, B:159:0x0217, B:162:0x021e, B:164:0x0223, B:167:0x022b, B:169:0x0233, B:171:0x023e, B:173:0x0242, B:176:0x0249, B:178:0x024d, B:179:0x0252, B:181:0x0257, B:183:0x025e, B:184:0x0263, B:186:0x026b, B:188:0x0276, B:190:0x027a, B:193:0x0281, B:195:0x0285, B:196:0x028a, B:198:0x028f, B:200:0x0296, B:202:0x029d, B:204:0x02a1, B:206:0x02ab, B:210:0x02b6, B:212:0x02ba, B:214:0x02c3, B:216:0x02ce, B:218:0x02d4, B:220:0x02d8, B:223:0x02e3, B:225:0x02e7, B:227:0x02eb, B:230:0x02f6, B:232:0x02fa, B:234:0x02fe, B:237:0x0309, B:239:0x030d, B:241:0x0311, B:244:0x031f, B:246:0x0323, B:248:0x0327, B:251:0x0334, B:253:0x0338, B:255:0x033c, B:258:0x034a, B:260:0x034e, B:262:0x0352, B:266:0x035e, B:268:0x0362, B:270:0x0366, B:272:0x0374, B:274:0x037f, B:278:0x0388, B:279:0x038e, B:281:0x045b, B:283:0x045f, B:285:0x0463, B:292:0x046d, B:294:0x0475, B:295:0x047d, B:297:0x0483, B:310:0x039c, B:311:0x039f, B:313:0x03a5, B:315:0x03b1, B:319:0x03c7, B:324:0x03d1, B:326:0x03e6, B:329:0x03f0, B:332:0x03fa, B:334:0x0402, B:335:0x040f, B:337:0x0418, B:339:0x041f, B:340:0x0423, B:342:0x042a, B:343:0x042e, B:344:0x0432, B:346:0x0437, B:347:0x043b, B:348:0x043f, B:350:0x0443, B:352:0x0447, B:356:0x0454, B:357:0x0458, B:358:0x03dc, B:382:0x049d, B:419:0x04e4, B:421:0x04ec, B:413:0x0502), top: B:120:0x0194 }] */
    /* JADX WARN: Removed duplicated region for block: B:418:0x04e4 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:41:0x05c0 A[Catch: all -> 0x05cf, TryCatch #5 {all -> 0x05cf, blocks: (B:58:0x052c, B:35:0x054e, B:36:0x059e, B:38:0x05a4, B:39:0x05bc, B:41:0x05c0, B:44:0x05c9, B:45:0x05ce, B:51:0x0563, B:53:0x0567, B:55:0x056d, B:56:0x0588), top: B:57:0x052c }] */
    /* JADX WARN: Removed duplicated region for block: B:428:0x04db  */
    /* JADX WARN: Removed duplicated region for block: B:433:0x00c1  */
    /* JADX WARN: Removed duplicated region for block: B:434:0x00b2  */
    /* JADX WARN: Removed duplicated region for block: B:43:0x05c6  */
    /* JADX WARN: Removed duplicated region for block: B:49:0x05c7  */
    /* JADX WARN: Removed duplicated region for block: B:50:0x0561  */
    /* JADX WARN: Removed duplicated region for block: B:57:0x052c A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:75:0x00b0  */
    /* JADX WARN: Removed duplicated region for block: B:78:0x00bf  */
    /* JADX WARN: Removed duplicated region for block: B:84:0x00d6 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    protected void write(com.alibaba.fastjson.serializer.JSONSerializer r34, java.lang.Object r35, java.lang.Object r36, java.lang.reflect.Type r37, int r38, boolean r39) throws java.io.IOException {
        /*
            Method dump skipped, instructions count: 1493
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.alibaba.fastjson.serializer.JavaBeanSerializer.write(com.alibaba.fastjson.serializer.JSONSerializer, java.lang.Object, java.lang.Object, java.lang.reflect.Type, int, boolean):void");
    }

    protected void writeClassName(JSONSerializer jSONSerializer, String str, Object obj) {
        if (str == null) {
            str = jSONSerializer.config.typeKey;
        }
        jSONSerializer.out.writeFieldName(str, false);
        String str2 = this.beanInfo.typeName;
        if (str2 == null) {
            Class<?> cls = obj.getClass();
            if (TypeUtils.isProxy(cls)) {
                cls = cls.getSuperclass();
            }
            str2 = cls.getName();
        }
        jSONSerializer.write(str2);
    }

    public boolean writeReference(JSONSerializer jSONSerializer, Object obj, int i2) {
        SerialContext serialContext = jSONSerializer.context;
        int i3 = SerializerFeature.DisableCircularReferenceDetect.mask;
        if (serialContext == null || (serialContext.features & i3) != 0 || (i2 & i3) != 0 || jSONSerializer.references == null || !jSONSerializer.references.containsKey(obj)) {
            return false;
        }
        jSONSerializer.writeReference(obj);
        return true;
    }

    protected boolean isWriteAsArray(JSONSerializer jSONSerializer) {
        return isWriteAsArray(jSONSerializer, 0);
    }

    protected boolean isWriteAsArray(JSONSerializer jSONSerializer, int i2) {
        int i3 = SerializerFeature.BeanToArray.mask;
        return ((this.beanInfo.features & i3) == 0 && !jSONSerializer.out.beanToArray && (i2 & i3) == 0) ? false : true;
    }

    public Object getFieldValue(Object obj, String str) {
        FieldSerializer fieldSerializer = getFieldSerializer(str);
        if (fieldSerializer == null) {
            throw new JSONException("field not found. " + str);
        }
        try {
            return fieldSerializer.getPropertyValue(obj);
        } catch (IllegalAccessException e2) {
            throw new JSONException("getFieldValue error." + str, e2);
        } catch (InvocationTargetException e3) {
            throw new JSONException("getFieldValue error." + str, e3);
        }
    }

    public Object getFieldValue(Object obj, String str, long j2, boolean z) {
        FieldSerializer fieldSerializer = getFieldSerializer(j2);
        if (fieldSerializer == null) {
            if (!z) {
                return null;
            }
            throw new JSONException("field not found. " + str);
        }
        try {
            return fieldSerializer.getPropertyValue(obj);
        } catch (IllegalAccessException e2) {
            throw new JSONException("getFieldValue error." + str, e2);
        } catch (InvocationTargetException e3) {
            throw new JSONException("getFieldValue error." + str, e3);
        }
    }

    public FieldSerializer getFieldSerializer(String str) {
        if (str == null) {
            return null;
        }
        int length = this.sortedGetters.length - 1;
        int i2 = 0;
        while (i2 <= length) {
            int i3 = (i2 + length) >>> 1;
            int compareTo = this.sortedGetters[i3].fieldInfo.name.compareTo(str);
            if (compareTo < 0) {
                i2 = i3 + 1;
            } else {
                if (compareTo <= 0) {
                    return this.sortedGetters[i3];
                }
                length = i3 - 1;
            }
        }
        return null;
    }

    public FieldSerializer getFieldSerializer(long j2) {
        PropertyNamingStrategy[] propertyNamingStrategyArr;
        int binarySearch;
        if (this.hashArray == null) {
            propertyNamingStrategyArr = PropertyNamingStrategy.values();
            long[] jArr = new long[this.sortedGetters.length * propertyNamingStrategyArr.length];
            int i2 = 0;
            int i3 = 0;
            while (true) {
                FieldSerializer[] fieldSerializerArr = this.sortedGetters;
                if (i2 >= fieldSerializerArr.length) {
                    break;
                }
                String str = fieldSerializerArr[i2].fieldInfo.name;
                jArr[i3] = TypeUtils.fnv1a_64(str);
                i3++;
                for (PropertyNamingStrategy propertyNamingStrategy : propertyNamingStrategyArr) {
                    String translate = propertyNamingStrategy.translate(str);
                    if (!str.equals(translate)) {
                        jArr[i3] = TypeUtils.fnv1a_64(translate);
                        i3++;
                    }
                }
                i2++;
            }
            Arrays.sort(jArr, 0, i3);
            this.hashArray = new long[i3];
            System.arraycopy(jArr, 0, this.hashArray, 0, i3);
        } else {
            propertyNamingStrategyArr = null;
        }
        int binarySearch2 = Arrays.binarySearch(this.hashArray, j2);
        if (binarySearch2 < 0) {
            return null;
        }
        if (this.hashArrayMapping == null) {
            if (propertyNamingStrategyArr == null) {
                propertyNamingStrategyArr = PropertyNamingStrategy.values();
            }
            short[] sArr = new short[this.hashArray.length];
            Arrays.fill(sArr, (short) -1);
            int i4 = 0;
            while (true) {
                FieldSerializer[] fieldSerializerArr2 = this.sortedGetters;
                if (i4 >= fieldSerializerArr2.length) {
                    break;
                }
                String str2 = fieldSerializerArr2[i4].fieldInfo.name;
                int binarySearch3 = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(str2));
                if (binarySearch3 >= 0) {
                    sArr[binarySearch3] = (short) i4;
                }
                for (PropertyNamingStrategy propertyNamingStrategy2 : propertyNamingStrategyArr) {
                    String translate2 = propertyNamingStrategy2.translate(str2);
                    if (!str2.equals(translate2) && (binarySearch = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(translate2))) >= 0) {
                        sArr[binarySearch] = (short) i4;
                    }
                }
                i4++;
            }
            this.hashArrayMapping = sArr;
        }
        short s = this.hashArrayMapping[binarySearch2];
        if (s != -1) {
            return this.sortedGetters[s];
        }
        return null;
    }

    public List<Object> getFieldValues(Object obj) throws Exception {
        ArrayList arrayList = new ArrayList(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            arrayList.add(fieldSerializer.getPropertyValue(obj));
        }
        return arrayList;
    }

    public List<Object> getObjectFieldValues(Object obj) throws Exception {
        ArrayList arrayList = new ArrayList(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            Class<?> cls = fieldSerializer.fieldInfo.fieldClass;
            if (!cls.isPrimitive() && !cls.getName().startsWith("java.lang.")) {
                arrayList.add(fieldSerializer.getPropertyValue(obj));
            }
        }
        return arrayList;
    }

    public int getSize(Object obj) throws Exception {
        int i2 = 0;
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            if (fieldSerializer.getPropertyValueDirect(obj) != null) {
                i2++;
            }
        }
        return i2;
    }

    public Set<String> getFieldNames(Object obj) throws Exception {
        HashSet hashSet = new HashSet();
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            if (fieldSerializer.getPropertyValueDirect(obj) != null) {
                hashSet.add(fieldSerializer.fieldInfo.name);
            }
        }
        return hashSet;
    }

    public Map<String, Object> getFieldValuesMap(Object obj) throws Exception {
        LinkedHashMap linkedHashMap = new LinkedHashMap(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            boolean isEnabled = SerializerFeature.isEnabled(fieldSerializer.features, SerializerFeature.SkipTransientField);
            FieldInfo fieldInfo = fieldSerializer.fieldInfo;
            if (!isEnabled || fieldInfo == null || !fieldInfo.fieldTransient) {
                if (fieldSerializer.fieldInfo.unwrapped) {
                    Object json = JSON.toJSON(fieldSerializer.getPropertyValue(obj));
                    if (json instanceof Map) {
                        linkedHashMap.putAll((Map) json);
                    } else {
                        linkedHashMap.put(fieldSerializer.fieldInfo.name, fieldSerializer.getPropertyValue(obj));
                    }
                } else {
                    linkedHashMap.put(fieldSerializer.fieldInfo.name, fieldSerializer.getPropertyValue(obj));
                }
            }
        }
        return linkedHashMap;
    }

    protected BeanContext getBeanContext(int i2) {
        return this.sortedGetters[i2].fieldContext;
    }

    protected Type getFieldType(int i2) {
        return this.sortedGetters[i2].fieldInfo.fieldType;
    }

    protected char writeBefore(JSONSerializer jSONSerializer, Object obj, char c2) {
        if (jSONSerializer.beforeFilters != null) {
            Iterator<BeforeFilter> it2 = jSONSerializer.beforeFilters.iterator();
            while (it2.hasNext()) {
                c2 = it2.next().writeBefore(jSONSerializer, obj, c2);
            }
        }
        if (this.beforeFilters != null) {
            Iterator<BeforeFilter> it3 = this.beforeFilters.iterator();
            while (it3.hasNext()) {
                c2 = it3.next().writeBefore(jSONSerializer, obj, c2);
            }
        }
        return c2;
    }

    protected char writeAfter(JSONSerializer jSONSerializer, Object obj, char c2) {
        if (jSONSerializer.afterFilters != null) {
            Iterator<AfterFilter> it2 = jSONSerializer.afterFilters.iterator();
            while (it2.hasNext()) {
                c2 = it2.next().writeAfter(jSONSerializer, obj, c2);
            }
        }
        if (this.afterFilters != null) {
            Iterator<AfterFilter> it3 = this.afterFilters.iterator();
            while (it3.hasNext()) {
                c2 = it3.next().writeAfter(jSONSerializer, obj, c2);
            }
        }
        return c2;
    }

    protected boolean applyLabel(JSONSerializer jSONSerializer, String str) {
        if (jSONSerializer.labelFilters != null) {
            Iterator<LabelFilter> it2 = jSONSerializer.labelFilters.iterator();
            while (it2.hasNext()) {
                if (!it2.next().apply(str)) {
                    return false;
                }
            }
        }
        if (this.labelFilters == null) {
            return true;
        }
        Iterator<LabelFilter> it3 = this.labelFilters.iterator();
        while (it3.hasNext()) {
            if (!it3.next().apply(str)) {
                return false;
            }
        }
        return true;
    }
}
