package com.amap.api.services.route;

import android.content.Context;
import android.os.Parcel;
import android.os.Parcelable;
import com.amap.api.col.p0003sl.fm;
import com.amap.api.col.p0003sl.hi;
import com.amap.api.services.core.AMapException;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.interfaces.IDistanceSearch;
import java.util.ArrayList;
import java.util.List;

/* loaded from: classes.dex */
public class DistanceSearch {
    public static final String EXTENSIONS_ALL = "all";
    public static final String EXTENSIONS_BASE = "base";
    public static final int TYPE_DISTANCE = 0;
    public static final int TYPE_DRIVING_DISTANCE = 1;
    public static final int TYPE_WALK_DISTANCE = 3;

    /* renamed from: a, reason: collision with root package name */
    private IDistanceSearch f2612a;

    public interface OnDistanceSearchListener {
        void onDistanceSearched(DistanceResult distanceResult, int i2);
    }

    public DistanceSearch(Context context) throws AMapException {
        if (this.f2612a == null) {
            try {
                this.f2612a = new hi(context);
            } catch (Exception e2) {
                e2.printStackTrace();
                if (e2 instanceof AMapException) {
                    throw ((AMapException) e2);
                }
            }
        }
    }

    public void setDistanceSearchListener(OnDistanceSearchListener onDistanceSearchListener) {
        IDistanceSearch iDistanceSearch = this.f2612a;
        if (iDistanceSearch != null) {
            iDistanceSearch.setDistanceSearchListener(onDistanceSearchListener);
        }
    }

    public DistanceResult calculateRouteDistance(DistanceQuery distanceQuery) throws AMapException {
        IDistanceSearch iDistanceSearch = this.f2612a;
        if (iDistanceSearch != null) {
            return iDistanceSearch.calculateRouteDistance(distanceQuery);
        }
        return null;
    }

    public void calculateRouteDistanceAsyn(DistanceQuery distanceQuery) {
        IDistanceSearch iDistanceSearch = this.f2612a;
        if (iDistanceSearch != null) {
            iDistanceSearch.calculateRouteDistanceAsyn(distanceQuery);
        }
    }

    public static class DistanceQuery implements Parcelable, Cloneable {
        public static final Parcelable.Creator<DistanceQuery> CREATOR = new Parcelable.Creator<DistanceQuery>() { // from class: com.amap.api.services.route.DistanceSearch.DistanceQuery.1
            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ DistanceQuery createFromParcel(Parcel parcel) {
                return a(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ DistanceQuery[] newArray(int i2) {
                return a(i2);
            }

            private static DistanceQuery a(Parcel parcel) {
                return new DistanceQuery(parcel);
            }

            private static DistanceQuery[] a(int i2) {
                return new DistanceQuery[i2];
            }
        };

        /* renamed from: a, reason: collision with root package name */
        private int f2613a;

        /* renamed from: b, reason: collision with root package name */
        private List<LatLonPoint> f2614b;

        /* renamed from: c, reason: collision with root package name */
        private LatLonPoint f2615c;

        /* renamed from: d, reason: collision with root package name */
        private String f2616d;

        /* renamed from: e, reason: collision with root package name */
        private int f2617e;

        @Override // android.os.Parcelable
        public int describeContents() {
            return 0;
        }

        public DistanceQuery() {
            this.f2613a = 1;
            this.f2614b = new ArrayList();
            this.f2616d = "base";
            this.f2617e = 4;
        }

        protected DistanceQuery(Parcel parcel) {
            this.f2613a = 1;
            this.f2614b = new ArrayList();
            this.f2616d = "base";
            this.f2617e = 4;
            this.f2613a = parcel.readInt();
            this.f2614b = parcel.createTypedArrayList(LatLonPoint.CREATOR);
            this.f2615c = (LatLonPoint) parcel.readParcelable(LatLonPoint.class.getClassLoader());
            this.f2616d = parcel.readString();
            this.f2617e = parcel.readInt();
        }

        /* renamed from: clone, reason: merged with bridge method [inline-methods] */
        public DistanceQuery m86clone() {
            try {
                super.clone();
            } catch (CloneNotSupportedException e2) {
                fm.a(e2, "DistanceSearch", "DistanceQueryclone");
            }
            DistanceQuery distanceQuery = new DistanceQuery();
            distanceQuery.setType(this.f2613a);
            distanceQuery.setOrigins(this.f2614b);
            distanceQuery.setDestination(this.f2615c);
            distanceQuery.setExtensions(this.f2616d);
            distanceQuery.setMode(this.f2617e);
            return distanceQuery;
        }

        @Override // android.os.Parcelable
        public void writeToParcel(Parcel parcel, int i2) {
            parcel.writeInt(this.f2613a);
            parcel.writeTypedList(this.f2614b);
            parcel.writeParcelable(this.f2615c, i2);
            parcel.writeString(this.f2616d);
            parcel.writeInt(this.f2617e);
        }

        public int getType() {
            return this.f2613a;
        }

        public List<LatLonPoint> getOrigins() {
            return this.f2614b;
        }

        public LatLonPoint getDestination() {
            return this.f2615c;
        }

        public void setType(int i2) {
            this.f2613a = i2;
        }

        public void setOrigins(List<LatLonPoint> list) {
            if (list != null) {
                this.f2614b = list;
            }
        }

        public void addOrigins(LatLonPoint... latLonPointArr) {
            for (LatLonPoint latLonPoint : latLonPointArr) {
                if (latLonPoint != null) {
                    this.f2614b.add(latLonPoint);
                }
            }
        }

        public void setDestination(LatLonPoint latLonPoint) {
            this.f2615c = latLonPoint;
        }

        public String getExtensions() {
            return this.f2616d;
        }

        public void setExtensions(String str) {
            this.f2616d = str;
        }

        public int getMode() {
            return this.f2617e;
        }

        public void setMode(int i2) {
            this.f2617e = i2;
        }
    }
}
