package com.amap.api.services.route;

import android.content.Context;
import android.os.Parcel;
import android.os.Parcelable;
import com.amap.api.col.p0003sl.fm;
import com.amap.api.col.p0003sl.hr;
import com.amap.api.services.core.AMapException;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.interfaces.IRouteSearchV2;
import com.amap.api.services.route.RouteSearch;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

/* loaded from: classes.dex */
public class RouteSearchV2 {

    /* renamed from: a, reason: collision with root package name */
    private IRouteSearchV2 f2775a;

    public static class BusMode {
        public static final int BUS_COMFORTABLE = 4;
        public static final int BUS_DEFAULT = 0;
        public static final int BUS_LEASE_CHANGE = 2;
        public static final int BUS_LEASE_WALK = 3;
        public static final int BUS_NO_SUBWAY = 5;
        public static final int BUS_SAVE_MONEY = 1;
        public static final int BUS_SUBWAY = 6;
        public static final int BUS_SUBWAY_FIRST = 7;
        public static final int BUS_WASTE_LESS = 8;
    }

    public interface OnRoutePlanSearchListener {
        void onDriveRoutePlanSearched(DriveRoutePlanResult driveRoutePlanResult, int i2);
    }

    public interface OnRouteSearchListener {
        void onBusRouteSearched(BusRouteResultV2 busRouteResultV2, int i2);

        void onDriveRouteSearched(DriveRouteResultV2 driveRouteResultV2, int i2);

        void onRideRouteSearched(RideRouteResultV2 rideRouteResultV2, int i2);

        void onWalkRouteSearched(WalkRouteResultV2 walkRouteResultV2, int i2);
    }

    public interface OnTruckRouteSearchListener {
        void onTruckRouteSearched(TruckRouteRestult truckRouteRestult, int i2);
    }

    public static class ShowFields {
        public static final int ALL = -1;
        public static final int CHARGE_STATION_INFO = 64;
        public static final int CITIES = 8;
        public static final int COST = 1;
        public static final int ELEC_COSUME_INFO = 32;
        public static final int NAVI = 4;
        public static final int POLINE = 16;
        public static final int TMCS = 2;
    }

    public enum DrivingStrategy {
        DEFAULT(32),
        AVOID_CONGESTION(33),
        HIGHWAY_PRIORITY(34),
        AVOID_HIGHWAY(35),
        LESS_CHARGE(36),
        ROAD_PRIORITY(37),
        SPEED_PRIORITY(38),
        AVOID_CONGESTION_HIGHWAY_PRIORITY(39),
        AVOID_CONGESTION_AVOID_HIGHWAY(40),
        AVOID_CONGESTION_LESS_CHARGE(41),
        LESS_CHARGE_AVOID_HIGHWAY(42),
        AVOID_CONGESTION_LESS_CHARGE_AVOID_HIGHWAY(43),
        AVOID_CONGESTION_ROAD_PRIORITY(44),
        AVOID_CONGESTION_SPEED_PRIORITY(45);


        /* renamed from: a, reason: collision with root package name */
        int f2807a;

        DrivingStrategy(int i2) {
            this.f2807a = i2;
        }

        public final int getValue() {
            return this.f2807a;
        }

        public static DrivingStrategy fromValue(int i2) {
            return values()[i2 - 32];
        }
    }

    public RouteSearchV2(Context context) throws AMapException {
        if (this.f2775a == null) {
            try {
                this.f2775a = new hr(context);
            } catch (Exception e2) {
                e2.printStackTrace();
                if (e2 instanceof AMapException) {
                    throw ((AMapException) e2);
                }
            }
        }
    }

    public void setRouteSearchListener(OnRouteSearchListener onRouteSearchListener) {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            iRouteSearchV2.setRouteSearchListener(onRouteSearchListener);
        }
    }

    public DriveRouteResultV2 calculateDriveRoute(DriveRouteQuery driveRouteQuery) throws AMapException {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            return iRouteSearchV2.calculateDriveRoute(driveRouteQuery);
        }
        return null;
    }

    public void calculateDriveRouteAsyn(DriveRouteQuery driveRouteQuery) {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            iRouteSearchV2.calculateDriveRouteAsyn(driveRouteQuery);
        }
    }

    public WalkRouteResultV2 calculateWalkRoute(WalkRouteQuery walkRouteQuery) throws AMapException {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            return iRouteSearchV2.calculateWalkRoute(walkRouteQuery);
        }
        return null;
    }

    public void calculateWalkRouteAsyn(WalkRouteQuery walkRouteQuery) {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            iRouteSearchV2.calculateWalkRouteAsyn(walkRouteQuery);
        }
    }

    public void calculateRideRouteAsyn(RideRouteQuery rideRouteQuery) {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            iRouteSearchV2.calculateRideRouteAsyn(rideRouteQuery);
        }
    }

    public RideRouteResultV2 calculateRideRoute(RideRouteQuery rideRouteQuery) throws AMapException {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            return iRouteSearchV2.calculateRideRoute(rideRouteQuery);
        }
        return null;
    }

    public BusRouteResultV2 calculateBusRoute(BusRouteQuery busRouteQuery) throws AMapException {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            return iRouteSearchV2.calculateBusRoute(busRouteQuery);
        }
        return null;
    }

    public void calculateBusRouteAsyn(BusRouteQuery busRouteQuery) {
        IRouteSearchV2 iRouteSearchV2 = this.f2775a;
        if (iRouteSearchV2 != null) {
            iRouteSearchV2.calculateBusRouteAsyn(busRouteQuery);
        }
    }

    public static class FromAndTo implements Parcelable, Cloneable {
        public static final Parcelable.Creator<FromAndTo> CREATOR = new Parcelable.Creator<FromAndTo>() { // from class: com.amap.api.services.route.RouteSearchV2.FromAndTo.1
            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ FromAndTo createFromParcel(Parcel parcel) {
                return a(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ FromAndTo[] newArray(int i2) {
                return a(i2);
            }

            private static FromAndTo a(Parcel parcel) {
                return new FromAndTo(parcel);
            }

            private static FromAndTo[] a(int i2) {
                return new FromAndTo[i2];
            }
        };

        /* renamed from: a, reason: collision with root package name */
        private LatLonPoint f2808a;

        /* renamed from: b, reason: collision with root package name */
        private LatLonPoint f2809b;

        /* renamed from: c, reason: collision with root package name */
        private String f2810c;

        /* renamed from: d, reason: collision with root package name */
        private String f2811d;

        /* renamed from: e, reason: collision with root package name */
        private String f2812e;

        /* renamed from: f, reason: collision with root package name */
        private String f2813f;

        /* renamed from: g, reason: collision with root package name */
        private String f2814g;

        @Override // android.os.Parcelable
        public int describeContents() {
            return 0;
        }

        public FromAndTo(LatLonPoint latLonPoint, LatLonPoint latLonPoint2) {
            this.f2808a = latLonPoint;
            this.f2809b = latLonPoint2;
        }

        public LatLonPoint getFrom() {
            return this.f2808a;
        }

        public LatLonPoint getTo() {
            return this.f2809b;
        }

        public String getStartPoiID() {
            return this.f2810c;
        }

        public void setStartPoiID(String str) {
            this.f2810c = str;
        }

        public String getDestinationPoiID() {
            return this.f2811d;
        }

        public void setDestinationPoiID(String str) {
            this.f2811d = str;
        }

        public String getOriginType() {
            return this.f2812e;
        }

        public void setOriginType(String str) {
            this.f2812e = str;
        }

        public String getDestinationType() {
            return this.f2813f;
        }

        public void setDestinationType(String str) {
            this.f2813f = str;
        }

        public String getPlateNumber() {
            return this.f2814g;
        }

        public void setPlateNumber(String str) {
            this.f2814g = str;
        }

        @Override // android.os.Parcelable
        public void writeToParcel(Parcel parcel, int i2) {
            parcel.writeParcelable(this.f2808a, i2);
            parcel.writeParcelable(this.f2809b, i2);
            parcel.writeString(this.f2810c);
            parcel.writeString(this.f2811d);
            parcel.writeString(this.f2812e);
            parcel.writeString(this.f2813f);
        }

        public FromAndTo(Parcel parcel) {
            this.f2808a = (LatLonPoint) parcel.readParcelable(LatLonPoint.class.getClassLoader());
            this.f2809b = (LatLonPoint) parcel.readParcelable(LatLonPoint.class.getClassLoader());
            this.f2810c = parcel.readString();
            this.f2811d = parcel.readString();
            this.f2812e = parcel.readString();
            this.f2813f = parcel.readString();
        }

        public FromAndTo() {
        }

        public int hashCode() {
            String str = this.f2811d;
            int hashCode = ((str == null ? 0 : str.hashCode()) + 31) * 31;
            LatLonPoint latLonPoint = this.f2808a;
            int hashCode2 = (hashCode + (latLonPoint == null ? 0 : latLonPoint.hashCode())) * 31;
            String str2 = this.f2810c;
            int hashCode3 = (hashCode2 + (str2 == null ? 0 : str2.hashCode())) * 31;
            LatLonPoint latLonPoint2 = this.f2809b;
            int hashCode4 = (hashCode3 + (latLonPoint2 == null ? 0 : latLonPoint2.hashCode())) * 31;
            String str3 = this.f2812e;
            int hashCode5 = (hashCode4 + (str3 == null ? 0 : str3.hashCode())) * 31;
            String str4 = this.f2813f;
            return hashCode5 + (str4 != null ? str4.hashCode() : 0);
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || getClass() != obj.getClass()) {
                return false;
            }
            FromAndTo fromAndTo = (FromAndTo) obj;
            String str = this.f2811d;
            if (str == null) {
                if (fromAndTo.f2811d != null) {
                    return false;
                }
            } else if (!str.equals(fromAndTo.f2811d)) {
                return false;
            }
            LatLonPoint latLonPoint = this.f2808a;
            if (latLonPoint == null) {
                if (fromAndTo.f2808a != null) {
                    return false;
                }
            } else if (!latLonPoint.equals(fromAndTo.f2808a)) {
                return false;
            }
            String str2 = this.f2810c;
            if (str2 == null) {
                if (fromAndTo.f2810c != null) {
                    return false;
                }
            } else if (!str2.equals(fromAndTo.f2810c)) {
                return false;
            }
            LatLonPoint latLonPoint2 = this.f2809b;
            if (latLonPoint2 == null) {
                if (fromAndTo.f2809b != null) {
                    return false;
                }
            } else if (!latLonPoint2.equals(fromAndTo.f2809b)) {
                return false;
            }
            String str3 = this.f2812e;
            if (str3 == null) {
                if (fromAndTo.f2812e != null) {
                    return false;
                }
            } else if (!str3.equals(fromAndTo.f2812e)) {
                return false;
            }
            String str4 = this.f2813f;
            if (str4 == null) {
                if (fromAndTo.f2813f != null) {
                    return false;
                }
            } else if (!str4.equals(fromAndTo.f2813f)) {
                return false;
            }
            return true;
        }

        /* renamed from: clone, reason: merged with bridge method [inline-methods] */
        public FromAndTo m96clone() {
            try {
                super.clone();
            } catch (CloneNotSupportedException e2) {
                fm.a(e2, "RouteSearchV2", "FromAndToclone");
            }
            FromAndTo fromAndTo = new FromAndTo(this.f2808a, this.f2809b);
            fromAndTo.setStartPoiID(this.f2810c);
            fromAndTo.setDestinationPoiID(this.f2811d);
            fromAndTo.setOriginType(this.f2812e);
            fromAndTo.setDestinationType(this.f2813f);
            return fromAndTo;
        }
    }

    public static class SpeedCost {

        /* renamed from: a, reason: collision with root package name */
        private int f2834a;

        /* renamed from: b, reason: collision with root package name */
        private float f2835b;

        public int getSpeed() {
            return this.f2834a;
        }

        public void setSpeed(int i2) {
            this.f2834a = i2;
        }

        public float getValue() {
            return this.f2835b;
        }

        public void setValue(float f2) {
            this.f2835b = f2;
        }
    }

    public static class CurveCost {

        /* renamed from: a, reason: collision with root package name */
        private float f2787a;

        /* renamed from: b, reason: collision with root package name */
        private float f2788b;

        public float getAccess() {
            return this.f2787a;
        }

        public void setAccess(float f2) {
            this.f2787a = f2;
        }

        public float getValue() {
            return this.f2788b;
        }

        public void setValue(float f2) {
            this.f2788b = f2;
        }
    }

    public static class SlopeCost {

        /* renamed from: a, reason: collision with root package name */
        private float f2832a;

        /* renamed from: b, reason: collision with root package name */
        private float f2833b;

        public float getUp() {
            return this.f2832a;
        }

        public void setUp(float f2) {
            this.f2832a = f2;
        }

        public float getDown() {
            return this.f2833b;
        }

        public void setDown(float f2) {
            this.f2833b = f2;
        }
    }

    public static class TransCost {

        /* renamed from: a, reason: collision with root package name */
        private float f2836a;

        /* renamed from: b, reason: collision with root package name */
        private float f2837b;

        public float getAccess() {
            return this.f2836a;
        }

        public void setAccess(float f2) {
            this.f2836a = f2;
        }

        public float getDecess() {
            return this.f2837b;
        }

        public void setDecess(float f2) {
            this.f2837b = f2;
        }
    }

    public static class PowerTrainLoss {

        /* renamed from: a, reason: collision with root package name */
        private int f2825a;

        /* renamed from: b, reason: collision with root package name */
        private float f2826b;

        /* renamed from: c, reason: collision with root package name */
        private int f2827c;

        /* renamed from: d, reason: collision with root package name */
        private int f2828d;

        public int getPowerDemand() {
            return this.f2825a;
        }

        public void setPowerDemand(int i2) {
            this.f2825a = i2;
        }

        public float getPowerDemandValue() {
            return this.f2826b;
        }

        public void setPowerDemandValue(float f2) {
            this.f2826b = f2;
        }

        public int getSpeed() {
            return this.f2827c;
        }

        public void setSpeed(int i2) {
            this.f2827c = i2;
        }

        public int getSpeedValue() {
            return this.f2828d;
        }

        public void setSpeedValue(int i2) {
            this.f2828d = i2;
        }
    }

    public static class CustomCostMode {

        /* renamed from: a, reason: collision with root package name */
        private List<SpeedCost> f2789a;

        /* renamed from: b, reason: collision with root package name */
        private CurveCost f2790b;

        /* renamed from: c, reason: collision with root package name */
        private SlopeCost f2791c;

        /* renamed from: d, reason: collision with root package name */
        private float f2792d;

        /* renamed from: e, reason: collision with root package name */
        private TransCost f2793e;

        /* renamed from: f, reason: collision with root package name */
        private float f2794f;

        /* renamed from: g, reason: collision with root package name */
        private PowerTrainLoss f2795g;

        public List<SpeedCost> getSpeedCosts() {
            return this.f2789a;
        }

        public void setSpeedCosts(List<SpeedCost> list) {
            this.f2789a = list;
        }

        public CurveCost getCurveCost() {
            return this.f2790b;
        }

        public void setCurveCost(CurveCost curveCost) {
            this.f2790b = curveCost;
        }

        public SlopeCost getSlopeCost() {
            return this.f2791c;
        }

        public void setSlopeCost(SlopeCost slopeCost) {
            this.f2791c = slopeCost;
        }

        public float getAuxCost() {
            return this.f2792d;
        }

        public void setAuxCost(float f2) {
            this.f2792d = f2;
        }

        public TransCost getTransCost() {
            return this.f2793e;
        }

        public void setTransCost(TransCost transCost) {
            this.f2793e = transCost;
        }

        public float getFerryCost() {
            return this.f2794f;
        }

        public void setFerryCost(float f2) {
            this.f2794f = f2;
        }

        public PowerTrainLoss getPowerTrainLosses() {
            return this.f2795g;
        }

        public void setPowerTrainLosses(PowerTrainLoss powerTrainLoss) {
            this.f2795g = powerTrainLoss;
        }

        public String toJson() {
            try {
                JSONObject jSONObject = new JSONObject();
                JSONArray jSONArray = new JSONArray();
                List<SpeedCost> list = this.f2789a;
                if (list != null) {
                    for (SpeedCost speedCost : list) {
                        JSONObject jSONObject2 = new JSONObject();
                        jSONObject2.put("speed", speedCost.getSpeed());
                        jSONObject2.put("value", speedCost.getValue());
                        jSONArray.put(jSONObject2);
                    }
                    jSONObject.put("speed_cost", jSONArray);
                }
                if (this.f2790b != null) {
                    JSONObject jSONObject3 = new JSONObject();
                    jSONObject3.put("access", this.f2790b.getAccess());
                    jSONObject3.put("value", this.f2790b.getValue());
                    jSONObject.put("curve_cost", jSONObject3);
                }
                if (this.f2791c != null) {
                    JSONObject jSONObject4 = new JSONObject();
                    jSONObject4.put("up", this.f2791c.getUp());
                    jSONObject4.put("down", this.f2791c.getDown());
                    jSONObject.put("slope_cost", jSONObject4);
                }
                jSONObject.put("aux_cost", this.f2792d);
                if (this.f2793e != null) {
                    JSONObject jSONObject5 = new JSONObject();
                    jSONObject5.put("access", this.f2793e.getAccess());
                    jSONObject5.put("decess", this.f2793e.getDecess());
                    jSONObject.put("trans_cost", jSONObject5);
                }
                jSONObject.put("ferry_cost", this.f2794f);
                if (this.f2795g != null) {
                    JSONArray jSONArray2 = new JSONArray();
                    JSONObject jSONObject6 = new JSONObject();
                    jSONObject6.put("powerdemand", this.f2795g.getPowerDemand());
                    jSONObject6.put("value", this.f2795g.getPowerDemandValue());
                    JSONObject jSONObject7 = new JSONObject();
                    jSONObject7.put("speed", this.f2795g.getSpeed());
                    jSONObject7.put("value", this.f2795g.getSpeedValue());
                    jSONArray2.put(jSONObject6);
                    jSONArray2.put(jSONObject7);
                    jSONObject.put("powertrain_loss", jSONArray2);
                }
                return jSONObject.toString();
            } catch (JSONException e2) {
                e2.printStackTrace();
                return null;
            }
        }
    }

    public static class NewEnergy {

        /* renamed from: a, reason: collision with root package name */
        private String f2815a;

        /* renamed from: b, reason: collision with root package name */
        private CustomCostMode f2816b;

        /* renamed from: i, reason: collision with root package name */
        private String f2823i;

        /* renamed from: c, reason: collision with root package name */
        private float f2817c = -1.0f;

        /* renamed from: d, reason: collision with root package name */
        private float f2818d = -1.0f;

        /* renamed from: e, reason: collision with root package name */
        private float f2819e = 1.5f;

        /* renamed from: f, reason: collision with root package name */
        private float f2820f = 100.0f;

        /* renamed from: g, reason: collision with root package name */
        private float f2821g = 0.0f;

        /* renamed from: h, reason: collision with root package name */
        private float f2822h = 0.0f;

        /* renamed from: j, reason: collision with root package name */
        private int f2824j = 0;

        public String getKey() {
            return this.f2815a;
        }

        public void setKey(String str) {
            this.f2815a = str;
        }

        public CustomCostMode getCustomCostMode() {
            return this.f2816b;
        }

        public void setCustomCostMode(CustomCostMode customCostMode) {
            this.f2816b = customCostMode;
        }

        public float getMaxVehicleCharge() {
            return this.f2817c;
        }

        public void setMaxVehicleCharge(float f2) {
            this.f2817c = f2;
        }

        public float getVehicleCharge() {
            return this.f2818d;
        }

        public void setVehicleCharge(float f2) {
            this.f2818d = f2;
        }

        public float getLoad() {
            return this.f2819e;
        }

        public void setLoad(float f2) {
            this.f2819e = f2;
        }

        public float getLeavingPercent() {
            return this.f2820f;
        }

        public void setLeavingPercent(float f2) {
            this.f2820f = f2;
        }

        public float getArrivingPercent() {
            return this.f2821g;
        }

        public void setArrivingPercent(float f2) {
            this.f2821g = f2;
        }

        public float getDestinationArrivingPercent() {
            return this.f2822h;
        }

        public void setDestinationArrivingPercent(float f2) {
            this.f2822h = f2;
        }

        public String getCustomChargingArguments() {
            return this.f2823i;
        }

        public void setCustomChargingArguments(String str) {
            this.f2823i = str;
        }

        public int getWaypointsArrivingPercent() {
            return this.f2824j;
        }

        public void setWaypointsArrivingPercent(int i2) {
            this.f2824j = i2;
        }

        public String buildParam() {
            StringBuilder sb = new StringBuilder();
            if (this.f2815a != null) {
                sb.append("&key=");
                sb.append(this.f2815a);
            }
            if (this.f2816b != null) {
                sb.append("&custom_cost_mode=");
                sb.append(this.f2816b.toJson());
            }
            if (this.f2817c > 0.0f) {
                sb.append("&max_vehicle_charge=");
                sb.append(this.f2817c);
            }
            if (this.f2818d > 0.0f) {
                sb.append("&vehicle_charge=");
                sb.append(this.f2818d);
            }
            sb.append("&load=");
            sb.append(this.f2819e);
            sb.append("&leaving_percent=");
            sb.append(this.f2820f);
            sb.append("&arriving_percent=");
            sb.append(this.f2821g);
            sb.append("&destination_arriving_percent=");
            sb.append(this.f2822h);
            if (this.f2823i != null) {
                sb.append("&custom_charging_arguments=");
                sb.append(this.f2823i);
            }
            if (this.f2824j > 0) {
                sb.append("&waypoints_arriving_percent=");
                sb.append(this.f2824j);
            }
            return sb.toString();
        }
    }

    public class AlternativeRoute {
        public static final int ALTERNATIVE_ROUTE_ONE = 1;
        public static final int ALTERNATIVE_ROUTE_THREE = 3;
        public static final int ALTERNATIVE_ROUTE_TWO = 2;

        public AlternativeRoute() {
        }
    }

    public static class WalkRouteQuery implements Parcelable, Cloneable {
        public static final Parcelable.Creator<WalkRouteQuery> CREATOR = new Parcelable.Creator<WalkRouteQuery>() { // from class: com.amap.api.services.route.RouteSearchV2.WalkRouteQuery.1
            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ WalkRouteQuery createFromParcel(Parcel parcel) {
                return a(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ WalkRouteQuery[] newArray(int i2) {
                return a(i2);
            }

            private static WalkRouteQuery a(Parcel parcel) {
                return new WalkRouteQuery(parcel);
            }

            private static WalkRouteQuery[] a(int i2) {
                return new WalkRouteQuery[i2];
            }
        };

        /* renamed from: a, reason: collision with root package name */
        private FromAndTo f2838a;

        /* renamed from: b, reason: collision with root package name */
        private int f2839b;

        /* renamed from: c, reason: collision with root package name */
        private boolean f2840c;

        /* renamed from: d, reason: collision with root package name */
        private int f2841d;

        @Override // android.os.Parcelable
        public int describeContents() {
            return 0;
        }

        public WalkRouteQuery(FromAndTo fromAndTo) {
            this.f2839b = 1;
            this.f2840c = false;
            this.f2841d = 1;
            this.f2838a = fromAndTo;
        }

        public FromAndTo getFromAndTo() {
            return this.f2838a;
        }

        public boolean isIndoor() {
            return this.f2840c;
        }

        public void setIndoor(boolean z) {
            this.f2840c = z;
        }

        public int getAlternativeRoute() {
            return this.f2841d;
        }

        public void setAlternativeRoute(int i2) {
            this.f2841d = i2;
        }

        public int getShowFields() {
            return this.f2839b;
        }

        public void setShowFields(int i2) {
            this.f2839b = i2;
        }

        @Override // android.os.Parcelable
        public void writeToParcel(Parcel parcel, int i2) {
            parcel.writeParcelable(this.f2838a, i2);
            parcel.writeBooleanArray(new boolean[]{this.f2840c});
            parcel.writeInt(this.f2841d);
            parcel.writeInt(this.f2839b);
        }

        public WalkRouteQuery(Parcel parcel) {
            this.f2839b = 1;
            this.f2840c = false;
            this.f2841d = 1;
            this.f2838a = (FromAndTo) parcel.readParcelable(FromAndTo.class.getClassLoader());
            boolean[] zArr = new boolean[1];
            parcel.readBooleanArray(zArr);
            this.f2840c = zArr[0];
            this.f2841d = parcel.readInt();
            this.f2839b = parcel.readInt();
        }

        public WalkRouteQuery() {
            this.f2839b = 1;
            this.f2840c = false;
            this.f2841d = 1;
        }

        public int hashCode() {
            return (((((this.f2838a.hashCode() * 31) + this.f2839b) * 31) + (this.f2840c ? 1 : 0)) * 31) + this.f2841d;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || getClass() != obj.getClass()) {
                return false;
            }
            WalkRouteQuery walkRouteQuery = (WalkRouteQuery) obj;
            if (this.f2839b == walkRouteQuery.f2839b && this.f2840c == walkRouteQuery.f2840c && this.f2841d == walkRouteQuery.f2841d) {
                return this.f2838a.equals(walkRouteQuery.f2838a);
            }
            return false;
        }

        /* renamed from: clone, reason: merged with bridge method [inline-methods] */
        public WalkRouteQuery m98clone() {
            try {
                super.clone();
            } catch (CloneNotSupportedException e2) {
                fm.a(e2, "RouteSearchV2", "WalkRouteQueryclone");
            }
            WalkRouteQuery walkRouteQuery = new WalkRouteQuery(this.f2838a);
            walkRouteQuery.setShowFields(this.f2839b);
            walkRouteQuery.setIndoor(this.f2840c);
            walkRouteQuery.setAlternativeRoute(this.f2841d);
            return walkRouteQuery;
        }
    }

    public static class DriveRouteQuery implements Parcelable, Cloneable {
        public static final Parcelable.Creator<DriveRouteQuery> CREATOR = new Parcelable.Creator<DriveRouteQuery>() { // from class: com.amap.api.services.route.RouteSearchV2.DriveRouteQuery.1
            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ DriveRouteQuery createFromParcel(Parcel parcel) {
                return a(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ DriveRouteQuery[] newArray(int i2) {
                return a(i2);
            }

            private static DriveRouteQuery a(Parcel parcel) {
                return new DriveRouteQuery(parcel);
            }

            private static DriveRouteQuery[] a(int i2) {
                return new DriveRouteQuery[i2];
            }
        };

        /* renamed from: a, reason: collision with root package name */
        private FromAndTo f2796a;

        /* renamed from: b, reason: collision with root package name */
        private NewEnergy f2797b;

        /* renamed from: c, reason: collision with root package name */
        private int f2798c;

        /* renamed from: d, reason: collision with root package name */
        private List<LatLonPoint> f2799d;

        /* renamed from: e, reason: collision with root package name */
        private List<List<LatLonPoint>> f2800e;

        /* renamed from: f, reason: collision with root package name */
        private String f2801f;

        /* renamed from: g, reason: collision with root package name */
        private boolean f2802g;

        /* renamed from: h, reason: collision with root package name */
        private int f2803h;

        /* renamed from: i, reason: collision with root package name */
        private String f2804i;

        /* renamed from: j, reason: collision with root package name */
        private int f2805j;

        @Override // android.os.Parcelable
        public int describeContents() {
            return 0;
        }

        public DriveRouteQuery(FromAndTo fromAndTo, DrivingStrategy drivingStrategy, List<LatLonPoint> list, List<List<LatLonPoint>> list2, String str) {
            this.f2798c = DrivingStrategy.DEFAULT.getValue();
            this.f2802g = true;
            this.f2803h = 0;
            this.f2804i = null;
            this.f2805j = 1;
            this.f2796a = fromAndTo;
            this.f2798c = drivingStrategy.getValue();
            this.f2799d = list;
            this.f2800e = list2;
            this.f2801f = str;
        }

        public NewEnergy getNewEnergy() {
            return this.f2797b;
        }

        public void setNewEnergy(NewEnergy newEnergy) {
            this.f2797b = newEnergy;
        }

        public FromAndTo getFromAndTo() {
            return this.f2796a;
        }

        public DrivingStrategy getMode() {
            return DrivingStrategy.fromValue(this.f2798c);
        }

        public int getCarType() {
            return this.f2803h;
        }

        public List<LatLonPoint> getPassedByPoints() {
            return this.f2799d;
        }

        public List<List<LatLonPoint>> getAvoidpolygons() {
            return this.f2800e;
        }

        public String getAvoidRoad() {
            return this.f2801f;
        }

        public String getPassedPointStr() {
            StringBuffer stringBuffer = new StringBuffer();
            List<LatLonPoint> list = this.f2799d;
            if (list == null || list.size() == 0) {
                return null;
            }
            for (int i2 = 0; i2 < this.f2799d.size(); i2++) {
                LatLonPoint latLonPoint = this.f2799d.get(i2);
                stringBuffer.append(latLonPoint.getLongitude());
                stringBuffer.append(",");
                stringBuffer.append(latLonPoint.getLatitude());
                if (i2 < this.f2799d.size() - 1) {
                    stringBuffer.append(";");
                }
            }
            return stringBuffer.toString();
        }

        public boolean hasPassPoint() {
            return !fm.a(getPassedPointStr());
        }

        public String getAvoidpolygonsStr() {
            StringBuffer stringBuffer = new StringBuffer();
            List<List<LatLonPoint>> list = this.f2800e;
            if (list == null || list.size() == 0) {
                return null;
            }
            for (int i2 = 0; i2 < this.f2800e.size(); i2++) {
                List<LatLonPoint> list2 = this.f2800e.get(i2);
                for (int i3 = 0; i3 < list2.size(); i3++) {
                    LatLonPoint latLonPoint = list2.get(i3);
                    stringBuffer.append(latLonPoint.getLongitude());
                    stringBuffer.append(",");
                    stringBuffer.append(latLonPoint.getLatitude());
                    if (i3 < list2.size() - 1) {
                        stringBuffer.append(";");
                    }
                }
                if (i2 < this.f2800e.size() - 1) {
                    stringBuffer.append("|");
                }
            }
            return stringBuffer.toString();
        }

        public boolean hasAvoidpolygons() {
            return !fm.a(getAvoidpolygonsStr());
        }

        public boolean hasAvoidRoad() {
            return !fm.a(getAvoidRoad());
        }

        public String getExclude() {
            return this.f2804i;
        }

        public void setExclude(String str) {
            this.f2804i = str;
        }

        public int getShowFields() {
            return this.f2805j;
        }

        public void setShowFields(int i2) {
            this.f2805j = i2;
        }

        @Override // android.os.Parcelable
        public void writeToParcel(Parcel parcel, int i2) {
            parcel.writeParcelable(this.f2796a, i2);
            parcel.writeInt(this.f2798c);
            parcel.writeTypedList(this.f2799d);
            List<List<LatLonPoint>> list = this.f2800e;
            if (list == null) {
                parcel.writeInt(0);
            } else {
                parcel.writeInt(list.size());
                Iterator<List<LatLonPoint>> it2 = this.f2800e.iterator();
                while (it2.hasNext()) {
                    parcel.writeTypedList(it2.next());
                }
            }
            parcel.writeString(this.f2801f);
            parcel.writeInt(this.f2802g ? 1 : 0);
            parcel.writeInt(this.f2803h);
            parcel.writeString(this.f2804i);
            parcel.writeInt(this.f2805j);
        }

        public DriveRouteQuery(Parcel parcel) {
            this.f2798c = DrivingStrategy.DEFAULT.getValue();
            this.f2802g = true;
            this.f2803h = 0;
            this.f2804i = null;
            this.f2805j = 1;
            this.f2796a = (FromAndTo) parcel.readParcelable(FromAndTo.class.getClassLoader());
            this.f2798c = parcel.readInt();
            this.f2799d = parcel.createTypedArrayList(LatLonPoint.CREATOR);
            int readInt = parcel.readInt();
            if (readInt == 0) {
                this.f2800e = null;
            } else {
                this.f2800e = new ArrayList();
            }
            for (int i2 = 0; i2 < readInt; i2++) {
                this.f2800e.add(parcel.createTypedArrayList(LatLonPoint.CREATOR));
            }
            this.f2801f = parcel.readString();
            this.f2802g = parcel.readInt() == 1;
            this.f2803h = parcel.readInt();
            this.f2804i = parcel.readString();
            this.f2805j = parcel.readInt();
        }

        public DriveRouteQuery() {
            this.f2798c = DrivingStrategy.DEFAULT.getValue();
            this.f2802g = true;
            this.f2803h = 0;
            this.f2804i = null;
            this.f2805j = 1;
        }

        public int hashCode() {
            String str = this.f2801f;
            int hashCode = ((str == null ? 0 : str.hashCode()) + 31) * 31;
            List<List<LatLonPoint>> list = this.f2800e;
            int hashCode2 = (hashCode + (list == null ? 0 : list.hashCode())) * 31;
            FromAndTo fromAndTo = this.f2796a;
            int hashCode3 = (((hashCode2 + (fromAndTo == null ? 0 : fromAndTo.hashCode())) * 31) + this.f2798c) * 31;
            List<LatLonPoint> list2 = this.f2799d;
            return ((hashCode3 + (list2 != null ? list2.hashCode() : 0)) * 31) + this.f2803h;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || getClass() != obj.getClass()) {
                return false;
            }
            DriveRouteQuery driveRouteQuery = (DriveRouteQuery) obj;
            String str = this.f2801f;
            if (str == null) {
                if (driveRouteQuery.f2801f != null) {
                    return false;
                }
            } else if (!str.equals(driveRouteQuery.f2801f)) {
                return false;
            }
            List<List<LatLonPoint>> list = this.f2800e;
            if (list == null) {
                if (driveRouteQuery.f2800e != null) {
                    return false;
                }
            } else if (!list.equals(driveRouteQuery.f2800e)) {
                return false;
            }
            FromAndTo fromAndTo = this.f2796a;
            if (fromAndTo == null) {
                if (driveRouteQuery.f2796a != null) {
                    return false;
                }
            } else if (!fromAndTo.equals(driveRouteQuery.f2796a)) {
                return false;
            }
            if (this.f2798c != driveRouteQuery.f2798c) {
                return false;
            }
            List<LatLonPoint> list2 = this.f2799d;
            if (list2 == null) {
                if (driveRouteQuery.f2799d != null) {
                    return false;
                }
            } else if (!list2.equals(driveRouteQuery.f2799d) || this.f2802g != driveRouteQuery.isUseFerry() || this.f2803h != driveRouteQuery.f2803h || this.f2805j != driveRouteQuery.f2805j) {
                return false;
            }
            return true;
        }

        /* renamed from: clone, reason: merged with bridge method [inline-methods] */
        public DriveRouteQuery m95clone() {
            try {
                super.clone();
            } catch (CloneNotSupportedException e2) {
                fm.a(e2, "RouteSearchV2", "DriveRouteQueryclone");
            }
            DriveRouteQuery driveRouteQuery = new DriveRouteQuery(this.f2796a, DrivingStrategy.fromValue(this.f2798c), this.f2799d, this.f2800e, this.f2801f);
            driveRouteQuery.setUseFerry(this.f2802g);
            driveRouteQuery.setCarType(this.f2803h);
            driveRouteQuery.setExclude(this.f2804i);
            driveRouteQuery.setShowFields(this.f2805j);
            driveRouteQuery.setNewEnergy(this.f2797b);
            return driveRouteQuery;
        }

        public boolean isUseFerry() {
            return this.f2802g;
        }

        public void setUseFerry(boolean z) {
            this.f2802g = z;
        }

        public void setCarType(int i2) {
            this.f2803h = i2;
        }
    }

    public static class RideRouteQuery implements Parcelable, Cloneable {
        public static final Parcelable.Creator<RideRouteQuery> CREATOR = new Parcelable.Creator<RideRouteQuery>() { // from class: com.amap.api.services.route.RouteSearchV2.RideRouteQuery.1
            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ RideRouteQuery createFromParcel(Parcel parcel) {
                return a(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ RideRouteQuery[] newArray(int i2) {
                return a(i2);
            }

            private static RideRouteQuery a(Parcel parcel) {
                return new RideRouteQuery(parcel);
            }

            private static RideRouteQuery[] a(int i2) {
                return new RideRouteQuery[i2];
            }
        };

        /* renamed from: a, reason: collision with root package name */
        private FromAndTo f2829a;

        /* renamed from: b, reason: collision with root package name */
        private int f2830b;

        /* renamed from: c, reason: collision with root package name */
        private int f2831c;

        @Override // android.os.Parcelable
        public int describeContents() {
            return 0;
        }

        public RideRouteQuery(FromAndTo fromAndTo) {
            this.f2830b = 1;
            this.f2831c = 1;
            this.f2829a = fromAndTo;
        }

        public FromAndTo getFromAndTo() {
            return this.f2829a;
        }

        public int getShowFields() {
            return this.f2830b;
        }

        public void setShowFields(int i2) {
            this.f2830b = i2;
        }

        public int getAlternativeRoute() {
            return this.f2831c;
        }

        public void setAlternativeRoute(int i2) {
            this.f2831c = i2;
        }

        @Override // android.os.Parcelable
        public void writeToParcel(Parcel parcel, int i2) {
            parcel.writeParcelable(this.f2829a, i2);
            parcel.writeInt(this.f2831c);
            parcel.writeInt(this.f2830b);
        }

        public RideRouteQuery(Parcel parcel) {
            this.f2830b = 1;
            this.f2831c = 1;
            this.f2829a = (FromAndTo) parcel.readParcelable(RouteSearch.FromAndTo.class.getClassLoader());
            this.f2831c = parcel.readInt();
            this.f2830b = parcel.readInt();
        }

        public RideRouteQuery() {
            this.f2830b = 1;
            this.f2831c = 1;
        }

        public int hashCode() {
            FromAndTo fromAndTo = this.f2829a;
            return (((((fromAndTo == null ? 0 : fromAndTo.hashCode()) + 31) * 31) + this.f2830b) * 31) + this.f2831c;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || getClass() != obj.getClass()) {
                return false;
            }
            RideRouteQuery rideRouteQuery = (RideRouteQuery) obj;
            FromAndTo fromAndTo = this.f2829a;
            if (fromAndTo == null) {
                if (rideRouteQuery.f2829a != null) {
                    return false;
                }
            } else if (!fromAndTo.equals(rideRouteQuery.f2829a)) {
                return false;
            }
            return this.f2830b == rideRouteQuery.f2830b && this.f2831c == rideRouteQuery.f2831c;
        }

        /* renamed from: clone, reason: merged with bridge method [inline-methods] */
        public RideRouteQuery m97clone() {
            try {
                super.clone();
            } catch (CloneNotSupportedException e2) {
                fm.a(e2, "RouteSearchV2", "RideRouteQueryclone");
            }
            RideRouteQuery rideRouteQuery = new RideRouteQuery(this.f2829a);
            rideRouteQuery.setShowFields(this.f2830b);
            rideRouteQuery.setAlternativeRoute(this.f2831c);
            return rideRouteQuery;
        }
    }

    public static class BusRouteQuery implements Parcelable, Cloneable {
        public static final Parcelable.Creator<BusRouteQuery> CREATOR = new Parcelable.Creator<BusRouteQuery>() { // from class: com.amap.api.services.route.RouteSearchV2.BusRouteQuery.1
            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ BusRouteQuery createFromParcel(Parcel parcel) {
                return a(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public final /* synthetic */ BusRouteQuery[] newArray(int i2) {
                return a(i2);
            }

            private static BusRouteQuery a(Parcel parcel) {
                return new BusRouteQuery(parcel);
            }

            private static BusRouteQuery[] a(int i2) {
                return new BusRouteQuery[i2];
            }
        };

        /* renamed from: a, reason: collision with root package name */
        private FromAndTo f2777a;

        /* renamed from: b, reason: collision with root package name */
        private int f2778b;

        /* renamed from: c, reason: collision with root package name */
        private String f2779c;

        /* renamed from: d, reason: collision with root package name */
        private String f2780d;

        /* renamed from: e, reason: collision with root package name */
        private String f2781e;

        /* renamed from: f, reason: collision with root package name */
        private String f2782f;

        /* renamed from: g, reason: collision with root package name */
        private int f2783g;

        /* renamed from: h, reason: collision with root package name */
        private String f2784h;

        /* renamed from: i, reason: collision with root package name */
        private String f2785i;

        /* renamed from: j, reason: collision with root package name */
        private String f2786j;
        private String k;
        private int l;
        private int m;
        private int n;
        private int o;

        @Override // android.os.Parcelable
        public int describeContents() {
            return 0;
        }

        public BusRouteQuery(FromAndTo fromAndTo, int i2, String str, int i3) {
            this.l = 5;
            this.m = 0;
            this.n = 4;
            this.o = 1;
            this.f2777a = fromAndTo;
            this.f2778b = i2;
            this.f2779c = str;
            this.f2783g = i3;
        }

        public FromAndTo getFromAndTo() {
            return this.f2777a;
        }

        public int getMode() {
            return this.f2778b;
        }

        public String getCity() {
            return this.f2779c;
        }

        public int getNightFlag() {
            return this.f2783g;
        }

        public String getCityd() {
            return this.f2780d;
        }

        public void setCityd(String str) {
            this.f2780d = str;
        }

        public int getShowFields() {
            return this.o;
        }

        public void setShowFields(int i2) {
            this.o = i2;
        }

        public String getDate() {
            return this.f2781e;
        }

        public void setDate(String str) {
            this.f2781e = str;
        }

        public String getTime() {
            return this.f2782f;
        }

        public void setTime(String str) {
            this.f2782f = str;
        }

        public String getOriginPoiId() {
            return this.f2784h;
        }

        public void setOriginPoiId(String str) {
            this.f2784h = str;
        }

        public String getDestinationPoiId() {
            return this.f2785i;
        }

        public void setDestinationPoiId(String str) {
            this.f2785i = str;
        }

        public String getAd1() {
            return this.f2786j;
        }

        public void setAd1(String str) {
            this.f2786j = str;
        }

        public String getAd2() {
            return this.k;
        }

        public void setAd2(String str) {
            this.k = str;
        }

        public int getAlternativeRoute() {
            return this.l;
        }

        public void setAlternativeRoute(int i2) {
            this.l = i2;
        }

        public int getMultiExport() {
            return this.m;
        }

        public void setMultiExport(int i2) {
            this.m = i2;
        }

        public int getMaxTrans() {
            return this.n;
        }

        public void setMaxTrans(int i2) {
            this.n = i2;
        }

        @Override // android.os.Parcelable
        public void writeToParcel(Parcel parcel, int i2) {
            parcel.writeParcelable(this.f2777a, i2);
            parcel.writeInt(this.f2778b);
            parcel.writeString(this.f2779c);
            parcel.writeInt(this.f2783g);
            parcel.writeString(this.f2780d);
            parcel.writeInt(this.o);
            parcel.writeString(this.f2784h);
            parcel.writeString(this.f2785i);
            parcel.writeString(this.f2786j);
            parcel.writeString(this.k);
            parcel.writeInt(this.l);
            parcel.writeInt(this.n);
            parcel.writeInt(this.m);
            parcel.writeString(this.f2781e);
            parcel.writeString(this.f2782f);
        }

        public BusRouteQuery(Parcel parcel) {
            this.f2778b = 0;
            this.f2783g = 0;
            this.l = 5;
            this.m = 0;
            this.n = 4;
            this.o = 1;
            this.f2777a = (FromAndTo) parcel.readParcelable(FromAndTo.class.getClassLoader());
            this.f2778b = parcel.readInt();
            this.f2779c = parcel.readString();
            this.f2783g = parcel.readInt();
            this.f2780d = parcel.readString();
            this.o = parcel.readInt();
            this.f2784h = parcel.readString();
            this.f2785i = parcel.readString();
            this.f2781e = parcel.readString();
            this.f2782f = parcel.readString();
            this.n = parcel.readInt();
            this.m = parcel.readInt();
            this.l = parcel.readInt();
            this.f2786j = parcel.readString();
            this.k = parcel.readString();
        }

        public BusRouteQuery() {
            this.f2778b = 0;
            this.f2783g = 0;
            this.l = 5;
            this.m = 0;
            this.n = 4;
            this.o = 1;
        }

        public int hashCode() {
            return (((((((((((((((((((((((((((this.f2777a.hashCode() * 31) + this.f2778b) * 31) + this.f2779c.hashCode()) * 31) + this.f2780d.hashCode()) * 31) + this.f2781e.hashCode()) * 31) + this.f2782f.hashCode()) * 31) + this.f2783g) * 31) + this.f2784h.hashCode()) * 31) + this.f2785i.hashCode()) * 31) + this.f2786j.hashCode()) * 31) + this.k.hashCode()) * 31) + this.l) * 31) + this.m) * 31) + this.n) * 31) + this.o;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || getClass() != obj.getClass()) {
                return false;
            }
            BusRouteQuery busRouteQuery = (BusRouteQuery) obj;
            if (this.f2778b == busRouteQuery.f2778b && this.f2783g == busRouteQuery.f2783g && this.f2784h.equals(busRouteQuery.f2784h) && this.f2785i.equals(busRouteQuery.f2785i) && this.l == busRouteQuery.l && this.m == busRouteQuery.m && this.n == busRouteQuery.n && this.o == busRouteQuery.o && this.f2777a.equals(busRouteQuery.f2777a) && this.f2779c.equals(busRouteQuery.f2779c) && this.f2780d.equals(busRouteQuery.f2780d) && this.f2781e.equals(busRouteQuery.f2781e) && this.f2782f.equals(busRouteQuery.f2782f) && this.f2786j.equals(busRouteQuery.f2786j)) {
                return this.k.equals(busRouteQuery.k);
            }
            return false;
        }

        /* renamed from: clone, reason: merged with bridge method [inline-methods] */
        public BusRouteQuery m94clone() {
            try {
                super.clone();
            } catch (CloneNotSupportedException e2) {
                fm.a(e2, "RouteSearchV2", "BusRouteQueryclone");
            }
            BusRouteQuery busRouteQuery = new BusRouteQuery(this.f2777a, this.f2778b, this.f2779c, this.f2783g);
            busRouteQuery.setCityd(this.f2780d);
            busRouteQuery.setShowFields(this.o);
            busRouteQuery.setDate(this.f2781e);
            busRouteQuery.setTime(this.f2782f);
            busRouteQuery.setAd1(this.f2786j);
            busRouteQuery.setAd2(this.k);
            busRouteQuery.setOriginPoiId(this.f2784h);
            busRouteQuery.setDestinationPoiId(this.f2785i);
            busRouteQuery.setMaxTrans(this.n);
            busRouteQuery.setMultiExport(this.m);
            busRouteQuery.setAlternativeRoute(this.l);
            return busRouteQuery;
        }
    }
}
