package com.autonavi.base.ae.gmap;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Point;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import com.amap.api.col.p0003sl.dt;
import com.amap.api.col.p0003sl.dv;
import com.amap.api.col.p0003sl.jt;
import com.amap.api.maps.AMap;
import com.amap.api.maps.MapsInitializer;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.MyTrafficStyle;
import com.autonavi.amap.api.mapcore.IGLMapEngine;
import com.autonavi.amap.api.mapcore.IGLMapState;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.autonavi.amap.mapcore.AbstractCameraUpdateMessage;
import com.autonavi.base.ae.gmap.bean.InitStorageParam;
import com.autonavi.base.ae.gmap.bean.TileProviderInner;
import com.autonavi.base.ae.gmap.gesture.EAMapPlatformGestureInfo;
import com.autonavi.base.ae.gmap.glanimation.AdglMapAnimFling;
import com.autonavi.base.ae.gmap.glanimation.AdglMapAnimFlingP20;
import com.autonavi.base.ae.gmap.glanimation.AdglMapAnimGroup;
import com.autonavi.base.ae.gmap.glanimation.AdglMapAnimationMgr;
import com.autonavi.base.ae.gmap.gloverlay.BaseMapOverlay;
import com.autonavi.base.ae.gmap.gloverlay.GLOverlayBundle;
import com.autonavi.base.ae.gmap.gloverlay.GLTextureProperty;
import com.autonavi.base.ae.gmap.style.StyleItem;
import com.autonavi.base.amap.api.mapcore.IAMapDelegate;
import com.autonavi.base.amap.mapcore.FileUtil;
import com.autonavi.base.amap.mapcore.IAMapEngineCallback;
import com.autonavi.base.amap.mapcore.interfaces.IAMapListener;
import com.autonavi.base.amap.mapcore.maploader.AMapLoader;
import com.autonavi.base.amap.mapcore.maploader.NetworkState;
import com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage;
import com.autonavi.base.amap.mapcore.message.HoverGestureMapMessage;
import com.autonavi.base.amap.mapcore.message.MoveGestureMapMessage;
import com.autonavi.base.amap.mapcore.message.RotateGestureMapMessage;
import com.autonavi.base.amap.mapcore.message.ScaleGestureMapMessage;
import com.autonavi.base.amap.mapcore.tools.TextTextureGenerator;
import java.io.File;
import java.util.List;
import java.util.Vector;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

/* loaded from: classes.dex */
public class GLMapEngine implements IGLMapEngine, IAMapEngineCallback {
    private Context context;
    private int mEngineID;
    private IAMapDelegate mGlMapView;
    private IAMapListener mMapListener;
    boolean mRequestDestroy;
    private TextTextureGenerator mTextTextureGenerator;
    private AdglMapAnimationMgr mapAnimationMgr;
    GLMapState state;
    private TerrainOverlayProvider terrainTileProvider;
    private long mNativeMapengineInstance = 0;
    private final List<AbstractCameraUpdateMessage> mStateMessageList = new Vector();
    private final List<AbstractGestureMapMessage> mGestureMessageList = new Vector();
    private List<AbstractGestureMapMessage> mGestureEndMessageList = new Vector();
    private final List<AbstractCameraUpdateMessage> mAnimateStateMessageList = new Vector();
    boolean isMoveCameraStep = false;
    boolean isGestureStep = false;
    private int mapGestureCount = 0;
    private GLMapState copyGLMapState = null;
    private Lock mLock = new ReentrantLock();
    private Object mutLock = new Object();
    private NetworkState mNetworkState = null;
    GLOverlayBundle<BaseMapOverlay<?, ?>> bundle = null;
    private boolean isEngineRenderComplete = false;
    boolean isNetworkConnected = false;
    private AtomicInteger mRequestID = new AtomicInteger(1);

    public static class InitParam {
        public String mRootPath = "";
        public String mConfigPath = "";
        public String mConfigContent = "";
        public String mOfflineDataPath = "";
        public String mP3dCrossPath = "";
        public String mIntersectionResPath = "";
    }

    public static class MapViewInitParam {
        public int engineId;
        public int height;
        public float mapZoomScale;
        public int screenHeight;
        public float screenScale;
        public int screenWidth;
        public int taskThreadCount = 8;
        public float textScale;
        public int width;
        public int x;
        public int y;
    }

    public static native void nativeAddGestureSingleTapMessage(int i2, long j2, float f2, float f3);

    protected static native String nativeAddNativeOverlay(int i2, long j2, int i3, int i4);

    private static native boolean nativeAddOverlayTexture(int i2, long j2, int i3, int i4, float f2, float f3, Bitmap bitmap, boolean z, boolean z2);

    private static native void nativeCancelDownLoad(long j2);

    private static native boolean nativeCheckCustomStyleData(int i2, long j2, byte[] bArr);

    private static native void nativeCreateAMapEngineWithFrame(long j2, int i2, int i3, int i4, int i5, int i6, int i7, int i8, float f2, float f3, float f4, int i9);

    private static native long nativeCreateAMapInstance(float f2, float f3, float f4, int i2);

    protected static native long nativeCreateOverlay(int i2, long j2, int i3);

    private static native int nativeCreateTextureFromImage(int i2, long j2, Bitmap bitmap);

    private static native void nativeDestroy(long j2);

    private static native void nativeDestroyCurrentState(long j2, long j3);

    protected static native void nativeDestroyOverlay(int i2, long j2);

    private static native void nativeFailedDownLoad(long j2, int i2);

    private static native void nativeFinishDownLoad(long j2);

    private static native void nativeGetCurTileIDs(int i2, long j2, int[] iArr, int i3);

    private static native long nativeGetCurrentMapState(int i2, long j2);

    private static native long nativeGetGlOverlayMgrPtr(int i2, long j2);

    public static native String nativeGetMapEngineVersion(int i2);

    private static native int[] nativeGetMapModeState(int i2, long j2, boolean z);

    public static native String nativeGetMapSDKDeps();

    public static native String nativeGetMapSDKVersion();

    public static native long nativeGetNativeMapController(int i2, long j2);

    public static native int[] nativeGetScreenShot(int i2, long j2, int i3, int i4, int i5, int i6);

    private static native boolean nativeGetSrvViewStateBoolValue(int i2, long j2, int i3);

    public static native int nativeHideBuildings(int i2, long j2, LatLng[] latLngArr);

    private static native void nativeInitAMapEngineCallback(long j2, Object obj);

    private static native void nativeInitContourLineOptions(long j2, boolean z);

    private static native void nativeInitOpenLayer(int i2, long j2, byte[] bArr);

    private static native void nativeInitParam(String str, String str2, String str3, String str4, String str5, String str6, int i2);

    private static native boolean nativeIsEngineCreated(long j2, int i2);

    public static native void nativeMainThreadTrigger(int i2, long j2);

    private static native void nativePopRenderState(int i2, long j2);

    private static native void nativePostRenderAMap(long j2, int i2);

    private static native void nativePushRendererState(int i2, long j2);

    private static native void nativeReceiveNetData(byte[] bArr, long j2, int i2);

    protected static native void nativeRemoveNativeAllOverlay(int i2, long j2);

    protected static native void nativeRemoveNativeOverlay(int i2, long j2, String str);

    private static native void nativeRenderAMap(long j2, int i2);

    private static native void nativeSetAllContentEnable(int i2, long j2, boolean z);

    private static native void nativeSetBuildingEnable(int i2, long j2, boolean z);

    private static native void nativeSetBuildingTextureEnable(int i2, long j2, boolean z);

    private static native void nativeSetCustomStyleData(int i2, long j2, byte[] bArr, byte[] bArr2);

    private static native void nativeSetCustomStyleTexture(int i2, long j2, byte[] bArr);

    private static native void nativeSetCustomThirdLayerStyle(int i2, long j2, String str);

    private static native void nativeSetHighlightSubwayEnable(int i2, long j2, boolean z);

    private static native void nativeSetIndoorBuildingToBeActive(int i2, long j2, String str, int i3, String str2);

    private static native void nativeSetIndoorEnable(int i2, long j2, boolean z);

    private static native void nativeSetLabelEnable(int i2, long j2, boolean z);

    private static native boolean nativeSetMapModeAndStyle(int i2, long j2, int[] iArr);

    private static native void nativeSetNaviLabelEnable(int i2, long j2, boolean z, int i3, int i4);

    private static native void nativeSetNetStatus(long j2, int i2);

    private static native void nativeSetOfflineDataEnable(int i2, long j2, boolean z);

    private static native void nativeSetOpenLayerEnable(int i2, long j2, boolean z);

    private static native void nativeSetParameter(int i2, long j2, int i3, int i4, int i5, int i6, int i7);

    private static native void nativeSetProjectionCenter(int i2, long j2, float f2, float f3);

    private static native void nativeSetRenderListenerStatus(int i2, long j2);

    private static native void nativeSetRoadArrowEnable(int i2, long j2, boolean z);

    private static native void nativeSetServiceViewRect(int i2, long j2, int i3, int i4, int i5, int i6, int i7, int i8);

    private static native void nativeSetSetBackgroundTexture(int i2, long j2, byte[] bArr);

    private static native void nativeSetSimple3DEnable(int i2, long j2, boolean z);

    private static native void nativeSetSkyTexture(int i2, long j2, byte[] bArr);

    private static native void nativeSetSrvViewStateBoolValue(int i2, long j2, int i3, boolean z);

    private static native void nativeSetStyleChangeGradualEnable(int i2, long j2, boolean z);

    public static native void nativeSetTerrainAuth(int i2, long j2, boolean z);

    private static native void nativeSetTrafficEnable(int i2, long j2, boolean z);

    private static native void nativeSetTrafficTexture(int i2, long j2, byte[] bArr, long j3, int i3, int i4, int i5, int i6, int i7);

    private static native void nativeSetTrafficTextureAllInOne(int i2, long j2, byte[] bArr);

    public static native void nativeSetVectorOverlayPath(int i2, long j2, String str);

    public static native void nativeShowHideBuildings(int i2, long j2, int i3);

    protected static native void nativeUpdateNativeArrowOverlay(int i2, long j2, String str, int[] iArr, int[] iArr2, int i3, int i4, int i5, float f2, boolean z, int i6, int i7, int i8);

    public void changeSurface(int i2, int i3) {
    }

    public void clearAllMessages(int i2) {
    }

    public boolean getIsProcessBuildingMark(int i2) {
        return false;
    }

    public long getMapStateInstance(int i2) {
        return 0L;
    }

    public boolean isInMapAction(int i2) {
        return false;
    }

    public void onClearCache(int i2) {
    }

    public void putResourceData(int i2, byte[] bArr) {
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public void reloadMapResource(int i2, String str, int i3) {
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public void requireMapRender(int i2, int i3, int i4) {
    }

    public void startPivotZoomRotateAnim(int i2, Point point, float f2, int i3, int i4) {
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public byte[] requireMapResource(int i2, String str) {
        byte[] bArr;
        if (str == null) {
            return null;
        }
        String concat = "map_assets/".concat(String.valueOf(str));
        try {
            if (this.mGlMapView.getMapConfig().isCustomStyleEnable()) {
                if (this.mGlMapView.getCustomStyleManager() != null) {
                    bArr = this.mGlMapView.getCustomStyleManager().a(str);
                    if (bArr != null) {
                        return bArr;
                    }
                } else {
                    bArr = null;
                }
                if (str.startsWith("icons_5")) {
                    bArr = FileUtil.readFileContents(this.mGlMapView.getMapConfig().getCustomTextureResourcePath());
                } else if (str.startsWith("bktile")) {
                    bArr = FileUtil.readFileContentsFromAssets(this.context, concat);
                    int customBackgroundColor = this.mGlMapView.getMapConfig().getCustomBackgroundColor();
                    if (customBackgroundColor != 0) {
                        bArr = dv.a(bArr, customBackgroundColor);
                    }
                }
                if (bArr != null) {
                    return bArr;
                }
            }
            return FileUtil.readFileContentsFromAssets(this.context, concat);
        } catch (Throwable th) {
            dv.a(th);
            return null;
        }
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public int generateRequestId() {
        return this.mRequestID.incrementAndGet();
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public void cancelRequireMapData(Object obj) {
        if (obj == null || !(obj instanceof AMapLoader)) {
            return;
        }
        ((AMapLoader) obj).doCancel();
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public byte[] requireCharBitmap(int i2, int i3, int i4) {
        return this.mTextTextureGenerator.getTextPixelBuffer(i3, i4);
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public byte[] requireCharsWidths(int i2, int[] iArr, int i3, int i4) {
        return this.mTextTextureGenerator.getCharsWidths(iArr);
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public void onMapRender(int i2, int i3) {
        try {
            if (i3 == 5) {
                IAMapListener iAMapListener = this.mMapListener;
                if (iAMapListener != null) {
                    iAMapListener.beforeDrawLabel(i2, getMapState(i2));
                    return;
                }
                return;
            }
            if (i3 == 6) {
                IAMapListener iAMapListener2 = this.mMapListener;
                if (iAMapListener2 != null) {
                    iAMapListener2.afterDrawLabel(i2, getMapState(i2));
                    return;
                }
                return;
            }
            if (i3 != 7) {
                if (i3 != 13) {
                    return;
                }
                this.isEngineRenderComplete = true;
            } else {
                IAMapListener iAMapListener3 = this.mMapListener;
                if (iAMapListener3 != null) {
                    iAMapListener3.afterRendererOver(i2, getMapState(i2));
                }
            }
        } catch (Throwable unused) {
        }
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public void OnIndoorBuildingActivity(int i2, byte[] bArr) {
        IAMapDelegate iAMapDelegate = this.mGlMapView;
        if (iAMapDelegate != null) {
            try {
                iAMapDelegate.onIndoorBuildingActivity(i2, bArr);
            } catch (Throwable th) {
                th.printStackTrace();
            }
        }
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public TileProviderInner getTerrainTileProvider() {
        return this.terrainTileProvider.getTileProvider();
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public List<BitmapDescriptor> getSkyBoxImages() {
        return this.terrainTileProvider.getSkyBoxImages();
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public BitmapDescriptor getDefaultTerrainImage() {
        return this.terrainTileProvider.getDefaultTerrain();
    }

    public void triggerMainThread() {
        nativeMainThreadTrigger(this.mEngineID, this.mNativeMapengineInstance);
    }

    public Context getContext() {
        return this.context;
    }

    public void setParamater(int i2, int i3, int i4, int i5, int i6, int i7) {
        this.mLock.lock();
        try {
            long j2 = this.mNativeMapengineInstance;
            if (j2 != 0) {
                nativeSetParameter(i2, j2, i3, i4, i5, i6, i7);
            }
        } finally {
            this.mLock.unlock();
        }
    }

    public long getNativeInstance() {
        return this.mNativeMapengineInstance;
    }

    public boolean canStopMapRender(int i2) {
        return this.isEngineRenderComplete;
    }

    public int getEngineIDWithType(int i2) {
        return this.mEngineID;
    }

    public boolean isEngineCreated(int i2) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            return nativeIsEngineCreated(j2, i2);
        }
        return false;
    }

    public int getEngineIDWithGestureInfo(EAMapPlatformGestureInfo eAMapPlatformGestureInfo) {
        return this.mEngineID;
    }

    public void setServiceViewRect(int i2, int i3, int i4, int i5, int i6, int i7, int i8) {
        nativeSetServiceViewRect(i2, this.mNativeMapengineInstance, i3, i4, i5, i6, i7, i8);
    }

    public void setSrvViewStateBoolValue(int i2, int i3, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetSrvViewStateBoolValue(i2, j2, i3, z);
        }
    }

    public boolean getSrvViewStateBoolValue(int i2, int i3) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            return nativeGetSrvViewStateBoolValue(i2, j2, i3);
        }
        return false;
    }

    public void setIndoorBuildingToBeActive(int i2, String str, int i3, String str2) {
        if (TextUtils.isEmpty(str) || TextUtils.isEmpty(str2)) {
            return;
        }
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetIndoorBuildingToBeActive(i2, j2, str, i3, str2);
        }
    }

    public void setMapListener(IAMapListener iAMapListener) {
        this.mMapListener = iAMapListener;
    }

    public GLMapState getMapState(int i2) {
        this.mLock.lock();
        try {
            long j2 = this.mNativeMapengineInstance;
            if (j2 != 0 && this.state == null) {
                long nativeGetCurrentMapState = nativeGetCurrentMapState(i2, j2);
                if (nativeGetCurrentMapState != 0) {
                    this.state = new GLMapState(i2, this.mNativeMapengineInstance, nativeGetCurrentMapState);
                }
            }
            this.mLock.unlock();
            return this.state;
        } catch (Throwable th) {
            this.mLock.unlock();
            throw th;
        }
    }

    @Override // com.autonavi.amap.api.mapcore.IGLMapEngine
    public IGLMapState getNewMapState(int i2) {
        this.mLock.lock();
        try {
            long j2 = this.mNativeMapengineInstance;
            if (j2 != 0) {
                return new GLMapState(i2, j2);
            }
            this.mLock.unlock();
            return null;
        } finally {
            this.mLock.unlock();
        }
    }

    public GLMapState getCloneMapState() {
        this.mLock.lock();
        try {
            long j2 = this.mNativeMapengineInstance;
            if (j2 != 0) {
                if (this.copyGLMapState == null) {
                    this.copyGLMapState = new GLMapState(this.mEngineID, j2);
                }
                this.copyGLMapState.setMapZoomer(this.mGlMapView.getMapConfig().getSZ());
                this.copyGLMapState.setCameraDegree(this.mGlMapView.getMapConfig().getSC());
                this.copyGLMapState.setMapAngle(this.mGlMapView.getMapConfig().getSR());
                this.copyGLMapState.setMapGeoCenter(this.mGlMapView.getMapConfig().getSX(), this.mGlMapView.getMapConfig().getSY());
            }
            this.mLock.unlock();
            return this.copyGLMapState;
        } catch (Throwable th) {
            this.mLock.unlock();
            throw th;
        }
    }

    public void setMapState(int i2, GLMapState gLMapState) {
        setMapState(i2, gLMapState, true);
    }

    public void setMapState(int i2, GLMapState gLMapState, boolean z) {
        IAMapDelegate iAMapDelegate;
        if (this.mNativeMapengineInstance != 0) {
            if (z && (iAMapDelegate = this.mGlMapView) != null && iAMapDelegate.getMapConfig() != null) {
                this.mGlMapView.checkMapState(gLMapState);
            }
            this.mLock.lock();
            try {
                gLMapState.setNativeMapengineState(i2, this.mNativeMapengineInstance);
            } finally {
                this.mLock.unlock();
            }
        }
    }

    private void initAnimation() {
        AbstractCameraUpdateMessage remove;
        if (this.mStateMessageList.size() > 0) {
            return;
        }
        synchronized (this.mAnimateStateMessageList) {
            remove = this.mAnimateStateMessageList.size() > 0 ? this.mAnimateStateMessageList.remove(0) : null;
        }
        if (remove != null) {
            remove.generateMapAnimation(this);
        }
    }

    public void addGestureMessage(int i2, AbstractGestureMapMessage abstractGestureMapMessage, boolean z, int i3, int i4) {
        if (abstractGestureMapMessage == null) {
            return;
        }
        abstractGestureMapMessage.isGestureScaleByMapCenter = z;
        synchronized (this.mGestureMessageList) {
            this.mGestureMessageList.add(abstractGestureMapMessage);
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:16:0x0040, code lost:
    
        r1.setCameraDegree(com.amap.api.col.p0003sl.dv.a(r6.mGlMapView.getMapConfig(), r1.getCameraDegree(), r1.getMapZoomer()));
        setMapState(r6.mEngineID, r1);
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private boolean processMessage() {
        /*
            r6 = this;
            r0 = 0
            int r1 = r6.mEngineID     // Catch: java.lang.Exception -> L61
            com.autonavi.amap.api.mapcore.IGLMapState r1 = r6.getNewMapState(r1)     // Catch: java.lang.Exception -> L61
            com.autonavi.base.ae.gmap.GLMapState r1 = (com.autonavi.base.ae.gmap.GLMapState) r1     // Catch: java.lang.Exception -> L61
            boolean r2 = r6.processGestureMessage(r1)     // Catch: java.lang.Exception -> L61
            java.util.List<com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage> r3 = r6.mGestureMessageList     // Catch: java.lang.Exception -> L61
            int r3 = r3.size()     // Catch: java.lang.Exception -> L61
            r4 = 1
            if (r3 > 0) goto L23
            if (r2 != 0) goto L21
            boolean r2 = r6.processStateMapMessage(r1)     // Catch: java.lang.Exception -> L61
            if (r2 == 0) goto L1f
            goto L21
        L1f:
            r2 = r0
            goto L34
        L21:
            r2 = r4
            goto L34
        L23:
            java.util.List<com.autonavi.amap.mapcore.AbstractCameraUpdateMessage> r3 = r6.mStateMessageList     // Catch: java.lang.Exception -> L61
            monitor-enter(r3)     // Catch: java.lang.Exception -> L61
            java.util.List<com.autonavi.amap.mapcore.AbstractCameraUpdateMessage> r5 = r6.mStateMessageList     // Catch: java.lang.Throwable -> L5e
            int r5 = r5.size()     // Catch: java.lang.Throwable -> L5e
            if (r5 <= 0) goto L33
            java.util.List<com.autonavi.amap.mapcore.AbstractCameraUpdateMessage> r5 = r6.mStateMessageList     // Catch: java.lang.Throwable -> L5e
            r5.clear()     // Catch: java.lang.Throwable -> L5e
        L33:
            monitor-exit(r3)     // Catch: java.lang.Throwable -> L5e
        L34:
            if (r2 != 0) goto L3e
            boolean r2 = r6.processAnimations(r1)     // Catch: java.lang.Exception -> L61
            if (r2 == 0) goto L3d
            goto L3e
        L3d:
            r4 = r0
        L3e:
            if (r4 == 0) goto L5a
            float r2 = r1.getCameraDegree()     // Catch: java.lang.Exception -> L61
            com.autonavi.base.amap.api.mapcore.IAMapDelegate r3 = r6.mGlMapView     // Catch: java.lang.Exception -> L61
            com.autonavi.base.amap.mapcore.MapConfig r3 = r3.getMapConfig()     // Catch: java.lang.Exception -> L61
            float r5 = r1.getMapZoomer()     // Catch: java.lang.Exception -> L61
            float r2 = com.amap.api.col.p0003sl.dv.a(r3, r2, r5)     // Catch: java.lang.Exception -> L61
            r1.setCameraDegree(r2)     // Catch: java.lang.Exception -> L61
            int r2 = r6.mEngineID     // Catch: java.lang.Exception -> L61
            r6.setMapState(r2, r1)     // Catch: java.lang.Exception -> L61
        L5a:
            r1.recycle()     // Catch: java.lang.Exception -> L61
            return r4
        L5e:
            r1 = move-exception
            monitor-exit(r3)     // Catch: java.lang.Throwable -> L5e
            throw r1     // Catch: java.lang.Exception -> L61
        L61:
            r1 = move-exception
            r1.printStackTrace()
            return r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.autonavi.base.ae.gmap.GLMapEngine.processMessage():boolean");
    }

    /* JADX WARN: Code restructure failed: missing block: B:20:0x003d, code lost:
    
        if (r3.width != 0) goto L27;
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x003f, code lost:
    
        r3.width = r5.mGlMapView.getMapWidth();
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x0049, code lost:
    
        if (r3.height != 0) goto L30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x004b, code lost:
    
        r3.height = r5.mGlMapView.getMapHeight();
     */
    /* JADX WARN: Code restructure failed: missing block: B:25:0x0053, code lost:
    
        r2 = r3.getMapGestureState();
     */
    /* JADX WARN: Code restructure failed: missing block: B:26:0x0059, code lost:
    
        if (r2 != 100) goto L33;
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x005b, code lost:
    
        gestureBegin();
     */
    /* JADX WARN: Code restructure failed: missing block: B:31:0x0061, code lost:
    
        if (r2 != 101) goto L36;
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x0063, code lost:
    
        r3.runCameraUpdate(r6);
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x0069, code lost:
    
        if (r2 != 102) goto L49;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x006b, code lost:
    
        gestureEnd();
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private boolean processGestureMessage(com.autonavi.base.ae.gmap.GLMapState r6) {
        /*
            r5 = this;
            java.util.List<com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage> r0 = r5.mGestureMessageList
            int r0 = r0.size()
            r1 = 0
            if (r0 > 0) goto L10
            boolean r6 = r5.isGestureStep
            if (r6 == 0) goto Lf
            r5.isGestureStep = r1
        Lf:
            return r1
        L10:
            r0 = 1
            r5.isGestureStep = r0
            if (r6 != 0) goto L16
            return r1
        L16:
            java.util.List<com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage> r2 = r5.mGestureMessageList
            monitor-enter(r2)
            java.util.List<com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage> r3 = r5.mGestureMessageList     // Catch: java.lang.Throwable -> L74
            int r3 = r3.size()     // Catch: java.lang.Throwable -> L74
            if (r3 <= 0) goto L2a
            java.util.List<com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage> r3 = r5.mGestureMessageList     // Catch: java.lang.Throwable -> L74
            java.lang.Object r3 = r3.remove(r1)     // Catch: java.lang.Throwable -> L74
            com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage r3 = (com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage) r3     // Catch: java.lang.Throwable -> L74
            goto L2b
        L2a:
            r3 = 0
        L2b:
            if (r3 != 0) goto L3a
            monitor-exit(r2)     // Catch: java.lang.Throwable -> L74
            java.util.List<com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage> r6 = r5.mGestureEndMessageList
            int r6 = r6.size()
            if (r6 <= 0) goto L39
            r5.recycleMessage()
        L39:
            return r0
        L3a:
            monitor-exit(r2)     // Catch: java.lang.Throwable -> L74
            int r2 = r3.width
            if (r2 != 0) goto L47
            com.autonavi.base.amap.api.mapcore.IAMapDelegate r2 = r5.mGlMapView
            int r2 = r2.getMapWidth()
            r3.width = r2
        L47:
            int r2 = r3.height
            if (r2 != 0) goto L53
            com.autonavi.base.amap.api.mapcore.IAMapDelegate r2 = r5.mGlMapView
            int r2 = r2.getMapHeight()
            r3.height = r2
        L53:
            int r2 = r3.getMapGestureState()
            r4 = 100
            if (r2 != r4) goto L5f
            r5.gestureBegin()
            goto L6e
        L5f:
            r4 = 101(0x65, float:1.42E-43)
            if (r2 != r4) goto L67
            r3.runCameraUpdate(r6)
            goto L6e
        L67:
            r4 = 102(0x66, float:1.43E-43)
            if (r2 != r4) goto L6e
            r5.gestureEnd()
        L6e:
            java.util.List<com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage> r2 = r5.mGestureEndMessageList
            r2.add(r3)
            goto L16
        L74:
            r6 = move-exception
            monitor-exit(r2)     // Catch: java.lang.Throwable -> L74
            throw r6
        */
        throw new UnsupportedOperationException("Method not decompiled: com.autonavi.base.ae.gmap.GLMapEngine.processGestureMessage(com.autonavi.base.ae.gmap.GLMapState):boolean");
    }

    private boolean processAnimations(GLMapState gLMapState) {
        try {
            if (this.mapAnimationMgr.getAnimationsCount() <= 0) {
                return false;
            }
            gLMapState.recalculate();
            this.mapAnimationMgr.doAnimations(gLMapState);
            return true;
        } catch (Throwable th) {
            th.printStackTrace();
            return false;
        }
    }

    public void interruptAnimation() {
        if (isInMapAnimation(this.mEngineID)) {
            try {
                doMapAnimationCancelCallback(this.mapAnimationMgr.getCancelCallback());
                clearAnimations(this.mEngineID, false);
            } catch (Throwable th) {
                jt.c(th, getClass().getName(), "CancelableCallback.onCancel");
                th.printStackTrace();
            }
        }
    }

    @Override // com.autonavi.amap.api.mapcore.IGLMapEngine
    public void addGroupAnimation(int i2, int i3, float f2, int i4, int i5, int i6, int i7, AMap.CancelableCallback cancelableCallback) {
        AdglMapAnimGroup adglMapAnimGroup = new AdglMapAnimGroup(i3);
        adglMapAnimGroup.setToCameraDegree(i5, 0);
        adglMapAnimGroup.setToMapAngle(i4, 0);
        adglMapAnimGroup.setToMapLevel(f2, 0);
        adglMapAnimGroup.setToMapCenterGeo(i6, i7, 0);
        if (this.mapAnimationMgr == null || !adglMapAnimGroup.isValid()) {
            return;
        }
        this.mapAnimationMgr.addAnimation(adglMapAnimGroup, cancelableCallback);
    }

    private void doMapAnimationCancelCallback(final AMap.CancelableCallback cancelableCallback) {
        IAMapDelegate iAMapDelegate;
        if (cancelableCallback == null || (iAMapDelegate = this.mGlMapView) == null) {
            return;
        }
        iAMapDelegate.getMainHandler().post(new Runnable() { // from class: com.autonavi.base.ae.gmap.GLMapEngine.1
            @Override // java.lang.Runnable
            public void run() {
                try {
                    cancelableCallback.onCancel();
                } catch (Throwable th) {
                    th.printStackTrace();
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void doMapAnimationFinishCallback(final AMap.CancelableCallback cancelableCallback) {
        IAMapDelegate iAMapDelegate;
        IAMapListener iAMapListener = this.mMapListener;
        if (iAMapListener != null) {
            iAMapListener.afterAnimation();
        }
        if (cancelableCallback == null || (iAMapDelegate = this.mGlMapView) == null) {
            return;
        }
        iAMapDelegate.getMainHandler().post(new Runnable() { // from class: com.autonavi.base.ae.gmap.GLMapEngine.2
            @Override // java.lang.Runnable
            public void run() {
                try {
                    cancelableCallback.onFinish();
                } catch (Throwable th) {
                    th.printStackTrace();
                }
            }
        });
    }

    public boolean isInMapAnimation(int i2) {
        return getAnimateionsCount() > 0;
    }

    public int getAnimateionsCount() {
        if (this.mNativeMapengineInstance != 0) {
            return this.mapAnimationMgr.getAnimationsCount();
        }
        return 0;
    }

    public void clearAnimations(int i2, boolean z) {
        this.mapAnimationMgr.clearAnimations();
    }

    public void clearAnimations(int i2, boolean z, int i3) {
        this.mapAnimationMgr.clearAnimations();
    }

    public void startMapSlidAnim(int i2, Point point, float f2, float f3) {
        if (point == null) {
            return;
        }
        try {
            clearAnimations(i2, true);
            GLMapState cloneMapState = getCloneMapState();
            cloneMapState.reset();
            cloneMapState.recalculate();
            float abs = Math.abs(f2);
            float abs2 = Math.abs(f3);
            float f4 = 12000.0f;
            if ((abs > abs2 ? abs : abs2) > 12000.0f) {
                if (abs > abs2) {
                    f4 = (12000.0f / abs) * f3;
                    f2 = f2 > 0.0f ? 12000.0f : -12000.0f;
                } else {
                    float f5 = (12000.0f / abs2) * f2;
                    if (f3 > 0.0f) {
                        f2 = f5;
                    } else {
                        f2 = f5;
                        f3 = -12000.0f;
                    }
                }
                f3 = f4;
            }
            if (this.mGlMapView.getMapConfig().isTerrainEnable()) {
                AdglMapAnimFlingP20 adglMapAnimFlingP20 = new AdglMapAnimFlingP20(500);
                adglMapAnimFlingP20.setPositionAndVelocity(f2, f3);
                adglMapAnimFlingP20.commitAnimation(cloneMapState);
                this.mapAnimationMgr.addAnimation(adglMapAnimFlingP20, null);
                return;
            }
            int mapWidth = this.mGlMapView.getMapWidth() >> 1;
            int mapHeight = this.mGlMapView.getMapHeight() >> 1;
            if (this.mGlMapView.isUseAnchor()) {
                mapWidth = this.mGlMapView.getMapConfig().getAnchorX();
                mapHeight = this.mGlMapView.getMapConfig().getAnchorY();
            }
            AdglMapAnimFling adglMapAnimFling = new AdglMapAnimFling(500, mapWidth, mapHeight);
            adglMapAnimFling.setPositionAndVelocity(f2, f3);
            adglMapAnimFling.commitAnimation(cloneMapState);
            this.mapAnimationMgr.addAnimation(adglMapAnimFling, null);
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private void gestureBegin() {
        this.mapGestureCount++;
    }

    private void gestureEnd() {
        int i2 = this.mapGestureCount - 1;
        this.mapGestureCount = i2;
        if (i2 == 0) {
            recycleMessage();
        }
    }

    public int getStateMessageCount() {
        return this.mStateMessageList.size();
    }

    public void addMessage(AbstractCameraUpdateMessage abstractCameraUpdateMessage, boolean z) {
        if (z) {
            synchronized (this.mAnimateStateMessageList) {
                this.mAnimateStateMessageList.clear();
                this.mAnimateStateMessageList.add(abstractCameraUpdateMessage);
            }
            return;
        }
        synchronized (this.mStateMessageList) {
            this.mStateMessageList.add(abstractCameraUpdateMessage);
        }
    }

    public AbstractCameraUpdateMessage getStateMessage() {
        synchronized (this.mStateMessageList) {
            if (this.mStateMessageList.size() == 0) {
                return null;
            }
            return this.mStateMessageList.remove(0);
        }
    }

    private void recycleMessage() {
        AbstractGestureMapMessage remove;
        while (this.mGestureEndMessageList.size() > 0 && (remove = this.mGestureEndMessageList.remove(0)) != null) {
            if (remove instanceof MoveGestureMapMessage) {
                ((MoveGestureMapMessage) remove).recycle();
            } else if (remove instanceof HoverGestureMapMessage) {
                ((HoverGestureMapMessage) remove).recycle();
            } else if (remove instanceof RotateGestureMapMessage) {
                ((RotateGestureMapMessage) remove).recycle();
            } else if (remove instanceof ScaleGestureMapMessage) {
                ((ScaleGestureMapMessage) remove).recycle();
            }
        }
    }

    private boolean processStateMapMessage(GLMapState gLMapState) {
        AbstractCameraUpdateMessage remove;
        if (this.mStateMessageList.size() <= 0) {
            if (this.isMoveCameraStep) {
                this.isMoveCameraStep = false;
            }
            return false;
        }
        this.isMoveCameraStep = true;
        if (gLMapState == null) {
            return false;
        }
        while (true) {
            synchronized (this.mStateMessageList) {
                remove = this.mStateMessageList.size() > 0 ? this.mStateMessageList.remove(0) : null;
                if (remove == null) {
                    return true;
                }
            }
            if (remove.width == 0) {
                remove.width = this.mGlMapView.getMapWidth();
            }
            if (remove.height == 0) {
                remove.height = this.mGlMapView.getMapHeight();
            }
            gLMapState.recalculate();
            remove.runCameraUpdate(gLMapState);
        }
    }

    public void initMapOpenLayer(String str) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0 || str == null) {
            return;
        }
        nativeInitOpenLayer(this.mEngineID, j2, str.getBytes());
    }

    public void setMapOpenLayerEnable(boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetOpenLayerEnable(this.mEngineID, j2, z);
        }
    }

    public void pushRendererState() {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativePushRendererState(this.mEngineID, j2);
        }
    }

    public void popRendererState() {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativePopRenderState(this.mEngineID, j2);
        }
    }

    public int[] getMapModeState(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0) {
            return null;
        }
        nativeGetMapModeState(i2, j2, z);
        return null;
    }

    public boolean setNativeMapModeAndStyle(int i2, int i3, int i4) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0) {
            return false;
        }
        return nativeSetMapModeAndStyle(i2, j2, new int[]{i3, i4});
    }

    public boolean setMapModeAndStyle(int i2, int i3, int i4, boolean z, StyleItem[] styleItemArr) {
        if (this.mNativeMapengineInstance == 0) {
            return false;
        }
        boolean nativeMapModeAndStyle = setNativeMapModeAndStyle(i2, i3, i4);
        if (styleItemArr != null && z) {
            int customBackgroundColor = this.mGlMapView.getMapConfig().getCustomBackgroundColor();
            if (customBackgroundColor != 0) {
                setBackgroundTexture(i2, dv.a(FileUtil.readFileContentsFromAssets(this.context, AMapEngineUtils.MAP_CUSTOM_ASSETS_NAME + File.separator + AMapEngineUtils.MAP_MAP_ASSETS_CUSTOM_BACKGROUND_NAME), customBackgroundColor));
            }
            String customTextureResourcePath = this.mGlMapView.getMapConfig().getCustomTextureResourcePath();
            if (this.mGlMapView.getMapConfig().isProFunctionAuthEnable() && !TextUtils.isEmpty(customTextureResourcePath)) {
                this.mGlMapView.getMapConfig().setUseProFunction(true);
                setCustomStyleTexture(i2, FileUtil.readFileContents(customTextureResourcePath));
            }
        } else if (i3 == 0 && i4 == 0) {
            setBackgroundTexture(i2, FileUtil.readFileContentsFromAssets(this.context, AMapEngineUtils.MAP_MAP_ASSETS_NAME + File.separator + AMapEngineUtils.MAP_MAP_ASSETS_BACKGROUND_NAME));
            setCustomStyleTexture(i2, FileUtil.readFileContentsFromAssets(this.context, AMapEngineUtils.MAP_MAP_ASSETS_NAME + File.separator + AMapEngineUtils.MAP_MAP_ASSETS_ICON_5_NAME));
        }
        return nativeMapModeAndStyle;
    }

    public void setNetStatus(boolean z) {
        if (this.mRequestDestroy) {
            return;
        }
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0) {
            return;
        }
        nativeSetNetStatus(j2, z ? 1 : 0);
    }

    public long createOverlay(int i2, int i3) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            return nativeCreateOverlay(i2, j2, i3);
        }
        return 0L;
    }

    public String addNativeOverlay(int i2, int i3, int i4) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0) {
            return null;
        }
        String nativeAddNativeOverlay = nativeAddNativeOverlay(i2, j2, i3, i4);
        if (TextUtils.isEmpty(nativeAddNativeOverlay)) {
            return null;
        }
        return nativeAddNativeOverlay;
    }

    public long getGlOverlayMgrPtr(int i2) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            return nativeGetGlOverlayMgrPtr(i2, j2);
        }
        return 0L;
    }

    public void setOvelayBundle(int i2, GLOverlayBundle<BaseMapOverlay<?, ?>> gLOverlayBundle) {
        this.bundle = gLOverlayBundle;
    }

    public void addOverlayTexture(int i2, GLTextureProperty gLTextureProperty) {
        if (this.mNativeMapengineInstance == 0 || gLTextureProperty == null || gLTextureProperty.mBitmap == null || gLTextureProperty.mBitmap.isRecycled()) {
            return;
        }
        nativeAddOverlayTexture(i2, this.mNativeMapengineInstance, gLTextureProperty.mId, gLTextureProperty.mAnchor, gLTextureProperty.mXRatio, gLTextureProperty.mYRatio, gLTextureProperty.mBitmap, gLTextureProperty.isGenMimps, gLTextureProperty.isRepeat);
    }

    public int createOverlayTexture(int i2, Bitmap bitmap) {
        if (this.mNativeMapengineInstance == 0 || bitmap == null || bitmap.isRecycled()) {
            return -1;
        }
        return nativeCreateTextureFromImage(i2, this.mNativeMapengineInstance, bitmap);
    }

    public GLOverlayBundle getOverlayBundle(int i2) {
        return this.bundle;
    }

    public void destroyOverlay(int i2, long j2) {
        synchronized (GLMapEngine.class) {
            nativeDestroyOverlay(i2, j2);
        }
    }

    public void setSimple3DEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetSimple3DEnable(i2, j2, z);
        }
    }

    public void setStyleChangeGradualEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetStyleChangeGradualEnable(i2, j2, z);
        }
    }

    public void setRoadArrowEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetRoadArrowEnable(i2, j2, z);
        }
    }

    public void setNaviLabelEnable(int i2, boolean z, int i3, int i4) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetNaviLabelEnable(i2, j2, z, i3, i4);
        }
    }

    public void setSkyTexture(int i2, byte[] bArr) {
        if (bArr == null) {
            return;
        }
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetSkyTexture(i2, j2, bArr);
        }
    }

    public void setBackgroundTexture(int i2, byte[] bArr) {
        if (bArr == null) {
            return;
        }
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetSetBackgroundTexture(i2, j2, bArr);
        }
    }

    public void setCustomStyleTexture(int i2, byte[] bArr) {
        if (bArr == null) {
            return;
        }
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetCustomStyleTexture(i2, j2, bArr);
        }
    }

    public boolean checkCustomStyleData(int i2, byte[] bArr) {
        if (bArr == null) {
            return false;
        }
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0) {
            return false;
        }
        return nativeCheckCustomStyleData(i2, j2, bArr);
    }

    public void setCustomStyleData(int i2, byte[] bArr, byte[] bArr2) {
        if (bArr == null) {
            return;
        }
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetCustomStyleData(i2, j2, bArr, bArr2);
        }
    }

    public void setCustomThirdLayerStyle(int i2, String str) {
        if (TextUtils.isEmpty(str)) {
            return;
        }
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetCustomThirdLayerStyle(this.mEngineID, j2, str);
        }
    }

    public void setTrafficEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetTrafficEnable(i2, j2, z);
        }
    }

    public void setBuildingEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetBuildingEnable(i2, j2, z);
        }
    }

    public void setLabelEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetLabelEnable(i2, j2, z);
        }
    }

    public void setAllContentEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            if (z) {
                nativeSetAllContentEnable(i2, j2, true);
            } else {
                nativeSetAllContentEnable(i2, j2, false);
            }
            setSimple3DEnable(i2, false);
        }
    }

    public void setProjectionCenter(int i2, int i3, int i4) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetProjectionCenter(i2, j2, i3, i4);
        }
    }

    public void setTrafficStyleWithTextureData(int i2, byte[] bArr) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0 || bArr == null) {
            return;
        }
        nativeSetTrafficTextureAllInOne(i2, j2, bArr);
    }

    public void setTrafficStyleWithTexture(int i2, byte[] bArr, MyTrafficStyle myTrafficStyle) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0 || myTrafficStyle == null) {
            return;
        }
        nativeSetTrafficTexture(i2, j2, bArr, bArr.length, myTrafficStyle.getExtremelySmoothColor(), myTrafficStyle.getSmoothColor(), myTrafficStyle.getSlowColor(), myTrafficStyle.getCongestedColor(), myTrafficStyle.getSeriousCongestedColor());
    }

    public void startCheckEngineRenderComplete() {
        this.isEngineRenderComplete = false;
    }

    public void getCurTileIDs(int i2, int[] iArr) {
        if (iArr != null) {
            for (int i3 = 0; i3 < iArr.length; i3++) {
                iArr[i3] = 0;
            }
            nativeGetCurTileIDs(i2, this.mNativeMapengineInstance, iArr, iArr.length);
        }
    }

    public void setIndoorEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetIndoorEnable(i2, j2, z);
        }
    }

    public void setOfflineDataEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetOfflineDataEnable(i2, j2, z);
        }
    }

    public void setHighlightSubwayEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetHighlightSubwayEnable(i2, j2, z);
        }
    }

    public void setBuildingTextureEnable(int i2, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeSetBuildingTextureEnable(i2, j2, z);
        }
    }

    public void initNativeTexture(int i2) {
        try {
            BitmapDescriptor fromAsset = BitmapDescriptorFactory.fromAsset("arrow/arrow_line_inner.png");
            Bitmap bitmap = fromAsset != null ? fromAsset.getBitmap() : null;
            BitmapDescriptor fromAsset2 = BitmapDescriptorFactory.fromAsset("arrow/arrow_line_outer.png");
            Bitmap bitmap2 = fromAsset2 != null ? fromAsset2.getBitmap() : null;
            BitmapDescriptor fromAsset3 = BitmapDescriptorFactory.fromAsset("arrow/arrow_line_shadow.png");
            Bitmap bitmap3 = fromAsset3 != null ? fromAsset3.getBitmap() : null;
            addOverlayTexture(i2, bitmap, 111, 4);
            addOverlayTexture(i2, bitmap2, AMapEngineUtils.ARROW_LINE_OUTER_TEXTURE_ID, 4);
            addOverlayTexture(i2, bitmap3, AMapEngineUtils.ARROW_LINE_SHADOW_TEXTURE_ID, 4);
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    public void addOverlayTexture(int i2, Bitmap bitmap, int i3, int i4) {
        GLTextureProperty gLTextureProperty = new GLTextureProperty();
        gLTextureProperty.mId = i3;
        gLTextureProperty.mAnchor = i4;
        gLTextureProperty.mBitmap = bitmap;
        gLTextureProperty.mXRatio = 0.0f;
        gLTextureProperty.mYRatio = 0.0f;
        gLTextureProperty.isGenMimps = true;
        addOverlayTexture(i2, gLTextureProperty);
    }

    public void updateNativeArrowOverlay(int i2, String str, int[] iArr, int[] iArr2, int i3, int i4, int i5, float f2, int i6, int i7, int i8, boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0 || str == null) {
            return;
        }
        nativeUpdateNativeArrowOverlay(i2, j2, str, iArr, iArr2, i3, i4, i5, f2, z, i6, i7, i8);
    }

    public void removeNativeOverlay(int i2, String str) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0 || str == null) {
            return;
        }
        nativeRemoveNativeOverlay(i2, j2, str);
    }

    public void removeNativeAllOverlay(int i2) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            nativeRemoveNativeAllOverlay(i2, j2);
        }
    }

    public Bitmap getScreenShot(int i2, int i3, int i4, int i5, int i6) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            return dv.a(nativeGetScreenShot(i2, j2, i3, i4, i5, i6), i5 - i3, i6 - i4, true);
        }
        return null;
    }

    public GLMapEngine(Context context, IAMapDelegate iAMapDelegate) {
        this.mGlMapView = null;
        this.mapAnimationMgr = null;
        this.mRequestDestroy = false;
        this.terrainTileProvider = null;
        this.mRequestDestroy = false;
        if (context == null) {
            return;
        }
        this.context = context.getApplicationContext();
        this.mGlMapView = iAMapDelegate;
        this.mTextTextureGenerator = new TextTextureGenerator();
        AdglMapAnimationMgr adglMapAnimationMgr = new AdglMapAnimationMgr();
        this.mapAnimationMgr = adglMapAnimationMgr;
        adglMapAnimationMgr.setMapAnimationListener(new AdglMapAnimationMgr.MapAnimationListener() { // from class: com.autonavi.base.ae.gmap.GLMapEngine.3
            @Override // com.autonavi.base.ae.gmap.glanimation.AdglMapAnimationMgr.MapAnimationListener
            public void onMapAnimationFinish(AMap.CancelableCallback cancelableCallback) {
                GLMapEngine.this.doMapAnimationFinishCallback(cancelableCallback);
            }
        });
        this.terrainTileProvider = new TerrainOverlayProvider(iAMapDelegate.getGlOverlayLayer());
        this.mEngineID = GLEngineIDController.getController().generate();
    }

    public boolean createAMapInstance(InitParam initParam) {
        if (initParam == null) {
            return false;
        }
        synchronized (GLMapEngine.class) {
            DisplayMetrics displayMetrics = this.context.getResources().getDisplayMetrics();
            int i2 = displayMetrics.densityDpi;
            float f2 = displayMetrics.density;
            float adapterDpiScale = adapterDpiScale(displayMetrics, displayMetrics.widthPixels, displayMetrics.heightPixels, displayMetrics.densityDpi);
            this.mGlMapView.getMapConfig().setTerrainEnable(MapsInitializer.isTerrainEnable());
            int i3 = MapsInitializer.isTerrainEnable() ? 1 : 0;
            nativeInitParam(initParam.mRootPath, initParam.mConfigContent, initParam.mOfflineDataPath, initParam.mP3dCrossPath, "https://mpsapi.amap.com/", "https://m5.amap.com/", i2);
            InitStorageParam.Holder.initPath(initParam.mP3dCrossPath);
            long nativeCreateAMapInstance = nativeCreateAMapInstance(i2, f2, adapterDpiScale, i3);
            this.mNativeMapengineInstance = nativeCreateAMapInstance;
            if (nativeCreateAMapInstance == 0) {
                return false;
            }
            if (MapsInitializer.isTerrainEnable()) {
                nativeInitContourLineOptions(this.mNativeMapengineInstance, MapsInitializer.isContourLineEnable());
            }
            nativeInitAMapEngineCallback(this.mNativeMapengineInstance, this);
            if (!NetworkProxyManager.getInstance().isReady()) {
                NetworkProxyManager.getInstance().initContext(this.context);
                NetworkProxyManager.getInstance().init();
            }
            NetworkProxyManager.getInstance().notifyMapEngineCreated(this.mEngineID, this);
            return true;
        }
    }

    private static String getEMUI() {
        try {
            Class<?> cls = Class.forName("android.os.SystemProperties");
            return (String) cls.getDeclaredMethod("get", String.class).invoke(cls, "ro.build.version.emui");
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    /* JADX WARN: Can't wrap try/catch for region: R(7:12|(2:13|14)|16|17|18|19|(4:24|(1:26)|27|(1:31)(2:29|30))(1:23)) */
    /* JADX WARN: Code restructure failed: missing block: B:33:0x0067, code lost:
    
        r8 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:34:0x0068, code lost:
    
        r8.printStackTrace();
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x006c, code lost:
    
        r8 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x006d, code lost:
    
        r8.printStackTrace();
     */
    /* JADX WARN: Code restructure failed: missing block: B:38:0x004d, code lost:
    
        r4 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:39:0x004e, code lost:
    
        r4.printStackTrace();
     */
    /* JADX WARN: Code restructure failed: missing block: B:40:0x0056, code lost:
    
        r4 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x0052, code lost:
    
        r4 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:42:0x0053, code lost:
    
        r4.printStackTrace();
     */
    /* JADX WARN: Removed duplicated region for block: B:21:0x0072 A[ADDED_TO_REGION] */
    /* JADX WARN: Removed duplicated region for block: B:26:0x007f  */
    /* JADX WARN: Removed duplicated region for block: B:29:0x0085  */
    /* JADX WARN: Removed duplicated region for block: B:31:? A[RETURN, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private float adapterDpiScale(android.util.DisplayMetrics r8, int r9, int r10, int r11) {
        /*
            r7 = this;
            java.lang.String r0 = getEMUI()
            r1 = 1065353216(0x3f800000, float:1.0)
            if (r0 == 0) goto L86
            boolean r2 = r0.isEmpty()
            if (r2 != 0) goto L86
            java.lang.String r2 = "EmotionUI_8"
            int r2 = r0.indexOf(r2)
            r3 = -1
            if (r2 != r3) goto L1f
            java.lang.String r2 = "EmotionUI_9"
            int r0 = r0.indexOf(r2)
            if (r0 == r3) goto L86
        L1f:
            if (r11 <= 0) goto L86
            r0 = 1
            r2 = 0
            java.lang.Class<android.util.DisplayMetrics> r3 = android.util.DisplayMetrics.class
            java.lang.String r4 = "noncompatWidthPixels"
            java.lang.reflect.Field r3 = r3.getDeclaredField(r4)     // Catch: java.lang.IllegalAccessException -> L33 java.lang.NoSuchFieldException -> L38
            r3.setAccessible(r0)     // Catch: java.lang.IllegalAccessException -> L33 java.lang.NoSuchFieldException -> L38
            int r3 = r3.getInt(r8)     // Catch: java.lang.IllegalAccessException -> L33 java.lang.NoSuchFieldException -> L38
            goto L3d
        L33:
            r3 = move-exception
            r3.printStackTrace()
            goto L3c
        L38:
            r3 = move-exception
            r3.printStackTrace()
        L3c:
            r3 = r2
        L3d:
            java.lang.Class<android.util.DisplayMetrics> r4 = android.util.DisplayMetrics.class
            java.lang.String r5 = "noncompatHeightPixels"
            java.lang.reflect.Field r4 = r4.getDeclaredField(r5)     // Catch: java.lang.IllegalAccessException -> L4d java.lang.NoSuchFieldException -> L52
            r4.setAccessible(r0)     // Catch: java.lang.IllegalAccessException -> L4d java.lang.NoSuchFieldException -> L52
            int r4 = r4.getInt(r8)     // Catch: java.lang.IllegalAccessException -> L4d java.lang.NoSuchFieldException -> L52
            goto L57
        L4d:
            r4 = move-exception
            r4.printStackTrace()
            goto L56
        L52:
            r4 = move-exception
            r4.printStackTrace()
        L56:
            r4 = r2
        L57:
            java.lang.Class<android.util.DisplayMetrics> r5 = android.util.DisplayMetrics.class
            java.lang.String r6 = "noncompatDensityDpi"
            java.lang.reflect.Field r5 = r5.getDeclaredField(r6)     // Catch: java.lang.IllegalAccessException -> L67 java.lang.NoSuchFieldException -> L6c
            r5.setAccessible(r0)     // Catch: java.lang.IllegalAccessException -> L67 java.lang.NoSuchFieldException -> L6c
            int r2 = r5.getInt(r8)     // Catch: java.lang.IllegalAccessException -> L67 java.lang.NoSuchFieldException -> L6c
            goto L70
        L67:
            r8 = move-exception
            r8.printStackTrace()
            goto L70
        L6c:
            r8 = move-exception
            r8.printStackTrace()
        L70:
            if (r2 > r11) goto L76
            if (r3 > r9) goto L76
            if (r4 <= r10) goto L86
        L76:
            float r8 = (float) r2
            float r9 = (float) r11
            float r8 = r8 / r9
            r9 = 1073741824(0x40000000, float:2.0)
            int r10 = (r8 > r9 ? 1 : (r8 == r9 ? 0 : -1))
            if (r10 <= 0) goto L80
            r8 = r9
        L80:
            int r9 = (r8 > r1 ? 1 : (r8 == r1 ? 0 : -1))
            if (r9 >= 0) goto L85
            goto L86
        L85:
            r1 = r8
        L86:
            return r1
        */
        throw new UnsupportedOperationException("Method not decompiled: com.autonavi.base.ae.gmap.GLMapEngine.adapterDpiScale(android.util.DisplayMetrics, int, int, int):float");
    }

    public void createAMapEngineWithFrame(MapViewInitParam mapViewInitParam) {
        if (this.mNativeMapengineInstance != 0) {
            synchronized (GLMapEngine.class) {
                nativeCreateAMapEngineWithFrame(this.mNativeMapengineInstance, mapViewInitParam.engineId, mapViewInitParam.x, mapViewInitParam.y, mapViewInitParam.width, mapViewInitParam.height, mapViewInitParam.screenWidth, mapViewInitParam.screenHeight, mapViewInitParam.screenScale, mapViewInitParam.textScale, mapViewInitParam.mapZoomScale, mapViewInitParam.taskThreadCount);
            }
            if (this.mGlMapView.getMapConfig().isTerrainEnable()) {
                setCustomStyleData(mapViewInitParam.engineId, FileUtil.uncompressToByteArray(FileUtil.readFileContentsFromAssets(this.context, "map_assets/style_1_17_for_terrain.data")), null);
            }
        }
    }

    public void renderAMap() {
        if (this.mNativeMapengineInstance != 0) {
            boolean processMessage = processMessage();
            synchronized (GLMapEngine.class) {
                nativeRenderAMap(this.mNativeMapengineInstance, this.mEngineID);
                nativePostRenderAMap(this.mNativeMapengineInstance, this.mEngineID);
            }
            initAnimation();
            if (processMessage) {
                startCheckEngineRenderComplete();
            }
            if (this.isEngineRenderComplete) {
                return;
            }
            nativeSetRenderListenerStatus(this.mEngineID, this.mNativeMapengineInstance);
        }
    }

    public void destroyAMapEngine() {
        try {
            this.mRequestDestroy = true;
            synchronized (this.mutLock) {
                if (this.mNativeMapengineInstance != 0) {
                    this.mLock.lock();
                    try {
                        GLMapState gLMapState = this.copyGLMapState;
                        if (gLMapState != null) {
                            gLMapState.recycle();
                        }
                        this.mLock.unlock();
                        nativeDestroyCurrentState(this.mNativeMapengineInstance, this.state.getNativeInstance());
                        nativeDestroy(this.mNativeMapengineInstance);
                    } catch (Throwable th) {
                        this.mLock.unlock();
                        throw th;
                    }
                }
                this.mNativeMapengineInstance = 0L;
                NetworkProxyManager.getInstance().notifyMapEngineDestroyed(this.mEngineID);
            }
            this.mGlMapView = null;
            synchronized (this.mStateMessageList) {
                this.mStateMessageList.clear();
            }
            synchronized (this.mAnimateStateMessageList) {
                this.mAnimateStateMessageList.clear();
            }
            synchronized (this.mGestureMessageList) {
                this.mGestureMessageList.clear();
            }
            this.mGestureEndMessageList.clear();
            this.mMapListener = null;
            this.bundle = null;
            dt.b();
        } catch (Throwable th2) {
            th2.printStackTrace();
            dv.a(th2);
        }
    }

    public long getNativeMapController(int i2) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 != 0) {
            return nativeGetNativeMapController(i2, j2);
        }
        return 0L;
    }

    public boolean isNetworkConnected() {
        return this.isNetworkConnected;
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public InitStorageParam getStorageInitParam() {
        return InitStorageParam.obtain();
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public void onMapPOIClick(MapPoi mapPoi) {
        IAMapListener iAMapListener = this.mMapListener;
        if (iAMapListener != null) {
            iAMapListener.onMapPOIClick(mapPoi);
        }
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public void onMapBlandClick(double d2, double d3) {
        IAMapListener iAMapListener = this.mMapListener;
        if (iAMapListener != null) {
            iAMapListener.onMapBlankClick(d2, d3);
        }
    }

    @Override // com.autonavi.base.amap.mapcore.IAMapEngineCallback
    public void onAMapAppResourceRequest(AMapAppRequestParam aMapAppRequestParam) {
        IAMapDelegate iAMapDelegate = this.mGlMapView;
        if (iAMapDelegate != null) {
            iAMapDelegate.onAMapAppResourceRequest(aMapAppRequestParam);
        }
    }

    public void setVectorOverlayPath(String str) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0) {
            return;
        }
        nativeSetVectorOverlayPath(this.mEngineID, j2, str);
    }

    public void setTerrainAuth(boolean z) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0) {
            return;
        }
        nativeSetTerrainAuth(this.mEngineID, j2, z);
    }

    public void addGestureSingleTapMessage(float f2, float f3) {
        nativeAddGestureSingleTapMessage(this.mEngineID, this.mNativeMapengineInstance, f2, f3);
    }

    public int hideBuildings(List<LatLng> list) {
        if (this.mNativeMapengineInstance == 0) {
            return -1;
        }
        LatLng[] latLngArr = new LatLng[list.size()];
        list.toArray(latLngArr);
        return nativeHideBuildings(this.mEngineID, this.mNativeMapengineInstance, latLngArr);
    }

    public void showHideBuildings(int i2) {
        long j2 = this.mNativeMapengineInstance;
        if (j2 == 0) {
            return;
        }
        nativeShowHideBuildings(this.mEngineID, j2, i2);
    }
}
