package com.autonavi.base.ae.gmap;

import android.content.Context;
import com.amap.api.col.p0003sl.dt;
import com.amap.api.col.p0003sl.dv;
import com.amap.api.col.p0003sl.jt;
import com.amap.api.col.p0003sl.ma;
import com.amap.api.maps.MapsInitializer;
import com.autonavi.amap.mapcore.tools.GlMapUtil;
import com.autonavi.base.amap.mapcore.maploader.AMapLoader;
import com.autonavi.base.amap.mapcore.maploader.NetworkState;
import com.autonavi.base.amap.mapcore.tools.GLConvertUtil;
import java.util.Iterator;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/* loaded from: classes.dex */
public class NetworkProxyManager {
    private static NetworkProxyManager sInstance;
    private Context context;
    private NetworkProxy networkProxy;
    private NetworkState networkState;
    private String userAgent;
    private boolean isNetworkConnected = false;
    private Map<Long, AMapLoader> aMapLoaderHashtable = new ConcurrentHashMap();
    private Map<Long, GLMapEngine> engines = new ConcurrentHashMap();
    private NetworkState.NetworkChangeListener networkChangeListener = new NetworkState.NetworkChangeListener() { // from class: com.autonavi.base.ae.gmap.NetworkProxyManager.1
        @Override // com.autonavi.base.amap.mapcore.maploader.NetworkState.NetworkChangeListener
        public void networkStateChanged(Context context) {
            NetworkProxyManager.this.isNetworkConnected = NetworkState.isNetworkConnected(context);
            Iterator it2 = NetworkProxyManager.this.engines.entrySet().iterator();
            while (it2.hasNext()) {
                ((GLMapEngine) ((Map.Entry) it2.next()).getValue()).setNetStatus(NetworkProxyManager.this.isNetworkConnected);
            }
        }
    };

    private static native void nativeCancelDownLoad(long j2);

    private static native long nativeCreateNetworkProxy(Object obj);

    private static native void nativeDestroyNetworkProxy(long j2);

    private static native void nativeFailedDownLoad(long j2, int i2);

    private static native void nativeFinishDownLoad(long j2);

    private static native void nativeInitNetworkProxy(long j2);

    private static native void nativeReceiveNetData(byte[] bArr, long j2, int i2);

    public static NetworkProxyManager getInstance() {
        if (sInstance == null) {
            sInstance = new NetworkProxyManager();
        }
        return sInstance;
    }

    private NetworkProxyManager() {
    }

    public void init() {
        NetworkProxy createNetworkProxy = createNetworkProxy();
        this.networkProxy = createNetworkProxy;
        initNetworkProxy(createNetworkProxy);
        initNetworkState();
    }

    public boolean isReady() {
        return (this.context == null || this.networkProxy == null || this.networkState == null) ? false : true;
    }

    public void destroy() {
        NetworkProxy networkProxy = this.networkProxy;
        if (networkProxy != null) {
            destroyNetworkProxy(networkProxy);
            this.networkProxy = null;
        }
        releaseNetworkState();
        this.context = null;
    }

    public void initContext(Context context) {
        if (context == null) {
            return;
        }
        this.context = context.getApplicationContext();
    }

    public NetworkProxy createNetworkProxy() {
        return new NetworkProxy(nativeCreateNetworkProxy(this));
    }

    public void initNetworkProxy(NetworkProxy networkProxy) {
        nativeInitNetworkProxy(networkProxy.networkProxyInstance);
    }

    public void destroyNetworkProxy(NetworkProxy networkProxy) {
        nativeDestroyNetworkProxy(networkProxy.networkProxyInstance);
    }

    public boolean isNetworkConnected() {
        return this.isNetworkConnected;
    }

    public String getUserAgent() {
        return this.userAgent;
    }

    private void initNetworkState() {
        this.userAgent = System.getProperty("http.agent") + " amap/" + GlMapUtil.getAppVersionName(this.context);
        NetworkState networkState = new NetworkState();
        this.networkState = networkState;
        networkState.setNetworkListener(this.networkChangeListener);
        this.networkState.registerNetChangeReceiver(this.context.getApplicationContext(), true);
        this.isNetworkConnected = NetworkState.isNetworkConnected(this.context.getApplicationContext());
    }

    private void releaseNetworkState() {
        NetworkState networkState = this.networkState;
        if (networkState != null) {
            networkState.registerNetChangeReceiver(this.context.getApplicationContext(), false);
            this.networkState.setNetworkListener(null);
            this.networkState = null;
        }
    }

    public void notifyMapEngineCreated(long j2, GLMapEngine gLMapEngine) {
        this.engines.put(Long.valueOf(j2), gLMapEngine);
    }

    private synchronized void cancelAllAMapDownload() {
        try {
            Iterator it2 = new ConcurrentHashMap(this.aMapLoaderHashtable).entrySet().iterator();
            while (it2.hasNext()) {
                ((AMapLoader) ((Map.Entry) it2.next()).getValue()).doCancelAndNotify();
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    public void notifyMapEngineDestroyed(long j2) {
        this.engines.remove(Long.valueOf(j2));
        cancelAllAMapDownload();
    }

    public synchronized int requireMapDataAsyn(int i2, byte[] bArr) {
        if (bArr != null) {
            AMapLoader.ADataRequestParam aDataRequestParam = new AMapLoader.ADataRequestParam();
            int i3 = GLConvertUtil.getInt(bArr, 0);
            aDataRequestParam.requestBaseUrl = GLConvertUtil.getString(bArr, 4, i3);
            int i4 = i3 + 4;
            int i5 = GLConvertUtil.getInt(bArr, i4);
            int i6 = i4 + 4;
            aDataRequestParam.requestUrl = GLConvertUtil.getString(bArr, i6, i5);
            int i7 = i6 + i5;
            aDataRequestParam.handler = GLConvertUtil.getLong(bArr, i7);
            int i8 = i7 + 8;
            aDataRequestParam.nRequestType = GLConvertUtil.getInt(bArr, i8);
            int i9 = i8 + 4;
            int i10 = GLConvertUtil.getInt(bArr, i9);
            int i11 = i9 + 4;
            aDataRequestParam.enCodeString = GLConvertUtil.getSubBytes(bArr, i11, i10);
            aDataRequestParam.nCompress = GLConvertUtil.getInt(bArr, i11 + i10);
            final AMapLoader aMapLoader = new AMapLoader(this.context, aDataRequestParam);
            this.aMapLoaderHashtable.put(Long.valueOf(aDataRequestParam.handler), aMapLoader);
            try {
                dt.a().a(new ma() { // from class: com.autonavi.base.ae.gmap.NetworkProxyManager.2
                    @Override // com.amap.api.col.p0003sl.ma
                    public void runTask() {
                        try {
                            aMapLoader.doRequest();
                        } catch (Throwable th) {
                            jt.c(th, "download Thread", "AMapLoader doRequest");
                            dv.a(th);
                        }
                    }
                });
            } catch (Throwable th) {
                jt.c(th, "download Thread", "requireMapData");
                dv.a(th);
            }
        }
        return 0;
    }

    public synchronized void receiveNetData(long j2, byte[] bArr, int i2) {
        if (this.aMapLoaderHashtable.containsKey(Long.valueOf(j2))) {
            nativeReceiveNetData(bArr, j2, i2);
        }
    }

    public synchronized void finishDownLoad(long j2) {
        if (this.aMapLoaderHashtable.containsKey(Long.valueOf(j2))) {
            nativeFinishDownLoad(j2);
            this.aMapLoaderHashtable.remove(Long.valueOf(j2));
        }
    }

    public synchronized void netStop(long j2, int i2) {
        if (this.aMapLoaderHashtable.containsKey(Long.valueOf(j2))) {
            nativeFailedDownLoad(j2, -1);
            this.aMapLoaderHashtable.remove(Long.valueOf(j2));
        }
    }

    public synchronized void netCancel(long j2, int i2) {
        if (this.aMapLoaderHashtable.containsKey(Long.valueOf(j2))) {
            nativeFailedDownLoad(j2, -1);
            this.aMapLoaderHashtable.remove(Long.valueOf(j2));
        }
    }

    public synchronized void netError(long j2, int i2, int i3) {
        if (this.aMapLoaderHashtable.containsKey(Long.valueOf(j2))) {
            nativeFailedDownLoad(j2, i3);
            this.aMapLoaderHashtable.remove(Long.valueOf(j2));
            try {
                if (MapsInitializer.getExceptionLogger() != null) {
                    MapsInitializer.getExceptionLogger().onDownloaderException(i2, i3);
                }
            } catch (Throwable unused) {
            }
        }
    }
}
