package com.autonavi.base.amap.mapcore.message;

import com.autonavi.amap.mapcore.IPoint;
import com.autonavi.base.ae.gmap.GLMapState;
import com.autonavi.base.ae.gmap.maploader.Pools;

/* loaded from: classes.dex */
public class RotateGestureMapMessage extends AbstractGestureMapMessage {
    private static final Pools.SynchronizedPool<RotateGestureMapMessage> M_POOL = new Pools.SynchronizedPool<>(256);
    public float angleDelta;
    public int pivotX;
    public int pivotY;

    @Override // com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage, com.autonavi.base.ae.gmap.AbstractMapMessage
    public int getType() {
        return 2;
    }

    public static RotateGestureMapMessage obtain(int i2, float f2, int i3, int i4) {
        RotateGestureMapMessage acquire = M_POOL.acquire();
        if (acquire == null) {
            return new RotateGestureMapMessage(i2, f2, i3, i4);
        }
        acquire.reset();
        acquire.setParams(i2, f2, i3, i4);
        return acquire;
    }

    public void recycle() {
        M_POOL.release(this);
    }

    public static void destory() {
        M_POOL.destory();
    }

    private void setParams(int i2, float f2, int i3, int i4) {
        setState(i2);
        this.angleDelta = f2;
        this.pivotX = i3;
        this.pivotY = i4;
    }

    public RotateGestureMapMessage(int i2, float f2, int i3, int i4) {
        super(i2);
        this.pivotX = 0;
        this.pivotY = 0;
        this.angleDelta = 0.0f;
        setParams(i2, f2, i3, i4);
        this.angleDelta = f2;
        this.pivotX = i3;
        this.pivotY = i4;
    }

    @Override // com.autonavi.base.amap.mapcore.message.AbstractGestureMapMessage
    public void runCameraUpdate(GLMapState gLMapState) {
        IPoint obtain;
        IPoint obtain2;
        float mapAngle = gLMapState.getMapAngle() + this.angleDelta;
        if (this.isGestureScaleByMapCenter) {
            gLMapState.setMapAngle(mapAngle);
            gLMapState.recalculate();
            return;
        }
        int i2 = this.pivotX;
        int i3 = this.pivotY;
        if (this.isUseAnchor) {
            i2 = this.anchorX;
            i3 = this.anchorY;
        }
        if (i2 > 0 || i3 > 0) {
            obtain = IPoint.obtain();
            obtain2 = IPoint.obtain();
            win2geo(gLMapState, i2, i3, obtain);
            gLMapState.setMapGeoCenter(obtain.x, obtain.y);
        } else {
            obtain = null;
            obtain2 = null;
        }
        gLMapState.setMapAngle(mapAngle);
        gLMapState.recalculate();
        if (i2 > 0 || i3 > 0) {
            win2geo(gLMapState, i2, i3, obtain2);
            if (obtain != null) {
                gLMapState.setMapGeoCenter((obtain.x * 2) - obtain2.x, (obtain.y * 2) - obtain2.y);
            }
            gLMapState.recalculate();
        }
        if (obtain != null) {
            obtain.recycle();
        }
        if (obtain2 != null) {
            obtain2.recycle();
        }
    }
}
