package com.dd.plist;

import com.google.firebase.crashlytics.buildtools.reloc.org.apache.http.protocol.HTTP;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.nio.CharBuffer;
import java.nio.charset.CharacterCodingException;
import java.nio.charset.Charset;
import java.nio.charset.CharsetEncoder;
import java.text.ParseException;
import java.text.StringCharacterIterator;
import java.util.Iterator;
import java.util.LinkedList;

/* loaded from: classes.dex */
public class ASCIIPropertyListParser {
    public static final char ARRAY_BEGIN_TOKEN = '(';
    public static final char ARRAY_END_TOKEN = ')';
    public static final char ARRAY_ITEM_DELIMITER_TOKEN = ',';
    public static final char COMMENT_BEGIN_TOKEN = '/';
    public static final char DATA_BEGIN_TOKEN = '<';
    public static final char DATA_END_TOKEN = '>';
    public static final char DATA_GSBOOL_BEGIN_TOKEN = 'B';
    public static final char DATA_GSBOOL_FALSE_TOKEN = 'N';
    public static final char DATA_GSBOOL_TRUE_TOKEN = 'Y';
    public static final char DATA_GSDATE_BEGIN_TOKEN = 'D';
    public static final char DATA_GSINT_BEGIN_TOKEN = 'I';
    public static final char DATA_GSOBJECT_BEGIN_TOKEN = '*';
    public static final char DATA_GSREAL_BEGIN_TOKEN = 'R';
    public static final char DATE_APPLE_DATE_TIME_DELIMITER = 'T';
    public static final char DATE_APPLE_END_TOKEN = 'Z';
    public static final char DATE_DATE_FIELD_DELIMITER = '-';
    public static final char DATE_GS_DATE_TIME_DELIMITER = ' ';
    public static final char DATE_TIME_FIELD_DELIMITER = ':';
    public static final char DICTIONARY_ASSIGN_TOKEN = '=';
    public static final char DICTIONARY_BEGIN_TOKEN = '{';
    public static final char DICTIONARY_END_TOKEN = '}';
    public static final char DICTIONARY_ITEM_DELIMITER_TOKEN = ';';
    public static final char MULTILINE_COMMENT_END_TOKEN = '/';
    public static final char MULTILINE_COMMENT_SECOND_TOKEN = '*';
    public static final char QUOTEDSTRING_BEGIN_TOKEN = '\"';
    public static final char QUOTEDSTRING_END_TOKEN = '\"';
    public static final char QUOTEDSTRING_ESCAPE_TOKEN = '\\';
    public static final char SINGLELINE_COMMENT_SECOND_TOKEN = '/';
    public static final char WHITESPACE_CARRIAGE_RETURN = '\r';
    public static final char WHITESPACE_NEWLINE = '\n';
    public static final char WHITESPACE_SPACE = ' ';
    public static final char WHITESPACE_TAB = '\t';
    private static CharsetEncoder asciiEncoder;
    private byte[] data;
    private int index;

    public static NSObject parse(File file) throws IOException, ParseException {
        return parse(new FileInputStream(file));
    }

    public static NSObject parse(InputStream inputStream) throws ParseException, IOException {
        byte[] readAll = PropertyListParser.readAll(inputStream);
        inputStream.close();
        return parse(readAll);
    }

    public static NSObject parse(byte[] bArr) throws ParseException {
        return new ASCIIPropertyListParser(bArr).parse();
    }

    protected ASCIIPropertyListParser() {
    }

    private ASCIIPropertyListParser(byte[] bArr) {
        this.data = bArr;
    }

    private boolean acceptSequence(char... cArr) {
        for (int i2 = 0; i2 < cArr.length; i2++) {
            if (this.data[this.index + i2] != cArr[i2]) {
                return false;
            }
        }
        return true;
    }

    private boolean accept(char... cArr) {
        boolean z = false;
        for (char c2 : cArr) {
            if (this.data[this.index] == c2) {
                z = true;
            }
        }
        return z;
    }

    private boolean accept(char c2) {
        return this.data[this.index] == c2;
    }

    private void expect(char... cArr) throws ParseException {
        if (accept(cArr)) {
            return;
        }
        String str = "Expected '" + cArr[0] + "'";
        for (int i2 = 1; i2 < cArr.length; i2++) {
            str = str + " or '" + cArr[i2] + "'";
        }
        throw new ParseException(str + " but found '" + ((char) this.data[this.index]) + "'", this.index);
    }

    private void expect(char c2) throws ParseException {
        if (accept(c2)) {
            return;
        }
        throw new ParseException("Expected '" + c2 + "' but found '" + ((char) this.data[this.index]) + "'", this.index);
    }

    private void read(char c2) throws ParseException {
        expect(c2);
        this.index++;
    }

    private void skip() {
        this.index++;
    }

    private void skip(int i2) {
        this.index += i2;
    }

    private void skipWhitespacesAndComments() {
        while (true) {
            if (accept('\r', '\n', ' ', '\t')) {
                skip();
            } else {
                boolean z = true;
                if (acceptSequence('/', '/')) {
                    skip(2);
                    readInputUntil('\r', '\n');
                } else if (acceptSequence('/', '*')) {
                    skip(2);
                    while (!acceptSequence('*', '/')) {
                        skip();
                    }
                    skip(2);
                } else {
                    z = false;
                }
                if (!z) {
                    return;
                }
            }
        }
    }

    private String readInputUntil(char... cArr) {
        String str = "";
        while (!accept(cArr)) {
            str = str + ((char) this.data[this.index]);
            skip();
        }
        return str;
    }

    private String readInputUntil(char c2) {
        String str = "";
        while (!accept(c2)) {
            str = str + ((char) this.data[this.index]);
            skip();
        }
        return str;
    }

    public NSObject parse() throws ParseException {
        this.index = 0;
        byte[] bArr = this.data;
        if (bArr.length >= 3 && (bArr[0] & 255) == 239 && (bArr[1] & 255) == 187 && (bArr[2] & 255) == 191) {
            skip(3);
        }
        skipWhitespacesAndComments();
        expect(DICTIONARY_BEGIN_TOKEN, ARRAY_BEGIN_TOKEN, '/');
        try {
            return parseObject();
        } catch (ArrayIndexOutOfBoundsException unused) {
            throw new ParseException("Reached end of input unexpectedly.", this.index);
        }
    }

    private NSObject parseObject() throws ParseException {
        byte b2 = this.data[this.index];
        if (b2 == 34) {
            String parseQuotedString = parseQuotedString();
            if (parseQuotedString.length() == 20 && parseQuotedString.charAt(4) == '-') {
                try {
                    return new NSDate(parseQuotedString);
                } catch (Exception unused) {
                    return new NSString(parseQuotedString);
                }
            }
            return new NSString(parseQuotedString);
        }
        if (b2 == 40) {
            return parseArray();
        }
        if (b2 == 60) {
            return parseData();
        }
        if (b2 == 123) {
            return parseDictionary();
        }
        if (b2 > 47 && b2 < 58) {
            return parseDateString();
        }
        return new NSString(parseString());
    }

    private NSArray parseArray() throws ParseException {
        skip();
        skipWhitespacesAndComments();
        LinkedList linkedList = new LinkedList();
        while (!accept(ARRAY_END_TOKEN)) {
            linkedList.add(parseObject());
            skipWhitespacesAndComments();
            if (!accept(ARRAY_ITEM_DELIMITER_TOKEN)) {
                break;
            }
            skip();
            skipWhitespacesAndComments();
        }
        read(ARRAY_END_TOKEN);
        return new NSArray((NSObject[]) linkedList.toArray(new NSObject[linkedList.size()]));
    }

    private NSDictionary parseDictionary() throws ParseException {
        String parseString;
        skip();
        skipWhitespacesAndComments();
        NSDictionary nSDictionary = new NSDictionary();
        while (!accept(DICTIONARY_END_TOKEN)) {
            if (accept('\"')) {
                parseString = parseQuotedString();
            } else {
                parseString = parseString();
            }
            skipWhitespacesAndComments();
            read(DICTIONARY_ASSIGN_TOKEN);
            skipWhitespacesAndComments();
            nSDictionary.put(parseString, parseObject());
            skipWhitespacesAndComments();
            read(DICTIONARY_ITEM_DELIMITER_TOKEN);
            skipWhitespacesAndComments();
        }
        skip();
        return nSDictionary;
    }

    private NSObject parseData() throws ParseException {
        NSObject nSObject;
        NSObject nSNumber;
        skip();
        if (accept('*')) {
            skip();
            expect(DATA_GSBOOL_BEGIN_TOKEN, DATA_GSDATE_BEGIN_TOKEN, DATA_GSINT_BEGIN_TOKEN, DATA_GSREAL_BEGIN_TOKEN);
            if (accept(DATA_GSBOOL_BEGIN_TOKEN)) {
                skip();
                expect(DATA_GSBOOL_TRUE_TOKEN, DATA_GSBOOL_FALSE_TOKEN);
                if (accept(DATA_GSBOOL_TRUE_TOKEN)) {
                    nSObject = new NSNumber(true);
                } else {
                    nSObject = new NSNumber(false);
                }
                skip();
            } else {
                if (accept(DATA_GSDATE_BEGIN_TOKEN)) {
                    skip();
                    nSNumber = new NSDate(readInputUntil('>'));
                } else if (accept(DATA_GSINT_BEGIN_TOKEN, DATA_GSREAL_BEGIN_TOKEN)) {
                    skip();
                    nSNumber = new NSNumber(readInputUntil('>'));
                } else {
                    nSObject = null;
                }
                nSObject = nSNumber;
            }
            read('>');
            return nSObject;
        }
        String replaceAll = readInputUntil('>').replaceAll("\\s+", "");
        int length = replaceAll.length() / 2;
        byte[] bArr = new byte[length];
        for (int i2 = 0; i2 < length; i2++) {
            int i3 = i2 * 2;
            bArr[i2] = (byte) Integer.parseInt(replaceAll.substring(i3, i3 + 2), 16);
        }
        NSData nSData = new NSData(bArr);
        skip();
        return nSData;
    }

    private NSObject parseDateString() {
        String parseString = parseString();
        if (parseString.length() > 4 && parseString.charAt(4) == '-') {
            try {
                return new NSDate(parseString);
            } catch (Exception unused) {
            }
        }
        return new NSString(parseString);
    }

    private String parseString() {
        return readInputUntil(' ', '\t', '\n', '\r', ARRAY_ITEM_DELIMITER_TOKEN, DICTIONARY_ITEM_DELIMITER_TOKEN, DICTIONARY_ASSIGN_TOKEN, ARRAY_END_TOKEN);
    }

    private String parseQuotedString() throws ParseException {
        skip();
        String str = "";
        boolean z = true;
        while (true) {
            byte[] bArr = this.data;
            int i2 = this.index;
            if (bArr[i2] != 34 || (bArr[i2 - 1] == 92 && z)) {
                str = str + ((char) this.data[this.index]);
                if (accept('\\')) {
                    z = (this.data[this.index - 1] == 92 && z) ? false : true;
                }
                skip();
            } else {
                try {
                    String parseQuotedString = parseQuotedString(str);
                    skip();
                    return parseQuotedString;
                } catch (Exception unused) {
                    throw new ParseException("The quoted string could not be parsed.", this.index);
                }
            }
        }
    }

    public static synchronized String parseQuotedString(String str) throws UnsupportedEncodingException, CharacterCodingException {
        int i2;
        synchronized (ASCIIPropertyListParser.class) {
            LinkedList linkedList = new LinkedList();
            StringCharacterIterator stringCharacterIterator = new StringCharacterIterator(str);
            char current = stringCharacterIterator.current();
            while (true) {
                i2 = 0;
                if (stringCharacterIterator.getIndex() >= stringCharacterIterator.getEndIndex()) {
                    break;
                }
                if (current == '\\') {
                    byte[] bytes = parseEscapedSequence(stringCharacterIterator).getBytes("UTF-8");
                    int length = bytes.length;
                    while (i2 < length) {
                        linkedList.add(Byte.valueOf(bytes[i2]));
                        i2++;
                    }
                } else {
                    linkedList.add((byte) 0);
                    linkedList.add(Byte.valueOf((byte) current));
                }
                current = stringCharacterIterator.next();
            }
            byte[] bArr = new byte[linkedList.size()];
            Iterator it2 = linkedList.iterator();
            while (it2.hasNext()) {
                bArr[i2] = ((Byte) it2.next()).byteValue();
                i2++;
            }
            String str2 = new String(bArr, "UTF-8");
            CharBuffer wrap = CharBuffer.wrap(str2);
            if (asciiEncoder == null) {
                asciiEncoder = Charset.forName(HTTP.ASCII).newEncoder();
            }
            if (!asciiEncoder.canEncode(wrap)) {
                return str2;
            }
            return asciiEncoder.encode(wrap).asCharBuffer().toString();
        }
    }

    private static String parseEscapedSequence(StringCharacterIterator stringCharacterIterator) throws UnsupportedEncodingException {
        char next = stringCharacterIterator.next();
        if (next == '\\') {
            return new String("\u0000\\".getBytes(), "UTF-8");
        }
        if (next == '\"') {
            return new String("\u0000\"".getBytes(), "UTF-8");
        }
        if (next == 'b') {
            return new String(new byte[]{0, 8}, "UTF-8");
        }
        if (next == 'n') {
            return new String(new byte[]{0, 10}, "UTF-8");
        }
        if (next == 'r') {
            return new String(new byte[]{0, 13}, "UTF-8");
        }
        if (next == 't') {
            return new String(new byte[]{0, 9}, "UTF-8");
        }
        if (next == 'U' || next == 'u') {
            return new String(new byte[]{(byte) Integer.parseInt(("" + stringCharacterIterator.next()) + stringCharacterIterator.next(), 16), (byte) Integer.parseInt(("" + stringCharacterIterator.next()) + stringCharacterIterator.next(), 16)}, "UTF-8");
        }
        return new String(new byte[]{0, (byte) Integer.parseInt((("" + next) + stringCharacterIterator.next()) + stringCharacterIterator.next(), 8)}, "UTF-8");
    }
}
