package com.dd.plist;

import android.support.v4.media.session.PlaybackStateCompat;
import java.io.BufferedOutputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

/* loaded from: classes.dex */
public class BinaryPropertyListWriter {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int VERSION_00 = 0;
    public static final int VERSION_10 = 10;
    public static final int VERSION_15 = 15;
    public static final int VERSION_20 = 20;
    private long count;
    private Map<NSObject, Integer> idMap;
    private int idSizeInBytes;
    private OutputStream out;
    private int version;

    private static int computeIdSizeInBytes(int i2) {
        if (i2 < 256) {
            return 1;
        }
        return i2 < 65536 ? 2 : 4;
    }

    private int computeOffsetSizeInBytes(long j2) {
        if (j2 < 256) {
            return 1;
        }
        if (j2 < PlaybackStateCompat.ACTION_PREPARE_FROM_SEARCH) {
            return 2;
        }
        return j2 < 4294967296L ? 4 : 8;
    }

    private static int getMinimumRequiredVersion(NSObject nSObject) {
        int i2 = 10;
        int i3 = 0;
        int i4 = nSObject == null ? 10 : 0;
        if (nSObject instanceof NSDictionary) {
            Iterator<NSObject> it2 = ((NSDictionary) nSObject).getHashMap().values().iterator();
            while (it2.hasNext()) {
                int minimumRequiredVersion = getMinimumRequiredVersion(it2.next());
                if (minimumRequiredVersion > i4) {
                    i4 = minimumRequiredVersion;
                }
            }
            return i4;
        }
        if (nSObject instanceof NSArray) {
            NSObject[] array = ((NSArray) nSObject).getArray();
            int length = array.length;
            while (i3 < length) {
                int minimumRequiredVersion2 = getMinimumRequiredVersion(array[i3]);
                if (minimumRequiredVersion2 > i4) {
                    i4 = minimumRequiredVersion2;
                }
                i3++;
            }
            return i4;
        }
        if (!(nSObject instanceof NSSet)) {
            return i4;
        }
        NSObject[] allObjects = ((NSSet) nSObject).allObjects();
        int length2 = allObjects.length;
        while (i3 < length2) {
            int minimumRequiredVersion3 = getMinimumRequiredVersion(allObjects[i3]);
            if (minimumRequiredVersion3 > i2) {
                i2 = minimumRequiredVersion3;
            }
            i3++;
        }
        return i2;
    }

    public static void write(File file, NSObject nSObject) throws IOException {
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        write(fileOutputStream, nSObject);
        fileOutputStream.close();
    }

    public static void write(OutputStream outputStream, NSObject nSObject) throws IOException {
        int minimumRequiredVersion = getMinimumRequiredVersion(nSObject);
        if (minimumRequiredVersion > 0) {
            throw new IOException("The given property list structure cannot be saved. The required version of the binary format (" + (minimumRequiredVersion != 10 ? minimumRequiredVersion != 15 ? minimumRequiredVersion == 20 ? "v2.0" : "v0.0" : "v1.5" : "v1.0") + ") is not yet supported.");
        }
        new BinaryPropertyListWriter(outputStream, minimumRequiredVersion).write(nSObject);
    }

    public static byte[] writeToArray(NSObject nSObject) throws IOException {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        write(byteArrayOutputStream, nSObject);
        return byteArrayOutputStream.toByteArray();
    }

    BinaryPropertyListWriter(OutputStream outputStream) throws IOException {
        this.version = 0;
        this.idMap = new HashMap();
        this.out = new BufferedOutputStream(outputStream);
    }

    BinaryPropertyListWriter(OutputStream outputStream, int i2) throws IOException {
        this.version = 0;
        this.idMap = new HashMap();
        this.version = i2;
        this.out = new BufferedOutputStream(outputStream);
    }

    void write(NSObject nSObject) throws IOException {
        int i2;
        write(new byte[]{98, 112, 108, 105, 115, 116});
        int i3 = this.version;
        if (i3 == 0) {
            write(new byte[]{48, 48});
        } else if (i3 == 10) {
            write(new byte[]{49, 48});
        } else if (i3 == 15) {
            write(new byte[]{49, 53});
        } else if (i3 == 20) {
            write(new byte[]{50, 48});
        }
        nSObject.assignIDs(this);
        this.idSizeInBytes = computeIdSizeInBytes(this.idMap.size());
        int size = this.idMap.size();
        long[] jArr = new long[size];
        Iterator<Map.Entry<NSObject, Integer>> it2 = this.idMap.entrySet().iterator();
        while (true) {
            if (!it2.hasNext()) {
                break;
            }
            Map.Entry<NSObject, Integer> next = it2.next();
            NSObject key = next.getKey();
            jArr[next.getValue().intValue()] = this.count;
            if (key == null) {
                write(0);
            } else {
                key.toBinary(this);
            }
        }
        long j2 = this.count;
        int computeOffsetSizeInBytes = computeOffsetSizeInBytes(j2);
        for (i2 = 0; i2 < size; i2++) {
            writeBytes(jArr[i2], computeOffsetSizeInBytes);
        }
        if (this.version != 15) {
            write(new byte[6]);
            write(computeOffsetSizeInBytes);
            write(this.idSizeInBytes);
            writeLong(this.idMap.size());
            writeLong(this.idMap.get(nSObject).intValue());
            writeLong(j2);
        }
        this.out.flush();
    }

    void assignID(NSObject nSObject) {
        if (this.idMap.containsKey(nSObject)) {
            return;
        }
        Map<NSObject, Integer> map = this.idMap;
        map.put(nSObject, Integer.valueOf(map.size()));
    }

    int getID(NSObject nSObject) {
        return this.idMap.get(nSObject).intValue();
    }

    void writeIntHeader(int i2, int i3) throws IOException {
        if (i3 < 15) {
            write((i2 << 4) + i3);
            return;
        }
        if (i3 < 256) {
            write((i2 << 4) + 15);
            write(16);
            writeBytes(i3, 1);
        } else if (i3 < 65536) {
            write((i2 << 4) + 15);
            write(17);
            writeBytes(i3, 2);
        } else {
            write((i2 << 4) + 15);
            write(18);
            writeBytes(i3, 4);
        }
    }

    void write(int i2) throws IOException {
        this.out.write(i2);
        this.count++;
    }

    void write(byte[] bArr) throws IOException {
        this.out.write(bArr);
        this.count += bArr.length;
    }

    void writeBytes(long j2, int i2) throws IOException {
        for (int i3 = i2 - 1; i3 >= 0; i3--) {
            write((int) (j2 >> (i3 * 8)));
        }
    }

    void writeID(int i2) throws IOException {
        writeBytes(i2, this.idSizeInBytes);
    }

    void writeLong(long j2) throws IOException {
        writeBytes(j2, 8);
    }

    void writeDouble(double d2) throws IOException {
        writeLong(Double.doubleToRawLongBits(d2));
    }
}
