package com.dd.plist;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;
import org.apache.commons.lang3.time.TimeZones;

/* loaded from: classes.dex */
public class NSDate extends NSObject {
    private static final long EPOCH = 978307200000L;
    private static final SimpleDateFormat sdfDefault;
    private static final SimpleDateFormat sdfGnuStep;
    private Date date;

    static {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'");
        sdfDefault = simpleDateFormat;
        SimpleDateFormat simpleDateFormat2 = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss Z");
        sdfGnuStep = simpleDateFormat2;
        simpleDateFormat.setTimeZone(TimeZone.getTimeZone(TimeZones.GMT_ID));
        simpleDateFormat2.setTimeZone(TimeZone.getTimeZone(TimeZones.GMT_ID));
    }

    private static synchronized Date parseDateString(String str) throws ParseException {
        Date parse;
        synchronized (NSDate.class) {
            try {
                parse = sdfDefault.parse(str);
            } catch (ParseException unused) {
                return sdfGnuStep.parse(str);
            }
        }
        return parse;
    }

    private static synchronized String makeDateString(Date date) {
        String format;
        synchronized (NSDate.class) {
            format = sdfDefault.format(date);
        }
        return format;
    }

    private static synchronized String makeDateStringGnuStep(Date date) {
        String format;
        synchronized (NSDate.class) {
            format = sdfGnuStep.format(date);
        }
        return format;
    }

    public NSDate(byte[] bArr) {
        this.date = new Date(((long) (BinaryPropertyListParser.parseDouble(bArr) * 1000.0d)) + EPOCH);
    }

    public NSDate(String str) throws ParseException {
        this.date = parseDateString(str);
    }

    public NSDate(Date date) {
        if (date == null) {
            throw new IllegalArgumentException("Date cannot be null");
        }
        this.date = date;
    }

    public Date getDate() {
        return this.date;
    }

    public boolean equals(Object obj) {
        return obj.getClass().equals(getClass()) && this.date.equals(((NSDate) obj).getDate());
    }

    public int hashCode() {
        return this.date.hashCode();
    }

    @Override // com.dd.plist.NSObject
    void toXML(StringBuilder sb, int i2) {
        indent(sb, i2);
        sb.append("<date>");
        sb.append(makeDateString(this.date));
        sb.append("</date>");
    }

    @Override // com.dd.plist.NSObject
    public void toBinary(BinaryPropertyListWriter binaryPropertyListWriter) throws IOException {
        binaryPropertyListWriter.write(51);
        binaryPropertyListWriter.writeDouble((this.date.getTime() - EPOCH) / 1000.0d);
    }

    public String toString() {
        return this.date.toString();
    }

    @Override // com.dd.plist.NSObject
    protected void toASCII(StringBuilder sb, int i2) {
        indent(sb, i2);
        sb.append("\"");
        sb.append(makeDateString(this.date));
        sb.append("\"");
    }

    @Override // com.dd.plist.NSObject
    protected void toASCIIGnuStep(StringBuilder sb, int i2) {
        indent(sb, i2);
        sb.append("<*D");
        sb.append(makeDateStringGnuStep(this.date));
        sb.append(">");
    }
}
