package com.dd.plist;

import java.io.IOException;
import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Set;

/* loaded from: classes.dex */
public class NSDictionary extends NSObject implements Map<String, NSObject> {
    private HashMap<String, NSObject> dict = new LinkedHashMap();

    public HashMap<String, NSObject> getHashMap() {
        return this.dict;
    }

    public NSObject objectForKey(String str) {
        return this.dict.get(str);
    }

    @Override // java.util.Map
    public int size() {
        return this.dict.size();
    }

    @Override // java.util.Map
    public boolean isEmpty() {
        return this.dict.isEmpty();
    }

    @Override // java.util.Map
    public boolean containsKey(Object obj) {
        return this.dict.containsKey(obj);
    }

    @Override // java.util.Map
    public boolean containsValue(Object obj) {
        if (obj == null) {
            return false;
        }
        return this.dict.containsValue(NSObject.wrap(obj));
    }

    /* JADX WARN: Can't rename method to resolve collision */
    @Override // java.util.Map
    public NSObject get(Object obj) {
        return this.dict.get(obj);
    }

    @Override // java.util.Map
    public void putAll(Map<? extends String, ? extends NSObject> map) {
        for (Map.Entry<? extends String, ? extends NSObject> entry : map.entrySet()) {
            put(entry.getKey(), entry.getValue());
        }
    }

    @Override // java.util.Map
    public NSObject put(String str, NSObject nSObject) {
        if (str == null) {
            return null;
        }
        if (nSObject == null) {
            return this.dict.get(str);
        }
        return this.dict.put(str, nSObject);
    }

    public NSObject put(String str, Object obj) {
        return put(str, NSObject.wrap(obj));
    }

    public NSObject remove(String str) {
        return this.dict.remove(str);
    }

    /* JADX WARN: Can't rename method to resolve collision */
    @Override // java.util.Map
    public NSObject remove(Object obj) {
        return this.dict.remove(obj);
    }

    @Override // java.util.Map
    public void clear() {
        this.dict.clear();
    }

    @Override // java.util.Map
    public Set<String> keySet() {
        return this.dict.keySet();
    }

    @Override // java.util.Map
    public Collection<NSObject> values() {
        return this.dict.values();
    }

    @Override // java.util.Map
    public Set<Map.Entry<String, NSObject>> entrySet() {
        return this.dict.entrySet();
    }

    public boolean containsKey(String str) {
        return this.dict.containsKey(str);
    }

    public boolean containsValue(NSObject nSObject) {
        return nSObject != null && this.dict.containsValue(nSObject);
    }

    public boolean containsValue(String str) {
        for (NSObject nSObject : this.dict.values()) {
            if (nSObject.getClass().equals(NSString.class) && ((NSString) nSObject).getContent().equals(str)) {
                return true;
            }
        }
        return false;
    }

    public boolean containsValue(long j2) {
        for (NSObject nSObject : this.dict.values()) {
            if (nSObject.getClass().equals(NSNumber.class)) {
                if (((NSNumber) nSObject).isInteger() && r1.intValue() == j2) {
                    return true;
                }
            }
        }
        return false;
    }

    public boolean containsValue(double d2) {
        for (NSObject nSObject : this.dict.values()) {
            if (nSObject.getClass().equals(NSNumber.class)) {
                NSNumber nSNumber = (NSNumber) nSObject;
                if (nSNumber.isReal() && nSNumber.doubleValue() == d2) {
                    return true;
                }
            }
        }
        return false;
    }

    public boolean containsValue(boolean z) {
        for (NSObject nSObject : this.dict.values()) {
            if (nSObject.getClass().equals(NSNumber.class)) {
                NSNumber nSNumber = (NSNumber) nSObject;
                if (nSNumber.isBoolean() && nSNumber.boolValue() == z) {
                    return true;
                }
            }
        }
        return false;
    }

    public boolean containsValue(Date date) {
        for (NSObject nSObject : this.dict.values()) {
            if (nSObject.getClass().equals(NSDate.class) && ((NSDate) nSObject).getDate().equals(date)) {
                return true;
            }
        }
        return false;
    }

    public boolean containsValue(byte[] bArr) {
        for (NSObject nSObject : this.dict.values()) {
            if (nSObject.getClass().equals(NSData.class) && Arrays.equals(((NSData) nSObject).bytes(), bArr)) {
                return true;
            }
        }
        return false;
    }

    public int count() {
        return this.dict.size();
    }

    @Override // java.util.Map
    public boolean equals(Object obj) {
        return obj.getClass().equals(getClass()) && ((NSDictionary) obj).dict.equals(this.dict);
    }

    public String[] allKeys() {
        return (String[]) this.dict.keySet().toArray(new String[count()]);
    }

    @Override // java.util.Map
    public int hashCode() {
        HashMap<String, NSObject> hashMap = this.dict;
        return 581 + (hashMap != null ? hashMap.hashCode() : 0);
    }

    @Override // com.dd.plist.NSObject
    void toXML(StringBuilder sb, int i2) {
        indent(sb, i2);
        sb.append("<dict>");
        sb.append(NSObject.NEWLINE);
        for (String str : this.dict.keySet()) {
            NSObject objectForKey = objectForKey(str);
            int i3 = i2 + 1;
            indent(sb, i3);
            sb.append("<key>");
            if (str.contains("&") || str.contains("<") || str.contains(">")) {
                sb.append("<![CDATA[");
                sb.append(str.replaceAll("]]>", "]]]]><![CDATA[>"));
                sb.append("]]>");
            } else {
                sb.append(str);
            }
            sb.append("</key>");
            sb.append(NSObject.NEWLINE);
            objectForKey.toXML(sb, i3);
            sb.append(NSObject.NEWLINE);
        }
        indent(sb, i2);
        sb.append("</dict>");
    }

    @Override // com.dd.plist.NSObject
    void assignIDs(BinaryPropertyListWriter binaryPropertyListWriter) {
        super.assignIDs(binaryPropertyListWriter);
        for (Map.Entry<String, NSObject> entry : this.dict.entrySet()) {
            new NSString(entry.getKey()).assignIDs(binaryPropertyListWriter);
            entry.getValue().assignIDs(binaryPropertyListWriter);
        }
    }

    @Override // com.dd.plist.NSObject
    void toBinary(BinaryPropertyListWriter binaryPropertyListWriter) throws IOException {
        binaryPropertyListWriter.writeIntHeader(13, this.dict.size());
        Set<Map.Entry<String, NSObject>> entrySet = this.dict.entrySet();
        Iterator<Map.Entry<String, NSObject>> it2 = entrySet.iterator();
        while (it2.hasNext()) {
            binaryPropertyListWriter.writeID(binaryPropertyListWriter.getID(new NSString(it2.next().getKey())));
        }
        Iterator<Map.Entry<String, NSObject>> it3 = entrySet.iterator();
        while (it3.hasNext()) {
            binaryPropertyListWriter.writeID(binaryPropertyListWriter.getID(it3.next().getValue()));
        }
    }

    public String toASCIIPropertyList() {
        StringBuilder sb = new StringBuilder();
        toASCII(sb, 0);
        sb.append(NEWLINE);
        return sb.toString();
    }

    public String toGnuStepASCIIPropertyList() {
        StringBuilder sb = new StringBuilder();
        toASCIIGnuStep(sb, 0);
        sb.append(NEWLINE);
        return sb.toString();
    }

    @Override // com.dd.plist.NSObject
    protected void toASCII(StringBuilder sb, int i2) {
        indent(sb, i2);
        sb.append(ASCIIPropertyListParser.DICTIONARY_BEGIN_TOKEN);
        sb.append(NEWLINE);
        for (String str : allKeys()) {
            NSObject objectForKey = objectForKey(str);
            indent(sb, i2 + 1);
            sb.append("\"");
            sb.append(NSString.escapeStringForASCII(str));
            sb.append("\" =");
            Class<?> cls = objectForKey.getClass();
            if (cls.equals(NSDictionary.class) || cls.equals(NSArray.class) || cls.equals(NSData.class)) {
                sb.append(NEWLINE);
                objectForKey.toASCII(sb, i2 + 2);
            } else {
                sb.append(" ");
                objectForKey.toASCII(sb, 0);
            }
            sb.append(ASCIIPropertyListParser.DICTIONARY_ITEM_DELIMITER_TOKEN);
            sb.append(NEWLINE);
        }
        indent(sb, i2);
        sb.append(ASCIIPropertyListParser.DICTIONARY_END_TOKEN);
    }

    @Override // com.dd.plist.NSObject
    protected void toASCIIGnuStep(StringBuilder sb, int i2) {
        indent(sb, i2);
        sb.append(ASCIIPropertyListParser.DICTIONARY_BEGIN_TOKEN);
        sb.append(NEWLINE);
        for (String str : (String[]) this.dict.keySet().toArray(new String[this.dict.size()])) {
            NSObject objectForKey = objectForKey(str);
            indent(sb, i2 + 1);
            sb.append("\"");
            sb.append(NSString.escapeStringForASCII(str));
            sb.append("\" =");
            Class<?> cls = objectForKey.getClass();
            if (cls.equals(NSDictionary.class) || cls.equals(NSArray.class) || cls.equals(NSData.class)) {
                sb.append(NEWLINE);
                objectForKey.toASCIIGnuStep(sb, i2 + 2);
            } else {
                sb.append(" ");
                objectForKey.toASCIIGnuStep(sb, 0);
            }
            sb.append(ASCIIPropertyListParser.DICTIONARY_ITEM_DELIMITER_TOKEN);
            sb.append(NEWLINE);
        }
        indent(sb, i2);
        sb.append(ASCIIPropertyListParser.DICTIONARY_END_TOKEN);
    }
}
