package com.dd.plist;

import com.facebook.internal.ServerProtocol;
import java.io.IOException;
import okhttp3.internal.ws.WebSocketProtocol;

/* loaded from: classes.dex */
public class NSNumber extends NSObject implements Comparable<Object> {
    public static final int BOOLEAN = 2;
    public static final int INTEGER = 0;
    public static final int REAL = 1;
    private boolean boolValue;
    private double doubleValue;
    private long longValue;
    private int type;

    public NSNumber(byte[] bArr, int i2) {
        if (i2 == 0) {
            long parseLong = BinaryPropertyListParser.parseLong(bArr);
            this.longValue = parseLong;
            this.doubleValue = parseLong;
        } else if (i2 == 1) {
            double parseDouble = BinaryPropertyListParser.parseDouble(bArr);
            this.doubleValue = parseDouble;
            this.longValue = Math.round(parseDouble);
        } else {
            throw new IllegalArgumentException("Type argument is not valid.");
        }
        this.type = i2;
    }

    public NSNumber(String str) {
        if (str == null) {
            throw new IllegalArgumentException("The given string is null and cannot be parsed as number.");
        }
        try {
            long parseLong = Long.parseLong(str);
            this.longValue = parseLong;
            this.doubleValue = parseLong;
            this.type = 0;
        } catch (Exception unused) {
            try {
                try {
                    double parseDouble = Double.parseDouble(str);
                    this.doubleValue = parseDouble;
                    this.longValue = Math.round(parseDouble);
                    this.type = 1;
                } catch (Exception unused2) {
                    boolean z = str.toLowerCase().equals(ServerProtocol.DIALOG_RETURN_SCOPES_TRUE) || str.toLowerCase().equals("yes");
                    this.boolValue = z;
                    if (!z && !str.toLowerCase().equals("false") && !str.toLowerCase().equals("no")) {
                        throw new Exception("not a boolean");
                    }
                    this.type = 2;
                    long j2 = this.boolValue ? 1L : 0L;
                    this.longValue = j2;
                    this.doubleValue = j2;
                }
            } catch (Exception unused3) {
                throw new IllegalArgumentException("The given string neither represents a double, an int nor a boolean value.");
            }
        }
    }

    public NSNumber(int i2) {
        long j2 = i2;
        this.longValue = j2;
        this.doubleValue = j2;
        this.type = 0;
    }

    public NSNumber(long j2) {
        this.longValue = j2;
        this.doubleValue = j2;
        this.type = 0;
    }

    public NSNumber(double d2) {
        this.doubleValue = d2;
        this.longValue = (long) d2;
        this.type = 1;
    }

    public NSNumber(boolean z) {
        this.boolValue = z;
        long j2 = z ? 1L : 0L;
        this.longValue = j2;
        this.doubleValue = j2;
        this.type = 2;
    }

    public int type() {
        return this.type;
    }

    public boolean isBoolean() {
        return this.type == 2;
    }

    public boolean isInteger() {
        return this.type == 0;
    }

    public boolean isReal() {
        return this.type == 1;
    }

    public boolean boolValue() {
        if (this.type == 2) {
            return this.boolValue;
        }
        return this.longValue != 0;
    }

    public long longValue() {
        return this.longValue;
    }

    public int intValue() {
        return (int) this.longValue;
    }

    public double doubleValue() {
        return this.doubleValue;
    }

    public float floatValue() {
        return (float) this.doubleValue;
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof NSNumber)) {
            return false;
        }
        NSNumber nSNumber = (NSNumber) obj;
        return this.type == nSNumber.type && this.longValue == nSNumber.longValue && this.doubleValue == nSNumber.doubleValue && this.boolValue == nSNumber.boolValue;
    }

    public int hashCode() {
        int i2 = this.type * 37;
        long j2 = this.longValue;
        return ((((i2 + ((int) (j2 ^ (j2 >>> 32)))) * 37) + ((int) (Double.doubleToLongBits(this.doubleValue) ^ (Double.doubleToLongBits(this.doubleValue) >>> 32)))) * 37) + (boolValue() ? 1 : 0);
    }

    public String toString() {
        int i2 = this.type;
        if (i2 == 0) {
            return String.valueOf(longValue());
        }
        if (i2 == 1) {
            return String.valueOf(doubleValue());
        }
        if (i2 == 2) {
            return String.valueOf(boolValue());
        }
        return super.toString();
    }

    @Override // com.dd.plist.NSObject
    void toXML(StringBuilder sb, int i2) {
        indent(sb, i2);
        int i3 = this.type;
        if (i3 == 0) {
            sb.append("<integer>");
            sb.append(longValue());
            sb.append("</integer>");
        } else if (i3 == 1) {
            sb.append("<real>");
            sb.append(doubleValue());
            sb.append("</real>");
        } else {
            if (i3 != 2) {
                return;
            }
            if (boolValue()) {
                sb.append("<true/>");
            } else {
                sb.append("<false/>");
            }
        }
    }

    @Override // com.dd.plist.NSObject
    void toBinary(BinaryPropertyListWriter binaryPropertyListWriter) throws IOException {
        int type = type();
        if (type != 0) {
            if (type == 1) {
                binaryPropertyListWriter.write(35);
                binaryPropertyListWriter.writeDouble(doubleValue());
                return;
            } else {
                if (type != 2) {
                    return;
                }
                binaryPropertyListWriter.write(boolValue() ? 9 : 8);
                return;
            }
        }
        if (longValue() < 0) {
            binaryPropertyListWriter.write(19);
            binaryPropertyListWriter.writeBytes(longValue(), 8);
            return;
        }
        if (longValue() <= 255) {
            binaryPropertyListWriter.write(16);
            binaryPropertyListWriter.writeBytes(longValue(), 1);
        } else if (longValue() <= WebSocketProtocol.PAYLOAD_SHORT_MAX) {
            binaryPropertyListWriter.write(17);
            binaryPropertyListWriter.writeBytes(longValue(), 2);
        } else if (longValue() <= 4294967295L) {
            binaryPropertyListWriter.write(18);
            binaryPropertyListWriter.writeBytes(longValue(), 4);
        } else {
            binaryPropertyListWriter.write(19);
            binaryPropertyListWriter.writeBytes(longValue(), 8);
        }
    }

    @Override // com.dd.plist.NSObject
    protected void toASCII(StringBuilder sb, int i2) {
        indent(sb, i2);
        if (this.type == 2) {
            sb.append(this.boolValue ? "YES" : "NO");
        } else {
            sb.append(toString());
        }
    }

    @Override // com.dd.plist.NSObject
    protected void toASCIIGnuStep(StringBuilder sb, int i2) {
        indent(sb, i2);
        int i3 = this.type;
        if (i3 == 0) {
            sb.append("<*I");
            sb.append(toString());
            sb.append(">");
        } else if (i3 == 1) {
            sb.append("<*R");
            sb.append(toString());
            sb.append(">");
        } else {
            if (i3 != 2) {
                return;
            }
            if (this.boolValue) {
                sb.append("<*BY>");
            } else {
                sb.append("<*BN>");
            }
        }
    }

    @Override // java.lang.Comparable
    public int compareTo(Object obj) {
        double doubleValue = doubleValue();
        if (obj instanceof NSNumber) {
            double doubleValue2 = ((NSNumber) obj).doubleValue();
            if (doubleValue < doubleValue2) {
                return -1;
            }
            return doubleValue == doubleValue2 ? 0 : 1;
        }
        if (!(obj instanceof Number)) {
            return -1;
        }
        double doubleValue3 = ((Number) obj).doubleValue();
        if (doubleValue < doubleValue3) {
            return -1;
        }
        return doubleValue == doubleValue3 ? 0 : 1;
    }
}
