package com.dd.plist;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

/* loaded from: classes.dex */
public abstract class NSObject {
    static final int ASCII_LINE_LENGTH = 80;
    static final String INDENT = "\t";
    static final String NEWLINE = System.getProperty("line.separator");

    protected abstract void toASCII(StringBuilder sb, int i2);

    protected abstract void toASCIIGnuStep(StringBuilder sb, int i2);

    abstract void toBinary(BinaryPropertyListWriter binaryPropertyListWriter) throws IOException;

    abstract void toXML(StringBuilder sb, int i2);

    void assignIDs(BinaryPropertyListWriter binaryPropertyListWriter) {
        binaryPropertyListWriter.assignID(this);
    }

    public String toXMLPropertyList() {
        StringBuilder sb = new StringBuilder("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
        String str = NEWLINE;
        sb.append(str);
        sb.append("<!DOCTYPE plist PUBLIC \"-//Apple//DTD PLIST 1.0//EN\" \"http://www.apple.com/DTDs/PropertyList-1.0.dtd\">");
        sb.append(str);
        sb.append("<plist version=\"1.0\">");
        sb.append(str);
        toXML(sb, 0);
        sb.append(str);
        sb.append("</plist>");
        return sb.toString();
    }

    void indent(StringBuilder sb, int i2) {
        for (int i3 = 0; i3 < i2; i3++) {
            sb.append(INDENT);
        }
    }

    public static NSNumber wrap(long j2) {
        return new NSNumber(j2);
    }

    public static NSNumber wrap(double d2) {
        return new NSNumber(d2);
    }

    public static NSNumber wrap(boolean z) {
        return new NSNumber(z);
    }

    public static NSData wrap(byte[] bArr) {
        return new NSData(bArr);
    }

    public static NSArray wrap(Object[] objArr) {
        NSArray nSArray = new NSArray(objArr.length);
        for (int i2 = 0; i2 < objArr.length; i2++) {
            nSArray.setValue(i2, wrap(objArr[i2]));
        }
        return nSArray;
    }

    public static NSDictionary wrap(Map<String, Object> map) {
        NSDictionary nSDictionary = new NSDictionary();
        for (String str : map.keySet()) {
            nSDictionary.put(str, wrap(map.get(str)));
        }
        return nSDictionary;
    }

    public static NSSet wrap(Set<Object> set) {
        NSSet nSSet = new NSSet();
        for (Object obj : set.toArray()) {
            nSSet.addObject(wrap(obj));
        }
        return nSSet;
    }

    public static NSObject wrap(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof NSObject) {
            return (NSObject) obj;
        }
        Class<?> cls = obj.getClass();
        if (Boolean.class.equals(cls)) {
            return wrap(((Boolean) obj).booleanValue());
        }
        if (Byte.class.equals(cls)) {
            return wrap(((Byte) obj).byteValue());
        }
        if (Short.class.equals(cls)) {
            return wrap(((Short) obj).shortValue());
        }
        if (Integer.class.equals(cls)) {
            return wrap(((Integer) obj).intValue());
        }
        if (Long.class.isAssignableFrom(cls)) {
            return wrap(((Long) obj).longValue());
        }
        if (Float.class.equals(cls)) {
            return wrap(((Float) obj).floatValue());
        }
        if (Double.class.isAssignableFrom(cls)) {
            return wrap(((Double) obj).doubleValue());
        }
        if (String.class.equals(cls)) {
            return new NSString((String) obj);
        }
        if (Date.class.equals(cls)) {
            return new NSDate((Date) obj);
        }
        if (cls.isArray()) {
            Class<?> componentType = cls.getComponentType();
            if (componentType.equals(Byte.TYPE)) {
                return wrap((byte[]) obj);
            }
            int i2 = 0;
            if (componentType.equals(Boolean.TYPE)) {
                boolean[] zArr = (boolean[]) obj;
                NSArray nSArray = new NSArray(zArr.length);
                while (i2 < zArr.length) {
                    nSArray.setValue(i2, wrap(zArr[i2]));
                    i2++;
                }
                return nSArray;
            }
            if (Float.TYPE.equals(componentType)) {
                float[] fArr = (float[]) obj;
                NSArray nSArray2 = new NSArray(fArr.length);
                while (i2 < fArr.length) {
                    nSArray2.setValue(i2, wrap(fArr[i2]));
                    i2++;
                }
                return nSArray2;
            }
            if (Double.TYPE.equals(componentType)) {
                double[] dArr = (double[]) obj;
                NSArray nSArray3 = new NSArray(dArr.length);
                while (i2 < dArr.length) {
                    nSArray3.setValue(i2, wrap(dArr[i2]));
                    i2++;
                }
                return nSArray3;
            }
            if (Short.TYPE.equals(componentType)) {
                short[] sArr = (short[]) obj;
                NSArray nSArray4 = new NSArray(sArr.length);
                while (i2 < sArr.length) {
                    nSArray4.setValue(i2, wrap(sArr[i2]));
                    i2++;
                }
                return nSArray4;
            }
            if (Integer.TYPE.equals(componentType)) {
                int[] iArr = (int[]) obj;
                NSArray nSArray5 = new NSArray(iArr.length);
                while (i2 < iArr.length) {
                    nSArray5.setValue(i2, wrap(iArr[i2]));
                    i2++;
                }
                return nSArray5;
            }
            if (Long.TYPE.equals(componentType)) {
                long[] jArr = (long[]) obj;
                NSArray nSArray6 = new NSArray(jArr.length);
                while (i2 < jArr.length) {
                    nSArray6.setValue(i2, wrap(jArr[i2]));
                    i2++;
                }
                return nSArray6;
            }
            return wrap((Object[]) obj);
        }
        if (Map.class.isAssignableFrom(cls)) {
            Map map = (Map) obj;
            Set keySet = map.keySet();
            NSDictionary nSDictionary = new NSDictionary();
            for (Object obj2 : keySet) {
                nSDictionary.put(String.valueOf(obj2), wrap(map.get(obj2)));
            }
            return nSDictionary;
        }
        if (Collection.class.isAssignableFrom(cls)) {
            return wrap(((Collection) obj).toArray());
        }
        return wrapSerialized(obj);
    }

    public static NSData wrapSerialized(Object obj) {
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            new ObjectOutputStream(byteArrayOutputStream).writeObject(obj);
            return new NSData(byteArrayOutputStream.toByteArray());
        } catch (IOException unused) {
            throw new RuntimeException("The given object of class " + obj.getClass().toString() + " could not be serialized and stored in a NSData object.");
        }
    }

    public Object toJavaObject() {
        Set treeSet;
        if (this instanceof NSArray) {
            NSObject[] array = ((NSArray) this).getArray();
            Object[] objArr = new Object[array.length];
            for (int i2 = 0; i2 < array.length; i2++) {
                objArr[i2] = array[i2].toJavaObject();
            }
            return objArr;
        }
        if (this instanceof NSDictionary) {
            HashMap<String, NSObject> hashMap = ((NSDictionary) this).getHashMap();
            HashMap hashMap2 = new HashMap(hashMap.size());
            for (String str : hashMap.keySet()) {
                hashMap2.put(str, hashMap.get(str).toJavaObject());
            }
            return hashMap2;
        }
        if (this instanceof NSSet) {
            Set<NSObject> set = ((NSSet) this).getSet();
            if (set instanceof LinkedHashSet) {
                treeSet = new LinkedHashSet(set.size());
            } else {
                treeSet = new TreeSet();
            }
            Iterator<NSObject> it2 = set.iterator();
            while (it2.hasNext()) {
                treeSet.add(it2.next().toJavaObject());
            }
            return treeSet;
        }
        if (this instanceof NSNumber) {
            NSNumber nSNumber = (NSNumber) this;
            int type = nSNumber.type();
            if (type != 0) {
                if (type == 1) {
                    return Double.valueOf(nSNumber.doubleValue());
                }
                if (type == 2) {
                    return Boolean.valueOf(nSNumber.boolValue());
                }
                return Double.valueOf(nSNumber.doubleValue());
            }
            long longValue = nSNumber.longValue();
            if (longValue > 2147483647L || longValue < -2147483648L) {
                return Long.valueOf(longValue);
            }
            return Integer.valueOf(nSNumber.intValue());
        }
        if (this instanceof NSString) {
            return ((NSString) this).getContent();
        }
        if (this instanceof NSData) {
            return ((NSData) this).bytes();
        }
        if (this instanceof NSDate) {
            return ((NSDate) this).getDate();
        }
        return this instanceof UID ? ((UID) this).getBytes() : this;
    }
}
