package com.dd.plist;

import com.google.firebase.crashlytics.buildtools.reloc.org.apache.http.HttpStatus;
import java.io.IOException;
import java.util.Arrays;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.Set;
import java.util.TreeSet;

/* loaded from: classes.dex */
public class NSSet extends NSObject {
    private boolean ordered;
    private Set<NSObject> set;

    public NSSet() {
        this.ordered = false;
        this.set = new LinkedHashSet();
    }

    public NSSet(boolean z) {
        this.ordered = z;
        if (!z) {
            this.set = new LinkedHashSet();
        } else {
            this.set = new TreeSet();
        }
    }

    public NSSet(NSObject... nSObjectArr) {
        this.ordered = false;
        LinkedHashSet linkedHashSet = new LinkedHashSet();
        this.set = linkedHashSet;
        linkedHashSet.addAll(Arrays.asList(nSObjectArr));
    }

    public NSSet(boolean z, NSObject... nSObjectArr) {
        this.ordered = z;
        if (!z) {
            this.set = new LinkedHashSet();
        } else {
            this.set = new TreeSet();
        }
        this.set.addAll(Arrays.asList(nSObjectArr));
    }

    public synchronized void addObject(NSObject nSObject) {
        this.set.add(nSObject);
    }

    public synchronized void removeObject(NSObject nSObject) {
        this.set.remove(nSObject);
    }

    public synchronized NSObject[] allObjects() {
        return (NSObject[]) this.set.toArray(new NSObject[count()]);
    }

    public synchronized NSObject anyObject() {
        if (this.set.isEmpty()) {
            return null;
        }
        return this.set.iterator().next();
    }

    public boolean containsObject(NSObject nSObject) {
        return this.set.contains(nSObject);
    }

    public synchronized NSObject member(NSObject nSObject) {
        for (NSObject nSObject2 : this.set) {
            if (nSObject2.equals(nSObject)) {
                return nSObject2;
            }
        }
        return null;
    }

    public synchronized boolean intersectsSet(NSSet nSSet) {
        Iterator<NSObject> it2 = this.set.iterator();
        while (it2.hasNext()) {
            if (nSSet.containsObject(it2.next())) {
                return true;
            }
        }
        return false;
    }

    public synchronized boolean isSubsetOfSet(NSSet nSSet) {
        Iterator<NSObject> it2 = this.set.iterator();
        while (it2.hasNext()) {
            if (!nSSet.containsObject(it2.next())) {
                return false;
            }
        }
        return true;
    }

    public synchronized Iterator<NSObject> objectIterator() {
        return this.set.iterator();
    }

    Set<NSObject> getSet() {
        return this.set;
    }

    public int hashCode() {
        Set<NSObject> set = this.set;
        return HttpStatus.SC_NON_AUTHORITATIVE_INFORMATION + (set != null ? set.hashCode() : 0);
    }

    public boolean equals(Object obj) {
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        Set<NSObject> set = this.set;
        Set<NSObject> set2 = ((NSSet) obj).set;
        return set == set2 || (set != null && set.equals(set2));
    }

    public synchronized int count() {
        return this.set.size();
    }

    @Override // com.dd.plist.NSObject
    void toXML(StringBuilder sb, int i2) {
        indent(sb, i2);
        sb.append("<array>");
        sb.append(NSObject.NEWLINE);
        Iterator<NSObject> it2 = this.set.iterator();
        while (it2.hasNext()) {
            it2.next().toXML(sb, i2 + 1);
            sb.append(NSObject.NEWLINE);
        }
        indent(sb, i2);
        sb.append("</array>");
    }

    @Override // com.dd.plist.NSObject
    void assignIDs(BinaryPropertyListWriter binaryPropertyListWriter) {
        super.assignIDs(binaryPropertyListWriter);
        Iterator<NSObject> it2 = this.set.iterator();
        while (it2.hasNext()) {
            it2.next().assignIDs(binaryPropertyListWriter);
        }
    }

    @Override // com.dd.plist.NSObject
    void toBinary(BinaryPropertyListWriter binaryPropertyListWriter) throws IOException {
        if (this.ordered) {
            binaryPropertyListWriter.writeIntHeader(11, this.set.size());
        } else {
            binaryPropertyListWriter.writeIntHeader(12, this.set.size());
        }
        Iterator<NSObject> it2 = this.set.iterator();
        while (it2.hasNext()) {
            binaryPropertyListWriter.writeID(binaryPropertyListWriter.getID(it2.next()));
        }
    }

    @Override // com.dd.plist.NSObject
    protected void toASCII(StringBuilder sb, int i2) {
        indent(sb, i2);
        NSObject[] allObjects = allObjects();
        sb.append(ASCIIPropertyListParser.ARRAY_BEGIN_TOKEN);
        int lastIndexOf = sb.lastIndexOf(NEWLINE);
        for (int i3 = 0; i3 < allObjects.length; i3++) {
            Class<?> cls = allObjects[i3].getClass();
            if ((cls.equals(NSDictionary.class) || cls.equals(NSArray.class) || cls.equals(NSData.class)) && lastIndexOf != sb.length()) {
                sb.append(NEWLINE);
                lastIndexOf = sb.length();
                allObjects[i3].toASCII(sb, i2 + 1);
            } else {
                if (i3 != 0) {
                    sb.append(" ");
                }
                allObjects[i3].toASCII(sb, 0);
            }
            if (i3 != allObjects.length - 1) {
                sb.append(ASCIIPropertyListParser.ARRAY_ITEM_DELIMITER_TOKEN);
            }
            if (sb.length() - lastIndexOf > 80) {
                sb.append(NEWLINE);
                lastIndexOf = sb.length();
            }
        }
        sb.append(ASCIIPropertyListParser.ARRAY_END_TOKEN);
    }

    @Override // com.dd.plist.NSObject
    protected void toASCIIGnuStep(StringBuilder sb, int i2) {
        indent(sb, i2);
        NSObject[] allObjects = allObjects();
        sb.append(ASCIIPropertyListParser.ARRAY_BEGIN_TOKEN);
        int lastIndexOf = sb.lastIndexOf(NEWLINE);
        for (int i3 = 0; i3 < allObjects.length; i3++) {
            Class<?> cls = allObjects[i3].getClass();
            if ((cls.equals(NSDictionary.class) || cls.equals(NSArray.class) || cls.equals(NSData.class)) && lastIndexOf != sb.length()) {
                sb.append(NEWLINE);
                lastIndexOf = sb.length();
                allObjects[i3].toASCIIGnuStep(sb, i2 + 1);
            } else {
                if (i3 != 0) {
                    sb.append(" ");
                }
                allObjects[i3].toASCIIGnuStep(sb, 0);
            }
            if (i3 != allObjects.length - 1) {
                sb.append(ASCIIPropertyListParser.ARRAY_ITEM_DELIMITER_TOKEN);
            }
            if (sb.length() - lastIndexOf > 80) {
                sb.append(NEWLINE);
                lastIndexOf = sb.length();
            }
        }
        sb.append(ASCIIPropertyListParser.ARRAY_END_TOKEN);
    }
}
