package com.dd.plist;

import com.google.firebase.crashlytics.buildtools.reloc.org.apache.http.protocol.HTTP;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.text.ParseException;
import javax.xml.parsers.ParserConfigurationException;
import org.xml.sax.SAXException;

/* loaded from: classes.dex */
public class PropertyListParser {
    private static final int TYPE_ASCII = 2;
    private static final int TYPE_BINARY = 1;
    private static final int TYPE_ERROR_BLANK = 10;
    private static final int TYPE_ERROR_UNKNOWN = 11;
    private static final int TYPE_XML = 0;

    protected PropertyListParser() {
    }

    private static int determineType(String str) {
        String trim = str.trim();
        if (trim.length() == 0) {
            return 10;
        }
        if (trim.startsWith("bplist")) {
            return 1;
        }
        if (trim.startsWith("(") || trim.startsWith("{") || trim.startsWith("/")) {
            return 2;
        }
        return trim.startsWith("<") ? 0 : 11;
    }

    private static int determineType(byte[] bArr) {
        byte b2;
        int i2 = 0;
        if (bArr.length >= 3 && (bArr[0] & 255) == 239 && (bArr[1] & 255) == 187 && (bArr[2] & 255) == 191) {
            i2 = 3;
        }
        while (true) {
            if ((i2 >= bArr.length || bArr[i2] != 32) && (b2 = bArr[i2]) != 9 && b2 != 13 && b2 != 10 && b2 != 12) {
                return determineType(new String(bArr, i2, Math.min(8, bArr.length - i2)));
            }
            i2++;
        }
    }

    private static int determineType(InputStream inputStream) throws IOException {
        int read;
        byte[] bArr = new byte[8];
        long j2 = -1;
        boolean z = false;
        while (true) {
            if (inputStream.markSupported()) {
                inputStream.mark(16);
            }
            read = inputStream.read();
            j2++;
            z = j2 < 3 && ((j2 == 0 && read == 239) || (z && ((j2 == 1 && read == 187) || (j2 == 2 && read == 191))));
            if (read == -1 || read != 32) {
                if (read != 9 && read != 13 && read != 10 && read != 12 && !z) {
                    break;
                }
            }
        }
        bArr[0] = (byte) read;
        int determineType = determineType(new String(bArr, 0, inputStream.read(bArr, 1, 7)));
        if (inputStream.markSupported()) {
            inputStream.reset();
        }
        return determineType;
    }

    protected static byte[] readAll(InputStream inputStream) throws IOException {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byte[] bArr = new byte[512];
        int i2 = 512;
        while (i2 == 512) {
            i2 = inputStream.read(bArr);
            if (i2 != -1) {
                byteArrayOutputStream.write(bArr, 0, i2);
            }
        }
        return byteArrayOutputStream.toByteArray();
    }

    public static NSObject parse(String str) throws ParserConfigurationException, ParseException, SAXException, PropertyListFormatException, IOException {
        return parse(new File(str));
    }

    public static NSObject parse(File file) throws IOException, PropertyListFormatException, ParseException, ParserConfigurationException, SAXException {
        FileInputStream fileInputStream = new FileInputStream(file);
        int determineType = determineType(fileInputStream);
        fileInputStream.close();
        if (determineType == 0) {
            return XMLPropertyListParser.parse(file);
        }
        if (determineType == 1) {
            return BinaryPropertyListParser.parse(file);
        }
        if (determineType == 2) {
            return ASCIIPropertyListParser.parse(file);
        }
        throw new PropertyListFormatException("The given file is not a property list of a supported format.");
    }

    public static NSObject parse(byte[] bArr) throws IOException, PropertyListFormatException, ParseException, ParserConfigurationException, SAXException {
        int determineType = determineType(bArr);
        if (determineType == 0) {
            return XMLPropertyListParser.parse(bArr);
        }
        if (determineType == 1) {
            return BinaryPropertyListParser.parse(bArr);
        }
        if (determineType == 2) {
            return ASCIIPropertyListParser.parse(bArr);
        }
        throw new PropertyListFormatException("The given data is not a property list of a supported format.");
    }

    public static NSObject parse(InputStream inputStream) throws IOException, PropertyListFormatException, ParseException, ParserConfigurationException, SAXException {
        return parse(readAll(inputStream));
    }

    public static void saveAsXML(NSObject nSObject, File file) throws IOException {
        File parentFile = file.getParentFile();
        if (!parentFile.exists() && !parentFile.mkdirs()) {
            throw new IOException("The output directory does not exist and could not be created.");
        }
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        saveAsXML(nSObject, fileOutputStream);
        fileOutputStream.close();
    }

    public static void saveAsXML(NSObject nSObject, OutputStream outputStream) throws IOException {
        OutputStreamWriter outputStreamWriter = new OutputStreamWriter(outputStream, "UTF-8");
        outputStreamWriter.write(nSObject.toXMLPropertyList());
        outputStreamWriter.close();
    }

    public static void convertToXml(File file, File file2) throws ParserConfigurationException, ParseException, SAXException, PropertyListFormatException, IOException {
        saveAsXML(parse(file), file2);
    }

    public static void saveAsBinary(NSObject nSObject, File file) throws IOException {
        File parentFile = file.getParentFile();
        if (!parentFile.exists() && !parentFile.mkdirs()) {
            throw new IOException("The output directory does not exist and could not be created.");
        }
        BinaryPropertyListWriter.write(file, nSObject);
    }

    public static void saveAsBinary(NSObject nSObject, OutputStream outputStream) throws IOException {
        BinaryPropertyListWriter.write(outputStream, nSObject);
    }

    public static void convertToBinary(File file, File file2) throws IOException, ParserConfigurationException, ParseException, SAXException, PropertyListFormatException {
        saveAsBinary(parse(file), file2);
    }

    public static void saveAsASCII(NSDictionary nSDictionary, File file) throws IOException {
        File parentFile = file.getParentFile();
        if (!parentFile.exists() && !parentFile.mkdirs()) {
            throw new IOException("The output directory does not exist and could not be created.");
        }
        OutputStreamWriter outputStreamWriter = new OutputStreamWriter(new FileOutputStream(file), HTTP.ASCII);
        outputStreamWriter.write(nSDictionary.toASCIIPropertyList());
        outputStreamWriter.close();
    }

    public static void saveAsASCII(NSArray nSArray, File file) throws IOException {
        OutputStreamWriter outputStreamWriter = new OutputStreamWriter(new FileOutputStream(file), HTTP.ASCII);
        outputStreamWriter.write(nSArray.toASCIIPropertyList());
        outputStreamWriter.close();
    }

    public static void convertToASCII(File file, File file2) throws ParserConfigurationException, ParseException, SAXException, PropertyListFormatException, IOException {
        NSObject parse = parse(file);
        if (parse instanceof NSDictionary) {
            saveAsASCII((NSDictionary) parse, file2);
        } else {
            if (parse instanceof NSArray) {
                saveAsASCII((NSArray) parse, file2);
                return;
            }
            throw new PropertyListFormatException("The root of the given input property list is neither a Dictionary nor an Array!");
        }
    }

    public static void saveAsGnuStepASCII(NSDictionary nSDictionary, File file) throws IOException {
        File parentFile = file.getParentFile();
        if (!parentFile.exists() && !parentFile.mkdirs()) {
            throw new IOException("The output directory does not exist and could not be created.");
        }
        OutputStreamWriter outputStreamWriter = new OutputStreamWriter(new FileOutputStream(file), HTTP.ASCII);
        outputStreamWriter.write(nSDictionary.toGnuStepASCIIPropertyList());
        outputStreamWriter.close();
    }

    public static void saveAsGnuStepASCII(NSArray nSArray, File file) throws IOException {
        File parentFile = file.getParentFile();
        if (!parentFile.exists() && !parentFile.mkdirs()) {
            throw new IOException("The output directory does not exist and could not be created.");
        }
        OutputStreamWriter outputStreamWriter = new OutputStreamWriter(new FileOutputStream(file), HTTP.ASCII);
        outputStreamWriter.write(nSArray.toGnuStepASCIIPropertyList());
        outputStreamWriter.close();
    }

    public static void convertToGnuStepASCII(File file, File file2) throws ParserConfigurationException, ParseException, SAXException, PropertyListFormatException, IOException {
        NSObject parse = parse(file);
        if (parse instanceof NSDictionary) {
            saveAsGnuStepASCII((NSDictionary) parse, file2);
        } else {
            if (parse instanceof NSArray) {
                saveAsGnuStepASCII((NSArray) parse, file2);
                return;
            }
            throw new PropertyListFormatException("The root of the given input property list is neither a Dictionary nor an Array!");
        }
    }
}
