package com.flyco.dialog.widget;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.LayoutAnimationController;
import android.view.animation.TranslateAnimation;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.TextView;
import com.flyco.dialog.entity.DialogMenuItem;
import com.flyco.dialog.listener.OnOperItemClickL;
import com.flyco.dialog.utils.CornerUtils;
import com.flyco.dialog.widget.base.BottomBaseDialog;
import java.util.ArrayList;

/* loaded from: classes2.dex */
public class ActionSheetDialog extends BottomBaseDialog<ActionSheetDialog> {
    private BaseAdapter mAdapter;
    private String mCancelText;
    private int mCancelTextColor;
    private float mCancelTextSize;
    private ArrayList<DialogMenuItem> mContents;
    private float mCornerRadius;
    private int mDividerColor;
    private float mDividerHeight;
    private boolean mIsTitleShow;
    private float mItemHeight;
    private int mItemPressColor;
    private int mItemTextColor;
    private float mItemTextSize;
    private LayoutAnimationController mLac;
    private ListView mLv;
    private int mLvBgColor;
    private OnOperItemClickL mOnOperItemClickL;
    private String mTitle;
    private int mTitleBgColor;
    private float mTitleHeight;
    private int mTitleTextColor;
    private float mTitleTextSize;
    private TextView mTvCancel;
    private TextView mTvTitle;
    private View mVLineTitle;

    public void setOnOperItemClickL(OnOperItemClickL onOperItemClickL) {
        this.mOnOperItemClickL = onOperItemClickL;
    }

    public ActionSheetDialog(Context context, ArrayList<DialogMenuItem> arrayList, View view) {
        super(context, view);
        this.mCornerRadius = 5.0f;
        this.mTitleBgColor = Color.parseColor("#ddffffff");
        this.mTitle = "提示";
        this.mTitleHeight = 48.0f;
        this.mTitleTextColor = Color.parseColor("#8F8F8F");
        this.mTitleTextSize = 17.5f;
        this.mLvBgColor = Color.parseColor("#ddffffff");
        this.mDividerColor = Color.parseColor("#D7D7D9");
        this.mDividerHeight = 0.8f;
        this.mItemPressColor = Color.parseColor("#ffcccccc");
        this.mItemTextColor = Color.parseColor("#44A2FF");
        this.mItemTextSize = 17.5f;
        this.mItemHeight = 48.0f;
        this.mIsTitleShow = true;
        this.mCancelText = "取消";
        this.mCancelTextColor = Color.parseColor("#44A2FF");
        this.mCancelTextSize = 17.5f;
        ArrayList<DialogMenuItem> arrayList2 = new ArrayList<>();
        this.mContents = arrayList2;
        arrayList2.addAll(arrayList);
        init();
    }

    public ActionSheetDialog(Context context, String[] strArr, View view) {
        super(context, view);
        this.mCornerRadius = 5.0f;
        this.mTitleBgColor = Color.parseColor("#ddffffff");
        this.mTitle = "提示";
        this.mTitleHeight = 48.0f;
        this.mTitleTextColor = Color.parseColor("#8F8F8F");
        this.mTitleTextSize = 17.5f;
        this.mLvBgColor = Color.parseColor("#ddffffff");
        this.mDividerColor = Color.parseColor("#D7D7D9");
        this.mDividerHeight = 0.8f;
        this.mItemPressColor = Color.parseColor("#ffcccccc");
        this.mItemTextColor = Color.parseColor("#44A2FF");
        this.mItemTextSize = 17.5f;
        this.mItemHeight = 48.0f;
        this.mIsTitleShow = true;
        this.mCancelText = "取消";
        this.mCancelTextColor = Color.parseColor("#44A2FF");
        this.mCancelTextSize = 17.5f;
        this.mContents = new ArrayList<>();
        this.mContents = new ArrayList<>();
        for (String str : strArr) {
            this.mContents.add(new DialogMenuItem(str, 0));
        }
        init();
    }

    public ActionSheetDialog(Context context, BaseAdapter baseAdapter, View view) {
        super(context, view);
        this.mCornerRadius = 5.0f;
        this.mTitleBgColor = Color.parseColor("#ddffffff");
        this.mTitle = "提示";
        this.mTitleHeight = 48.0f;
        this.mTitleTextColor = Color.parseColor("#8F8F8F");
        this.mTitleTextSize = 17.5f;
        this.mLvBgColor = Color.parseColor("#ddffffff");
        this.mDividerColor = Color.parseColor("#D7D7D9");
        this.mDividerHeight = 0.8f;
        this.mItemPressColor = Color.parseColor("#ffcccccc");
        this.mItemTextColor = Color.parseColor("#44A2FF");
        this.mItemTextSize = 17.5f;
        this.mItemHeight = 48.0f;
        this.mIsTitleShow = true;
        this.mCancelText = "取消";
        this.mCancelTextColor = Color.parseColor("#44A2FF");
        this.mCancelTextSize = 17.5f;
        this.mContents = new ArrayList<>();
        this.mAdapter = baseAdapter;
        init();
    }

    private void init() {
        widthScale(0.95f);
        TranslateAnimation translateAnimation = new TranslateAnimation(1, 0.0f, 1, 0.0f, 1, 6.0f, 1, 0.0f);
        translateAnimation.setInterpolator(new DecelerateInterpolator());
        translateAnimation.setDuration(350L);
        translateAnimation.setStartOffset(150L);
        LayoutAnimationController layoutAnimationController = new LayoutAnimationController(translateAnimation, 0.12f);
        this.mLac = layoutAnimationController;
        layoutAnimationController.setInterpolator(new DecelerateInterpolator());
    }

    @Override // com.flyco.dialog.widget.base.BaseDialog
    public View onCreateView() {
        LinearLayout linearLayout = new LinearLayout(this.mContext);
        linearLayout.setOrientation(1);
        linearLayout.setBackgroundColor(0);
        TextView textView = new TextView(this.mContext);
        this.mTvTitle = textView;
        textView.setGravity(17);
        this.mTvTitle.setPadding(dp2px(10.0f), dp2px(5.0f), dp2px(10.0f), dp2px(5.0f));
        LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(-1, -2);
        layoutParams.topMargin = dp2px(20.0f);
        linearLayout.addView(this.mTvTitle, layoutParams);
        View view = new View(this.mContext);
        this.mVLineTitle = view;
        linearLayout.addView(view);
        ListView listView = new ListView(this.mContext);
        this.mLv = listView;
        listView.setLayoutParams(new LinearLayout.LayoutParams(-1, -2, 1.0f));
        this.mLv.setCacheColorHint(0);
        this.mLv.setFadingEdgeLength(0);
        this.mLv.setVerticalScrollBarEnabled(false);
        this.mLv.setSelector(new ColorDrawable(0));
        linearLayout.addView(this.mLv);
        TextView textView2 = new TextView(this.mContext);
        this.mTvCancel = textView2;
        textView2.setGravity(17);
        LinearLayout.LayoutParams layoutParams2 = new LinearLayout.LayoutParams(-1, -2);
        layoutParams2.topMargin = dp2px(7.0f);
        layoutParams2.bottomMargin = dp2px(7.0f);
        this.mTvCancel.setLayoutParams(layoutParams2);
        linearLayout.addView(this.mTvCancel);
        return linearLayout;
    }

    @Override // com.flyco.dialog.widget.base.BaseDialog
    public void setUiBeforShow() {
        float dp2px = dp2px(this.mCornerRadius);
        this.mTvTitle.setHeight(dp2px(this.mTitleHeight));
        this.mTvTitle.setBackgroundDrawable(CornerUtils.cornerDrawable(this.mTitleBgColor, new float[]{dp2px, dp2px, dp2px, dp2px, 0.0f, 0.0f, 0.0f, 0.0f}));
        this.mTvTitle.setText(this.mTitle);
        this.mTvTitle.setTextSize(2, this.mTitleTextSize);
        this.mTvTitle.setTextColor(this.mTitleTextColor);
        this.mTvTitle.setVisibility(this.mIsTitleShow ? 0 : 8);
        this.mVLineTitle.setLayoutParams(new LinearLayout.LayoutParams(-1, dp2px(this.mDividerHeight)));
        this.mVLineTitle.setBackgroundColor(this.mDividerColor);
        this.mVLineTitle.setVisibility(this.mIsTitleShow ? 0 : 8);
        this.mTvCancel.setHeight(dp2px(this.mItemHeight));
        this.mTvCancel.setText(this.mCancelText);
        this.mTvCancel.setTextSize(2, this.mCancelTextSize);
        this.mTvCancel.setTextColor(this.mCancelTextColor);
        this.mTvCancel.setBackgroundDrawable(CornerUtils.listItemSelector(dp2px, this.mLvBgColor, this.mItemPressColor, 1, 0));
        this.mTvCancel.setOnClickListener(new View.OnClickListener() { // from class: com.flyco.dialog.widget.ActionSheetDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                ActionSheetDialog.this.dismiss();
            }
        });
        this.mLv.setDivider(new ColorDrawable(this.mDividerColor));
        this.mLv.setDividerHeight(dp2px(this.mDividerHeight));
        if (this.mIsTitleShow) {
            this.mLv.setBackgroundDrawable(CornerUtils.cornerDrawable(this.mLvBgColor, new float[]{0.0f, 0.0f, 0.0f, 0.0f, dp2px, dp2px, dp2px, dp2px}));
        } else {
            this.mLv.setBackgroundDrawable(CornerUtils.cornerDrawable(this.mLvBgColor, dp2px));
        }
        if (this.mAdapter == null) {
            this.mAdapter = new ListDialogAdapter();
        }
        this.mLv.setAdapter((ListAdapter) this.mAdapter);
        this.mLv.setOnItemClickListener(new AdapterView.OnItemClickListener() { // from class: com.flyco.dialog.widget.ActionSheetDialog.2
            @Override // android.widget.AdapterView.OnItemClickListener
            public void onItemClick(AdapterView<?> adapterView, View view, int i2, long j2) {
                if (ActionSheetDialog.this.mOnOperItemClickL != null) {
                    ActionSheetDialog.this.mOnOperItemClickL.onOperItemClick(adapterView, view, i2, j2);
                }
            }
        });
        this.mLv.setLayoutAnimation(this.mLac);
    }

    public ActionSheetDialog titleBgColor(int i2) {
        this.mTitleBgColor = i2;
        return this;
    }

    public ActionSheetDialog title(String str) {
        this.mTitle = str;
        return this;
    }

    public ActionSheetDialog titleHeight(float f2) {
        this.mTitleHeight = f2;
        return this;
    }

    public ActionSheetDialog titleTextSize_SP(float f2) {
        this.mTitleTextSize = f2;
        return this;
    }

    public ActionSheetDialog titleTextColor(int i2) {
        this.mTitleTextColor = i2;
        return this;
    }

    public ActionSheetDialog isTitleShow(boolean z) {
        this.mIsTitleShow = z;
        return this;
    }

    public ActionSheetDialog lvBgColor(int i2) {
        this.mLvBgColor = i2;
        return this;
    }

    public ActionSheetDialog cornerRadius(float f2) {
        this.mCornerRadius = f2;
        return this;
    }

    public ActionSheetDialog dividerColor(int i2) {
        this.mDividerColor = i2;
        return this;
    }

    public ActionSheetDialog dividerHeight(float f2) {
        this.mDividerHeight = f2;
        return this;
    }

    public ActionSheetDialog itemPressColor(int i2) {
        this.mItemPressColor = i2;
        return this;
    }

    public ActionSheetDialog itemTextColor(int i2) {
        this.mItemTextColor = i2;
        return this;
    }

    public ActionSheetDialog itemTextSize(float f2) {
        this.mItemTextSize = f2;
        return this;
    }

    public ActionSheetDialog itemHeight(float f2) {
        this.mItemHeight = f2;
        return this;
    }

    public ActionSheetDialog layoutAnimation(LayoutAnimationController layoutAnimationController) {
        this.mLac = layoutAnimationController;
        return this;
    }

    public ActionSheetDialog cancelText(String str) {
        this.mCancelText = str;
        return this;
    }

    public ActionSheetDialog cancelText(int i2) {
        this.mCancelTextColor = i2;
        return this;
    }

    public ActionSheetDialog cancelTextSize(float f2) {
        this.mCancelTextSize = f2;
        return this;
    }

    class ListDialogAdapter extends BaseAdapter {
        @Override // android.widget.Adapter
        public Object getItem(int i2) {
            return null;
        }

        @Override // android.widget.Adapter
        public long getItemId(int i2) {
            return i2;
        }

        ListDialogAdapter() {
        }

        @Override // android.widget.Adapter
        public int getCount() {
            return ActionSheetDialog.this.mContents.size();
        }

        @Override // android.widget.Adapter
        public View getView(int i2, View view, ViewGroup viewGroup) {
            DialogMenuItem dialogMenuItem = (DialogMenuItem) ActionSheetDialog.this.mContents.get(i2);
            LinearLayout linearLayout = new LinearLayout(ActionSheetDialog.this.mContext);
            linearLayout.setOrientation(0);
            linearLayout.setGravity(16);
            ImageView imageView = new ImageView(ActionSheetDialog.this.mContext);
            imageView.setPadding(0, 0, ActionSheetDialog.this.dp2px(15.0f), 0);
            linearLayout.addView(imageView);
            TextView textView = new TextView(ActionSheetDialog.this.mContext);
            textView.setLayoutParams(new LinearLayout.LayoutParams(-1, -2));
            textView.setSingleLine(true);
            textView.setGravity(17);
            textView.setTextColor(ActionSheetDialog.this.mItemTextColor);
            textView.setTextSize(2, ActionSheetDialog.this.mItemTextSize);
            ActionSheetDialog actionSheetDialog = ActionSheetDialog.this;
            textView.setHeight(actionSheetDialog.dp2px(actionSheetDialog.mItemHeight));
            linearLayout.addView(textView);
            ActionSheetDialog actionSheetDialog2 = ActionSheetDialog.this;
            float dp2px = actionSheetDialog2.dp2px(actionSheetDialog2.mCornerRadius);
            if (ActionSheetDialog.this.mIsTitleShow) {
                linearLayout.setBackgroundDrawable(CornerUtils.listItemSelector(dp2px, 0, ActionSheetDialog.this.mItemPressColor, i2 == ActionSheetDialog.this.mContents.size() - 1));
            } else {
                linearLayout.setBackgroundDrawable(CornerUtils.listItemSelector(dp2px, 0, ActionSheetDialog.this.mItemPressColor, ActionSheetDialog.this.mContents.size(), i2));
            }
            imageView.setImageResource(dialogMenuItem.mResId);
            textView.setText(dialogMenuItem.mOperName);
            imageView.setVisibility(dialogMenuItem.mResId == 0 ? 8 : 0);
            return linearLayout;
        }
    }
}
