package com.flyco.dialog.widget.base;

import android.animation.Animator;
import android.app.Dialog;
import android.content.Context;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.view.WindowManager;
import android.widget.LinearLayout;
import com.flyco.animation.BaseAnimatorSet;
import com.flyco.dialog.utils.StatusBarUtils;
import com.flyco.dialog.widget.base.BaseDialog;

/* loaded from: classes2.dex */
public abstract class BaseDialog<T extends BaseDialog<T>> extends Dialog {
    private boolean mAutoDismiss;
    private long mAutoDismissDelay;
    protected boolean mCancel;
    protected Context mContext;
    private BaseAnimatorSet mDismissAnim;
    protected DisplayMetrics mDisplayMetrics;
    private Handler mHandler;
    protected float mHeightScale;
    private boolean mIsDismissAnim;
    private boolean mIsPopupStyle;
    private boolean mIsShowAnim;
    protected LinearLayout mLlControlHeight;
    protected LinearLayout mLlTop;
    protected float mMaxHeight;
    protected View mOnCreateView;
    private BaseAnimatorSet mShowAnim;
    protected String mTag;
    protected float mWidthScale;

    public abstract View onCreateView();

    public void onViewCreated(View view) {
    }

    public abstract void setUiBeforShow();

    public BaseDialog(Context context) {
        super(context);
        this.mWidthScale = 1.0f;
        this.mAutoDismissDelay = 1500L;
        this.mHandler = new Handler(Looper.getMainLooper());
        setDialogTheme();
        this.mContext = context;
        this.mTag = getClass().getSimpleName();
        setCanceledOnTouchOutside(true);
        Log.d(this.mTag, "constructor");
    }

    public BaseDialog(Context context, boolean z) {
        this(context);
        this.mIsPopupStyle = z;
    }

    private void setDialogTheme() {
        requestWindowFeature(1);
        getWindow().setBackgroundDrawable(new ColorDrawable(0));
        getWindow().addFlags(2);
    }

    @Override // android.app.Dialog
    protected void onCreate(Bundle bundle) {
        Log.d(this.mTag, "onCreate");
        this.mDisplayMetrics = this.mContext.getResources().getDisplayMetrics();
        this.mMaxHeight = r5.heightPixels - StatusBarUtils.getHeight(this.mContext);
        LinearLayout linearLayout = new LinearLayout(this.mContext);
        this.mLlTop = linearLayout;
        linearLayout.setGravity(17);
        LinearLayout linearLayout2 = new LinearLayout(this.mContext);
        this.mLlControlHeight = linearLayout2;
        linearLayout2.setOrientation(1);
        View onCreateView = onCreateView();
        this.mOnCreateView = onCreateView;
        this.mLlControlHeight.addView(onCreateView);
        this.mLlTop.addView(this.mLlControlHeight);
        onViewCreated(this.mOnCreateView);
        if (this.mIsPopupStyle) {
            setContentView(this.mLlTop, new ViewGroup.LayoutParams(-2, -2));
        } else {
            setContentView(this.mLlTop, new ViewGroup.LayoutParams(this.mDisplayMetrics.widthPixels, (int) this.mMaxHeight));
        }
        this.mLlTop.setOnClickListener(new View.OnClickListener() { // from class: com.flyco.dialog.widget.base.BaseDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (BaseDialog.this.mCancel) {
                    BaseDialog.this.dismiss();
                }
            }
        });
        this.mOnCreateView.setClickable(true);
    }

    public View getCreateView() {
        return this.mOnCreateView;
    }

    @Override // android.app.Dialog, android.view.Window.Callback
    public void onAttachedToWindow() {
        float f2;
        super.onAttachedToWindow();
        Log.d(this.mTag, "onAttachedToWindow");
        setUiBeforShow();
        int i2 = -2;
        int i3 = this.mWidthScale == 0.0f ? -2 : (int) (this.mDisplayMetrics.widthPixels * this.mWidthScale);
        float f3 = this.mHeightScale;
        if (f3 != 0.0f) {
            if (f3 == 1.0f) {
                f2 = this.mMaxHeight;
            } else {
                f2 = this.mMaxHeight * f3;
            }
            i2 = (int) f2;
        }
        this.mLlControlHeight.setLayoutParams(new LinearLayout.LayoutParams(i3, i2));
        BaseAnimatorSet baseAnimatorSet = this.mShowAnim;
        if (baseAnimatorSet != null) {
            baseAnimatorSet.listener(new BaseAnimatorSet.AnimatorListener() { // from class: com.flyco.dialog.widget.base.BaseDialog.2
                @Override // com.flyco.animation.BaseAnimatorSet.AnimatorListener
                public void onAnimationRepeat(Animator animator) {
                }

                @Override // com.flyco.animation.BaseAnimatorSet.AnimatorListener
                public void onAnimationStart(Animator animator) {
                    BaseDialog.this.mIsShowAnim = true;
                }

                @Override // com.flyco.animation.BaseAnimatorSet.AnimatorListener
                public void onAnimationEnd(Animator animator) {
                    BaseDialog.this.mIsShowAnim = false;
                    BaseDialog.this.delayDismiss();
                }

                @Override // com.flyco.animation.BaseAnimatorSet.AnimatorListener
                public void onAnimationCancel(Animator animator) {
                    BaseDialog.this.mIsShowAnim = false;
                }
            }).playOn(this.mLlControlHeight);
        } else {
            BaseAnimatorSet.reset(this.mLlControlHeight);
            delayDismiss();
        }
    }

    @Override // android.app.Dialog
    public void setCanceledOnTouchOutside(boolean z) {
        this.mCancel = z;
        super.setCanceledOnTouchOutside(z);
    }

    @Override // android.app.Dialog
    public void show() {
        Log.d(this.mTag, "show");
        super.show();
    }

    @Override // android.app.Dialog
    protected void onStart() {
        super.onStart();
        Log.d(this.mTag, "onStart");
    }

    @Override // android.app.Dialog
    protected void onStop() {
        super.onStop();
        Log.d(this.mTag, "onStop");
    }

    @Override // android.app.Dialog, android.view.Window.Callback
    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        Log.d(this.mTag, "onDetachedFromWindow");
    }

    @Override // android.app.Dialog, android.content.DialogInterface
    public void dismiss() {
        Log.d(this.mTag, "dismiss");
        BaseAnimatorSet baseAnimatorSet = this.mDismissAnim;
        if (baseAnimatorSet != null) {
            baseAnimatorSet.listener(new BaseAnimatorSet.AnimatorListener() { // from class: com.flyco.dialog.widget.base.BaseDialog.3
                @Override // com.flyco.animation.BaseAnimatorSet.AnimatorListener
                public void onAnimationRepeat(Animator animator) {
                }

                @Override // com.flyco.animation.BaseAnimatorSet.AnimatorListener
                public void onAnimationStart(Animator animator) {
                    BaseDialog.this.mIsDismissAnim = true;
                }

                @Override // com.flyco.animation.BaseAnimatorSet.AnimatorListener
                public void onAnimationEnd(Animator animator) {
                    BaseDialog.this.mIsDismissAnim = false;
                    BaseDialog.this.superDismiss();
                }

                @Override // com.flyco.animation.BaseAnimatorSet.AnimatorListener
                public void onAnimationCancel(Animator animator) {
                    BaseDialog.this.mIsDismissAnim = false;
                    BaseDialog.this.superDismiss();
                }
            }).playOn(this.mLlControlHeight);
        } else {
            superDismiss();
        }
    }

    public void superDismiss() {
        super.dismiss();
    }

    public void show(int i2) {
        getWindow().setWindowAnimations(i2);
        show();
    }

    public void showAtLocation(int i2, int i3, int i4) {
        if (this.mIsPopupStyle) {
            Window window = getWindow();
            WindowManager.LayoutParams attributes = window.getAttributes();
            window.setGravity(i2);
            attributes.x = i3;
            attributes.y = i4;
        }
        show();
    }

    public void showAtLocation(int i2, int i3) {
        showAtLocation(51, i2, i3);
    }

    public T dimEnabled(boolean z) {
        if (z) {
            getWindow().addFlags(2);
        } else {
            getWindow().clearFlags(2);
        }
        return this;
    }

    public T widthScale(float f2) {
        this.mWidthScale = f2;
        return this;
    }

    public T heightScale(float f2) {
        this.mHeightScale = f2;
        return this;
    }

    public T showAnim(BaseAnimatorSet baseAnimatorSet) {
        this.mShowAnim = baseAnimatorSet;
        return this;
    }

    public T dismissAnim(BaseAnimatorSet baseAnimatorSet) {
        this.mDismissAnim = baseAnimatorSet;
        return this;
    }

    public T autoDismiss(boolean z) {
        this.mAutoDismiss = z;
        return this;
    }

    public T autoDismissDelay(long j2) {
        this.mAutoDismissDelay = j2;
        return this;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void delayDismiss() {
        if (!this.mAutoDismiss || this.mAutoDismissDelay <= 0) {
            return;
        }
        this.mHandler.postDelayed(new Runnable() { // from class: com.flyco.dialog.widget.base.BaseDialog.4
            @Override // java.lang.Runnable
            public void run() {
                BaseDialog.this.dismiss();
            }
        }, this.mAutoDismissDelay);
    }

    @Override // android.app.Dialog, android.view.Window.Callback
    public boolean dispatchTouchEvent(MotionEvent motionEvent) {
        if (this.mIsDismissAnim || this.mIsShowAnim || this.mAutoDismiss) {
            return true;
        }
        return super.dispatchTouchEvent(motionEvent);
    }

    @Override // android.app.Dialog
    public void onBackPressed() {
        if (this.mIsDismissAnim || this.mIsShowAnim || this.mAutoDismiss) {
            return;
        }
        super.onBackPressed();
    }

    protected int dp2px(float f2) {
        return (int) ((f2 * this.mContext.getResources().getDisplayMetrics().density) + 0.5f);
    }
}
