package com.flyco.dialog.widget.base;

import android.content.Context;
import android.view.MotionEvent;
import android.view.View;
import android.view.animation.Animation;
import com.flyco.animation.BaseAnimatorSet;
import com.flyco.dialog.widget.base.BottomTopBaseDialog;

/* loaded from: classes2.dex */
public abstract class BottomTopBaseDialog<T extends BottomTopBaseDialog<T>> extends BaseDialog<T> {
    protected View mAnimateView;
    protected int mBottom;
    protected long mInnerAnimDuration;
    protected Animation mInnerDismissAnim;
    protected Animation mInnerShowAnim;
    protected boolean mIsInnerDismissAnim;
    protected boolean mIsInnerShowAnim;
    protected int mLeft;
    protected int mRight;
    protected int mTop;
    private BaseAnimatorSet mWindowInAs;
    private BaseAnimatorSet mWindowOutAs;

    protected abstract BaseAnimatorSet getWindowInAs();

    protected abstract BaseAnimatorSet getWindowOutAs();

    public BottomTopBaseDialog(Context context) {
        super(context);
        this.mInnerAnimDuration = 350L;
    }

    public T innerAnimDuration(long j2) {
        this.mInnerAnimDuration = j2;
        return this;
    }

    public T padding(int i2, int i3, int i4, int i5) {
        this.mLeft = i2;
        this.mTop = i3;
        this.mRight = i4;
        this.mBottom = i5;
        return this;
    }

    protected void showWithAnim() {
        Animation animation = this.mInnerShowAnim;
        if (animation != null) {
            animation.setDuration(this.mInnerAnimDuration);
            this.mInnerShowAnim.setAnimationListener(new Animation.AnimationListener() { // from class: com.flyco.dialog.widget.base.BottomTopBaseDialog.1
                @Override // android.view.animation.Animation.AnimationListener
                public void onAnimationRepeat(Animation animation2) {
                }

                @Override // android.view.animation.Animation.AnimationListener
                public void onAnimationStart(Animation animation2) {
                    BottomTopBaseDialog.this.mIsInnerShowAnim = true;
                }

                @Override // android.view.animation.Animation.AnimationListener
                public void onAnimationEnd(Animation animation2) {
                    BottomTopBaseDialog.this.mIsInnerShowAnim = false;
                }
            });
            this.mLlControlHeight.startAnimation(this.mInnerShowAnim);
        }
        if (this.mAnimateView != null) {
            if (getWindowInAs() != null) {
                this.mWindowInAs = getWindowInAs();
            }
            this.mWindowInAs.duration(this.mInnerAnimDuration).playOn(this.mAnimateView);
        }
    }

    protected void dismissWithAnim() {
        Animation animation = this.mInnerDismissAnim;
        if (animation != null) {
            animation.setDuration(this.mInnerAnimDuration);
            this.mInnerDismissAnim.setAnimationListener(new Animation.AnimationListener() { // from class: com.flyco.dialog.widget.base.BottomTopBaseDialog.2
                @Override // android.view.animation.Animation.AnimationListener
                public void onAnimationRepeat(Animation animation2) {
                }

                @Override // android.view.animation.Animation.AnimationListener
                public void onAnimationStart(Animation animation2) {
                    BottomTopBaseDialog.this.mIsInnerDismissAnim = true;
                }

                @Override // android.view.animation.Animation.AnimationListener
                public void onAnimationEnd(Animation animation2) {
                    BottomTopBaseDialog.this.mIsInnerDismissAnim = false;
                    BottomTopBaseDialog.this.superDismiss();
                }
            });
            this.mLlControlHeight.startAnimation(this.mInnerDismissAnim);
        } else {
            superDismiss();
        }
        if (this.mAnimateView != null) {
            if (getWindowOutAs() != null) {
                this.mWindowOutAs = getWindowOutAs();
            }
            this.mWindowOutAs.duration(this.mInnerAnimDuration).playOn(this.mAnimateView);
        }
    }

    @Override // com.flyco.dialog.widget.base.BaseDialog, android.app.Dialog, android.view.Window.Callback
    public boolean dispatchTouchEvent(MotionEvent motionEvent) {
        if (this.mIsInnerDismissAnim || this.mIsInnerShowAnim) {
            return true;
        }
        return super.dispatchTouchEvent(motionEvent);
    }

    @Override // com.flyco.dialog.widget.base.BaseDialog, android.app.Dialog
    public void onBackPressed() {
        if (this.mIsInnerDismissAnim || this.mIsInnerShowAnim) {
            return;
        }
        super.onBackPressed();
    }
}
