package com.flyco.dialog.widget.popup.base;

import android.content.Context;
import android.graphics.Color;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import com.flyco.animation.BounceEnter.BounceLeftEnter;
import com.flyco.animation.FadeExit.FadeExit;
import com.flyco.dialog.R;
import com.flyco.dialog.utils.CornerUtils;
import com.flyco.dialog.utils.StatusBarUtils;
import com.flyco.dialog.view.TriangleView;
import com.flyco.dialog.widget.internal.InternalBasePopup;
import com.flyco.dialog.widget.popup.base.BaseBubblePopup;

/* loaded from: classes2.dex */
public abstract class BaseBubblePopup<T extends BaseBubblePopup<T>> extends InternalBasePopup<T> {
    protected int mBubbleColor;
    protected int mCornerRadius;
    protected RelativeLayout.LayoutParams mLayoutParams;
    protected LinearLayout mLlContent;
    protected int mMarginLeft;
    protected int mMarginRight;
    private RelativeLayout.LayoutParams mTriangleLayoutParams;
    protected TriangleView mTriangleView;
    protected View mWrappedView;
    protected int triangleHeight;
    protected int triangleWidth;

    public abstract View onCreateBubbleView();

    public BaseBubblePopup(Context context) {
        super(context);
        this.mWrappedView = onCreateBubbleView();
        init();
    }

    public BaseBubblePopup(Context context, View view) {
        super(context);
        this.mWrappedView = view;
        init();
    }

    private void init() {
        showAnim(new BounceLeftEnter());
        dismissAnim(new FadeExit());
        dimEnabled(false);
        bubbleColor(Color.parseColor("#BB000000"));
        cornerRadius(5.0f);
        margin(8.0f, 8.0f);
        gravity(48);
        triangleWidth(24.0f);
        triangleHeight(12.0f);
    }

    @Override // com.flyco.dialog.widget.base.BaseDialog
    public View onCreateView() {
        View inflate = View.inflate(this.mContext, R.layout.popup_bubble, null);
        this.mLlContent = (LinearLayout) inflate.findViewById(R.id.ll_content);
        this.mTriangleView = (TriangleView) inflate.findViewById(R.id.triangle_view);
        this.mLlContent.addView(this.mWrappedView);
        this.mLayoutParams = (RelativeLayout.LayoutParams) this.mLlContent.getLayoutParams();
        this.mTriangleLayoutParams = (RelativeLayout.LayoutParams) this.mTriangleView.getLayoutParams();
        inflate.setLayoutParams(new LinearLayout.LayoutParams(-1, -1));
        return inflate;
    }

    @Override // com.flyco.dialog.widget.base.BaseDialog
    public void setUiBeforShow() {
        this.mLlContent.setBackgroundDrawable(CornerUtils.cornerDrawable(this.mBubbleColor, this.mCornerRadius));
        this.mLayoutParams.setMargins(this.mMarginLeft, 0, this.mMarginRight, 0);
        this.mLlContent.setLayoutParams(this.mLayoutParams);
        this.mTriangleView.setColor(this.mBubbleColor);
        this.mTriangleView.setGravity(this.mGravity == 48 ? 80 : 48);
        this.mTriangleLayoutParams.width = this.triangleWidth;
        this.mTriangleLayoutParams.height = this.triangleHeight;
        this.mTriangleView.setLayoutParams(this.mTriangleLayoutParams);
    }

    @Override // com.flyco.dialog.widget.internal.InternalBasePopup
    public void onLayoutObtain() {
        int i2;
        this.mTriangleView.setX(this.mX - (this.mTriangleView.getWidth() / 2));
        if (this.mGravity == 48) {
            this.mTriangleView.setY(this.mY - this.mTriangleView.getHeight());
            this.mLlContent.setY(r0 - r1.getHeight());
        } else {
            this.mTriangleView.setY(this.mY);
            this.mLlContent.setY(this.mY + this.mTriangleView.getHeight());
        }
        int i3 = this.mX - this.mLayoutParams.leftMargin;
        int i4 = (this.mDisplayMetrics.widthPixels - this.mX) - this.mLayoutParams.rightMargin;
        int width = this.mLlContent.getWidth();
        int i5 = width / 2;
        if (i5 <= i3 && i5 <= i4) {
            i2 = this.mX - i5;
        } else if (i3 <= i4) {
            i2 = this.mLayoutParams.leftMargin;
        } else {
            i2 = this.mDisplayMetrics.widthPixels - (width + this.mLayoutParams.rightMargin);
        }
        this.mLlContent.setX(i2);
    }

    @Override // com.flyco.dialog.widget.internal.InternalBasePopup
    public T anchorView(View view) {
        if (view != null) {
            this.mAnchorView = view;
            int[] iArr = new int[2];
            this.mAnchorView.getLocationOnScreen(iArr);
            this.mX = iArr[0] + (view.getWidth() / 2);
            if (this.mGravity == 48) {
                this.mY = (iArr[1] - StatusBarUtils.getHeight(this.mContext)) - dp2px(1.0f);
            } else {
                this.mY = (iArr[1] - StatusBarUtils.getHeight(this.mContext)) + view.getHeight() + dp2px(1.0f);
            }
        }
        return this;
    }

    public T bubbleColor(int i2) {
        this.mBubbleColor = i2;
        return this;
    }

    public T cornerRadius(float f2) {
        this.mCornerRadius = dp2px(f2);
        return this;
    }

    public T margin(float f2, float f3) {
        this.mMarginLeft = dp2px(f2);
        this.mMarginRight = dp2px(f3);
        return this;
    }

    public T triangleWidth(float f2) {
        this.triangleWidth = dp2px(f2);
        return this;
    }

    public T triangleHeight(float f2) {
        this.triangleHeight = dp2px(f2);
        return this;
    }
}
