package com.flyco.dialog.widget.popup.base;

import android.content.Context;
import android.view.View;
import android.widget.LinearLayout;
import com.flyco.dialog.R;
import com.flyco.dialog.utils.StatusBarUtils;
import com.flyco.dialog.widget.internal.InternalBasePopup;
import com.flyco.dialog.widget.popup.base.BasePopup;

/* loaded from: classes2.dex */
public abstract class BasePopup<T extends BasePopup<T>> extends InternalBasePopup<T> {
    protected boolean mAlignCenter;
    protected LinearLayout mLlContent;
    protected View mWrappedView;

    public abstract View onCreatePopupView();

    public BasePopup(Context context) {
        super(context);
        this.mWrappedView = onCreatePopupView();
        gravity(80);
    }

    @Override // com.flyco.dialog.widget.base.BaseDialog
    public View onCreateView() {
        View inflate = View.inflate(this.mContext, R.layout.popup_base, null);
        LinearLayout linearLayout = (LinearLayout) inflate.findViewById(R.id.ll_content);
        this.mLlContent = linearLayout;
        linearLayout.addView(this.mWrappedView);
        inflate.setLayoutParams(new LinearLayout.LayoutParams(-1, -1));
        return inflate;
    }

    public T offset(float f2, float f3) {
        this.mXOffset = f2;
        this.mYOffset = f3;
        return this;
    }

    public T alignCenter(boolean z) {
        this.mAlignCenter = z;
        return this;
    }

    @Override // com.flyco.dialog.widget.internal.InternalBasePopup
    public T anchorView(View view) {
        if (view != null) {
            this.mAnchorView = view;
            int[] iArr = new int[2];
            this.mAnchorView.getLocationOnScreen(iArr);
            this.mX = iArr[0];
            if (this.mGravity == 48) {
                this.mY = iArr[1] - StatusBarUtils.getHeight(this.mContext);
            } else {
                this.mY = (iArr[1] - StatusBarUtils.getHeight(this.mContext)) + view.getHeight();
            }
        }
        return this;
    }

    @Override // com.flyco.dialog.widget.internal.InternalBasePopup
    public void onLayoutObtain() {
        int i2 = this.mX;
        int i3 = this.mY;
        if (this.mGravity == 48) {
            i3 = this.mY - this.mLlContent.getHeight();
        }
        if (this.mAlignCenter) {
            i2 = (this.mX + (this.mAnchorView.getWidth() / 2)) - (this.mLlContent.getWidth() / 2);
        }
        int x = getX(i2);
        int y = getY(i3);
        int x2 = getX(x + dp2px(this.mXOffset));
        int y2 = getY(y + dp2px(this.mYOffset));
        this.mLlContent.setX(x2);
        this.mLlContent.setY(y2);
    }

    private int getX(int i2) {
        if (i2 < 0) {
            i2 = 0;
        }
        return this.mLlContent.getWidth() + i2 > this.mDisplayMetrics.widthPixels ? this.mDisplayMetrics.widthPixels - this.mLlContent.getWidth() : i2;
    }

    private int getY(int i2) {
        if (i2 < 0) {
            i2 = 0;
        }
        return ((float) (this.mLlContent.getHeight() + i2)) > this.mMaxHeight ? (int) (this.mMaxHeight - this.mLlContent.getHeight()) : i2;
    }
}
