package com.github.ybq.android.spinkit.style;

import android.animation.ValueAnimator;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.os.Build;
import android.view.animation.LinearInterpolator;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.github.ybq.android.spinkit.animation.SpriteAnimatorBuilder;
import com.github.ybq.android.spinkit.sprite.RectSprite;
import com.github.ybq.android.spinkit.sprite.Sprite;
import com.github.ybq.android.spinkit.sprite.SpriteContainer;

/* loaded from: classes2.dex */
public class FoldingCube extends SpriteContainer {
    private boolean wrapContent = false;

    @Override // com.github.ybq.android.spinkit.sprite.SpriteContainer
    public Sprite[] onCreateChild() {
        Cube[] cubeArr = new Cube[4];
        for (int i2 = 0; i2 < 4; i2++) {
            cubeArr[i2] = new Cube();
            if (Build.VERSION.SDK_INT >= 24) {
                cubeArr[i2].setAnimationDelay(i2 * 300);
            } else {
                cubeArr[i2].setAnimationDelay((i2 * 300) - 1200);
            }
        }
        return cubeArr;
    }

    @Override // com.github.ybq.android.spinkit.sprite.SpriteContainer, com.github.ybq.android.spinkit.sprite.Sprite, android.graphics.drawable.Drawable
    protected void onBoundsChange(Rect rect) {
        super.onBoundsChange(rect);
        Rect clipSquare = clipSquare(rect);
        int min = Math.min(clipSquare.width(), clipSquare.height());
        if (this.wrapContent) {
            min = (int) Math.sqrt((min * min) / 2);
            int width = (clipSquare.width() - min) / 2;
            int height = (clipSquare.height() - min) / 2;
            clipSquare = new Rect(clipSquare.left + width, clipSquare.top + height, clipSquare.right - width, clipSquare.bottom - height);
        }
        int i2 = min / 2;
        int i3 = clipSquare.left + i2 + 1;
        int i4 = clipSquare.top + i2 + 1;
        for (int i5 = 0; i5 < getChildCount(); i5++) {
            Sprite childAt = getChildAt(i5);
            childAt.setDrawBounds(clipSquare.left, clipSquare.top, i3, i4);
            childAt.setPivotX(childAt.getDrawBounds().right);
            childAt.setPivotY(childAt.getDrawBounds().bottom);
        }
    }

    @Override // com.github.ybq.android.spinkit.sprite.SpriteContainer
    public void drawChild(Canvas canvas) {
        Rect clipSquare = clipSquare(getBounds());
        for (int i2 = 0; i2 < getChildCount(); i2++) {
            int save = canvas.save();
            canvas.rotate((i2 * 90) + 45, clipSquare.centerX(), clipSquare.centerY());
            getChildAt(i2).draw(canvas);
            canvas.restoreToCount(save);
        }
    }

    private class Cube extends RectSprite {
        Cube() {
            setAlpha(0);
            setRotateX(AMapEngineUtils.MIN_LONGITUDE_DEGREE);
        }

        @Override // com.github.ybq.android.spinkit.sprite.RectSprite, com.github.ybq.android.spinkit.sprite.Sprite
        public ValueAnimator onCreateAnimation() {
            float[] fArr = {0.0f, 0.1f, 0.25f, 0.75f, 0.9f, 1.0f};
            SpriteAnimatorBuilder alpha = new SpriteAnimatorBuilder(this).alpha(fArr, 0, 0, 255, 255, 0, 0);
            Integer valueOf = Integer.valueOf(AMapEngineUtils.MIN_LONGITUDE_DEGREE);
            return alpha.rotateX(fArr, valueOf, valueOf, 0, 0, 0, 0).rotateY(fArr, 0, 0, 0, 0, 180, 180).duration(2400L).interpolator(new LinearInterpolator()).build();
        }
    }
}
