package com.google.android.gms.internal.p003firebaseauthapi;

import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.util.Log;
import java.io.CharConversionException;
import java.io.IOException;
import java.security.GeneralSecurityException;
import java.security.KeyStoreException;
import java.security.ProviderException;

/* compiled from: com.google.firebase:firebase-auth@@22.1.2 */
/* loaded from: classes2.dex */
public final class zzmh {
    private Context zza = null;
    private String zzb = null;
    private String zzc = null;
    private String zzd = null;
    private zzbd zze = null;
    private zzbv zzf = null;
    private zzwn zzg = null;
    private zzbz zzh;

    private final zzbd zzj() throws GeneralSecurityException {
        if (!zzmj.zzd()) {
            Log.w(zzmj.zzb, "Android Keystore requires at least Android M");
            return null;
        }
        zzml zzmlVar = new zzml();
        try {
            boolean zzc = zzml.zzc(this.zzd);
            try {
                return zzmlVar.zza(this.zzd);
            } catch (GeneralSecurityException | ProviderException e2) {
                if (!zzc) {
                    throw new KeyStoreException(String.format("the master key %s exists but is unusable", this.zzd), e2);
                }
                Log.w(zzmj.zzb, "cannot use Android Keystore, it'll be disabled", e2);
                return null;
            }
        } catch (GeneralSecurityException | ProviderException e3) {
            Log.w(zzmj.zzb, "cannot use Android Keystore, it'll be disabled", e3);
            return null;
        }
    }

    private final zzbz zzk(byte[] bArr) throws GeneralSecurityException, IOException {
        try {
            this.zze = new zzml().zza(this.zzd);
            try {
                return zzbz.zzf(zzby.zzh(zzbe.zzc(bArr), this.zze));
            } catch (IOException | GeneralSecurityException e2) {
                try {
                    return zzl(bArr);
                } catch (IOException unused) {
                    throw e2;
                }
            }
        } catch (GeneralSecurityException | ProviderException e3) {
            try {
                zzbz zzl = zzl(bArr);
                Log.w(zzmj.zzb, "cannot use Android Keystore, it'll be disabled", e3);
                return zzl;
            } catch (IOException unused2) {
                throw e3;
            }
        }
    }

    private static final zzbz zzl(byte[] bArr) throws GeneralSecurityException, IOException {
        return zzbz.zzf(zzbg.zzb(zzbe.zzc(bArr)));
    }

    public final zzmh zzd(zzwn zzwnVar) {
        this.zzg = zzwnVar;
        return this;
    }

    public final zzmh zze(String str) {
        if (!str.startsWith("android-keystore://")) {
            throw new IllegalArgumentException("key URI must start with android-keystore://");
        }
        this.zzd = str;
        return this;
    }

    public final zzmh zzf(Context context, String str, String str2) throws IOException {
        if (context == null) {
            throw new IllegalArgumentException("need an Android context");
        }
        this.zza = context;
        this.zzb = "GenericIdpKeyset";
        this.zzc = str2;
        return this;
    }

    public final synchronized zzmj zzg() throws GeneralSecurityException, IOException {
        byte[] bArr;
        zzmj zzmjVar;
        if (this.zzb == null) {
            throw new IllegalArgumentException("keysetName cannot be null");
        }
        zzwn zzwnVar = this.zzg;
        if (zzwnVar != null && this.zzf == null) {
            this.zzf = zzbv.zza(zzcs.zza(zzwnVar.zzq()));
        }
        synchronized (zzmj.zza) {
            Context context = this.zza;
            String str = this.zzb;
            String str2 = this.zzc;
            if (str == null) {
                throw new IllegalArgumentException("keysetName cannot be null");
            }
            Context applicationContext = context.getApplicationContext();
            SharedPreferences defaultSharedPreferences = str2 == null ? PreferenceManager.getDefaultSharedPreferences(applicationContext) : applicationContext.getSharedPreferences(str2, 0);
            zzmi zzmiVar = null;
            try {
                String string = defaultSharedPreferences.getString(str, null);
                if (string == null) {
                    bArr = null;
                } else {
                    if (string.length() % 2 != 0) {
                        throw new IllegalArgumentException("Expected a string of even length");
                    }
                    int length = string.length() / 2;
                    bArr = new byte[length];
                    for (int i2 = 0; i2 < length; i2++) {
                        int i3 = i2 + i2;
                        int digit = Character.digit(string.charAt(i3), 16);
                        int digit2 = Character.digit(string.charAt(i3 + 1), 16);
                        if (digit == -1 || digit2 == -1) {
                            throw new IllegalArgumentException("input is not hexadecimal");
                        }
                        bArr[i2] = (byte) ((digit * 16) + digit2);
                    }
                }
                if (bArr == null) {
                    if (this.zzd != null) {
                        this.zze = zzj();
                    }
                    if (this.zzf == null) {
                        throw new GeneralSecurityException("cannot read or generate keyset");
                    }
                    zzbz zze = zzbz.zze();
                    zze.zzc(this.zzf);
                    zze.zzd(zze.zzb().zzd().zzb(0).zza());
                    zzmm zzmmVar = new zzmm(this.zza, this.zzb, this.zzc);
                    zzby zzb = zze.zzb();
                    zzbd zzbdVar = this.zze;
                    try {
                        if (zzbdVar != null) {
                            zzb.zzf(zzmmVar, zzbdVar);
                        } else {
                            zzbg.zza(zzb, zzmmVar);
                        }
                        this.zzh = zze;
                    } catch (IOException e2) {
                        throw new GeneralSecurityException(e2);
                    }
                } else {
                    if (this.zzd != null && zzmj.zzd()) {
                        this.zzh = zzk(bArr);
                    }
                    this.zzh = zzl(bArr);
                }
                zzmjVar = new zzmj(this, zzmiVar);
            } catch (ClassCastException | IllegalArgumentException unused) {
                throw new CharConversionException(String.format("can't read keyset; the pref value %s is not a valid hex string", str));
            }
        }
        return zzmjVar;
    }
}
