package com.google.android.material.color;

import android.content.Context;
import android.graphics.Color;
import android.util.TypedValue;
import android.view.View;
import com.google.android.material.R;
import com.google.android.material.resources.MaterialAttributes;

/* loaded from: classes2.dex */
public class MaterialColors {
    public static final float ALPHA_DISABLED = 0.38f;
    public static final float ALPHA_DISABLED_LOW = 0.12f;
    public static final float ALPHA_FULL = 1.0f;
    public static final float ALPHA_LOW = 0.32f;
    public static final float ALPHA_MEDIUM = 0.54f;
    private static final int TONE_ACCENT_CONTAINER_DARK = 30;
    private static final int TONE_ACCENT_CONTAINER_LIGHT = 90;
    private static final int TONE_ACCENT_DARK = 80;
    private static final int TONE_ACCENT_LIGHT = 40;
    private static final int TONE_ON_ACCENT_CONTAINER_DARK = 90;
    private static final int TONE_ON_ACCENT_CONTAINER_LIGHT = 10;
    private static final int TONE_ON_ACCENT_DARK = 20;
    private static final int TONE_ON_ACCENT_LIGHT = 100;

    private MaterialColors() {
    }

    public static int getColor(View view, int i2) {
        return MaterialAttributes.resolveOrThrow(view, i2);
    }

    public static int getColor(Context context, int i2, String str) {
        return MaterialAttributes.resolveOrThrow(context, i2, str);
    }

    public static int getColor(View view, int i2, int i3) {
        return getColor(view.getContext(), i2, i3);
    }

    public static int getColor(Context context, int i2, int i3) {
        TypedValue resolve = MaterialAttributes.resolve(context, i2);
        return resolve != null ? resolve.data : i3;
    }

    public static int layer(View view, int i2, int i3) {
        return layer(view, i2, i3, 1.0f);
    }

    public static int layer(View view, int i2, int i3, float f2) {
        return layer(getColor(view, i2), getColor(view, i3), f2);
    }

    public static int layer(int i2, int i3, float f2) {
        return layer(i2, androidx.core.graphics.ColorUtils.setAlphaComponent(i3, Math.round(Color.alpha(i3) * f2)));
    }

    public static int layer(int i2, int i3) {
        return androidx.core.graphics.ColorUtils.compositeColors(i3, i2);
    }

    public static int compositeARGBWithAlpha(int i2, int i3) {
        return androidx.core.graphics.ColorUtils.setAlphaComponent(i2, (Color.alpha(i2) * i3) / 255);
    }

    public static boolean isColorLight(int i2) {
        return i2 != 0 && androidx.core.graphics.ColorUtils.calculateLuminance(i2) > 0.5d;
    }

    public static int harmonizeWithPrimary(Context context, int i2) {
        return harmonize(i2, getColor(context, R.attr.colorPrimary, MaterialColors.class.getCanonicalName()));
    }

    public static int harmonize(int i2, int i3) {
        return Blend.harmonize(i2, i3);
    }

    public static ColorRoles getColorRoles(Context context, int i2) {
        return getColorRoles(i2, MaterialAttributes.resolveBoolean(context, R.attr.isLightTheme, true));
    }

    public static ColorRoles getColorRoles(int i2, boolean z) {
        if (z) {
            return new ColorRoles(getColorRole(i2, 40), getColorRole(i2, 100), getColorRole(i2, 90), getColorRole(i2, 10));
        }
        return new ColorRoles(getColorRole(i2, 80), getColorRole(i2, 20), getColorRole(i2, 30), getColorRole(i2, 90));
    }

    private static int getColorRole(int i2, int i3) {
        Hct fromInt = Hct.fromInt(i2);
        fromInt.setTone(i3);
        return fromInt.toInt();
    }
}
