package com.google.firebase.crashlytics.buildtools.reloc.com.google.common.io;

import com.google.firebase.crashlytics.buildtools.reloc.com.google.common.base.Preconditions;
import com.google.firebase.crashlytics.buildtools.reloc.org.checkerframework.checker.nullness.compatqual.NullableDecl;
import java.io.IOException;
import java.io.Reader;
import java.util.Iterator;

/* loaded from: classes3.dex */
class MultiReader extends Reader {

    @NullableDecl
    private Reader current;

    /* renamed from: it, reason: collision with root package name */
    private final Iterator<? extends CharSource> f3320it;

    MultiReader(Iterator<? extends CharSource> it2) throws IOException {
        this.f3320it = it2;
        advance();
    }

    private void advance() throws IOException {
        close();
        if (this.f3320it.hasNext()) {
            this.current = this.f3320it.next().openStream();
        }
    }

    @Override // java.io.Reader
    public int read(@NullableDecl char[] cArr, int i2, int i3) throws IOException {
        Reader reader = this.current;
        if (reader == null) {
            return -1;
        }
        int read = reader.read(cArr, i2, i3);
        if (read != -1) {
            return read;
        }
        advance();
        return read(cArr, i2, i3);
    }

    @Override // java.io.Reader
    public long skip(long j2) throws IOException {
        Preconditions.checkArgument(j2 >= 0, "n is negative");
        if (j2 > 0) {
            while (true) {
                Reader reader = this.current;
                if (reader == null) {
                    break;
                }
                long skip = reader.skip(j2);
                if (skip > 0) {
                    return skip;
                }
                advance();
            }
        }
        return 0L;
    }

    @Override // java.io.Reader
    public boolean ready() throws IOException {
        Reader reader = this.current;
        return reader != null && reader.ready();
    }

    @Override // java.io.Reader, java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        Reader reader = this.current;
        if (reader != null) {
            try {
                reader.close();
            } finally {
                this.current = null;
            }
        }
    }
}
