package com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent;

import com.google.firebase.crashlytics.buildtools.reloc.com.google.common.base.Preconditions;
import java.util.ArrayDeque;
import java.util.Deque;
import java.util.concurrent.Executor;
import java.util.concurrent.RejectedExecutionException;
import java.util.logging.Logger;

/* loaded from: classes3.dex */
final class SequentialExecutor implements Executor {
    private static final Logger log = Logger.getLogger(SequentialExecutor.class.getName());
    private final Executor executor;
    private final Deque<Runnable> queue = new ArrayDeque();
    private WorkerRunningState workerRunningState = WorkerRunningState.IDLE;
    private long workerRunCount = 0;
    private final QueueWorker worker = new QueueWorker();

    enum WorkerRunningState {
        IDLE,
        QUEUING,
        QUEUED,
        RUNNING
    }

    static /* synthetic */ long access$308(SequentialExecutor sequentialExecutor) {
        long j2 = sequentialExecutor.workerRunCount;
        sequentialExecutor.workerRunCount = 1 + j2;
        return j2;
    }

    SequentialExecutor(Executor executor) {
        this.executor = (Executor) Preconditions.checkNotNull(executor);
    }

    @Override // java.util.concurrent.Executor
    public void execute(final Runnable runnable) {
        Preconditions.checkNotNull(runnable);
        synchronized (this.queue) {
            if (this.workerRunningState != WorkerRunningState.RUNNING && this.workerRunningState != WorkerRunningState.QUEUED) {
                long j2 = this.workerRunCount;
                Runnable runnable2 = new Runnable() { // from class: com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.1
                    @Override // java.lang.Runnable
                    public void run() {
                        runnable.run();
                    }
                };
                this.queue.add(runnable2);
                this.workerRunningState = WorkerRunningState.QUEUING;
                try {
                    this.executor.execute(this.worker);
                    if (this.workerRunningState != WorkerRunningState.QUEUING) {
                        return;
                    }
                    synchronized (this.queue) {
                        if (this.workerRunCount == j2 && this.workerRunningState == WorkerRunningState.QUEUING) {
                            this.workerRunningState = WorkerRunningState.QUEUED;
                        }
                    }
                    return;
                } catch (Error | RuntimeException e2) {
                    synchronized (this.queue) {
                        if ((this.workerRunningState != WorkerRunningState.IDLE && this.workerRunningState != WorkerRunningState.QUEUING) || !this.queue.removeLastOccurrence(runnable2)) {
                            r8 = false;
                        }
                        if (!(e2 instanceof RejectedExecutionException) || r8) {
                            throw e2;
                        }
                    }
                    return;
                }
            }
            this.queue.add(runnable);
        }
    }

    private final class QueueWorker implements Runnable {
        private QueueWorker() {
        }

        @Override // java.lang.Runnable
        public void run() {
            try {
                workOnQueue();
            } catch (Error e2) {
                synchronized (SequentialExecutor.this.queue) {
                    SequentialExecutor.this.workerRunningState = WorkerRunningState.IDLE;
                    throw e2;
                }
            }
        }

        /* JADX WARN: Code restructure failed: missing block: B:10:0x0052, code lost:
        
            r1 = r1 | java.lang.Thread.interrupted();
         */
        /* JADX WARN: Code restructure failed: missing block: B:12:0x0053, code lost:
        
            r3.run();
         */
        /* JADX WARN: Code restructure failed: missing block: B:16:0x0057, code lost:
        
            r2 = move-exception;
         */
        /* JADX WARN: Code restructure failed: missing block: B:17:0x0058, code lost:
        
            com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.log.log(java.util.logging.Level.SEVERE, "Exception while executing runnable " + r3, (java.lang.Throwable) r2);
         */
        /* JADX WARN: Code restructure failed: missing block: B:24:0x004c, code lost:
        
            return;
         */
        /* JADX WARN: Code restructure failed: missing block: B:26:?, code lost:
        
            return;
         */
        /*
            Code decompiled incorrectly, please refer to instructions dump.
            To view partially-correct code enable 'Show inconsistent code' option in preferences
        */
        private void workOnQueue() {
            /*
                r8 = this;
                r0 = 0
                r1 = r0
            L2:
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor r2 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.this     // Catch: java.lang.Throwable -> L76
                java.util.Deque r2 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.access$100(r2)     // Catch: java.lang.Throwable -> L76
                monitor-enter(r2)     // Catch: java.lang.Throwable -> L76
                if (r0 != 0) goto L2d
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor r0 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.this     // Catch: java.lang.Throwable -> L73
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor$WorkerRunningState r0 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.access$200(r0)     // Catch: java.lang.Throwable -> L73
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor$WorkerRunningState r3 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.WorkerRunningState.RUNNING     // Catch: java.lang.Throwable -> L73
                if (r0 != r3) goto L20
                monitor-exit(r2)     // Catch: java.lang.Throwable -> L73
                if (r1 == 0) goto L1f
                java.lang.Thread r0 = java.lang.Thread.currentThread()
                r0.interrupt()
            L1f:
                return
            L20:
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor r0 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.this     // Catch: java.lang.Throwable -> L73
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.access$308(r0)     // Catch: java.lang.Throwable -> L73
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor r0 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.this     // Catch: java.lang.Throwable -> L73
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor$WorkerRunningState r3 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.WorkerRunningState.RUNNING     // Catch: java.lang.Throwable -> L73
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.access$202(r0, r3)     // Catch: java.lang.Throwable -> L73
                r0 = 1
            L2d:
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor r3 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.this     // Catch: java.lang.Throwable -> L73
                java.util.Deque r3 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.access$100(r3)     // Catch: java.lang.Throwable -> L73
                java.lang.Object r3 = r3.poll()     // Catch: java.lang.Throwable -> L73
                java.lang.Runnable r3 = (java.lang.Runnable) r3     // Catch: java.lang.Throwable -> L73
                if (r3 != 0) goto L4d
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor r0 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.this     // Catch: java.lang.Throwable -> L73
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor$WorkerRunningState r3 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.WorkerRunningState.IDLE     // Catch: java.lang.Throwable -> L73
                com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.access$202(r0, r3)     // Catch: java.lang.Throwable -> L73
                monitor-exit(r2)     // Catch: java.lang.Throwable -> L73
                if (r1 == 0) goto L4c
                java.lang.Thread r0 = java.lang.Thread.currentThread()
                r0.interrupt()
            L4c:
                return
            L4d:
                monitor-exit(r2)     // Catch: java.lang.Throwable -> L73
                boolean r2 = java.lang.Thread.interrupted()     // Catch: java.lang.Throwable -> L76
                r1 = r1 | r2
                r3.run()     // Catch: java.lang.RuntimeException -> L57 java.lang.Throwable -> L76
                goto L2
            L57:
                r2 = move-exception
                java.util.logging.Logger r4 = com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.access$400()     // Catch: java.lang.Throwable -> L76
                java.util.logging.Level r5 = java.util.logging.Level.SEVERE     // Catch: java.lang.Throwable -> L76
                java.lang.StringBuilder r6 = new java.lang.StringBuilder     // Catch: java.lang.Throwable -> L76
                r6.<init>()     // Catch: java.lang.Throwable -> L76
                java.lang.String r7 = "Exception while executing runnable "
                r6.append(r7)     // Catch: java.lang.Throwable -> L76
                r6.append(r3)     // Catch: java.lang.Throwable -> L76
                java.lang.String r3 = r6.toString()     // Catch: java.lang.Throwable -> L76
                r4.log(r5, r3, r2)     // Catch: java.lang.Throwable -> L76
                goto L2
            L73:
                r0 = move-exception
                monitor-exit(r2)     // Catch: java.lang.Throwable -> L73
                throw r0     // Catch: java.lang.Throwable -> L76
            L76:
                r0 = move-exception
                if (r1 == 0) goto L80
                java.lang.Thread r1 = java.lang.Thread.currentThread()
                r1.interrupt()
            L80:
                throw r0
            */
            throw new UnsupportedOperationException("Method not decompiled: com.google.firebase.crashlytics.buildtools.reloc.com.google.common.util.concurrent.SequentialExecutor.QueueWorker.workOnQueue():void");
        }
    }
}
