package com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io;

import com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.filefilter.FileFilterUtils;
import com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.filefilter.IOFileFilter;
import com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.filefilter.TrueFileFilter;
import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import java.util.Collection;

/* loaded from: classes3.dex */
public abstract class DirectoryWalker<T> {
    private final int depthLimit;
    private final FileFilter filter;

    protected File[] filterDirectoryContents(File file, int i2, File[] fileArr) throws IOException {
        return fileArr;
    }

    protected boolean handleDirectory(File file, int i2, Collection<T> collection) throws IOException {
        return true;
    }

    protected void handleDirectoryEnd(File file, int i2, Collection<T> collection) throws IOException {
    }

    protected void handleDirectoryStart(File file, int i2, Collection<T> collection) throws IOException {
    }

    protected void handleEnd(Collection<T> collection) throws IOException {
    }

    protected void handleFile(File file, int i2, Collection<T> collection) throws IOException {
    }

    protected boolean handleIsCancelled(File file, int i2, Collection<T> collection) throws IOException {
        return false;
    }

    protected void handleRestricted(File file, int i2, Collection<T> collection) throws IOException {
    }

    protected void handleStart(File file, Collection<T> collection) throws IOException {
    }

    protected DirectoryWalker() {
        this(null, -1);
    }

    protected DirectoryWalker(FileFilter fileFilter, int i2) {
        this.filter = fileFilter;
        this.depthLimit = i2;
    }

    protected DirectoryWalker(IOFileFilter iOFileFilter, IOFileFilter iOFileFilter2, int i2) {
        if (iOFileFilter == null && iOFileFilter2 == null) {
            this.filter = null;
        } else {
            this.filter = FileFilterUtils.or(FileFilterUtils.makeDirectoryOnly(iOFileFilter == null ? TrueFileFilter.TRUE : iOFileFilter), FileFilterUtils.makeFileOnly(iOFileFilter2 == null ? TrueFileFilter.TRUE : iOFileFilter2));
        }
        this.depthLimit = i2;
    }

    protected final void walk(File file, Collection<T> collection) throws IOException {
        if (file == null) {
            throw new NullPointerException("Start Directory is null");
        }
        try {
            handleStart(file, collection);
            walk(file, 0, collection);
            handleEnd(collection);
        } catch (CancelException e2) {
            handleCancelled(file, collection, e2);
        }
    }

    private void walk(File file, int i2, Collection<T> collection) throws IOException {
        checkIfCancelled(file, i2, collection);
        if (handleDirectory(file, i2, collection)) {
            handleDirectoryStart(file, i2, collection);
            int i3 = i2 + 1;
            int i4 = this.depthLimit;
            if (i4 < 0 || i3 <= i4) {
                checkIfCancelled(file, i2, collection);
                FileFilter fileFilter = this.filter;
                File[] filterDirectoryContents = filterDirectoryContents(file, i2, fileFilter == null ? file.listFiles() : file.listFiles(fileFilter));
                if (filterDirectoryContents == null) {
                    handleRestricted(file, i3, collection);
                } else {
                    for (File file2 : filterDirectoryContents) {
                        if (file2.isDirectory()) {
                            walk(file2, i3, collection);
                        } else {
                            checkIfCancelled(file2, i3, collection);
                            handleFile(file2, i3, collection);
                            checkIfCancelled(file2, i3, collection);
                        }
                    }
                }
            }
            handleDirectoryEnd(file, i2, collection);
        }
        checkIfCancelled(file, i2, collection);
    }

    protected final void checkIfCancelled(File file, int i2, Collection<T> collection) throws IOException {
        if (handleIsCancelled(file, i2, collection)) {
            throw new CancelException(file, i2);
        }
    }

    protected void handleCancelled(File file, Collection<T> collection, CancelException cancelException) throws IOException {
        throw cancelException;
    }

    public static class CancelException extends IOException {
        private static final long serialVersionUID = 1347339620135041008L;
        private final int depth;
        private final File file;

        public CancelException(File file, int i2) {
            this("Operation Cancelled", file, i2);
        }

        public CancelException(String str, File file, int i2) {
            super(str);
            this.file = file;
            this.depth = i2;
        }

        public File getFile() {
            return this.file;
        }

        public int getDepth() {
            return this.depth;
        }
    }
}
