package com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.input;

import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/* loaded from: classes3.dex */
public class ObservableInputStream extends ProxyInputStream {
    private final List<Observer> observers;

    public static abstract class Observer {
        void closed() throws IOException {
        }

        void data(int i2) throws IOException {
        }

        void data(byte[] bArr, int i2, int i3) throws IOException {
        }

        void finished() throws IOException {
        }

        void error(IOException iOException) throws IOException {
            throw iOException;
        }
    }

    public ObservableInputStream(InputStream inputStream) {
        super(inputStream);
        this.observers = new ArrayList();
    }

    public void add(Observer observer) {
        this.observers.add(observer);
    }

    public void remove(Observer observer) {
        this.observers.remove(observer);
    }

    public void removeAllObservers() {
        this.observers.clear();
    }

    @Override // com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.input.ProxyInputStream, java.io.FilterInputStream, java.io.InputStream
    public int read() throws IOException {
        int i2;
        try {
            i2 = super.read();
            e = null;
        } catch (IOException e2) {
            e = e2;
            i2 = 0;
        }
        if (e != null) {
            noteError(e);
        } else if (i2 == -1) {
            noteFinished();
        } else {
            noteDataByte(i2);
        }
        return i2;
    }

    @Override // com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.input.ProxyInputStream, java.io.FilterInputStream, java.io.InputStream
    public int read(byte[] bArr) throws IOException {
        int i2;
        try {
            i2 = super.read(bArr);
            e = null;
        } catch (IOException e2) {
            e = e2;
            i2 = 0;
        }
        if (e != null) {
            noteError(e);
        } else if (i2 == -1) {
            noteFinished();
        } else if (i2 > 0) {
            noteDataBytes(bArr, 0, i2);
        }
        return i2;
    }

    @Override // com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.input.ProxyInputStream, java.io.FilterInputStream, java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) throws IOException {
        int i4;
        try {
            i4 = super.read(bArr, i2, i3);
            e = null;
        } catch (IOException e2) {
            e = e2;
            i4 = 0;
        }
        if (e != null) {
            noteError(e);
        } else if (i4 == -1) {
            noteFinished();
        } else if (i4 > 0) {
            noteDataBytes(bArr, i2, i4);
        }
        return i4;
    }

    protected void noteDataBytes(byte[] bArr, int i2, int i3) throws IOException {
        Iterator<Observer> it2 = getObservers().iterator();
        while (it2.hasNext()) {
            it2.next().data(bArr, i2, i3);
        }
    }

    protected void noteFinished() throws IOException {
        Iterator<Observer> it2 = getObservers().iterator();
        while (it2.hasNext()) {
            it2.next().finished();
        }
    }

    protected void noteDataByte(int i2) throws IOException {
        Iterator<Observer> it2 = getObservers().iterator();
        while (it2.hasNext()) {
            it2.next().data(i2);
        }
    }

    protected void noteError(IOException iOException) throws IOException {
        Iterator<Observer> it2 = getObservers().iterator();
        while (it2.hasNext()) {
            it2.next().error(iOException);
        }
    }

    protected void noteClosed() throws IOException {
        Iterator<Observer> it2 = getObservers().iterator();
        while (it2.hasNext()) {
            it2.next().closed();
        }
    }

    protected List<Observer> getObservers() {
        return this.observers;
    }

    @Override // com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.input.ProxyInputStream, java.io.FilterInputStream, java.io.InputStream, java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        try {
            super.close();
            e = null;
        } catch (IOException e2) {
            e = e2;
        }
        if (e == null) {
            noteClosed();
        } else {
            noteError(e);
        }
    }

    public void consume() throws IOException {
        while (read(new byte[8192]) != -1) {
        }
    }
}
