package com.google.gson.internal.bind.util;

import com.dd.plist.ASCIIPropertyListParser;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Locale;
import java.util.TimeZone;

/* loaded from: classes3.dex */
public class ISO8601Utils {
    private static final String UTC_ID = "UTC";
    private static final TimeZone TIMEZONE_UTC = TimeZone.getTimeZone(UTC_ID);

    public static String format(Date date) {
        return format(date, false, TIMEZONE_UTC);
    }

    public static String format(Date date, boolean z) {
        return format(date, z, TIMEZONE_UTC);
    }

    public static String format(Date date, boolean z, TimeZone timeZone) {
        GregorianCalendar gregorianCalendar = new GregorianCalendar(timeZone, Locale.US);
        gregorianCalendar.setTime(date);
        StringBuilder sb = new StringBuilder(19 + (z ? 4 : 0) + (timeZone.getRawOffset() == 0 ? 1 : 6));
        padInt(sb, gregorianCalendar.get(1), 4);
        char c2 = ASCIIPropertyListParser.DATE_DATE_FIELD_DELIMITER;
        sb.append(ASCIIPropertyListParser.DATE_DATE_FIELD_DELIMITER);
        padInt(sb, gregorianCalendar.get(2) + 1, 2);
        sb.append(ASCIIPropertyListParser.DATE_DATE_FIELD_DELIMITER);
        padInt(sb, gregorianCalendar.get(5), 2);
        sb.append(ASCIIPropertyListParser.DATE_APPLE_DATE_TIME_DELIMITER);
        padInt(sb, gregorianCalendar.get(11), 2);
        sb.append(ASCIIPropertyListParser.DATE_TIME_FIELD_DELIMITER);
        padInt(sb, gregorianCalendar.get(12), 2);
        sb.append(ASCIIPropertyListParser.DATE_TIME_FIELD_DELIMITER);
        padInt(sb, gregorianCalendar.get(13), 2);
        if (z) {
            sb.append('.');
            padInt(sb, gregorianCalendar.get(14), 3);
        }
        int offset = timeZone.getOffset(gregorianCalendar.getTimeInMillis());
        if (offset != 0) {
            int i2 = offset / 60000;
            int abs = Math.abs(i2 / 60);
            int abs2 = Math.abs(i2 % 60);
            if (offset >= 0) {
                c2 = '+';
            }
            sb.append(c2);
            padInt(sb, abs, 2);
            sb.append(ASCIIPropertyListParser.DATE_TIME_FIELD_DELIMITER);
            padInt(sb, abs2, 2);
        } else {
            sb.append(ASCIIPropertyListParser.DATE_APPLE_END_TOKEN);
        }
        return sb.toString();
    }

    /* JADX WARN: Removed duplicated region for block: B:45:0x00d8 A[Catch: IllegalArgumentException | IndexOutOfBoundsException | NumberFormatException -> 0x01bc, NumberFormatException -> 0x01be, IndexOutOfBoundsException -> 0x01c0, TryCatch #2 {IllegalArgumentException | IndexOutOfBoundsException | NumberFormatException -> 0x01bc, blocks: (B:3:0x000a, B:5:0x001c, B:6:0x001e, B:8:0x002a, B:9:0x002c, B:11:0x003c, B:13:0x0042, B:18:0x0059, B:20:0x0069, B:21:0x006b, B:23:0x0077, B:24:0x0079, B:26:0x007f, B:30:0x0089, B:35:0x0099, B:37:0x00a1, B:43:0x00d2, B:45:0x00d8, B:47:0x00df, B:48:0x0182, B:55:0x00ee, B:56:0x0104, B:57:0x0105, B:60:0x0121, B:62:0x012e, B:65:0x0137, B:67:0x0151, B:70:0x0160, B:71:0x017d, B:73:0x0180, B:74:0x0110, B:75:0x01b4, B:76:0x01bb, B:77:0x00ba, B:78:0x00bd), top: B:2:0x000a }] */
    /* JADX WARN: Removed duplicated region for block: B:75:0x01b4 A[Catch: IllegalArgumentException | IndexOutOfBoundsException | NumberFormatException -> 0x01bc, NumberFormatException -> 0x01be, IndexOutOfBoundsException -> 0x01c0, TryCatch #2 {IllegalArgumentException | IndexOutOfBoundsException | NumberFormatException -> 0x01bc, blocks: (B:3:0x000a, B:5:0x001c, B:6:0x001e, B:8:0x002a, B:9:0x002c, B:11:0x003c, B:13:0x0042, B:18:0x0059, B:20:0x0069, B:21:0x006b, B:23:0x0077, B:24:0x0079, B:26:0x007f, B:30:0x0089, B:35:0x0099, B:37:0x00a1, B:43:0x00d2, B:45:0x00d8, B:47:0x00df, B:48:0x0182, B:55:0x00ee, B:56:0x0104, B:57:0x0105, B:60:0x0121, B:62:0x012e, B:65:0x0137, B:67:0x0151, B:70:0x0160, B:71:0x017d, B:73:0x0180, B:74:0x0110, B:75:0x01b4, B:76:0x01bb, B:77:0x00ba, B:78:0x00bd), top: B:2:0x000a }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static java.util.Date parse(java.lang.String r19, java.text.ParsePosition r20) throws java.text.ParseException {
        /*
            Method dump skipped, instructions count: 546
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.gson.internal.bind.util.ISO8601Utils.parse(java.lang.String, java.text.ParsePosition):java.util.Date");
    }

    private static boolean checkOffset(String str, int i2, char c2) {
        return i2 < str.length() && str.charAt(i2) == c2;
    }

    private static int parseInt(String str, int i2, int i3) throws NumberFormatException {
        int i4;
        int i5;
        if (i2 < 0 || i3 > str.length() || i2 > i3) {
            throw new NumberFormatException(str);
        }
        if (i2 < i3) {
            i5 = i2 + 1;
            int digit = Character.digit(str.charAt(i2), 10);
            if (digit < 0) {
                throw new NumberFormatException("Invalid number: " + str.substring(i2, i3));
            }
            i4 = -digit;
        } else {
            i4 = 0;
            i5 = i2;
        }
        while (i5 < i3) {
            int i6 = i5 + 1;
            int digit2 = Character.digit(str.charAt(i5), 10);
            if (digit2 < 0) {
                throw new NumberFormatException("Invalid number: " + str.substring(i2, i3));
            }
            i4 = (i4 * 10) - digit2;
            i5 = i6;
        }
        return -i4;
    }

    private static void padInt(StringBuilder sb, int i2, int i3) {
        String num = Integer.toString(i2);
        for (int length = i3 - num.length(); length > 0; length--) {
            sb.append('0');
        }
        sb.append(num);
    }

    private static int indexOfNonDigit(String str, int i2) {
        while (i2 < str.length()) {
            char charAt = str.charAt(i2);
            if (charAt < '0' || charAt > '9') {
                return i2;
            }
            i2++;
        }
        return str.length();
    }
}
