package com.google.maps;

import com.google.maps.PendingResult;
import com.google.maps.PendingResultBase;
import com.google.maps.errors.ApiException;
import com.google.maps.internal.ApiConfig;
import com.google.maps.internal.ApiResponse;
import com.google.maps.internal.StringJoin;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* loaded from: classes3.dex */
abstract class PendingResultBase<T, A extends PendingResultBase<T, A, R>, R extends ApiResponse<T>> implements PendingResult<T> {
    private final ApiConfig config;
    private final GeoApiContext context;
    private PendingResult<T> delegate;
    private HashMap<String, List<String>> params = new HashMap<>();
    private Class<? extends R> responseClass;

    private A getInstance() {
        return this;
    }

    protected abstract void validateRequest();

    protected PendingResultBase(GeoApiContext geoApiContext, ApiConfig apiConfig, Class<? extends R> cls) {
        this.context = geoApiContext;
        this.config = apiConfig;
        this.responseClass = cls;
    }

    @Override // com.google.maps.PendingResult
    public final void setCallback(PendingResult.Callback<T> callback) {
        makeRequest().setCallback(callback);
    }

    @Override // com.google.maps.PendingResult
    public final T await() throws ApiException, InterruptedException, IOException {
        return makeRequest().await();
    }

    @Override // com.google.maps.PendingResult
    public final T awaitIgnoreError() {
        return makeRequest().awaitIgnoreError();
    }

    @Override // com.google.maps.PendingResult
    public final void cancel() {
        PendingResult<T> pendingResult = this.delegate;
        if (pendingResult == null) {
            return;
        }
        pendingResult.cancel();
    }

    private PendingResult<T> makeRequest() {
        if (this.delegate != null) {
            throw new IllegalStateException("'await', 'awaitIgnoreError' or 'setCallback' was already called.");
        }
        validateRequest();
        String str = this.config.requestVerb;
        str.hashCode();
        if (str.equals("GET")) {
            PendingResult<T> pendingResult = this.context.get(this.config, this.responseClass, this.params);
            this.delegate = pendingResult;
            return pendingResult;
        }
        if (str.equals("POST")) {
            PendingResult<T> post = this.context.post(this.config, this.responseClass, this.params);
            this.delegate = post;
            return post;
        }
        throw new IllegalStateException(String.format("Unexpected request method '%s'", this.config.requestVerb));
    }

    protected A param(String str, String str2) {
        this.params.put(str, new ArrayList());
        return paramAddToList(str, str2);
    }

    protected A param(String str, int i2) {
        return param(str, Integer.toString(i2));
    }

    protected A param(String str, StringJoin.UrlValue urlValue) {
        if (urlValue != null) {
            return param(str, urlValue.toUrlValue());
        }
        return getInstance();
    }

    protected A paramAddToList(String str, String str2) {
        if (this.params.get(str) == null) {
            this.params.put(str, new ArrayList());
        }
        this.params.get(str).add(str2);
        return getInstance();
    }

    protected A paramAddToList(String str, StringJoin.UrlValue urlValue) {
        if (urlValue != null) {
            return paramAddToList(str, urlValue.toUrlValue());
        }
        return getInstance();
    }

    protected Map<String, List<String>> params() {
        return Collections.unmodifiableMap(this.params);
    }

    public final A language(String str) {
        return param("language", str);
    }

    public A channel(String str) {
        return param("channel", str);
    }

    public A custom(String str, String str2) {
        return param(str, str2);
    }
}
