package com.google.maps.internal;

import com.dd.plist.ASCIIPropertyListParser;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import okio.ByteString;

/* loaded from: classes3.dex */
public class UrlSigner {
    private static final String ALGORITHM_HMAC_SHA1 = "HmacSHA1";
    private final Mac mac;

    public UrlSigner(String str) throws NoSuchAlgorithmException, InvalidKeyException {
        ByteString decodeBase64 = ByteString.decodeBase64(str.replace(ASCIIPropertyListParser.DATE_DATE_FIELD_DELIMITER, '+').replace('_', '/'));
        if (decodeBase64 == null) {
            throw new IllegalArgumentException("Private key is invalid.");
        }
        Mac mac = Mac.getInstance(ALGORITHM_HMAC_SHA1);
        this.mac = mac;
        mac.init(new SecretKeySpec(decodeBase64.toByteArray(), ALGORITHM_HMAC_SHA1));
    }

    public String getSignature(String str) {
        return ByteString.of(getMac().doFinal(str.getBytes())).base64().replace('+', ASCIIPropertyListParser.DATE_DATE_FIELD_DELIMITER).replace('/', '_');
    }

    private Mac getMac() {
        try {
            return (Mac) this.mac.clone();
        } catch (CloneNotSupportedException e2) {
            throw new IllegalStateException(e2);
        }
    }
}
