package com.google.zxing.datamatrix.encoder;

import com.alibaba.fastjson.asm.Opcodes;
import com.google.firebase.crashlytics.buildtools.ndk.internal.elf.EMachine;
import com.google.firebase.crashlytics.buildtools.reloc.org.apache.http.HttpStatus;
import com.jieli.jl_rcsp.constant.Command;
import com.jieli.jl_rcsp.model.SportHealthConfigure;

/* loaded from: classes3.dex */
public final class ErrorCorrection {
    private static final int MODULO_VALUE = 301;
    private static final int[] FACTOR_SETS = {5, 7, 10, 11, 12, 14, 18, 20, 24, 28, 36, 42, 48, 56, 62, 68};
    private static final int[][] FACTORS = {new int[]{228, 48, 15, 111, 62}, new int[]{23, 68, 144, EMachine.EM_ECOG2, 240, 92, SportHealthConfigure.CONFIGURE_TYPE_SPORT_MODE}, new int[]{28, 24, 185, 166, 223, 248, 116, 255, 110, 61}, new int[]{EMachine.EM_MCST_ELBRUS, EMachine.EM_LATTICEMICO32, HttpStatus.SC_RESET_CONTENT, 12, 194, 168, 39, 245, 60, 97, 120}, new int[]{41, Opcodes.IFEQ, Opcodes.IFLE, 91, 61, 42, EMachine.EM_TI_C5500, Command.CMD_GET_LOW_LATENCY_SETTINGS, 97, 178, 100, 242}, new int[]{156, 97, 192, 252, 95, 9, 157, 119, EMachine.EM_LATTICEMICO32, 45, 18, EMachine.EM_STM8, 83, 185}, new int[]{83, 195, 100, 39, 188, 75, 66, 61, 241, Command.CMD_GET_LOW_LATENCY_SETTINGS, 109, 129, 94, SportHealthConfigure.CONFIGURE_TYPE_SPORT_MODE, 225, 48, 90, 188}, new int[]{15, 195, 244, 9, 233, 71, 168, 2, 188, 160, Opcodes.IFEQ, 145, 253, 79, 108, 82, 27, EMachine.EM_METAG, EMachine.EM_STM8, EMachine.EM_CRAYNV2}, new int[]{52, 190, 88, HttpStatus.SC_RESET_CONTENT, 109, 39, 176, 21, 155, EMachine.EM_RL78, 251, 223, 155, 21, 5, EMachine.EM_CRAYNV2, SportHealthConfigure.CONFIGURE_TYPE_SPORT_MODE, 124, 12, 181, Opcodes.INVOKESTATIC, 96, 50, 193}, new int[]{211, 231, 43, 97, 71, 96, 103, EMachine.EM_METAG, 37, Opcodes.DCMPL, EMachine.EM_XIMO16, 53, 75, 34, 249, 121, 17, EMachine.EM_LATTICEMICO32, 110, Command.CMD_GET_LOW_LATENCY_SETTINGS, EMachine.EM_TI_C2000, EMachine.EM_DSP24, 120, Opcodes.DCMPL, 233, 168, 93, 255}, new int[]{245, 127, 242, 218, 130, 250, 162, 181, 102, 120, 84, EMachine.EM_SLE9X, 220, 251, 80, Opcodes.INVOKEVIRTUAL, 229, 18, 2, 4, 68, 33, 101, EMachine.EM_VIDEOCORE3, 95, 119, 115, 44, EMachine.EM_MCST_ELBRUS, Opcodes.INVOKESTATIC, 59, 25, 225, 98, 81, 112}, new int[]{77, 193, EMachine.EM_VIDEOCORE3, 31, 19, 38, 22, Opcodes.IFEQ, 247, 105, 122, 2, 245, 133, 242, 8, EMachine.EM_MCST_ELBRUS, 95, 100, 9, 167, 105, Command.CMD_GET_EXTERNAL_FLASH_MSG, 111, 57, 121, 21, 1, 253, 57, 54, 101, 248, 202, 69, 50, 150, 177, 226, 5, 9, 5}, new int[]{245, 132, EMachine.EM_CRAYNV2, 223, 96, 32, 117, 22, 238, 133, 238, 231, HttpStatus.SC_RESET_CONTENT, 188, 237, 87, EMachine.EM_TILEGX, 106, 16, 147, 118, 23, 37, 90, EMachine.EM_XIMO16, HttpStatus.SC_RESET_CONTENT, EMachine.EM_TSK3000, 88, 120, 100, 66, EMachine.EM_LATTICEMICO32, EMachine.EM_STM8, 240, 82, 44, 176, 87, 187, 147, 160, EMachine.EM_MCST_ELBRUS, 69, Command.CMD_GET_LOW_LATENCY_SETTINGS, 92, 253, 225, 19}, new int[]{EMachine.EM_MCST_ELBRUS, 9, 223, 238, 12, 17, 220, Command.CMD_NOTIFY_DEVICE_APP_INFO, 100, 29, EMachine.EM_MCST_ELBRUS, EMachine.EM_XIMO16, 230, 192, 215, 235, 150, Opcodes.IF_ICMPEQ, 36, 223, 38, 200, 132, 54, 228, 146, 218, 234, 117, HttpStatus.SC_NON_AUTHORITATIVE_INFORMATION, 29, 232, 144, 238, 22, 150, HttpStatus.SC_CREATED, 117, 62, HttpStatus.SC_MULTI_STATUS, 164, 13, EMachine.EM_VIDEOCORE3, 245, 127, 67, 247, 28, 155, 43, HttpStatus.SC_NON_AUTHORITATIVE_INFORMATION, 107, 233, 53, 143, 46}, new int[]{242, 93, 169, 50, 144, Command.CMD_RECEIVE_SPEECH_CANCEL, 39, 118, 202, 188, HttpStatus.SC_CREATED, 189, 143, 108, 196, 37, 185, 112, EMachine.EM_ECOG2, 230, 245, 63, EMachine.EM_RL78, 190, 250, 106, 185, 221, EMachine.EM_MCST_ELBRUS, 64, 114, 71, 161, 44, 147, 6, 27, 218, 51, 63, 87, 10, 40, 130, 188, 17, 163, 31, 176, EMachine.EM_XIMO16, 4, 107, 232, 7, 94, 166, 224, 124, 86, 47, 11, HttpStatus.SC_NO_CONTENT}, new int[]{220, 228, EMachine.EM_RX, 89, 251, Opcodes.FCMPL, Opcodes.IF_ICMPEQ, 56, 89, 33, 147, 244, Opcodes.IFNE, 36, 73, 127, Command.CMD_GET_LOW_LATENCY_SETTINGS, EMachine.EM_DSP24, 248, 180, 234, EMachine.EM_RL78, Opcodes.IFLE, 177, 68, 122, 93, Command.CMD_GET_LOW_LATENCY_SETTINGS, 15, 160, 227, 236, 66, EMachine.EM_SE_C17, Opcodes.IFEQ, 185, 202, 167, EMachine.EM_SLE9X, 25, 220, 232, 96, Command.CMD_RECEIVE_SPEECH_CANCEL, 231, EMachine.EM_DSP24, 223, 239, 181, 241, 59, 52, EMachine.EM_CRAYNV2, 25, 49, 232, 211, 189, 64, 54, 108, Opcodes.IFEQ, 132, 63, 96, 103, 82, EMachine.EM_STM8}};
    private static final int[] LOG = new int[256];
    private static final int[] ALOG = new int[255];

    static {
        int i2 = 1;
        for (int i3 = 0; i3 < 255; i3++) {
            ALOG[i3] = i2;
            LOG[i2] = i3;
            i2 *= 2;
            if (i2 >= 256) {
                i2 ^= 301;
            }
        }
    }

    private ErrorCorrection() {
    }

    public static String encodeECC200(String str, SymbolInfo symbolInfo) {
        if (str.length() != symbolInfo.getDataCapacity()) {
            throw new IllegalArgumentException("The number of codewords does not match the selected symbol");
        }
        StringBuilder sb = new StringBuilder(symbolInfo.getDataCapacity() + symbolInfo.getErrorCodewords());
        sb.append(str);
        int interleavedBlockCount = symbolInfo.getInterleavedBlockCount();
        if (interleavedBlockCount == 1) {
            sb.append(createECCBlock(str, symbolInfo.getErrorCodewords()));
        } else {
            sb.setLength(sb.capacity());
            int[] iArr = new int[interleavedBlockCount];
            int[] iArr2 = new int[interleavedBlockCount];
            int i2 = 0;
            while (i2 < interleavedBlockCount) {
                int i3 = i2 + 1;
                iArr[i2] = symbolInfo.getDataLengthForInterleavedBlock(i3);
                iArr2[i2] = symbolInfo.getErrorLengthForInterleavedBlock(i3);
                i2 = i3;
            }
            for (int i4 = 0; i4 < interleavedBlockCount; i4++) {
                StringBuilder sb2 = new StringBuilder(iArr[i4]);
                for (int i5 = i4; i5 < symbolInfo.getDataCapacity(); i5 += interleavedBlockCount) {
                    sb2.append(str.charAt(i5));
                }
                String createECCBlock = createECCBlock(sb2.toString(), iArr2[i4]);
                int i6 = 0;
                int i7 = i4;
                while (i7 < iArr2[i4] * interleavedBlockCount) {
                    sb.setCharAt(symbolInfo.getDataCapacity() + i7, createECCBlock.charAt(i6));
                    i7 += interleavedBlockCount;
                    i6++;
                }
            }
        }
        return sb.toString();
    }

    private static String createECCBlock(CharSequence charSequence, int i2) {
        int i3;
        int i4;
        int i5 = 0;
        while (true) {
            int[] iArr = FACTOR_SETS;
            if (i5 >= iArr.length) {
                i5 = -1;
                break;
            }
            if (iArr[i5] == i2) {
                break;
            }
            i5++;
        }
        if (i5 < 0) {
            throw new IllegalArgumentException("Illegal number of error correction codewords specified: " + i2);
        }
        int[] iArr2 = FACTORS[i5];
        char[] cArr = new char[i2];
        for (int i6 = 0; i6 < i2; i6++) {
            cArr[i6] = 0;
        }
        for (int i7 = 0; i7 < charSequence.length(); i7++) {
            int i8 = i2 - 1;
            int charAt = cArr[i8] ^ charSequence.charAt(i7);
            while (i8 > 0) {
                if (charAt != 0 && (i4 = iArr2[i8]) != 0) {
                    char c2 = cArr[i8 - 1];
                    int[] iArr3 = ALOG;
                    int[] iArr4 = LOG;
                    cArr[i8] = (char) (iArr3[(iArr4[charAt] + iArr4[i4]) % 255] ^ c2);
                } else {
                    cArr[i8] = cArr[i8 - 1];
                }
                i8--;
            }
            if (charAt != 0 && (i3 = iArr2[0]) != 0) {
                int[] iArr5 = ALOG;
                int[] iArr6 = LOG;
                cArr[0] = (char) iArr5[(iArr6[charAt] + iArr6[i3]) % 255];
            } else {
                cArr[0] = 0;
            }
        }
        char[] cArr2 = new char[i2];
        for (int i9 = 0; i9 < i2; i9++) {
            cArr2[i9] = cArr[(i2 - i9) - 1];
        }
        return String.valueOf(cArr2);
    }
}
