package com.google.zxing.maxicode.decoder;

import androidx.constraintlayout.core.motion.utils.TypedValues;
import androidx.core.app.FrameMetricsAggregator;
import com.alibaba.fastjson.asm.Opcodes;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.autonavi.amap.mapcore.tools.GlMapUtil;
import com.facebook.internal.FacebookRequestErrorClassification;
import com.google.firebase.crashlytics.buildtools.ndk.internal.elf.EMachine;
import com.google.firebase.crashlytics.buildtools.reloc.org.apache.http.HttpStatus;
import com.google.zxing.common.BitMatrix;
import com.haibin.calendarview.BuildConfig;
import com.jieli.jl_rcsp.constant.Command;
import com.jieli.jl_rcsp.model.SportHealthConfigure;
import com.realsil.sdk.dfu.DfuConstants;
import com.realsil.sdk.dfu.DfuException;
import com.realsil.sdk.dfu.utils.DfuAdapter;
import com.yucheng.ycbtsdk.Constants;

/* loaded from: classes3.dex */
final class BitMatrixParser {
    private static final int[][] BITNR = {new int[]{121, 120, 127, 126, 133, 132, EMachine.EM_SE_C17, EMachine.EM_LATTICEMICO32, 145, 144, Opcodes.DCMPL, 150, 157, 156, 163, 162, 169, 168, EMachine.EM_MCST_ELBRUS, EMachine.EM_METAG, 181, 180, 187, EMachine.EM_STM8, 193, 192, 199, 198, -2, -2}, new int[]{123, 122, 129, 128, EMachine.EM_SCORE7, EMachine.EM_ECOG2, EMachine.EM_TI_C2000, 140, 147, 146, Opcodes.IFEQ, 152, Opcodes.IF_ICMPEQ, Opcodes.IFLE, 165, 164, EMachine.EM_MANIK, EMachine.EM_XIMO16, 177, 176, 183, Opcodes.INVOKEVIRTUAL, 189, 188, 195, 194, HttpStatus.SC_CREATED, 200, Constants.DATATYPE.SpecificInformationPush, -3}, new int[]{125, 124, EMachine.EM_TSK3000, 130, EMachine.EM_VIDEOCORE3, EMachine.EM_DSP24, 143, EMachine.EM_TI_C5500, Opcodes.FCMPL, Opcodes.LCMP, 155, Opcodes.IFNE, 161, 160, 167, 166, EMachine.EM_RX, EMachine.EM_CRAYNV2, EMachine.EM_SLE9X, 178, 185, Opcodes.INVOKESTATIC, EMachine.EM_TILEGX, 190, EMachine.EM_RL78, 196, HttpStatus.SC_NON_AUTHORITATIVE_INFORMATION, 202, Constants.DATATYPE.AppPDNumber, Constants.DATATYPE.AppBloodSugarCalibration}, new int[]{283, 282, 277, 276, 271, 270, 265, 264, 259, 258, 253, 252, 247, 246, 241, 240, 235, 234, 229, 228, 223, AMapEngineUtils.ARROW_LINE_OUTER_TEXTURE_ID, Command.CMD_GET_DEVICE_CONFIG_INFO, Command.CMD_SET_DEVICE_STORAGE, 211, Command.CMD_RECEIVE_SPEECH_CANCEL, HttpStatus.SC_RESET_CONTENT, HttpStatus.SC_NO_CONTENT, Constants.DATATYPE.AppSendLocationNumber, -3}, new int[]{285, 284, 279, Constants.DATATYPE.SettingBloodRange, DfuException.ERROR_READ_IMAGE_VERSION_FAILED, DfuException.ERROR_READ_PATCH_INFO_ERROR, 267, 266, 261, 260, 255, SportHealthConfigure.CONFIGURE_TYPE_SPORT_MODE, 249, 248, 243, 242, 237, 236, 231, 230, 225, 224, 219, 218, Command.CMD_GET_LOW_LATENCY_SETTINGS, 212, HttpStatus.SC_MULTI_STATUS, HttpStatus.SC_PARTIAL_CONTENT, Constants.DATATYPE.AppSendMeasureNumber, Constants.DATATYPE.AppSendCardNumber}, new int[]{Constants.DATATYPE.SettingTemperatureAlarm, Constants.DATATYPE.SettingStudentData, 281, DfuException.ERROR_ENTER_OTA_MODE_FAILED, 275, 274, 269, 268, DfuException.ERROR_NO_CHARACTERISTIC_FOUND_OR_LOSS, 262, 257, 256, 251, 250, 245, 244, 239, 238, 233, 232, 227, 226, 221, 220, 215, Command.CMD_GET_EXTERNAL_FLASH_MSG, 209, Command.CMD_NOTIFY_DEVICE_APP_INFO, Constants.DATATYPE.AppSendProductInfo, -3}, new int[]{Constants.DATATYPE.SettingScreenTime, Constants.DATATYPE.SettingTemperatureMonitor, Constants.DATATYPE.SettingScheduleModification, Constants.DATATYPE.SettingBloodOxygenModeMonitor, 301, 300, 307, 306, 313, 312, Constants.DATATYPE.SettingBloodSugarAlarm, 318, 325, 324, 331, 330, 337, 336, 343, 342, 349, 348, 355, 354, 361, 360, 367, 366, Constants.DATATYPE.AppLipidCalibration, Constants.DATATYPE.AppUricAcidCalibration}, new int[]{Constants.DATATYPE.SettingWorkingMode, Constants.DATATYPE.SettingAmbientLight, Constants.DATATYPE.SettingScheduleSwitch, Constants.DATATYPE.SettingAmbientTemperatureAndHumidity, 303, 302, 309, 308, 315, 314, Constants.DATATYPE.SettingSettingCustomDial, 320, 327, 326, AMapEngineUtils.ARROW_LINE_SHADOW_TEXTURE_ID, 332, 339, 338, 345, 344, 351, 350, 357, 356, 363, 362, 369, 368, Constants.DATATYPE.AppSendUUID, -3}, new int[]{Constants.DATATYPE.SettingBraceletStatusAlert, Constants.DATATYPE.SettingAccidentMode, Constants.DATATYPE.SettingUploadReminder, Constants.DATATYPE.SettingStepCountingStateTime, 305, 304, 311, 310, 317, 316, 323, 322, 329, 328, 335, 334, FacebookRequestErrorClassification.EC_TOO_MANY_USER_ACTION_CALLS, 340, 347, 346, 353, 352, 359, 358, 365, 364, BuildConfig.VERSION_CODE, 370, 827, 826}, new int[]{HttpStatus.SC_CONFLICT, HttpStatus.SC_REQUEST_TIMEOUT, 403, 402, 397, 396, 391, 390, 79, 78, -2, -2, 13, 12, 37, 36, 2, -1, 44, 43, 109, 108, 385, 384, 379, 378, 373, 372, 828, -3}, new int[]{HttpStatus.SC_LENGTH_REQUIRED, HttpStatus.SC_GONE, HttpStatus.SC_METHOD_NOT_ALLOWED, HttpStatus.SC_NOT_FOUND, 399, 398, 393, 392, 81, 80, 40, -2, 15, 14, 39, 38, 3, -1, -1, 45, 111, 110, 387, 386, 381, 380, 375, 374, 830, 829}, new int[]{HttpStatus.SC_REQUEST_TOO_LONG, 412, HttpStatus.SC_PROXY_AUTHENTICATION_REQUIRED, HttpStatus.SC_NOT_ACCEPTABLE, 401, 400, 395, 394, 83, 82, 41, -3, -3, -3, -3, -3, 5, 4, 47, 46, 113, 112, 389, 388, 383, 382, 377, 376, 831, -3}, new int[]{HttpStatus.SC_UNSUPPORTED_MEDIA_TYPE, HttpStatus.SC_REQUEST_URI_TOO_LONG, 421, 420, 427, 426, 103, 102, 55, 54, 16, -3, -3, -3, -3, -3, -3, -3, 20, 19, 85, 84, 433, 432, 439, 438, 445, 444, 833, 832}, new int[]{HttpStatus.SC_EXPECTATION_FAILED, 416, 423, 422, 429, 428, 105, 104, 57, 56, -3, -3, -3, -3, -3, -3, -3, -3, 22, 21, 87, 86, 435, 434, 441, 440, 447, 446, 834, -3}, new int[]{HttpStatus.SC_INSUFFICIENT_SPACE_ON_RESOURCE, 418, TypedValues.CycleType.TYPE_WAVE_PHASE, 424, 431, 430, 107, 106, 59, 58, -3, -3, -3, -3, -3, -3, -3, -3, -3, 23, 89, 88, 437, 436, 443, 442, 449, 448, 836, 835}, new int[]{481, GlMapUtil.DEVICE_DISPLAY_DPI_XHIGH, 475, 474, 469, 468, 48, -2, 30, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, 0, 53, 52, 463, 462, 457, 456, 451, 450, 837, -3}, new int[]{483, 482, 477, 476, 471, 470, 49, -1, -2, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -2, -1, 465, 464, 459, FacebookRequestErrorClassification.ESC_APP_NOT_INSTALLED, 453, 452, 839, 838}, new int[]{485, 484, 479, 478, 473, 472, 51, 50, 31, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, 1, -2, 42, 467, 466, 461, 460, 455, 454, 840, -3}, new int[]{487, 486, FacebookRequestErrorClassification.ESC_APP_INACTIVE, 492, 499, 498, 97, 96, 61, 60, -3, -3, -3, -3, -3, -3, -3, -3, -3, 26, 91, 90, 505, 504, FrameMetricsAggregator.EVERY_DURATION, TypedValues.PositionType.TYPE_POSITION_TYPE, 517, 516, 842, 841}, new int[]{489, 488, 495, 494, 501, 500, 99, 98, 63, 62, -3, -3, -3, -3, -3, -3, -3, -3, 28, 27, 93, 92, 507, TypedValues.PositionType.TYPE_PERCENT_X, 513, 512, 519, DfuConstants.PROGRESS_REMOTE_ENTER_OTA, 843, -3}, new int[]{491, 490, 497, 496, 503, 502, 101, 100, 65, 64, 17, -3, -3, -3, -3, -3, -3, -3, 18, 29, 95, 94, 509, TypedValues.PositionType.TYPE_CURVE_FIT, 515, 514, 521, 520, 845, 844}, new int[]{559, 558, 553, 552, Constants.DATATYPE.GetScreenParameters, Constants.DATATYPE.GetALiIOTActivationState, 541, DfuAdapter.STATE_READ_BATTERY_INFO, 73, 72, 32, -3, -3, -3, -3, -3, -3, 10, 67, 66, 115, 114, 535, 534, Constants.DATATYPE.GetRealBloodOxygen, Constants.DATATYPE.GetHeavenEarthAndFiveElement, 523, 522, 846, -3}, new int[]{561, 560, 555, 554, 549, Constants.DATATYPE.GetCardInfo, Constants.DATATYPE.GetDeviceRemindInfo, 542, 75, 74, -2, -1, 7, 6, 35, 34, 11, -2, 69, 68, 117, 116, 537, Constants.DATATYPE.GetUploadConfigurationInfoOfReminder, Constants.DATATYPE.GetCurrentAmbientTempAndHumidity, 530, 525, 524, 848, 847}, new int[]{563, 562, 557, 556, 551, 550, Constants.DATATYPE.GetLaserTreatmentParams, Constants.DATATYPE.GetAllRealDataFromDevice, 77, 76, -2, 33, 9, 8, 25, 24, -1, -2, 71, 70, 119, 118, 539, 538, 533, 532, 527, 526, 849, -3}, new int[]{565, 564, 571, 570, 577, 576, 583, 582, 589, 588, 595, 594, 601, 600, TypedValues.MotionType.TYPE_PATHMOTION_ARC, TypedValues.MotionType.TYPE_ANIMATE_CIRCLEANGLE_TO, 613, TypedValues.MotionType.TYPE_QUANTIZE_INTERPOLATOR_ID, 619, 618, 625, 624, 631, 630, 637, 636, 643, 642, 851, 850}, new int[]{567, 566, 573, 572, 579, 578, 585, 584, 591, 590, 597, 596, TypedValues.MotionType.TYPE_EASING, TypedValues.MotionType.TYPE_QUANTIZE_MOTION_PHASE, TypedValues.MotionType.TYPE_POLAR_RELATIVETO, TypedValues.MotionType.TYPE_DRAW_PATH, 615, 614, 621, 620, 627, 626, 633, 632, 639, 638, 645, 644, 852, -3}, new int[]{569, 568, 575, 574, 581, 580, 587, 586, 593, 592, 599, 598, TypedValues.MotionType.TYPE_ANIMATE_RELATIVE_TO, TypedValues.MotionType.TYPE_QUANTIZE_INTERPOLATOR, TypedValues.MotionType.TYPE_QUANTIZE_INTERPOLATOR_TYPE, TypedValues.MotionType.TYPE_QUANTIZE_MOTIONSTEPS, 617, 616, 623, 622, 629, 628, 635, 634, 641, GlMapUtil.DEVICE_DISPLAY_DPI_XXHIGH, 647, 646, 854, 853}, new int[]{727, 726, 721, 720, 715, 714, 709, 708, 703, TypedValues.TransitionType.TYPE_TO, 697, 696, 691, 690, 685, 684, 679, 678, 673, 672, 667, 666, 661, 660, 655, 654, 649, 648, 855, -3}, new int[]{729, 728, 723, 722, 717, 716, 711, 710, TypedValues.TransitionType.TYPE_INTERPOLATOR, TypedValues.TransitionType.TYPE_AUTO_TRANSITION, 699, 698, 693, 692, 687, 686, 681, 680, 675, 674, 669, 668, 663, 662, 657, 656, 651, 650, 857, 856}, new int[]{731, 730, 725, 724, 719, 718, 713, 712, TypedValues.TransitionType.TYPE_TRANSITION_FLAGS, TypedValues.TransitionType.TYPE_STAGGERED, TypedValues.TransitionType.TYPE_FROM, 700, 695, 694, 689, 688, 683, 682, 677, 676, 671, 670, 665, 664, 659, 658, 653, 652, 858, -3}, new int[]{733, 732, 739, 738, 745, 744, 751, 750, 757, 756, 763, 762, Constants.DATATYPE.AppHeartSwitch, 768, 775, 774, 781, Constants.DATATYPE.AppRunMode, Constants.DATATYPE.AppTomorrowWeather, Constants.DATATYPE.AppTodayWeather, Constants.DATATYPE.AppEmoticonIndex, Constants.DATATYPE.AppTemperatureMeasure, Constants.DATATYPE.AppTemperatureCode, Constants.DATATYPE.AppAmbientLightMeasurementControl, Constants.DATATYPE.AppEffectiveHeart, Constants.DATATYPE.AppEffectiveStep, Constants.DATATYPE.AppPushCallState, Constants.DATATYPE.AppPushFemalePhysiological, 860, 859}, new int[]{735, 734, 741, 740, 747, 746, 753, 752, 759, 758, 765, 764, Constants.DATATYPE.AppBloodCalibration, Constants.DATATYPE.AppBloodSwitch, Constants.DATATYPE.AppControlReal, Constants.DATATYPE.AppMessageControl, 783, Constants.DATATYPE.AppControlTakePhoto, Constants.DATATYPE.AppHealthArg, Constants.DATATYPE.AppECGPPGStatus, Constants.DATATYPE.AppSleepWriteBack, Constants.DATATYPE.AppHealthWriteBack, Constants.DATATYPE.AppInsuranceNews, 800, Constants.DATATYPE.AppPushMessage, Constants.DATATYPE.AppEarlyWarning, 813, Constants.DATATYPE.AppWritebackData, 861, -3}, new int[]{737, 736, 743, 742, 749, 748, 755, 754, 761, 760, DfuException.ERROR_NOTIFICATION_NO_RESPONSE, DfuException.ERROR_OPCODE_RESPONSE_NOT_SUPPORTED, 773, 772, Constants.DATATYPE.AppControlWave, 778, 785, 784, Constants.DATATYPE.AppTemperatureCorrect, Constants.DATATYPE.AppShutDown, Constants.DATATYPE.AppUpgradeReminder, Constants.DATATYPE.AppUserInfoWriteBack, Constants.DATATYPE.AppMobileModel, Constants.DATATYPE.AppSensorSwitchControl, Constants.DATATYPE.AppPushTempAndHumidCalibration, Constants.DATATYPE.AppPushContacts, Constants.DATATYPE.AppStartMeasurement, Constants.DATATYPE.AppStartBloodMeasurement, 863, 862}};
    private final BitMatrix bitMatrix;

    BitMatrixParser(BitMatrix bitMatrix) {
        this.bitMatrix = bitMatrix;
    }

    byte[] readCodewords() {
        byte[] bArr = new byte[144];
        int height = this.bitMatrix.getHeight();
        int width = this.bitMatrix.getWidth();
        for (int i2 = 0; i2 < height; i2++) {
            int[] iArr = BITNR[i2];
            for (int i3 = 0; i3 < width; i3++) {
                int i4 = iArr[i3];
                if (i4 >= 0 && this.bitMatrix.get(i3, i2)) {
                    int i5 = i4 / 6;
                    bArr[i5] = (byte) (((byte) (1 << (5 - (i4 % 6)))) | bArr[i5]);
                }
            }
        }
        return bArr;
    }
}
