package com.google.zxing.multi.qrcode.detector;

import com.google.zxing.DecodeHintType;
import com.google.zxing.NotFoundException;
import com.google.zxing.ResultPoint;
import com.google.zxing.ResultPointCallback;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.qrcode.detector.FinderPattern;
import com.google.zxing.qrcode.detector.FinderPatternFinder;
import com.google.zxing.qrcode.detector.FinderPatternInfo;
import com.yucheng.smarthealthpro.customchart.utils.Utils;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.Map;

/* loaded from: classes3.dex */
public final class MultiFinderPatternFinder extends FinderPatternFinder {
    private static final float DIFF_MODSIZE_CUTOFF = 0.5f;
    private static final float DIFF_MODSIZE_CUTOFF_PERCENT = 0.05f;
    private static final float MAX_MODULE_COUNT_PER_EDGE = 180.0f;
    private static final float MIN_MODULE_COUNT_PER_EDGE = 9.0f;
    private static final FinderPatternInfo[] EMPTY_RESULT_ARRAY = new FinderPatternInfo[0];
    private static final FinderPattern[] EMPTY_FP_ARRAY = new FinderPattern[0];
    private static final FinderPattern[][] EMPTY_FP_2D_ARRAY = new FinderPattern[0][];

    private static final class ModuleSizeComparator implements Comparator<FinderPattern>, Serializable {
        private ModuleSizeComparator() {
        }

        @Override // java.util.Comparator
        public int compare(FinderPattern finderPattern, FinderPattern finderPattern2) {
            double estimatedModuleSize = finderPattern2.getEstimatedModuleSize() - finderPattern.getEstimatedModuleSize();
            if (estimatedModuleSize < Utils.DOUBLE_EPSILON) {
                return -1;
            }
            return estimatedModuleSize > Utils.DOUBLE_EPSILON ? 1 : 0;
        }
    }

    public MultiFinderPatternFinder(BitMatrix bitMatrix, ResultPointCallback resultPointCallback) {
        super(bitMatrix, resultPointCallback);
    }

    private FinderPattern[][] selectMultipleBestPatterns() throws NotFoundException {
        char c2;
        char c3;
        ArrayList arrayList;
        int i2;
        ArrayList arrayList2;
        int i3;
        char c4;
        ArrayList arrayList3 = new ArrayList();
        Iterator<FinderPattern> it2 = getPossibleCenters().iterator();
        while (true) {
            c2 = 2;
            if (!it2.hasNext()) {
                break;
            }
            FinderPattern next = it2.next();
            if (next.getCount() >= 2) {
                arrayList3.add(next);
            }
        }
        int size = arrayList3.size();
        int i4 = 3;
        if (size < 3) {
            throw NotFoundException.getNotFoundInstance();
        }
        char c5 = 0;
        if (size == 3) {
            return new FinderPattern[][]{(FinderPattern[]) arrayList3.toArray(EMPTY_FP_ARRAY)};
        }
        Collections.sort(arrayList3, new ModuleSizeComparator());
        ArrayList arrayList4 = new ArrayList();
        int i5 = 0;
        while (i5 < size - 2) {
            FinderPattern finderPattern = (FinderPattern) arrayList3.get(i5);
            if (finderPattern != null) {
                int i6 = i5 + 1;
                while (i6 < size - 1) {
                    FinderPattern finderPattern2 = (FinderPattern) arrayList3.get(i6);
                    if (finderPattern2 != null) {
                        float estimatedModuleSize = (finderPattern.getEstimatedModuleSize() - finderPattern2.getEstimatedModuleSize()) / Math.min(finderPattern.getEstimatedModuleSize(), finderPattern2.getEstimatedModuleSize());
                        float abs = Math.abs(finderPattern.getEstimatedModuleSize() - finderPattern2.getEstimatedModuleSize());
                        float f2 = 0.5f;
                        float f3 = DIFF_MODSIZE_CUTOFF_PERCENT;
                        if (abs > 0.5f && estimatedModuleSize >= DIFF_MODSIZE_CUTOFF_PERCENT) {
                            break;
                        }
                        int i7 = i6 + 1;
                        while (i7 < size) {
                            FinderPattern finderPattern3 = (FinderPattern) arrayList3.get(i7);
                            if (finderPattern3 != null) {
                                float estimatedModuleSize2 = (finderPattern2.getEstimatedModuleSize() - finderPattern3.getEstimatedModuleSize()) / Math.min(finderPattern2.getEstimatedModuleSize(), finderPattern3.getEstimatedModuleSize());
                                if (Math.abs(finderPattern2.getEstimatedModuleSize() - finderPattern3.getEstimatedModuleSize()) > f2 && estimatedModuleSize2 >= f3) {
                                    arrayList2 = arrayList3;
                                    i3 = size;
                                    c4 = 2;
                                    break;
                                }
                                FinderPattern[] finderPatternArr = new FinderPattern[i4];
                                finderPatternArr[c5] = finderPattern;
                                finderPatternArr[1] = finderPattern2;
                                c3 = 2;
                                finderPatternArr[2] = finderPattern3;
                                ResultPoint.orderBestPatterns(finderPatternArr);
                                FinderPatternInfo finderPatternInfo = new FinderPatternInfo(finderPatternArr);
                                float distance = ResultPoint.distance(finderPatternInfo.getTopLeft(), finderPatternInfo.getBottomLeft());
                                float distance2 = ResultPoint.distance(finderPatternInfo.getTopRight(), finderPatternInfo.getBottomLeft());
                                float distance3 = ResultPoint.distance(finderPatternInfo.getTopLeft(), finderPatternInfo.getTopRight());
                                float estimatedModuleSize3 = (distance + distance3) / (finderPattern.getEstimatedModuleSize() * 2.0f);
                                if (estimatedModuleSize3 > 180.0f || estimatedModuleSize3 < MIN_MODULE_COUNT_PER_EDGE || Math.abs((distance - distance3) / Math.min(distance, distance3)) >= 0.1f) {
                                    arrayList = arrayList3;
                                    i2 = size;
                                } else {
                                    double d2 = distance;
                                    arrayList = arrayList3;
                                    i2 = size;
                                    double d3 = distance3;
                                    float sqrt = (float) Math.sqrt((d2 * d2) + (d3 * d3));
                                    if (Math.abs((distance2 - sqrt) / Math.min(distance2, sqrt)) < 0.1f) {
                                        arrayList4.add(finderPatternArr);
                                    }
                                }
                            } else {
                                arrayList = arrayList3;
                                i2 = size;
                                c3 = c2;
                            }
                            i7++;
                            size = i2;
                            c2 = c3;
                            arrayList3 = arrayList;
                            i4 = 3;
                            c5 = 0;
                            f2 = 0.5f;
                            f3 = DIFF_MODSIZE_CUTOFF_PERCENT;
                        }
                    }
                    arrayList2 = arrayList3;
                    i3 = size;
                    c4 = c2;
                    i6++;
                    size = i3;
                    c2 = c4;
                    arrayList3 = arrayList2;
                    i4 = 3;
                    c5 = 0;
                }
            }
            i5++;
            size = size;
            c2 = c2;
            arrayList3 = arrayList3;
            i4 = 3;
            c5 = 0;
        }
        if (!arrayList4.isEmpty()) {
            return (FinderPattern[][]) arrayList4.toArray(EMPTY_FP_2D_ARRAY);
        }
        throw NotFoundException.getNotFoundInstance();
    }

    public FinderPatternInfo[] findMulti(Map<DecodeHintType, ?> map) throws NotFoundException {
        boolean z = map != null && map.containsKey(DecodeHintType.TRY_HARDER);
        BitMatrix image = getImage();
        int height = image.getHeight();
        int width = image.getWidth();
        int i2 = (height * 3) / 388;
        if (i2 < 3 || z) {
            i2 = 3;
        }
        int[] iArr = new int[5];
        for (int i3 = i2 - 1; i3 < height; i3 += i2) {
            doClearCounts(iArr);
            int i4 = 0;
            for (int i5 = 0; i5 < width; i5++) {
                if (image.get(i5, i3)) {
                    if ((i4 & 1) == 1) {
                        i4++;
                    }
                    iArr[i4] = iArr[i4] + 1;
                } else if ((i4 & 1) != 0) {
                    iArr[i4] = iArr[i4] + 1;
                } else if (i4 == 4) {
                    if (foundPatternCross(iArr) && handlePossibleCenter(iArr, i3, i5)) {
                        doClearCounts(iArr);
                        i4 = 0;
                    } else {
                        doShiftCounts2(iArr);
                        i4 = 3;
                    }
                } else {
                    i4++;
                    iArr[i4] = iArr[i4] + 1;
                }
            }
            if (foundPatternCross(iArr)) {
                handlePossibleCenter(iArr, i3, width);
            }
        }
        FinderPattern[][] selectMultipleBestPatterns = selectMultipleBestPatterns();
        ArrayList arrayList = new ArrayList();
        for (FinderPattern[] finderPatternArr : selectMultipleBestPatterns) {
            ResultPoint.orderBestPatterns(finderPatternArr);
            arrayList.add(new FinderPatternInfo(finderPatternArr));
        }
        if (arrayList.isEmpty()) {
            return EMPTY_RESULT_ARRAY;
        }
        return (FinderPatternInfo[]) arrayList.toArray(EMPTY_RESULT_ARRAY);
    }
}
