package com.google.zxing.oned.rss.expanded.decoders;

import com.dd.plist.ASCIIPropertyListParser;
import com.google.zxing.NotFoundException;
import com.tencent.connect.common.Constants;
import java.util.HashMap;
import java.util.Map;

/* loaded from: classes3.dex */
final class FieldParser {
    private static final Map<String, DataLength> FOUR_DIGIT_DATA_LENGTH;
    private static final Map<String, DataLength> THREE_DIGIT_DATA_LENGTH;
    private static final Map<String, DataLength> THREE_DIGIT_PLUS_DIGIT_DATA_LENGTH;
    private static final Map<String, DataLength> TWO_DIGIT_DATA_LENGTH;

    static {
        HashMap hashMap = new HashMap();
        TWO_DIGIT_DATA_LENGTH = hashMap;
        hashMap.put("00", DataLength.fixed(18));
        hashMap.put("01", DataLength.fixed(14));
        hashMap.put("02", DataLength.fixed(14));
        hashMap.put(Constants.VIA_REPORT_TYPE_SHARE_TO_QQ, DataLength.variable(20));
        hashMap.put(Constants.VIA_REPORT_TYPE_SHARE_TO_QZONE, DataLength.fixed(6));
        hashMap.put(Constants.VIA_REPORT_TYPE_SET_AVATAR, DataLength.fixed(6));
        hashMap.put(Constants.VIA_REPORT_TYPE_JOININ_GROUP, DataLength.fixed(6));
        hashMap.put(Constants.VIA_REPORT_TYPE_WPA_STATE, DataLength.fixed(6));
        hashMap.put(Constants.VIA_REPORT_TYPE_START_GROUP, DataLength.fixed(6));
        hashMap.put("20", DataLength.fixed(2));
        hashMap.put("21", DataLength.variable(20));
        hashMap.put(Constants.VIA_REPORT_TYPE_DATALINE, DataLength.variable(29));
        hashMap.put("30", DataLength.variable(8));
        hashMap.put("37", DataLength.variable(8));
        for (int i2 = 90; i2 <= 99; i2++) {
            TWO_DIGIT_DATA_LENGTH.put(String.valueOf(i2), DataLength.variable(30));
        }
        HashMap hashMap2 = new HashMap();
        THREE_DIGIT_DATA_LENGTH = hashMap2;
        hashMap2.put("240", DataLength.variable(30));
        hashMap2.put("241", DataLength.variable(30));
        hashMap2.put("242", DataLength.variable(6));
        hashMap2.put("250", DataLength.variable(30));
        hashMap2.put("251", DataLength.variable(30));
        hashMap2.put("253", DataLength.variable(17));
        hashMap2.put("254", DataLength.variable(20));
        hashMap2.put("400", DataLength.variable(30));
        hashMap2.put("401", DataLength.variable(30));
        hashMap2.put("402", DataLength.fixed(17));
        hashMap2.put("403", DataLength.variable(30));
        hashMap2.put("410", DataLength.fixed(13));
        hashMap2.put("411", DataLength.fixed(13));
        hashMap2.put("412", DataLength.fixed(13));
        hashMap2.put("413", DataLength.fixed(13));
        hashMap2.put("414", DataLength.fixed(13));
        hashMap2.put("420", DataLength.variable(20));
        hashMap2.put("421", DataLength.variable(15));
        hashMap2.put("422", DataLength.fixed(3));
        hashMap2.put("423", DataLength.variable(15));
        hashMap2.put("424", DataLength.fixed(3));
        hashMap2.put("425", DataLength.fixed(3));
        hashMap2.put("426", DataLength.fixed(3));
        THREE_DIGIT_PLUS_DIGIT_DATA_LENGTH = new HashMap();
        for (int i3 = 310; i3 <= 316; i3++) {
            THREE_DIGIT_PLUS_DIGIT_DATA_LENGTH.put(String.valueOf(i3), DataLength.fixed(6));
        }
        for (int i4 = 320; i4 <= 336; i4++) {
            THREE_DIGIT_PLUS_DIGIT_DATA_LENGTH.put(String.valueOf(i4), DataLength.fixed(6));
        }
        for (int i5 = 340; i5 <= 357; i5++) {
            THREE_DIGIT_PLUS_DIGIT_DATA_LENGTH.put(String.valueOf(i5), DataLength.fixed(6));
        }
        for (int i6 = 360; i6 <= 369; i6++) {
            THREE_DIGIT_PLUS_DIGIT_DATA_LENGTH.put(String.valueOf(i6), DataLength.fixed(6));
        }
        Map<String, DataLength> map = THREE_DIGIT_PLUS_DIGIT_DATA_LENGTH;
        map.put("390", DataLength.variable(15));
        map.put("391", DataLength.variable(18));
        map.put("392", DataLength.variable(15));
        map.put("393", DataLength.variable(18));
        map.put("703", DataLength.variable(30));
        HashMap hashMap3 = new HashMap();
        FOUR_DIGIT_DATA_LENGTH = hashMap3;
        hashMap3.put("7001", DataLength.fixed(13));
        hashMap3.put("7002", DataLength.variable(30));
        hashMap3.put("7003", DataLength.fixed(10));
        hashMap3.put("8001", DataLength.fixed(14));
        hashMap3.put("8002", DataLength.variable(20));
        hashMap3.put("8003", DataLength.variable(30));
        hashMap3.put("8004", DataLength.variable(30));
        hashMap3.put("8005", DataLength.fixed(6));
        hashMap3.put("8006", DataLength.fixed(18));
        hashMap3.put("8007", DataLength.variable(30));
        hashMap3.put("8008", DataLength.variable(12));
        hashMap3.put("8018", DataLength.fixed(18));
        hashMap3.put("8020", DataLength.variable(25));
        hashMap3.put("8100", DataLength.fixed(6));
        hashMap3.put("8101", DataLength.fixed(10));
        hashMap3.put("8102", DataLength.fixed(2));
        hashMap3.put("8110", DataLength.variable(70));
        hashMap3.put("8200", DataLength.variable(70));
    }

    private FieldParser() {
    }

    static String parseFieldsInGeneralPurpose(String str) throws NotFoundException {
        if (str.isEmpty()) {
            return null;
        }
        if (str.length() < 2) {
            throw NotFoundException.getNotFoundInstance();
        }
        DataLength dataLength = TWO_DIGIT_DATA_LENGTH.get(str.substring(0, 2));
        if (dataLength != null) {
            if (dataLength.variable) {
                return processVariableAI(2, dataLength.length, str);
            }
            return processFixedAI(2, dataLength.length, str);
        }
        if (str.length() < 3) {
            throw NotFoundException.getNotFoundInstance();
        }
        String substring = str.substring(0, 3);
        DataLength dataLength2 = THREE_DIGIT_DATA_LENGTH.get(substring);
        if (dataLength2 != null) {
            if (dataLength2.variable) {
                return processVariableAI(3, dataLength2.length, str);
            }
            return processFixedAI(3, dataLength2.length, str);
        }
        if (str.length() < 4) {
            throw NotFoundException.getNotFoundInstance();
        }
        DataLength dataLength3 = THREE_DIGIT_PLUS_DIGIT_DATA_LENGTH.get(substring);
        if (dataLength3 != null) {
            if (dataLength3.variable) {
                return processVariableAI(4, dataLength3.length, str);
            }
            return processFixedAI(4, dataLength3.length, str);
        }
        DataLength dataLength4 = FOUR_DIGIT_DATA_LENGTH.get(str.substring(0, 4));
        if (dataLength4 != null) {
            if (dataLength4.variable) {
                return processVariableAI(4, dataLength4.length, str);
            }
            return processFixedAI(4, dataLength4.length, str);
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private static String processFixedAI(int i2, int i3, String str) throws NotFoundException {
        if (str.length() < i2) {
            throw NotFoundException.getNotFoundInstance();
        }
        String substring = str.substring(0, i2);
        int i4 = i3 + i2;
        if (str.length() < i4) {
            throw NotFoundException.getNotFoundInstance();
        }
        String substring2 = str.substring(i2, i4);
        String substring3 = str.substring(i4);
        String str2 = "(" + substring + ASCIIPropertyListParser.ARRAY_END_TOKEN + substring2;
        String parseFieldsInGeneralPurpose = parseFieldsInGeneralPurpose(substring3);
        if (parseFieldsInGeneralPurpose == null) {
            return str2;
        }
        return str2 + parseFieldsInGeneralPurpose;
    }

    private static String processVariableAI(int i2, int i3, String str) throws NotFoundException {
        String substring = str.substring(0, i2);
        int min = Math.min(str.length(), i3 + i2);
        String substring2 = str.substring(i2, min);
        String substring3 = str.substring(min);
        String str2 = "(" + substring + ASCIIPropertyListParser.ARRAY_END_TOKEN + substring2;
        String parseFieldsInGeneralPurpose = parseFieldsInGeneralPurpose(substring3);
        if (parseFieldsInGeneralPurpose == null) {
            return str2;
        }
        return str2 + parseFieldsInGeneralPurpose;
    }

    private static final class DataLength {
        final int length;
        final boolean variable;

        private DataLength(boolean z, int i2) {
            this.variable = z;
            this.length = i2;
        }

        static DataLength fixed(int i2) {
            return new DataLength(false, i2);
        }

        static DataLength variable(int i2) {
            return new DataLength(true, i2);
        }
    }
}
