package com.google.zxing.pdf417.encoder;

import androidx.constraintlayout.core.motion.utils.TypedValues;
import androidx.core.app.FrameMetricsAggregator;
import com.alibaba.fastjson.asm.Opcodes;
import com.autonavi.amap.mapcore.tools.GlMapUtil;
import com.facebook.internal.FacebookRequestErrorClassification;
import com.google.firebase.crashlytics.buildtools.ndk.internal.elf.EMachine;
import com.google.firebase.crashlytics.buildtools.reloc.org.apache.http.HttpStatus;
import com.google.zxing.WriterException;
import com.google.zxing.pdf417.PDF417Common;
import com.jieli.jl_rcsp.constant.Command;
import com.realsil.sdk.dfu.DfuConstants;
import com.realsil.sdk.dfu.DfuException;
import com.realsil.sdk.dfu.utils.DfuAdapter;
import com.yucheng.ycbtsdk.Constants;

/* loaded from: classes3.dex */
final class PDF417ErrorCorrection {
    private static final int[][] EC_COEFFICIENTS = {new int[]{27, 917}, new int[]{522, 568, 723, Constants.DATATYPE.AppPushTempAndHumidCalibration}, new int[]{237, 308, 436, 284, 646, 653, 428, 379}, new int[]{274, 562, 232, 755, 599, 524, Constants.DATATYPE.AppInsuranceNews, 132, Constants.DATATYPE.SettingScheduleModification, 116, 442, 428, Constants.DATATYPE.SettingScheduleModification, 42, 176, 65}, new int[]{361, 575, 922, 525, 176, 586, GlMapUtil.DEVICE_DISPLAY_DPI_XXHIGH, Constants.DATATYPE.SettingSettingCustomDial, Constants.DATATYPE.GetUploadConfigurationInfoOfReminder, 742, 677, 742, 687, 284, 193, 517, DfuException.ERROR_READ_IMAGE_VERSION_FAILED, 494, DfuException.ERROR_NO_CHARACTERISTIC_FOUND_OR_LOSS, 147, 593, 800, 571, 320, Constants.DATATYPE.AppMobileModel, 133, 231, 390, 685, 330, 63, HttpStatus.SC_GONE}, new int[]{539, 422, 6, 93, 862, Constants.DATATYPE.AppBloodCalibration, 453, 106, TypedValues.MotionType.TYPE_QUANTIZE_MOTIONSTEPS, Constants.DATATYPE.SettingTemperatureAlarm, 107, 505, 733, 877, 381, TypedValues.MotionType.TYPE_QUANTIZE_INTERPOLATOR_ID, 723, 476, 462, EMachine.EM_CRAYNV2, 430, TypedValues.MotionType.TYPE_POLAR_RELATIVETO, 858, Constants.DATATYPE.AppSendProductInfo, Constants.DATATYPE.GetDeviceRemindInfo, 376, FrameMetricsAggregator.EVERY_DURATION, 400, 672, 762, 283, Opcodes.INVOKESTATIC, 440, 35, 519, 31, 460, 594, 225, 535, 517, 352, TypedValues.MotionType.TYPE_ANIMATE_RELATIVE_TO, Opcodes.IFLE, 651, HttpStatus.SC_CREATED, 488, 502, 648, 733, 717, 83, HttpStatus.SC_NOT_FOUND, 97, DfuException.ERROR_ENTER_OTA_MODE_FAILED, Constants.DATATYPE.AppBloodCalibration, 840, 629, 4, 381, 843, 623, 264, Constants.DATATYPE.GetDeviceRemindInfo}, new int[]{521, 310, 864, Constants.DATATYPE.GetScreenParameters, 858, 580, Constants.DATATYPE.SettingAmbientTemperatureAndHumidity, 379, 53, Constants.DATATYPE.AppControlWave, 897, 444, 400, 925, 749, HttpStatus.SC_UNSUPPORTED_MEDIA_TYPE, Constants.DATATYPE.AppSendProductInfo, 93, Command.CMD_GET_DEVICE_CONFIG_INFO, Command.CMD_NOTIFY_DEVICE_APP_INFO, PDF417Common.MAX_CODEWORDS_IN_BARCODE, 244, 583, 620, 246, Opcodes.LCMP, 447, 631, Constants.DATATYPE.SettingAccidentMode, 908, 490, TypedValues.TransitionType.TYPE_AUTO_TRANSITION, 516, 258, 457, 907, 594, 723, 674, Constants.DATATYPE.SettingAccidentMode, DfuException.ERROR_READ_PATCH_INFO_ERROR, 96, 684, 432, 686, TypedValues.MotionType.TYPE_ANIMATE_CIRCLEANGLE_TO, 860, 569, 193, 219, 129, EMachine.EM_STM8, 236, Constants.DATATYPE.SettingTemperatureAlarm, 192, 775, Constants.DATATYPE.SettingBloodRange, EMachine.EM_RX, 40, 379, 712, 463, 646, Constants.DATATYPE.AppMessageControl, EMachine.EM_MANIK, 491, Constants.DATATYPE.SettingScheduleSwitch, 763, 156, 732, 95, 270, 447, 90, 507, 48, 228, Constants.DATATYPE.AppSendMeasureNumber, Constants.DATATYPE.AppPushContacts, 898, 784, 663, 627, 378, 382, 262, 380, TypedValues.MotionType.TYPE_QUANTIZE_MOTION_PHASE, 754, 336, 89, 614, 87, 432, 670, 616, 157, 374, 242, 726, 600, 269, 375, 898, 845, 454, 354, 130, Constants.DATATYPE.AppStartBloodMeasurement, 587, Constants.DATATYPE.AppEffectiveStep, 34, 211, 330, 539, Constants.DATATYPE.SettingScheduleSwitch, 827, 865, 37, 517, 834, 315, 550, 86, Constants.DATATYPE.AppInsuranceNews, 4, 108, 539}, new int[]{524, 894, 75, DfuException.ERROR_OPCODE_RESPONSE_NOT_SUPPORTED, 882, 857, 74, HttpStatus.SC_NO_CONTENT, 82, 586, 708, 250, TypedValues.Custom.TYPE_DIMENSION, Constants.DATATYPE.AppTodayWeather, EMachine.EM_LATTICEMICO32, 720, 858, 194, 311, 913, 275, 190, 375, 850, 438, 733, 194, DfuException.ERROR_ENTER_OTA_MODE_FAILED, HttpStatus.SC_CREATED, DfuException.ERROR_ENTER_OTA_MODE_FAILED, 828, 757, 710, Constants.DATATYPE.AppStartBloodMeasurement, 919, 89, 68, 569, 11, HttpStatus.SC_NO_CONTENT, Constants.DATATYPE.AppUserInfoWriteBack, TypedValues.MotionType.TYPE_ANIMATE_RELATIVE_TO, DfuAdapter.STATE_READ_BATTERY_INFO, 913, Constants.DATATYPE.AppInsuranceNews, 700, Constants.DATATYPE.AppTemperatureCode, EMachine.EM_VIDEOCORE3, 439, 418, 592, 668, 353, 859, 370, 694, 325, 240, Command.CMD_SET_DEVICE_STORAGE, 257, 284, 549, 209, 884, 315, 70, 329, Constants.DATATYPE.AppEmoticonIndex, 490, 274, 877, 162, 749, Constants.DATATYPE.AppWritebackData, 684, 461, 334, 376, 849, 521, 307, Constants.DATATYPE.SettingWorkingMode, Constants.DATATYPE.AppMobileModel, 712, 19, 358, 399, 908, 103, FrameMetricsAggregator.EVERY_DURATION, 51, 8, 517, 225, Constants.DATATYPE.SettingScreenTime, 470, 637, 731, 66, 255, 917, 269, 463, 830, 730, 433, 848, 585, EMachine.EM_DSP24, 538, TypedValues.Custom.TYPE_REFERENCE, 90, 2, Constants.DATATYPE.SettingAmbientLight, 743, 199, 655, TypedValues.Custom.TYPE_STRING, 329, 49, Constants.DATATYPE.AppSensorSwitchControl, 580, 355, 588, 188, 462, 10, EMachine.EM_ECOG2, 628, 320, 479, 130, 739, 71, DfuException.ERROR_NO_CHARACTERISTIC_FOUND_OR_LOSS, 318, 374, 601, 192, TypedValues.MotionType.TYPE_ANIMATE_RELATIVE_TO, EMachine.EM_TI_C5500, 673, 687, 234, 722, 384, 177, 752, TypedValues.MotionType.TYPE_PATHMOTION_ARC, GlMapUtil.DEVICE_DISPLAY_DPI_XXHIGH, 455, 193, 689, TypedValues.TransitionType.TYPE_TRANSITION_FLAGS, Constants.DATATYPE.AppEffectiveHeart, 641, 48, 60, 732, 621, 895, Constants.DATATYPE.GetAllRealDataFromDevice, 261, 852, 655, 309, 697, 755, 756, 60, 231, 773, 434, 421, 726, Constants.DATATYPE.GetHeavenEarthAndFiveElement, 503, 118, 49, Constants.DATATYPE.AppSleepWriteBack, 32, 144, 500, 238, 836, 394, DfuException.ERROR_ENTER_OTA_MODE_FAILED, 566, Constants.DATATYPE.SettingBloodSugarAlarm, 9, 647, 550, 73, 914, 342, 126, 32, 681, 331, Constants.DATATYPE.AppTemperatureMeasure, 620, 60, TypedValues.MotionType.TYPE_POLAR_RELATIVETO, 441, 180, Constants.DATATYPE.AppTemperatureCorrect, 893, 754, TypedValues.MotionType.TYPE_ANIMATE_RELATIVE_TO, 383, 228, 749, 760, Command.CMD_GET_LOW_LATENCY_SETTINGS, 54, Constants.DATATYPE.SettingScheduleSwitch, EMachine.EM_ECOG2, 54, 834, Constants.DATATYPE.SettingUploadReminder, 922, EMachine.EM_TILEGX, 910, 532, TypedValues.MotionType.TYPE_POLAR_RELATIVETO, 829, 189, 20, 167, 29, 872, 449, 83, 402, 41, 656, 505, 579, 481, EMachine.EM_RX, HttpStatus.SC_NOT_FOUND, 251, 688, 95, 497, 555, 642, Constants.DATATYPE.GetDeviceRemindInfo, 307, Opcodes.IF_ICMPEQ, 924, 558, 648, 55, 497, 10}, new int[]{352, 77, 373, 504, 35, 599, 428, HttpStatus.SC_MULTI_STATUS, HttpStatus.SC_CONFLICT, 574, 118, 498, 285, 380, 350, 492, EMachine.EM_RL78, 265, 920, 155, 914, Constants.DATATYPE.SettingUploadReminder, 229, 643, Constants.DATATYPE.SettingBloodOxygenModeMonitor, 871, 306, 88, 87, 193, 352, 781, 846, 75, 327, 520, 435, Constants.DATATYPE.GetDeviceRemindInfo, HttpStatus.SC_NON_AUTHORITATIVE_INFORMATION, 666, 249, 346, 781, 621, GlMapUtil.DEVICE_DISPLAY_DPI_XXHIGH, 268, Constants.DATATYPE.AppHealthWriteBack, 534, 539, 781, HttpStatus.SC_REQUEST_TIMEOUT, 390, 644, 102, 476, 499, Constants.DATATYPE.SettingAmbientLight, 632, Constants.DATATYPE.GetLaserTreatmentParams, 37, 858, 916, 552, 41, 542, Constants.DATATYPE.SettingScreenTime, 122, DfuException.ERROR_READ_PATCH_INFO_ERROR, 383, 800, 485, 98, 752, 472, 761, 107, 784, 860, 658, 741, Constants.DATATYPE.SettingAmbientLight, HttpStatus.SC_NO_CONTENT, 681, HttpStatus.SC_PROXY_AUTHENTICATION_REQUIRED, 855, 85, 99, 62, 482, 180, 20, Constants.DATATYPE.SettingScheduleSwitch, 451, 593, 913, EMachine.EM_TI_C5500, Constants.DATATYPE.AppPushContacts, 684, Constants.DATATYPE.SettingTemperatureAlarm, Constants.DATATYPE.GetUploadConfigurationInfoOfReminder, 561, 76, 653, 899, 729, 567, 744, 390, 513, 192, 516, 258, 240, DfuConstants.PROGRESS_REMOTE_ENTER_OTA, Constants.DATATYPE.AppHealthWriteBack, 395, 768, 848, 51, TypedValues.MotionType.TYPE_QUANTIZE_MOTIONSTEPS, 384, 168, 190, 826, 328, 596, Constants.DATATYPE.AppTodayWeather, 303, 570, 381, HttpStatus.SC_UNSUPPORTED_MEDIA_TYPE, 641, 156, 237, Opcodes.DCMPL, 429, Constants.DATATYPE.GetCurrentAmbientTempAndHumidity, HttpStatus.SC_MULTI_STATUS, 676, 710, 89, 168, 304, 402, 40, 708, 575, 162, 864, 229, 65, 861, 841, 512, 164, 477, 221, 92, 358, 785, Constants.DATATYPE.SettingTemperatureMonitor, 357, 850, 836, 827, 736, TypedValues.TransitionType.TYPE_TRANSITION_FLAGS, 94, 8, 494, 114, 521, 2, 499, 851, Constants.DATATYPE.GetDeviceRemindInfo, 152, 729, Constants.DATATYPE.AppBloodCalibration, 95, 248, 361, 578, 323, 856, Constants.DATATYPE.AppUpgradeReminder, Constants.DATATYPE.SettingScreenTime, 51, 684, 466, 533, Constants.DATATYPE.AppSendCardNumber, 669, 45, TypedValues.Custom.TYPE_COLOR, 452, 167, 342, 244, EMachine.EM_RX, 35, 463, 651, 51, 699, 591, 452, 578, 37, 124, Constants.DATATYPE.SettingStepCountingStateTime, 332, 552, 43, 427, 119, 662, Constants.DATATYPE.AppControlReal, 475, 850, 764, 364, 578, 911, 283, 711, 472, 420, 245, Constants.DATATYPE.SettingTemperatureMonitor, 594, 394, FrameMetricsAggregator.EVERY_DURATION, 327, 589, Constants.DATATYPE.AppControlReal, 699, 688, 43, HttpStatus.SC_REQUEST_TIMEOUT, 842, 383, 721, 521, 560, 644, 714, 559, 62, 145, 873, 663, 713, Opcodes.IF_ICMPEQ, 672, 729, 624, 59, 193, HttpStatus.SC_EXPECTATION_FAILED, Opcodes.IFLE, 209, 563, 564, 343, 693, 109, TypedValues.MotionType.TYPE_DRAW_PATH, 563, 365, 181, 772, 677, 310, 248, 353, 708, HttpStatus.SC_GONE, 579, 870, 617, 841, 632, 860, Constants.DATATYPE.SettingScreenTime, Constants.DATATYPE.GetUploadConfigurationInfoOfReminder, 35, Constants.DATATYPE.AppControlReal, 618, 586, 424, 833, 77, 597, 346, 269, 757, 632, 695, 751, 331, 247, Opcodes.INVOKESTATIC, 45, Constants.DATATYPE.AppTomorrowWeather, 680, 18, 66, HttpStatus.SC_PROXY_AUTHENTICATION_REQUIRED, 369, 54, 492, 228, 613, 830, 922, 437, 519, 644, TypedValues.Custom.TYPE_DIMENSION, Constants.DATATYPE.AppHealthArg, 420, 305, 441, HttpStatus.SC_MULTI_STATUS, 300, 892, 827, EMachine.EM_TI_C2000, 537, 381, 662, 513, 56, 252, FacebookRequestErrorClassification.EC_TOO_MANY_USER_ACTION_CALLS, 242, Constants.DATATYPE.AppUpgradeReminder, 838, 837, 720, 224, 307, 631, 61, 87, 560, 310, 756, 665, 397, Constants.DATATYPE.AppPushContacts, 851, 309, 473, Constants.DATATYPE.AppSleepWriteBack, 378, 31, 647, 915, 459, Constants.DATATYPE.AppEarlyWarning, 590, 731, TypedValues.CycleType.TYPE_WAVE_PHASE, Command.CMD_SET_DEVICE_STORAGE, Constants.DATATYPE.GetCardInfo, 249, Constants.DATATYPE.SettingSettingCustomDial, 881, 699, 535, 673, Constants.DATATYPE.AppControlTakePhoto, Command.CMD_RECEIVE_SPEECH_CANCEL, Constants.DATATYPE.AppStartMeasurement, TypedValues.Custom.TYPE_DIMENSION, 303, 843, 922, 281, 73, 469, Constants.DATATYPE.AppTemperatureCorrect, 660, 162, 498, 308, 155, 422, 907, Constants.DATATYPE.AppBloodSugarCalibration, 187, 62, 16, TypedValues.CycleType.TYPE_WAVE_PHASE, 535, 336, Constants.DATATYPE.SettingStudentData, 437, 375, DfuException.ERROR_READ_IMAGE_VERSION_FAILED, TypedValues.MotionType.TYPE_QUANTIZE_MOTIONSTEPS, Constants.DATATYPE.SettingAmbientTemperatureAndHumidity, 183, 923, 116, 667, 751, 353, 62, 366, 691, 379, 687, 842, 37, 357, 720, 742, 330, 5, 39, 923, 311, 424, 242, 749, Constants.DATATYPE.SettingSettingCustomDial, 54, 669, 316, 342, Constants.DATATYPE.SettingUploadReminder, 534, 105, 667, 488, GlMapUtil.DEVICE_DISPLAY_DPI_XXHIGH, 672, 576, DfuAdapter.STATE_READ_BATTERY_INFO, 316, 486, 721, TypedValues.MotionType.TYPE_QUANTIZE_MOTIONSTEPS, 46, 656, 447, EMachine.EM_MANIK, 616, 464, 190, Constants.DATATYPE.GetCurrentAmbientTempAndHumidity, Constants.DATATYPE.SettingScheduleSwitch, Constants.DATATYPE.SettingSettingCustomDial, 762, 752, 533, EMachine.EM_MCST_ELBRUS, EMachine.EM_ECOG2, 14, 381, 433, 717, 45, 111, 20, 596, 284, 736, EMachine.EM_LATTICEMICO32, 646, HttpStatus.SC_LENGTH_REQUIRED, 877, 669, EMachine.EM_TI_C2000, 919, 45, Constants.DATATYPE.AppRunMode, HttpStatus.SC_PROXY_AUTHENTICATION_REQUIRED, 164, 332, 899, 165, 726, 600, 325, 498, 655, 357, 752, 768, 223, 849, 647, 63, 310, 863, 251, 366, 304, 282, 738, 675, HttpStatus.SC_GONE, 389, 244, 31, 121, 303, DfuException.ERROR_NO_CHARACTERISTIC_FOUND_OR_LOSS}};

    private PDF417ErrorCorrection() {
    }

    static int getErrorCorrectionCodewordCount(int i2) {
        if (i2 < 0 || i2 > 8) {
            throw new IllegalArgumentException("Error correction level must be between 0 and 8!");
        }
        return 1 << (i2 + 1);
    }

    static int getRecommendedMinimumErrorCorrectionLevel(int i2) throws WriterException {
        if (i2 <= 0) {
            throw new IllegalArgumentException("n must be > 0");
        }
        if (i2 <= 40) {
            return 2;
        }
        if (i2 <= 160) {
            return 3;
        }
        if (i2 <= 320) {
            return 4;
        }
        if (i2 <= 863) {
            return 5;
        }
        throw new WriterException("No recommendation possible");
    }

    static String generateErrorCorrection(CharSequence charSequence, int i2) {
        int errorCorrectionCodewordCount = getErrorCorrectionCodewordCount(i2);
        char[] cArr = new char[errorCorrectionCodewordCount];
        int length = charSequence.length();
        for (int i3 = 0; i3 < length; i3++) {
            int i4 = errorCorrectionCodewordCount - 1;
            int charAt = (charSequence.charAt(i3) + cArr[i4]) % PDF417Common.NUMBER_OF_CODEWORDS;
            while (i4 >= 1) {
                cArr[i4] = (char) ((cArr[i4 - 1] + (929 - ((EC_COEFFICIENTS[i2][i4] * charAt) % PDF417Common.NUMBER_OF_CODEWORDS))) % PDF417Common.NUMBER_OF_CODEWORDS);
                i4--;
            }
            cArr[0] = (char) ((929 - ((charAt * EC_COEFFICIENTS[i2][0]) % PDF417Common.NUMBER_OF_CODEWORDS)) % PDF417Common.NUMBER_OF_CODEWORDS);
        }
        StringBuilder sb = new StringBuilder(errorCorrectionCodewordCount);
        for (int i5 = errorCorrectionCodewordCount - 1; i5 >= 0; i5--) {
            char c2 = cArr[i5];
            if (c2 != 0) {
                cArr[i5] = (char) (929 - c2);
            }
            sb.append(cArr[i5]);
        }
        return sb.toString();
    }
}
