package com.jieli.jl_bt_ota.impl;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import com.jieli.jl_bt_ota.constant.ErrorCode;
import com.jieli.jl_bt_ota.interfaces.CommandCallback;
import com.jieli.jl_bt_ota.interfaces.IBluetoothCallback;
import com.jieli.jl_bt_ota.interfaces.IBluetoothManager;
import com.jieli.jl_bt_ota.interfaces.IUpgradeManager;
import com.jieli.jl_bt_ota.interfaces.rcsp.ICmdSnGenerator;
import com.jieli.jl_bt_ota.model.BluetoothOTAConfigure;
import com.jieli.jl_bt_ota.model.DataInfo;
import com.jieli.jl_bt_ota.model.OTAError;
import com.jieli.jl_bt_ota.model.base.BaseError;
import com.jieli.jl_bt_ota.model.base.BasePacket;
import com.jieli.jl_bt_ota.model.base.CommandBase;
import com.jieli.jl_bt_ota.tool.BtEventCallbackHelper;
import com.jieli.jl_bt_ota.tool.CommandCache;
import com.jieli.jl_bt_ota.tool.DeviceStatusCache;
import com.jieli.jl_bt_ota.tool.IDataHandler;
import com.jieli.jl_bt_ota.tool.ParseHelper;
import com.jieli.jl_bt_ota.tool.SnGenerator;
import com.jieli.jl_bt_ota.util.BluetoothUtil;
import com.jieli.jl_bt_ota.util.CommonUtil;
import com.jieli.jl_bt_ota.util.JL_Log;

/* loaded from: classes3.dex */
public abstract class BluetoothBase implements IBluetoothManager, IUpgradeManager {

    /* renamed from: a, reason: collision with root package name */
    private volatile BluetoothDevice f3330a;

    /* renamed from: b, reason: collision with root package name */
    private ICmdSnGenerator f3331b;

    /* renamed from: c, reason: collision with root package name */
    private BluetoothAdapterReceiver f3332c;
    protected final Context context;

    /* renamed from: d, reason: collision with root package name */
    private final boolean f3333d;
    protected volatile IDataHandler dataHandler;
    protected final BluetoothAdapter mBluetoothAdapter;
    protected final BtEventCallbackHelper mBtEventCbHelper;
    protected final CommandCache mCommandCache;
    protected final DeviceStatusCache mDeviceStatusCache;
    protected String TAG = getClass().getSimpleName();
    protected BluetoothOTAConfigure mBluetoothOption = BluetoothOTAConfigure.createDefault();

    private class BluetoothAdapterReceiver extends BroadcastReceiver {
        private BluetoothAdapterReceiver() {
        }

        @Override // android.content.BroadcastReceiver
        public void onReceive(Context context, Intent intent) {
            BluetoothAdapter bluetoothAdapter;
            if (intent == null || !"android.bluetooth.adapter.action.STATE_CHANGED".equals(intent.getAction()) || (bluetoothAdapter = BluetoothBase.this.mBluetoothAdapter) == null) {
                return;
            }
            int state = bluetoothAdapter.getState();
            JL_Log.i(BluetoothBase.this.TAG, "recv action : ACTION_STATE_CHANGED, state : " + state);
            if (10 == state) {
                BluetoothBase bluetoothBase = BluetoothBase.this;
                bluetoothBase.mBtEventCbHelper.onAdapterStatus(false, bluetoothBase.f3333d);
            } else if (12 == state) {
                BluetoothBase bluetoothBase2 = BluetoothBase.this;
                bluetoothBase2.mBtEventCbHelper.onAdapterStatus(true, bluetoothBase2.f3333d);
            }
        }
    }

    public BluetoothBase(Context context) {
        this.context = context;
        CommonUtil.setMainContext(context);
        this.mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        this.mDeviceStatusCache = new DeviceStatusCache();
        this.mCommandCache = new CommandCache();
        this.f3333d = BluetoothUtil.hasBle(context);
        this.mBtEventCbHelper = new BtEventCallbackHelper();
        a();
    }

    private void b() {
        Context context;
        BluetoothAdapterReceiver bluetoothAdapterReceiver = this.f3332c;
        if (bluetoothAdapterReceiver == null || (context = this.context) == null) {
            return;
        }
        context.unregisterReceiver(bluetoothAdapterReceiver);
        this.f3332c = null;
    }

    public boolean checkDeviceIsCertify(BluetoothDevice bluetoothDevice) {
        return !this.mBluetoothOption.isUseAuthDevice() || this.mDeviceStatusCache.isAuthBtDevice(bluetoothDevice);
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IUpgradeManager
    public void configure(BluetoothOTAConfigure bluetoothOTAConfigure) {
        this.mBluetoothOption = (BluetoothOTAConfigure) CommonUtil.checkNotNull(bluetoothOTAConfigure, "configure must not null.");
        JL_Log.d(this.TAG, "configure : " + bluetoothOTAConfigure);
        this.f3331b = bluetoothOTAConfigure.getSnGenerator();
    }

    public BluetoothOTAConfigure getBluetoothOption() {
        return this.mBluetoothOption;
    }

    public CommandBase getCacheCommand(BluetoothDevice bluetoothDevice, BasePacket basePacket) {
        if (basePacket == null) {
            return null;
        }
        return this.mCommandCache.getCommand(bluetoothDevice, basePacket.getOpCode(), basePacket.getOpCodeSn());
    }

    protected BluetoothDevice getConnectedBtDevice() {
        if (this.f3330a == null) {
            this.f3330a = getConnectedDevice();
        } else if (getConnectedDevice() != null && !BluetoothUtil.deviceEquals(getConnectedDevice(), this.f3330a)) {
            this.f3330a = getConnectedDevice();
        }
        return this.f3330a;
    }

    public boolean isConnectedDevice(BluetoothDevice bluetoothDevice) {
        return BluetoothUtil.deviceEquals(getConnectedDevice(), bluetoothDevice);
    }

    protected void onA2dpStatus(BluetoothDevice bluetoothDevice, int i2) {
        this.mBtEventCbHelper.onA2dpStatus(bluetoothDevice, i2);
    }

    protected void onAdapterStatus(boolean z, boolean z2) {
        this.mBtEventCbHelper.onAdapterStatus(z, z2);
    }

    protected void onBleDataBlockChanged(BluetoothDevice bluetoothDevice, int i2, int i3) {
        this.mBtEventCbHelper.onBleDataBlockChanged(bluetoothDevice, i2, i3);
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IBluetoothManager
    public void onBtDeviceConnection(BluetoothDevice bluetoothDevice, int i2) {
        this.mBtEventCbHelper.onBtDeviceConnection(bluetoothDevice, i2);
    }

    protected void onConnection(BluetoothDevice bluetoothDevice, int i2) {
        this.mBtEventCbHelper.onConnection(bluetoothDevice, i2);
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IBluetoothManager
    public void onError(BaseError baseError) {
        this.mBtEventCbHelper.onError(baseError);
    }

    protected void onHfpStatus(BluetoothDevice bluetoothDevice, int i2) {
        this.mBtEventCbHelper.onHfpStatus(bluetoothDevice, i2);
    }

    protected void onReceiveCommand(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
        this.mBtEventCbHelper.onReceiveCommand(bluetoothDevice, commandBase);
    }

    protected String printBtDeviceInfo(BluetoothDevice bluetoothDevice) {
        return BluetoothUtil.printBtDeviceInfo(this.context, bluetoothDevice);
    }

    public boolean registerBluetoothCallback(IBluetoothCallback iBluetoothCallback) {
        return this.mBtEventCbHelper.addCallback(iBluetoothCallback);
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IUpgradeManager
    public void release() {
        b();
        this.mDeviceStatusCache.clear();
        this.mCommandCache.release();
        this.mBtEventCbHelper.release();
        ICmdSnGenerator iCmdSnGenerator = this.f3331b;
        if (iCmdSnGenerator != null) {
            if (iCmdSnGenerator instanceof SnGenerator) {
                ((SnGenerator) iCmdSnGenerator).destroy();
            }
            this.f3331b = null;
        }
    }

    public void removeCacheCommand(BluetoothDevice bluetoothDevice, BasePacket basePacket) {
        this.mCommandCache.removeCommandBase(bluetoothDevice, basePacket);
    }

    public void sendCommandAsync(CommandBase commandBase, CommandCallback commandCallback) {
        sendCommandAsync(getConnectedBtDevice(), commandBase, getBluetoothOption().getTimeoutMs(), commandCallback);
    }

    public void sendCommandResponse(CommandBase commandBase) {
        sendCommandResponse(getConnectedBtDevice(), commandBase);
    }

    protected void setConnectedBtDevice(BluetoothDevice bluetoothDevice) {
        this.f3330a = bluetoothDevice;
    }

    public boolean unregisterBluetoothCallback(IBluetoothCallback iBluetoothCallback) {
        return this.mBtEventCbHelper.removeCallback(iBluetoothCallback);
    }

    private void a() {
        if (this.f3332c != null || this.context == null) {
            return;
        }
        this.f3332c = new BluetoothAdapterReceiver();
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.bluetooth.adapter.action.STATE_CHANGED");
        this.context.registerReceiver(this.f3332c, intentFilter);
    }

    public void sendCommandAsync(CommandBase commandBase, int i2, CommandCallback commandCallback) {
        sendCommandAsync(getConnectedBtDevice(), commandBase, i2, commandCallback);
    }

    public void sendCommandResponse(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
        a(bluetoothDevice, commandBase, 0, getBluetoothOption().getTimeoutMs(), null);
    }

    public void sendCommandAsync(BluetoothDevice bluetoothDevice, CommandBase commandBase, int i2, CommandCallback commandCallback) {
        a(bluetoothDevice, commandBase, 1, i2, commandCallback);
    }

    private void a(BaseError baseError, CommandCallback commandCallback) {
        if (commandCallback != null) {
            commandCallback.onErrCode(baseError);
        } else {
            errorEventCallback(baseError);
        }
    }

    private void a(BluetoothDevice bluetoothDevice, CommandBase commandBase, int i2, int i3, CommandCallback commandCallback) {
        if (bluetoothDevice == null) {
            bluetoothDevice = getConnectedBtDevice();
        }
        if (bluetoothDevice == null) {
            a(OTAError.buildError(4114), commandCallback);
            return;
        }
        if (commandBase == null) {
            a(OTAError.buildError(4097, "Command is null."), commandCallback);
            return;
        }
        if (!checkDeviceIsCertify(bluetoothDevice)) {
            a(OTAError.buildError(ErrorCode.SUB_ERR_AUTH_DEVICE, "Device may need to be certified."), commandCallback);
            return;
        }
        if (this.dataHandler == null) {
            JL_Log.d(this.TAG, "-sendCommandAsync- Data handler is null.");
            a(OTAError.buildError(4114, "Data handler is null."), commandCallback);
            return;
        }
        if (i2 == 1) {
            commandBase.setOpCodeSn(a(bluetoothDevice));
            this.mCommandCache.putCommandBase(bluetoothDevice, commandBase);
        }
        BasePacket convert2BasePacket = ParseHelper.convert2BasePacket(commandBase, i2);
        if (convert2BasePacket == null) {
            a(OTAError.buildError(12293, "Data is error."), commandCallback);
            return;
        }
        DataInfo callback = new DataInfo().setType(0).setDevice(bluetoothDevice).setBasePacket(convert2BasePacket).setTimeoutMs(i3).setCallback(commandCallback);
        JL_Log.d(this.TAG, "sendRcspCommand >> addSendData : cmdType = " + i2 + ", " + callback);
        this.dataHandler.addSendData(callback);
    }

    private int a(BluetoothDevice bluetoothDevice) {
        if (this.f3331b == null) {
            this.f3331b = new SnGenerator();
        }
        return this.f3331b.getRcspCmdSeq(bluetoothDevice);
    }
}
