package com.jieli.jl_bt_ota.impl;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.le.BluetoothLeScanner;
import android.bluetooth.le.ScanCallback;
import android.bluetooth.le.ScanResult;
import android.bluetooth.le.ScanSettings;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.os.SystemClock;
import com.jieli.jl_bt_ota.model.BleScanMessage;
import com.jieli.jl_bt_ota.model.OTAError;
import com.jieli.jl_bt_ota.util.BluetoothUtil;
import com.jieli.jl_bt_ota.util.CommonUtil;
import com.jieli.jl_bt_ota.util.JL_Log;
import java.util.ArrayList;
import java.util.List;

/* loaded from: classes3.dex */
public abstract class BluetoothDiscovery extends BluetoothBase {
    private static final int p = 4660;
    private static final int q = 4661;

    /* renamed from: e, reason: collision with root package name */
    private final List<BluetoothDevice> f3337e;

    /* renamed from: f, reason: collision with root package name */
    private final List<BluetoothDevice> f3338f;

    /* renamed from: g, reason: collision with root package name */
    private BluetoothDiscoveryReceiver f3339g;

    /* renamed from: h, reason: collision with root package name */
    private BluetoothLeScanner f3340h;

    /* renamed from: i, reason: collision with root package name */
    private volatile int f3341i;

    /* renamed from: j, reason: collision with root package name */
    private volatile boolean f3342j;
    private volatile boolean k;
    private long l;
    private final Handler m;
    private final BluetoothAdapter.LeScanCallback n;
    private final ScanCallback o;

    private class BluetoothDiscoveryReceiver extends BroadcastReceiver {
        private BluetoothDiscoveryReceiver() {
        }

        @Override // android.content.BroadcastReceiver
        public void onReceive(Context context, Intent intent) {
            BluetoothDevice bluetoothDevice;
            String action = intent.getAction();
            if ("android.bluetooth.adapter.action.DISCOVERY_STARTED".equals(action)) {
                BluetoothDiscovery.this.k = true;
                BluetoothDiscovery.this.m.removeMessages(BluetoothDiscovery.p);
                BluetoothDiscovery.this.m.sendEmptyMessageDelayed(BluetoothDiscovery.p, BluetoothDiscovery.this.l);
                BluetoothDiscovery.this.a(true);
                return;
            }
            if ("android.bluetooth.adapter.action.DISCOVERY_FINISHED".equals(action)) {
                BluetoothDiscovery.this.k = false;
                BluetoothDiscovery.this.m.removeMessages(BluetoothDiscovery.p);
                BluetoothDiscovery.this.b();
                BluetoothDiscovery.this.a(false);
                return;
            }
            if ("android.bluetooth.device.action.FOUND".equals(action) && (bluetoothDevice = (BluetoothDevice) intent.getParcelableExtra("android.bluetooth.device.extra.DEVICE")) != null && BluetoothDiscovery.this.c() && CommonUtil.checkHasConnectPermission(BluetoothDiscovery.this.context)) {
                boolean z = (BluetoothDiscovery.this.f3341i == 1 && bluetoothDevice.getType() != 2) || (BluetoothDiscovery.this.f3341i == 0 && bluetoothDevice.getType() != 1) || BluetoothDiscovery.this.f3341i == 2;
                short shortExtra = intent.getShortExtra("android.bluetooth.device.extra.RSSI", (short) 0);
                if (!z || BluetoothDiscovery.this.f3338f.contains(bluetoothDevice)) {
                    return;
                }
                BluetoothDiscovery.this.f3338f.add(bluetoothDevice);
                BluetoothDiscovery.this.mBtEventCbHelper.onDiscovery(bluetoothDevice, new BleScanMessage().setRssi(shortExtra).setEnableConnect(true));
            }
        }
    }

    public BluetoothDiscovery(Context context) {
        super(context);
        this.f3337e = new ArrayList();
        this.f3338f = new ArrayList();
        this.f3342j = false;
        this.k = false;
        this.l = 8000L;
        this.m = new Handler(Looper.getMainLooper(), new Handler.Callback() { // from class: com.jieli.jl_bt_ota.impl.BluetoothDiscovery$$ExternalSyntheticLambda0
            @Override // android.os.Handler.Callback
            public final boolean handleMessage(Message message) {
                boolean a2;
                a2 = BluetoothDiscovery.this.a(message);
                return a2;
            }
        });
        this.n = new BluetoothAdapter.LeScanCallback() { // from class: com.jieli.jl_bt_ota.impl.BluetoothDiscovery$$ExternalSyntheticLambda1
            @Override // android.bluetooth.BluetoothAdapter.LeScanCallback
            public final void onLeScan(BluetoothDevice bluetoothDevice, int i2, byte[] bArr) {
                BluetoothDiscovery.this.a(bluetoothDevice, i2, bArr);
            }
        };
        this.o = new ScanCallback() { // from class: com.jieli.jl_bt_ota.impl.BluetoothDiscovery.1
            @Override // android.bluetooth.le.ScanCallback
            public void onBatchScanResults(List<ScanResult> list) {
                super.onBatchScanResults(list);
            }

            @Override // android.bluetooth.le.ScanCallback
            public void onScanFailed(int i2) {
                super.onScanFailed(i2);
                BluetoothDiscovery.this.onError(OTAError.buildError(8194, i2, "Scan ble error."));
            }

            @Override // android.bluetooth.le.ScanCallback
            public void onScanResult(int i2, ScanResult scanResult) {
                super.onScanResult(i2, scanResult);
                if (scanResult == null || scanResult.getScanRecord() == null) {
                    return;
                }
                BluetoothDiscovery.this.a(scanResult.getDevice(), scanResult.getRssi(), scanResult.getScanRecord().getBytes(), Build.VERSION.SDK_INT >= 26 ? scanResult.isConnectable() : true);
            }
        };
        BluetoothAdapter bluetoothAdapter = this.mBluetoothAdapter;
        if (bluetoothAdapter != null) {
            this.f3340h = bluetoothAdapter.getBluetoothLeScanner();
        }
    }

    public ArrayList<BluetoothDevice> getDiscoveredBluetoothDevices() {
        return this.f3341i == 0 ? new ArrayList<>(this.f3337e) : new ArrayList<>(this.f3338f);
    }

    public int getScanType() {
        return this.f3341i;
    }

    protected boolean isBleScanning() {
        return this.f3342j;
    }

    protected boolean isDeviceScanning() {
        return this.k;
    }

    public boolean isScanning() {
        return this.k || this.f3342j;
    }

    @Override // com.jieli.jl_bt_ota.impl.BluetoothBase
    public void onAdapterStatus(boolean z, boolean z2) {
        super.onAdapterStatus(z, z2);
        if (z) {
            return;
        }
        if (isDeviceScanning()) {
            a(false);
        }
        d();
    }

    @Override // com.jieli.jl_bt_ota.impl.BluetoothBase, com.jieli.jl_bt_ota.interfaces.IUpgradeManager
    public void release() {
        super.release();
        b();
        stopDeviceScan();
        stopBLEScan();
        d();
        this.m.removeCallbacksAndMessages(null);
    }

    public void setScanType(int i2) {
        this.f3341i = i2;
    }

    public int startBLEScan(long j2) {
        if (!CommonUtil.checkHasScanPermission(this.context)) {
            JL_Log.e(this.TAG, "startBLEScan : no scan permission");
            return 4113;
        }
        if (!CommonUtil.checkHasLocationPermission(this.context)) {
            JL_Log.e(this.TAG, "startBLEScan : no location permission");
            return 4113;
        }
        if (this.mBluetoothAdapter == null) {
            JL_Log.e(this.TAG, "startBLEScan : this device is not supported bluetooth.");
            return 4113;
        }
        if (!c()) {
            JL_Log.e(this.TAG, "startBLEScan : bluetooth is close.");
            return 4099;
        }
        if (this.k) {
            JL_Log.d(this.TAG, "startBLEScan : stopDeviceScan");
            if (stopDeviceScan() == 0) {
                int i2 = 0;
                do {
                    SystemClock.sleep(30L);
                    i2 += 30;
                    if (i2 > 300) {
                        break;
                    }
                } while (this.mBluetoothAdapter.isDiscovering());
            }
        }
        setScanType(0);
        if (j2 <= 0) {
            j2 = 8000;
        }
        if (this.f3342j) {
            JL_Log.i(this.TAG, "scanning ble ..... timeout = " + j2);
            BluetoothLeScanner bluetoothLeScanner = this.f3340h;
            if (bluetoothLeScanner != null) {
                bluetoothLeScanner.flushPendingScanResults(this.o);
            }
            this.m.removeMessages(q);
            this.m.sendEmptyMessageDelayed(q, j2);
            a(true);
            return 0;
        }
        if (this.f3340h != null) {
            this.f3340h.startScan(new ArrayList(), new ScanSettings.Builder().setScanMode(this.mBluetoothOption.getBleScanMode()).setMatchMode(1).build(), this.o);
            JL_Log.w(this.TAG, "-startBLEScan- >>>>>> startScan :>> timeout = " + j2);
        } else {
            boolean startLeScan = this.mBluetoothAdapter.startLeScan(this.n);
            JL_Log.w(this.TAG, "-startBLEScan- >>>>>> startLeScan : " + startLeScan);
            if (!startLeScan) {
                return 8194;
            }
        }
        JL_Log.i(this.TAG, "-startBLEScan- timeout = " + j2);
        this.m.removeMessages(q);
        this.m.sendEmptyMessageDelayed(q, j2);
        a(true);
        return 0;
    }

    public int startDeviceScan(long j2, int i2) {
        if (i2 == 0) {
            return startBLEScan(j2);
        }
        if (!CommonUtil.checkHasScanPermission(this.context)) {
            JL_Log.e(this.TAG, "startDeviceScan :: no scan permission");
            return 4113;
        }
        if (this.mBluetoothAdapter == null) {
            JL_Log.e(this.TAG, "startDeviceScan :: this device is not supported bluetooth.");
            return 4098;
        }
        if (!c()) {
            JL_Log.e(this.TAG, "startDeviceScan :: bluetooth is close.");
            return 4099;
        }
        if (this.f3342j) {
            JL_Log.w(this.TAG, "startDeviceScan :: stopBLEScan: ");
            stopBLEScan();
        }
        setScanType(i2);
        this.l = j2 <= 0 ? 8000L : j2;
        if (this.k) {
            JL_Log.i(this.TAG, "scanning br/edr ..... timeout = " + j2);
            this.m.removeMessages(p);
            this.m.sendEmptyMessageDelayed(p, this.l);
            a(true);
            return 0;
        }
        a();
        boolean startDiscovery = this.mBluetoothAdapter.startDiscovery();
        JL_Log.w(this.TAG, "-startDiscovery- >>>>>> bRet : " + startDiscovery);
        if (!startDiscovery) {
            b();
            return 8194;
        }
        this.m.removeMessages(p);
        this.m.sendEmptyMessageDelayed(p, this.l);
        return 0;
    }

    public int stopBLEScan() {
        if (!CommonUtil.checkHasScanPermission(this.context)) {
            JL_Log.e(this.TAG, "stopBLEScan : no scan permission.");
            return 4113;
        }
        if (this.mBluetoothAdapter == null) {
            JL_Log.e(this.TAG, "stopBLEScan : this device is not supported bluetooth.");
            return 4113;
        }
        if (!this.f3342j) {
            return 0;
        }
        JL_Log.w(this.TAG, "-stopBLEScan- >>>>>> " + this.f3341i);
        if (this.f3341i != 0) {
            setScanType(0);
        }
        if (c()) {
            try {
                BluetoothLeScanner bluetoothLeScanner = this.f3340h;
                if (bluetoothLeScanner != null) {
                    bluetoothLeScanner.stopScan(this.o);
                } else {
                    this.mBluetoothAdapter.stopLeScan(this.n);
                }
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
        this.m.removeMessages(q);
        a(false);
        return 0;
    }

    public int stopDeviceScan() {
        if (!CommonUtil.checkHasScanPermission(this.context)) {
            JL_Log.e(this.TAG, "stopDeviceScan : no scan permission");
            return 4113;
        }
        if (this.mBluetoothAdapter == null) {
            JL_Log.e(this.TAG, "stopDeviceScan : this device is not supported bluetooth.");
            return 4113;
        }
        if (!this.k) {
            return 0;
        }
        boolean cancelDiscovery = this.mBluetoothAdapter.cancelDiscovery();
        JL_Log.w(this.TAG, "stopDeviceScan : cancelDiscovery = " + cancelDiscovery);
        if (!cancelDiscovery) {
            return 8194;
        }
        this.m.removeMessages(p);
        return 0;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean c() {
        return BluetoothUtil.isBluetoothEnable();
    }

    private void d() {
        setScanType(0);
        this.f3342j = false;
        this.k = false;
        this.f3337e.clear();
        this.f3338f.clear();
    }

    private boolean b(BluetoothDevice bluetoothDevice) {
        if (bluetoothDevice == null || !CommonUtil.checkHasConnectPermission(this.context)) {
            return false;
        }
        return bluetoothDevice.getType() == 2 || bluetoothDevice.getType() == 3;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ boolean a(Message message) {
        int i2 = message.what;
        if (i2 != p) {
            if (i2 == q && this.f3342j) {
                JL_Log.w(this.TAG, "-mBleTimeOut- stopBLEScan");
                stopBLEScan();
            }
        } else if (this.k) {
            JL_Log.w(this.TAG, "-MSG_STOP_EDR- stopDeviceScan");
            stopDeviceScan();
            this.k = false;
        }
        return false;
    }

    private void b(boolean z) {
        List<BluetoothDevice> systemConnectedBtDeviceList = BluetoothUtil.getSystemConnectedBtDeviceList(this.context);
        if (systemConnectedBtDeviceList == null || systemConnectedBtDeviceList.isEmpty()) {
            return;
        }
        for (BluetoothDevice bluetoothDevice : systemConnectedBtDeviceList) {
            if (z && b(bluetoothDevice)) {
                if (!this.f3337e.contains(bluetoothDevice)) {
                    this.f3337e.add(bluetoothDevice);
                    this.mBtEventCbHelper.onDiscovery(bluetoothDevice, new BleScanMessage());
                }
            } else if (!z && !b(bluetoothDevice) && !this.f3338f.contains(bluetoothDevice)) {
                this.f3338f.add(bluetoothDevice);
                this.mBtEventCbHelper.onDiscovery(bluetoothDevice, new BleScanMessage());
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b() {
        Context context;
        BluetoothDiscoveryReceiver bluetoothDiscoveryReceiver = this.f3339g;
        if (bluetoothDiscoveryReceiver == null || (context = this.context) == null) {
            return;
        }
        context.unregisterReceiver(bluetoothDiscoveryReceiver);
        this.f3339g = null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(BluetoothDevice bluetoothDevice, int i2, byte[] bArr) {
        a(bluetoothDevice, i2, bArr, true);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, int i2, byte[] bArr, boolean z) {
        if (bluetoothDevice == null || !CommonUtil.checkHasConnectPermission(this.context) || !c() || this.f3337e.contains(bluetoothDevice)) {
            return;
        }
        this.f3337e.add(bluetoothDevice);
        this.mBtEventCbHelper.onDiscovery(bluetoothDevice, new BleScanMessage().setRawData(bArr).setRssi(i2).setEnableConnect(z));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(boolean z) {
        boolean z2 = this.f3341i == 0;
        JL_Log.i(this.TAG, "-notifyDiscoveryStatus- scanType : " + this.f3341i + " ,bStart : " + z);
        if (z) {
            if (z2) {
                this.f3342j = true;
                this.f3337e.clear();
            } else {
                this.k = true;
                this.f3338f.clear();
            }
        } else if (z2) {
            this.f3342j = false;
        } else {
            this.k = false;
        }
        this.mBtEventCbHelper.onDiscoveryStatus(z2, z);
        if (!z) {
            setScanType(0);
        } else {
            b(z2);
        }
    }

    private void a() {
        if (this.f3339g != null || this.context == null) {
            return;
        }
        this.f3339g = new BluetoothDiscoveryReceiver();
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.bluetooth.adapter.action.DISCOVERY_STARTED");
        intentFilter.addAction("android.bluetooth.adapter.action.DISCOVERY_FINISHED");
        intentFilter.addAction("android.bluetooth.device.action.FOUND");
        this.context.registerReceiver(this.f3339g, intentFilter);
    }
}
