package com.jieli.jl_bt_ota.impl;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothGatt;
import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import com.jieli.jl_bt_ota.constant.ErrorCode;
import com.jieli.jl_bt_ota.impl.RcspAuth;
import com.jieli.jl_bt_ota.interfaces.IActionCallback;
import com.jieli.jl_bt_ota.interfaces.IUpgradeCallback;
import com.jieli.jl_bt_ota.model.DataInfo;
import com.jieli.jl_bt_ota.model.FileOffset;
import com.jieli.jl_bt_ota.model.OTAError;
import com.jieli.jl_bt_ota.model.ReConnectDevMsg;
import com.jieli.jl_bt_ota.model.ReconnectParam;
import com.jieli.jl_bt_ota.model.base.BaseError;
import com.jieli.jl_bt_ota.model.base.BasePacket;
import com.jieli.jl_bt_ota.model.base.CommandBase;
import com.jieli.jl_bt_ota.model.command.EnterUpdateModeCmd;
import com.jieli.jl_bt_ota.model.command.FirmwareUpdateBlockCmd;
import com.jieli.jl_bt_ota.model.command.NotifyUpdateContentSizeCmd;
import com.jieli.jl_bt_ota.model.command.SettingsMtuCmd;
import com.jieli.jl_bt_ota.model.parameter.FirmwareUpdateBlockParam;
import com.jieli.jl_bt_ota.model.parameter.FirmwareUpdateBlockResponseParam;
import com.jieli.jl_bt_ota.model.parameter.NotifyUpdateContentSizeParam;
import com.jieli.jl_bt_ota.model.parameter.SettingsMtuParam;
import com.jieli.jl_bt_ota.model.response.EnterUpdateModeResponse;
import com.jieli.jl_bt_ota.model.response.SettingsMtuResponse;
import com.jieli.jl_bt_ota.model.response.TargetInfoResponse;
import com.jieli.jl_bt_ota.thread.ReadFileThread;
import com.jieli.jl_bt_ota.tool.DataHandler;
import com.jieli.jl_bt_ota.tool.DataHandlerModify;
import com.jieli.jl_bt_ota.tool.DeviceReConnectManager;
import com.jieli.jl_bt_ota.tool.ParseHelper;
import com.jieli.jl_bt_ota.tool.RcspOTA;
import com.jieli.jl_bt_ota.tool.UpgradeCbHelper;
import com.jieli.jl_bt_ota.util.BluetoothUtil;
import com.jieli.jl_bt_ota.util.CHexConver;
import com.jieli.jl_bt_ota.util.CommonUtil;
import com.jieli.jl_bt_ota.util.FileUtil;
import com.jieli.jl_bt_ota.util.JL_Log;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/* loaded from: classes3.dex */
public abstract class BluetoothOTAManager extends BluetoothBreProfiles implements RcspAuth.IRcspAuthOp {
    public static long FILE_CACHE_DATA_LIMIT = 2097152;
    public static boolean IS_SUPPORT_NEW_RECONNECT_WAY = true;
    public static boolean IS_USE_MODIFY_DATA_HANDLER = true;
    private static final long L = 6000;
    private static final long M = 1000;
    private static final long N = 5000;
    private static final int O = 4660;
    private static final int P = 4661;
    private static final int Q = 4662;
    private static final int R = 4663;
    private static final int S = 4664;
    private static final int T = 4665;
    private static final int U = 4672;
    private static final int V = 4673;
    private volatile boolean A;
    private volatile byte[] B;
    private volatile RandomAccessFile C;
    private long D;
    private long E;
    private long F;
    private int G;
    private int H;
    private ReconnectParam I;
    private final Handler J;
    private final RcspAuth.OnRcspAuthListener K;
    private final RcspOTA v;
    private final DeviceReConnectManager w;
    private final RcspAuth x;
    private final UpgradeCbHelper y;
    private final ExecutorService z;

    public BluetoothOTAManager(Context context) {
        super(context);
        this.z = Executors.newSingleThreadExecutor();
        this.A = false;
        this.D = 20000L;
        this.E = 0L;
        this.F = 0L;
        this.G = 0;
        this.H = 0;
        this.J = new Handler(Looper.getMainLooper(), new Handler.Callback() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.1
            /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
            @Override // android.os.Handler.Callback
            public boolean handleMessage(Message message) {
                int i2 = message.what;
                if (i2 == BluetoothOTAManager.S) {
                    BluetoothDevice bluetoothDevice = (BluetoothDevice) message.obj;
                    JL_Log.w(BluetoothOTAManager.this.TAG, "MSG_WAIT_EDR_DISCONNECT  ===> " + BluetoothOTAManager.this.printBtDeviceInfo(bluetoothDevice));
                    BluetoothOTAManager.this.h(bluetoothDevice);
                } else if (i2 == BluetoothOTAManager.T) {
                    JL_Log.w(BluetoothOTAManager.this.TAG, "MSG_WAIT_DEVICE_DISCONNECT :: ");
                    BluetoothOTAManager bluetoothOTAManager = BluetoothOTAManager.this;
                    bluetoothOTAManager.a(bluetoothOTAManager.getConnectedBtDevice(), BluetoothOTAManager.this.I);
                } else if (i2 == BluetoothOTAManager.U) {
                    BluetoothOTAManager.this.g();
                } else if (i2 != BluetoothOTAManager.V) {
                    switch (i2) {
                        case BluetoothOTAManager.O /* 4660 */:
                            JL_Log.w(BluetoothOTAManager.this.TAG, "-MSG_START_RECEIVE_CMD_TIMEOUT- ");
                            BluetoothOTAManager.this.a("Receive cmd timeout", OTAError.buildError(ErrorCode.SUB_ERR_WAITING_COMMAND_TIMEOUT));
                            break;
                        case BluetoothOTAManager.P /* 4661 */:
                            BluetoothDevice bluetoothDevice2 = (BluetoothDevice) message.obj;
                            JL_Log.i(BluetoothOTAManager.this.TAG, "-MSG_CHANGE_BLE_MTU_TIMEOUT- device : " + BluetoothOTAManager.this.printBtDeviceInfo(bluetoothDevice2));
                            if (!BluetoothOTAManager.this.i(bluetoothDevice2)) {
                                BluetoothOTAManager.this.c(bluetoothDevice2, 2);
                                break;
                            } else {
                                BluetoothOTAManager.this.b(bluetoothDevice2, 0);
                                break;
                            }
                        case BluetoothOTAManager.Q /* 4662 */:
                            boolean isOTA = BluetoothOTAManager.this.isOTA();
                            BluetoothOTAManager bluetoothOTAManager2 = BluetoothOTAManager.this;
                            boolean isConnectedDevice = bluetoothOTAManager2.isConnectedDevice(bluetoothOTAManager2.getConnectedBtDevice());
                            boolean isWaitingForUpdate = BluetoothOTAManager.this.w.isWaitingForUpdate();
                            BluetoothOTAManager bluetoothOTAManager3 = BluetoothOTAManager.this;
                            JL_Log.i(bluetoothOTAManager3.TAG, CommonUtil.formatString("-MSG_OTA_RECONNECT_DEVICE- device : %s, isOTA = %s, isWaitingForUpdate = %s, isConnectedDevice = %s ReconnectParam = %s", bluetoothOTAManager3.printBtDeviceInfo(bluetoothOTAManager3.getConnectedBtDevice()), Boolean.valueOf(isOTA), Boolean.valueOf(isWaitingForUpdate), Boolean.valueOf(isConnectedDevice), BluetoothOTAManager.this.I));
                            if (isOTA && !isConnectedDevice && isWaitingForUpdate && BluetoothOTAManager.this.I != null) {
                                BluetoothOTAManager bluetoothOTAManager4 = BluetoothOTAManager.this;
                                bluetoothOTAManager4.a(bluetoothOTAManager4.w.getReconnectAddress(), BluetoothOTAManager.this.I.getFlag() == 1);
                                if (BluetoothOTAManager.this.getBluetoothOption().isUseReconnect()) {
                                    BluetoothOTAManager.this.J.sendEmptyMessageDelayed(BluetoothOTAManager.V, DeviceReConnectManager.RECONNECT_TIMEOUT);
                                } else {
                                    BluetoothOTAManager.this.w.startReconnectTask();
                                }
                                BluetoothOTAManager.this.a((ReconnectParam) null);
                                break;
                            }
                            break;
                    }
                } else {
                    JL_Log.w(BluetoothOTAManager.this.TAG, "MSG_RECONNECT_DEVICE_TIMEOUT >>>>>");
                    BluetoothOTAManager.this.a("MSG_OTA_RECONNECT_DEVICE_TIMEOUT", OTAError.buildError(ErrorCode.SUB_ERR_RECONNECT_TIMEOUT));
                }
                return true;
            }
        });
        RcspAuth.OnRcspAuthListener onRcspAuthListener = new RcspAuth.OnRcspAuthListener() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.14
            @Override // com.jieli.jl_bt_ota.impl.RcspAuth.OnRcspAuthListener
            public void onAuthFailed(BluetoothDevice bluetoothDevice, int i2, String str) {
                BluetoothOTAManager bluetoothOTAManager = BluetoothOTAManager.this;
                JL_Log.w(bluetoothOTAManager.TAG, CommonUtil.formatString("-onAuthFailed- device : %s, code : %d, message : %s", bluetoothOTAManager.printBtDeviceInfo(bluetoothDevice), Integer.valueOf(i2), str));
                BluetoothOTAManager.this.mDeviceStatusCache.updateDeviceIsAuth(bluetoothDevice, false);
                if (BluetoothOTAManager.this.w.isDeviceReconnecting()) {
                    BluetoothOTAManager.this.c(bluetoothDevice, 2);
                } else {
                    BluetoothOTAManager.this.a(bluetoothDevice, OTAError.buildError(ErrorCode.SUB_ERR_AUTH_DEVICE, i2, str));
                }
            }

            @Override // com.jieli.jl_bt_ota.impl.RcspAuth.OnRcspAuthListener
            public void onAuthSuccess(BluetoothDevice bluetoothDevice) {
                BluetoothOTAManager.this.mDeviceStatusCache.updateDeviceIsAuth(bluetoothDevice, true);
                boolean i2 = BluetoothOTAManager.this.i(bluetoothDevice);
                BluetoothOTAManager bluetoothOTAManager = BluetoothOTAManager.this;
                JL_Log.w(bluetoothOTAManager.TAG, CommonUtil.formatString("-onAuthSuccess- >>> device[%s] auth ok, isBleConnected = %s", bluetoothOTAManager.printBtDeviceInfo(bluetoothDevice), Boolean.valueOf(i2)));
                if (i2) {
                    BluetoothOTAManager.this.l(bluetoothDevice);
                } else {
                    BluetoothOTAManager.this.b(bluetoothDevice, 1);
                }
            }

            @Override // com.jieli.jl_bt_ota.impl.RcspAuth.OnRcspAuthListener
            public void onInitResult(boolean z) {
                JL_Log.d(BluetoothOTAManager.this.TAG, "-onInitResult- " + z);
            }
        };
        this.K = onRcspAuthListener;
        this.v = new RcspOTA(this);
        this.w = new DeviceReConnectManager(context, this);
        this.x = new RcspAuth(context, this, onRcspAuthListener);
        this.y = new UpgradeCbHelper();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void k() {
        this.y.setUpgradeCallback(null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void l(BluetoothDevice bluetoothDevice) {
        if (bluetoothDevice == null) {
            return;
        }
        if (this.J.hasMessages(P)) {
            JL_Log.w(this.TAG, "-startChangeMtu- Adjusting the MTU for BLE");
            return;
        }
        boolean d2 = (!this.mBluetoothOption.isNeedChangeMtu() || this.mBluetoothOption.getMtu() <= 20) ? false : d(bluetoothDevice, this.mBluetoothOption.getMtu());
        JL_Log.d(this.TAG, "-startChangeMtu- requestBleMtu : " + d2);
        if (!d2) {
            b(bluetoothDevice, 0);
        } else {
            Handler handler = this.J;
            handler.sendMessageDelayed(handler.obtainMessage(P, bluetoothDevice), 5000L);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void m() {
        this.y.setUpgradeCallback(null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void n() {
        a("startReadFileThread", OTAError.buildError(ErrorCode.SUB_ERR_FILE_NOT_FOUND));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void o() {
        if (this.J.hasMessages(U)) {
            this.J.removeMessages(U);
            this.J.sendEmptyMessage(U);
        }
    }

    private void p() {
        JL_Log.w(this.TAG, "releaseDataHandler>>>>>>>>>>>>>>>>>");
        if (this.dataHandler != null) {
            this.dataHandler.release();
            this.dataHandler = null;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void q() {
        if (this.w.isWaitingForUpdate()) {
            this.w.setReConnectDevMsg(null);
            this.w.stopReconnectTask();
        }
    }

    private void r() {
        c(false);
        u();
        s();
        d(true);
        a((ReconnectParam) null);
        if (this.B != null) {
            this.B = null;
            System.gc();
        }
        if (this.C != null) {
            try {
                this.C.close();
            } catch (IOException e2) {
                e2.printStackTrace();
            } finally {
                this.C = null;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void s() {
        this.H = 0;
        this.G = 0;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void t() {
        if (!a("startReceiveCmdTimeout") && this.D > 0) {
            this.J.removeMessages(O);
            this.J.sendEmptyMessageDelayed(O, this.D);
        }
    }

    private void u() {
        this.J.removeMessages(O);
    }

    private void v() {
        if (a("upgradeStep03")) {
            return;
        }
        this.v.enterUpdateMode(new IActionCallback<Integer>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.10
            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onError(BaseError baseError) {
                BluetoothOTAManager.this.a("upgradeStep03", baseError);
            }

            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onSuccess(Integer num) {
                JL_Log.i(BluetoothOTAManager.this.TAG, "Step3.请求进入升级模式, 结果码: " + num);
                if (num.intValue() == 0) {
                    BluetoothOTAManager.this.t();
                    return;
                }
                onError(OTAError.buildError(16385, "Device is not allowed to enter the upgrade mode : " + num));
            }
        });
    }

    private void w() {
        if (a("upgradeStep05")) {
            return;
        }
        this.v.queryUpdateResult(new IActionCallback<Integer>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.12
            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onError(BaseError baseError) {
                BluetoothOTAManager.this.a("upgradeStep05", baseError);
            }

            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onSuccess(Integer num) {
                BaseError buildError;
                JL_Log.i(BluetoothOTAManager.this.TAG, "Step05.询问升级状态, 结果码: " + num);
                if (num.intValue() == 0) {
                    BluetoothOTAManager.this.c(false);
                    BluetoothOTAManager.this.J.removeMessages(BluetoothOTAManager.U);
                    BluetoothOTAManager.this.J.sendEmptyMessageDelayed(BluetoothOTAManager.U, 500L);
                    BluetoothOTAManager.this.v.rebootDevice(new IActionCallback<Boolean>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.12.1
                        @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                        public void onError(BaseError baseError) {
                        }

                        @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                        public void onSuccess(Boolean bool) {
                            BluetoothOTAManager.this.o();
                        }
                    });
                    return;
                }
                if (num.intValue() == 128) {
                    BluetoothOTAManager.this.resetTotalTime();
                    BluetoothOTAManager.this.s();
                    TargetInfoResponse deviceInfo = BluetoothOTAManager.this.getDeviceInfo();
                    JL_Log.i(BluetoothOTAManager.this.TAG, "upgradeStep05 :: check device info.\n" + deviceInfo);
                    if (deviceInfo == null || !deviceInfo.isSupportDoubleBackup()) {
                        BluetoothOTAManager bluetoothOTAManager = BluetoothOTAManager.this;
                        bluetoothOTAManager.k(bluetoothOTAManager.getConnectedBtDevice());
                        return;
                    }
                    BluetoothOTAManager.this.a("upgradeStep05", OTAError.buildError(16385, num.intValue(), "Double ota, but get a bad code: " + num));
                    return;
                }
                switch (num.intValue()) {
                    case 1:
                        buildError = OTAError.buildError(16389);
                        break;
                    case 2:
                        buildError = OTAError.buildError(16385, "Device return update failed.");
                        break;
                    case 3:
                        buildError = OTAError.buildError(ErrorCode.SUB_ERR_UPGRADE_KEY_NOT_MATCH);
                        break;
                    case 4:
                        buildError = OTAError.buildError(16387);
                        break;
                    case 5:
                        buildError = OTAError.buildError(ErrorCode.SUB_ERR_UPGRADE_TYPE_NOT_MATCH);
                        break;
                    case 6:
                        buildError = OTAError.buildError(ErrorCode.SUB_ERR_UPGRADE_DATA_LEN);
                        break;
                    case 7:
                        buildError = OTAError.buildError(ErrorCode.SUB_ERR_UPGRADE_FLASH_READ);
                        break;
                    case 8:
                        buildError = OTAError.buildError(ErrorCode.SUB_ERR_UPGRADE_CMD_TIMEOUT);
                        break;
                    case 9:
                        buildError = OTAError.buildError(ErrorCode.SUB_ERR_UPGRADE_SAME_FILE);
                        break;
                    default:
                        buildError = OTAError.buildError(ErrorCode.SUB_ERR_UPGRADE_UNKNOWN, num.intValue(), "Device returned to an unknown code : " + num);
                        break;
                }
                onError(buildError);
            }
        });
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IUpgradeManager
    public void cancelOTA() {
        i();
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IBluetoothManager
    public void errorEventCallback(BaseError baseError) {
        this.mBtEventCbHelper.onError(baseError);
        a("errorEventCallback", baseError);
    }

    public int getCommunicationMtu(BluetoothDevice bluetoothDevice) {
        return this.mDeviceStatusCache.getMaxCommunicationMtu(bluetoothDevice);
    }

    public TargetInfoResponse getDeviceInfo(BluetoothDevice bluetoothDevice) {
        return this.mDeviceStatusCache.getDeviceInfo(bluetoothDevice);
    }

    public int getReceiveMtu(BluetoothDevice bluetoothDevice) {
        return this.mDeviceStatusCache.getMaxReceiveMtu(bluetoothDevice);
    }

    public long getTimeout_ms() {
        return this.D;
    }

    public long getTotalTime() {
        return this.F;
    }

    public int getUpdateContentSize() {
        return this.G;
    }

    public boolean isOTA() {
        return this.A;
    }

    @Override // com.jieli.jl_bt_ota.impl.BluetoothBase
    public void onA2dpStatus(BluetoothDevice bluetoothDevice, int i2) {
        super.onA2dpStatus(bluetoothDevice, i2);
        a(bluetoothDevice, 2, i2);
    }

    @Override // com.jieli.jl_bt_ota.impl.BluetoothDiscovery, com.jieli.jl_bt_ota.impl.BluetoothBase
    public void onAdapterStatus(boolean z, boolean z2) {
        super.onAdapterStatus(z, z2);
        if (z) {
            return;
        }
        a("onAdapterStatus", OTAError.buildError(4099));
        BluetoothDevice connectedBtDevice = getConnectedBtDevice();
        if (connectedBtDevice != null) {
            c(connectedBtDevice, 0);
        }
    }

    @Override // com.jieli.jl_bt_ota.impl.BluetoothBase
    public void onBleDataBlockChanged(BluetoothDevice bluetoothDevice, int i2, int i3) {
        super.onBleDataBlockChanged(bluetoothDevice, i2, i3);
        JL_Log.i(this.TAG, CommonUtil.formatString("-onBleDataBlockChanged- device : %s, block : %d, status : %d", printBtDeviceInfo(bluetoothDevice), Integer.valueOf(i2), Integer.valueOf(i3)));
        if (this.J.hasMessages(P)) {
            this.J.removeMessages(P);
            JL_Log.i(this.TAG, "-onBleDataBlockChanged- handleConnectedEvent >>>");
            b(bluetoothDevice, 0);
        }
    }

    @Override // com.jieli.jl_bt_ota.impl.BluetoothBase, com.jieli.jl_bt_ota.interfaces.IBluetoothManager
    public void onBtDeviceConnection(BluetoothDevice bluetoothDevice, int i2) {
        super.onBtDeviceConnection(bluetoothDevice, i2);
        JL_Log.i(this.TAG, "-onBtDeviceConnection- device : " + printBtDeviceInfo(bluetoothDevice) + ", " + i2);
        if (i2 != 3) {
            this.J.removeMessages(V);
        }
        if (i2 != 1) {
            if (BluetoothUtil.deviceEquals(bluetoothDevice, getConnectedBtDevice())) {
                setConnectedBtDevice(null);
            }
            c(bluetoothDevice, i2);
            return;
        }
        if (this.dataHandler == null) {
            this.dataHandler = IS_USE_MODIFY_DATA_HANDLER ? new DataHandlerModify(this) : new DataHandler(this);
        }
        if (checkDeviceIsCertify(bluetoothDevice)) {
            if (i(bluetoothDevice)) {
                l(bluetoothDevice);
                return;
            } else {
                b(bluetoothDevice, 1);
                return;
            }
        }
        this.x.stopAuth(bluetoothDevice, false);
        if (this.x.startAuth(bluetoothDevice)) {
            return;
        }
        a(bluetoothDevice, OTAError.buildError(ErrorCode.SUB_ERR_AUTH_DEVICE));
    }

    /* JADX WARN: Code restructure failed: missing block: B:6:0x003a, code lost:
    
        if (r11 != 2) goto L23;
     */
    @Override // com.jieli.jl_bt_ota.impl.BluetoothBase
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public void onConnection(android.bluetooth.BluetoothDevice r10, int r11) {
        /*
            r9 = this;
            r0 = 3
            if (r11 == r0) goto Lcc
            boolean r1 = r9.isOTA()
            com.jieli.jl_bt_ota.tool.DeviceReConnectManager r2 = r9.w
            boolean r2 = r2.isWaitingForUpdate()
            java.lang.String r3 = r9.TAG
            r4 = 4
            java.lang.Object[] r4 = new java.lang.Object[r4]
            java.lang.String r5 = r9.printBtDeviceInfo(r10)
            r6 = 0
            r4[r6] = r5
            java.lang.Integer r5 = java.lang.Integer.valueOf(r11)
            r7 = 1
            r4[r7] = r5
            java.lang.Boolean r5 = java.lang.Boolean.valueOf(r1)
            r8 = 2
            r4[r8] = r5
            java.lang.Boolean r5 = java.lang.Boolean.valueOf(r2)
            r4[r0] = r5
            java.lang.String r0 = "onConnection :: device : %s, status : %d, isOTA = %s, isWaitingForUpdate = %s"
            java.lang.String r0 = com.jieli.jl_bt_ota.util.CommonUtil.formatString(r0, r4)
            com.jieli.jl_bt_ota.util.JL_Log.i(r3, r0)
            if (r11 == 0) goto L75
            if (r11 == r7) goto L3e
            if (r11 == r8) goto L75
            goto Lcc
        L3e:
            com.jieli.jl_bt_ota.tool.DeviceStatusCache r0 = r9.mDeviceStatusCache
            boolean r0 = r0.isMandatoryUpgrade(r10)
            java.lang.String r3 = r9.TAG
            java.lang.Object[] r4 = new java.lang.Object[r8]
            java.lang.Boolean r5 = java.lang.Boolean.valueOf(r0)
            r4[r6] = r5
            java.lang.Boolean r5 = java.lang.Boolean.valueOf(r2)
            r4[r7] = r5
            java.lang.String r5 = "onConnection :: connect success, isMandatoryUpgrade = %s, isWaitingForUpdate = %s"
            java.lang.String r4 = com.jieli.jl_bt_ota.util.CommonUtil.formatString(r5, r4)
            com.jieli.jl_bt_ota.util.JL_Log.w(r3, r4)
            if (r1 == 0) goto Lcc
            if (r2 == 0) goto Lcc
            r9.q()
            if (r0 == 0) goto Lcc
            java.lang.String r0 = r9.TAG
            java.lang.String r1 = "-wait for update- continue..."
            com.jieli.jl_bt_ota.util.JL_Log.e(r0, r1)
            r0 = 0
            r9.a(r10, r0)
            r9.v()
            goto Lcc
        L75:
            android.os.Handler r0 = r9.J
            r3 = 4663(0x1237, float:6.534E-42)
            r0.removeMessages(r3)
            if (r1 == 0) goto Lcc
            if (r2 == 0) goto Lba
            java.lang.String r0 = r9.TAG
            java.lang.StringBuilder r1 = new java.lang.StringBuilder
            java.lang.String r2 = "onConnection :: device state = "
            r1.<init>(r2)
            r1.append(r11)
            java.lang.String r2 = ", "
            r1.append(r2)
            com.jieli.jl_bt_ota.model.ReconnectParam r2 = r9.I
            r1.append(r2)
            java.lang.String r1 = r1.toString()
            com.jieli.jl_bt_ota.util.JL_Log.i(r0, r1)
            android.os.Handler r0 = r9.J
            r1 = 4664(0x1238, float:6.536E-42)
            r0.removeMessages(r1)
            android.os.Handler r0 = r9.J
            r1 = 4665(0x1239, float:6.537E-42)
            r0.removeMessages(r1)
            com.jieli.jl_bt_ota.model.ReconnectParam r0 = r9.I
            if (r0 == 0) goto Lcc
            java.lang.String r10 = r9.TAG
            java.lang.String r11 = "onConnection :: device communication channel is disconnect. ready reconnect task. "
            com.jieli.jl_bt_ota.util.JL_Log.i(r10, r11)
            r9.h()
            return
        Lba:
            java.lang.String r0 = r9.TAG
            java.lang.String r1 = "onConnection :: ota failed."
            com.jieli.jl_bt_ota.util.JL_Log.i(r0, r1)
            r0 = 4114(0x1012, float:5.765E-42)
            com.jieli.jl_bt_ota.model.base.BaseError r0 = com.jieli.jl_bt_ota.model.OTAError.buildError(r0)
            java.lang.String r1 = "onConnection"
            r9.a(r1, r0)
        Lcc:
            super.onConnection(r10, r11)
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.onConnection(android.bluetooth.BluetoothDevice, int):void");
    }

    @Override // com.jieli.jl_bt_ota.impl.BluetoothBase
    public void onHfpStatus(BluetoothDevice bluetoothDevice, int i2) {
        super.onHfpStatus(bluetoothDevice, i2);
        a(bluetoothDevice, 1, i2);
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IBluetoothManager
    public void onMtuChanged(BluetoothGatt bluetoothGatt, int i2, int i3) {
        if (bluetoothGatt == null) {
            return;
        }
        int i4 = i3 == 0 ? i2 - 3 : 20;
        JL_Log.e(this.TAG, "--onMtuChanged-- bleMtu : " + i4);
        onBleDataBlockChanged(bluetoothGatt.getDevice(), i4, i3);
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IBluetoothManager
    public void onReceiveDeviceData(BluetoothDevice bluetoothDevice, byte[] bArr) {
        if (bluetoothDevice == null || bArr == null) {
            return;
        }
        JL_Log.d(this.TAG, "---onReceiveDeviceData-- >>> device : " + printBtDeviceInfo(bluetoothDevice) + ", recv data : " + CHexConver.byte2HexStr(bArr));
        if (!checkDeviceIsCertify(bluetoothDevice)) {
            JL_Log.i(this.TAG, "--onReceiveDeviceData-- >>> handleAuthData ");
            this.x.handleAuthData(bluetoothDevice, bArr);
        } else {
            if (this.dataHandler == null) {
                JL_Log.i(this.TAG, "--onReceiveDeviceData-- >>> dataHandler is null ");
                return;
            }
            DataInfo recvData = new DataInfo().setType(1).setDevice(bluetoothDevice).setRecvData(bArr);
            this.dataHandler.addRecvData(recvData);
            JL_Log.d(this.TAG, "--onReceiveDeviceData-- >> addRecvData >>>> " + recvData);
        }
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IBluetoothManager
    public void queryMandatoryUpdate(final IActionCallback<TargetInfoResponse> iActionCallback) {
        final BluetoothDevice connectedBtDevice = getConnectedBtDevice();
        if (connectedBtDevice == null) {
            JL_Log.w(this.TAG, "-queryMandatoryUpdate- Bluetooth device is disconnected.");
            if (iActionCallback != null) {
                iActionCallback.onError(OTAError.buildError(4114));
                return;
            }
            return;
        }
        TargetInfoResponse deviceInfo = getDeviceInfo(connectedBtDevice);
        JL_Log.i(this.TAG, "-queryMandatoryUpdate- cache deviceInfo : " + deviceInfo);
        if (deviceInfo == null) {
            this.v.getDeviceInfo(new IActionCallback<TargetInfoResponse>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.2
                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onError(BaseError baseError) {
                    IActionCallback iActionCallback2 = iActionCallback;
                    if (iActionCallback2 != null) {
                        iActionCallback2.onError(baseError);
                    }
                }

                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onSuccess(TargetInfoResponse targetInfoResponse) {
                    BluetoothOTAManager.this.mDeviceStatusCache.updateDeviceTargetInfo(connectedBtDevice, targetInfoResponse);
                    BluetoothOTAManager.this.queryMandatoryUpdate(iActionCallback);
                }
            });
            return;
        }
        if (deviceInfo.isMandatoryUpgrade() || deviceInfo.getRequestOtaFlag() == 1) {
            if (iActionCallback != null) {
                iActionCallback.onSuccess(deviceInfo);
            }
            this.mBtEventCbHelper.onMandatoryUpgrade(connectedBtDevice);
        } else if (iActionCallback != null) {
            iActionCallback.onError(OTAError.buildError(0, "Device is connected."));
        }
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IBluetoothManager
    public void receiveDataFromDevice(BluetoothDevice bluetoothDevice, byte[] bArr) {
        ArrayList<BasePacket> findPacketData = ParseHelper.findPacketData(bluetoothDevice, getReceiveMtu(bluetoothDevice), bArr);
        if (findPacketData == null || findPacketData.isEmpty()) {
            JL_Log.w(this.TAG, "receiveDataFromDevice :: not find OTA command.");
            return;
        }
        Iterator<BasePacket> it2 = findPacketData.iterator();
        while (it2.hasNext()) {
            BasePacket next = it2.next();
            CommandBase convert2Command = ParseHelper.convert2Command(next, getCacheCommand(bluetoothDevice, next));
            if (convert2Command == null) {
                JL_Log.e(this.TAG, "receiveDataFromDevice :: command is null");
            } else {
                JL_Log.d(this.TAG, "receiveDataFromDevice :: " + convert2Command);
                if (next.getType() == 1) {
                    onReceiveCommand(bluetoothDevice, convert2Command);
                    a(bluetoothDevice, convert2Command, next.getHasResponse() == 1);
                } else {
                    a(bluetoothDevice, convert2Command);
                }
            }
        }
    }

    @Override // com.jieli.jl_bt_ota.impl.BluetoothBreProfiles, com.jieli.jl_bt_ota.impl.BluetoothDiscovery, com.jieli.jl_bt_ota.impl.BluetoothBase, com.jieli.jl_bt_ota.interfaces.IUpgradeManager
    public void release() {
        super.release();
        cancelOTA();
        r();
        this.w.release();
        if (!this.z.isShutdown()) {
            this.z.shutdownNow();
        }
        this.x.removeListener(this.K);
        this.x.destroy();
        this.y.release();
        this.J.removeCallbacksAndMessages(null);
        p();
        JL_Log.e(this.TAG, "release..........>>>>>>>>>>>>>>>>>");
    }

    public void resetTotalTime() {
        this.F = 0L;
    }

    @Override // com.jieli.jl_bt_ota.impl.RcspAuth.IRcspAuthOp
    public boolean sendAuthDataToDevice(BluetoothDevice bluetoothDevice, byte[] bArr) {
        return sendDataToDevice(bluetoothDevice, bArr);
    }

    public void setReconnectAddress(String str) {
        if (this.w.isWaitingForUpdate() && BluetoothAdapter.checkBluetoothAddress(str)) {
            this.w.setReconnectAddress(str);
        }
    }

    public void setTimeout_ms(long j2) {
        this.D = j2;
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IUpgradeManager
    public void startOTA(IUpgradeCallback iUpgradeCallback) {
        BluetoothDevice connectedBtDevice = getConnectedBtDevice();
        if (connectedBtDevice == null) {
            JL_Log.w(this.TAG, "startOTA : Bluetooth device is disconnected.");
            if (iUpgradeCallback != null) {
                iUpgradeCallback.onError(OTAError.buildError(4114));
                return;
            }
            return;
        }
        if (isOTA()) {
            JL_Log.w(this.TAG, "startOTA : OTA is in progress.");
            if (iUpgradeCallback != null) {
                iUpgradeCallback.onError(OTAError.buildError(ErrorCode.SUB_ERR_OTA_IN_HANDLE));
                return;
            }
            return;
        }
        if (!getBluetoothOption().isUseAuthDevice()) {
            this.mDeviceStatusCache.updateDeviceIsAuth(connectedBtDevice, true);
        }
        c(true);
        this.y.setUpgradeCallback(iUpgradeCallback);
        if (FileUtil.checkFileExist(getBluetoothOption().getFirmwareFilePath())) {
            a(connectedBtDevice, getBluetoothOption().getFirmwareFilePath());
            return;
        }
        if (getBluetoothOption().getFirmwareFileData() == null || getBluetoothOption().getFirmwareFileData().length <= 0) {
            a("startOTA", OTAError.buildError(ErrorCode.SUB_ERR_DATA_NOT_FOUND));
            return;
        }
        this.B = getBluetoothOption().getFirmwareFileData();
        String str = this.TAG;
        StringBuilder sb = new StringBuilder("startOTA : data size = ");
        sb.append(this.B == null ? 0 : this.B.length);
        JL_Log.d(str, sb.toString());
        f();
        m(connectedBtDevice);
    }

    private boolean j() {
        return getConnectedBtDevice() != null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void k(final BluetoothDevice bluetoothDevice) {
        if (a("readyToReconnectDevice")) {
            return;
        }
        int f2 = f(bluetoothDevice);
        String a2 = a(bluetoothDevice, f2);
        boolean z = IS_SUPPORT_NEW_RECONNECT_WAY;
        ReConnectDevMsg reConnectDevMsg = new ReConnectDevMsg(f2, a2);
        this.w.setReConnectDevMsg(reConnectDevMsg);
        JL_Log.d(this.TAG, "readyToReconnectDevice : flag = " + (z ? 1 : 0) + ", " + reConnectDevMsg);
        a(new ReconnectParam(bluetoothDevice.getAddress(), f2, a2));
        this.J.removeMessages(T);
        this.J.sendEmptyMessageDelayed(T, 6000L);
        this.v.changeCommunicationWay(f2, z ? 1 : 0, new IActionCallback<Integer>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.9
            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onError(BaseError baseError) {
                BluetoothOTAManager.this.a("readyToReconnectDevice", baseError);
            }

            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onSuccess(Integer num) {
                BluetoothOTAManager.this.J.removeMessages(BluetoothOTAManager.T);
                if (BluetoothOTAManager.this.w.isWaitingForUpdate()) {
                    BluetoothOTAManager.this.w.setReconnectUseADV(num.intValue() == 1);
                }
                if (BluetoothOTAManager.this.I != null) {
                    BluetoothOTAManager.this.I.setFlag(num.intValue());
                    BluetoothOTAManager bluetoothOTAManager = BluetoothOTAManager.this;
                    bluetoothOTAManager.a(bluetoothDevice, bluetoothOTAManager.I);
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void m(final BluetoothDevice bluetoothDevice) {
        if (a("upgradePrepare")) {
            return;
        }
        if (getDeviceInfo(bluetoothDevice) == null) {
            this.v.getDeviceInfo(new IActionCallback<TargetInfoResponse>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.5
                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onError(BaseError baseError) {
                    BluetoothOTAManager.this.a("upgradePrepare", baseError);
                }

                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onSuccess(TargetInfoResponse targetInfoResponse) {
                    BluetoothOTAManager.this.mDeviceStatusCache.updateDeviceTargetInfo(bluetoothDevice, targetInfoResponse);
                    BluetoothOTAManager.this.n(bluetoothDevice);
                }
            });
        } else {
            n(bluetoothDevice);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void n(final BluetoothDevice bluetoothDevice) {
        if (a("upgradeStep01")) {
            return;
        }
        this.v.readUpgradeFileFlag(new IActionCallback<FileOffset>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.6
            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onError(BaseError baseError) {
                BluetoothOTAManager.this.a("upgradeStep01", baseError);
            }

            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onSuccess(FileOffset fileOffset) {
                JL_Log.i(BluetoothOTAManager.this.TAG, CommonUtil.formatString("Step01.获取升级文件信息的偏移地址, %s", fileOffset));
                BluetoothOTAManager.this.a(bluetoothDevice, 0.0f);
                BluetoothOTAManager.this.b(bluetoothDevice, fileOffset.getOffset(), fileOffset.getLen());
            }
        });
    }

    @Override // com.jieli.jl_bt_ota.interfaces.IUpgradeManager
    public TargetInfoResponse getDeviceInfo() {
        return getDeviceInfo(getConnectedBtDevice());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void c(boolean z) {
        this.A = z;
    }

    private boolean d(BluetoothDevice bluetoothDevice, int i2) {
        if (!CommonUtil.checkHasConnectPermission(this.context)) {
            JL_Log.e(this.TAG, "--requestBleMtu-- no connect permission");
            return false;
        }
        BluetoothGatt connectedBluetoothGatt = getConnectedBluetoothGatt();
        if (connectedBluetoothGatt != null && BluetoothUtil.deviceEquals(connectedBluetoothGatt.getDevice(), bluetoothDevice)) {
            JL_Log.e(this.TAG, "--requestBleMtu-- requestMtu is started.");
            if (connectedBluetoothGatt.requestMtu(i2 + 3)) {
                return true;
            }
            JL_Log.e(this.TAG, "--requestBleMtu-- requestMtu failed. callback old mtu.");
            onBleDataBlockChanged(bluetoothDevice, 20, ErrorCode.SUB_ERR_CHANGE_BLE_MTU);
            return false;
        }
        JL_Log.e(this.TAG, "--requestBleMtu-- device is disconnected.");
        return false;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void e() {
        JL_Log.w(this.TAG, "callbackCancelOTA : ");
        r();
        this.y.onCancelOTA();
        this.J.postDelayed(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda9
            @Override // java.lang.Runnable
            public final void run() {
                BluetoothOTAManager.this.k();
            }
        }, 100L);
    }

    private int f(BluetoothDevice bluetoothDevice) {
        int priority = this.mBluetoothOption.getPriority();
        TargetInfoResponse deviceInfo = getDeviceInfo(bluetoothDevice);
        if (deviceInfo == null || deviceInfo.isSupportDoubleBackup()) {
            return priority;
        }
        int singleBackupOtaWay = deviceInfo.getSingleBackupOtaWay();
        if (singleBackupOtaWay != 1) {
            if (singleBackupOtaWay == 2) {
                return 1;
            }
            if (deviceInfo.getSdkType() < 2) {
                return priority;
            }
        }
        return 0;
    }

    private void g(final BluetoothDevice bluetoothDevice) {
        JL_Log.d(this.TAG, "-getDeviceInfoWithConnection- start....");
        this.v.getDeviceInfo(new IActionCallback<TargetInfoResponse>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.4
            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onError(BaseError baseError) {
                BluetoothOTAManager.this.a(bluetoothDevice, baseError);
            }

            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onSuccess(TargetInfoResponse targetInfoResponse) {
                BluetoothOTAManager.this.mDeviceStatusCache.updateDeviceTargetInfo(bluetoothDevice, targetInfoResponse);
                if (targetInfoResponse.isSupportMD5()) {
                    BluetoothOTAManager.this.v.getMD5(new IActionCallback<String>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.4.1
                        @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                        public void onError(BaseError baseError) {
                            JL_Log.i(BluetoothOTAManager.this.TAG, "getDevMD5 failed, " + baseError);
                        }

                        @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                        public void onSuccess(String str) {
                            JL_Log.i(BluetoothOTAManager.this.TAG, "getDevMD5 ok, MD5 : " + str);
                            AnonymousClass4 anonymousClass4 = AnonymousClass4.this;
                            BluetoothOTAManager.this.mDeviceStatusCache.updateDeviceMD5(bluetoothDevice, str);
                        }
                    });
                }
                if (targetInfoResponse.isMandatoryUpgrade()) {
                    JL_Log.w(BluetoothOTAManager.this.TAG, "getDeviceInfoWithConnection >>>> sdkType : " + targetInfoResponse.getSdkType());
                    BluetoothOTAManager.this.d(bluetoothDevice);
                    if (targetInfoResponse.getSdkType() >= 2) {
                        BluetoothGatt connectedBluetoothGatt = BluetoothOTAManager.this.getConnectedBluetoothGatt();
                        if (CommonUtil.checkHasConnectPermission(BluetoothOTAManager.this.context) && connectedBluetoothGatt != null) {
                            boolean requestConnectionPriority = connectedBluetoothGatt.requestConnectionPriority(1);
                            JL_Log.w(BluetoothOTAManager.this.TAG, "-getDeviceInfoWithConnection- requestConnectionPriority :: ret : " + requestConnectionPriority);
                        }
                    }
                } else {
                    BluetoothOTAManager.this.q();
                    if (BluetoothOTAManager.this.isOTA()) {
                        BluetoothOTAManager.this.J.sendEmptyMessage(BluetoothOTAManager.U);
                    }
                }
                BluetoothOTAManager.this.c(bluetoothDevice);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void h(BluetoothDevice bluetoothDevice) {
        if (this.w.isWaitingForUpdate()) {
            this.J.removeMessages(S);
            if (isConnectedDevice(bluetoothDevice)) {
                Handler handler = this.J;
                handler.sendMessageDelayed(handler.obtainMessage(S, bluetoothDevice), 5000L);
                disconnectBluetoothDevice(bluetoothDevice);
                return;
            }
            h();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean i(BluetoothDevice bluetoothDevice) {
        return isConnectedDevice(bluetoothDevice) && this.mBluetoothOption.getPriority() == 0;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void j(BluetoothDevice bluetoothDevice) {
        boolean removeBond = BluetoothUtil.removeBond(this.context, bluetoothDevice);
        JL_Log.i(this.TAG, "-startUpgradeReConnect- removeBond >>> " + removeBond);
    }

    private void b(final int i2, final int i3, final IActionCallback<byte[]> iActionCallback) {
        if (i2 >= 0 && i3 >= 0) {
            if (this.B != null && this.B.length > 0) {
                byte[] bArr = new byte[i3];
                if (i2 + i3 > this.B.length) {
                    if (iActionCallback != null) {
                        iActionCallback.onError(OTAError.buildError(16388, CommonUtil.formatString("readBlockData :: Can not read file data by Buffer. offset = %d, len = %d, file data length = %d.", Integer.valueOf(i2), Integer.valueOf(i3), Integer.valueOf(this.B.length))));
                        return;
                    }
                    return;
                } else {
                    System.arraycopy(this.B, i2, bArr, 0, i3);
                    if (iActionCallback != null) {
                        iActionCallback.onSuccess(bArr);
                        return;
                    }
                    return;
                }
            }
            if (this.C != null) {
                this.z.execute(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda3
                    @Override // java.lang.Runnable
                    public final void run() {
                        BluetoothOTAManager.this.a(i3, i2, iActionCallback);
                    }
                });
                return;
            }
        }
        if (iActionCallback != null) {
            iActionCallback.onError(OTAError.buildError(4097, CommonUtil.formatString("readBlockData :: Can not read file data. offset = %d, len = %d.", Integer.valueOf(i2), Integer.valueOf(i3))));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void c(BluetoothDevice bluetoothDevice, int i2) {
        JL_Log.i(this.TAG, "-notifyConnectionStatus- device : " + printBtDeviceInfo(bluetoothDevice) + ", status : " + i2);
        if (i2 != 3) {
            if (i2 == 1 || i2 == 4) {
                JL_Log.i(this.TAG, "-notifyConnectionStatus- handler connected event.");
            } else if (i2 == 2 || i2 == 0) {
                JL_Log.w(this.TAG, "-notifyConnectionStatus- handler disconnect event.");
                p();
                u();
                this.mDeviceStatusCache.removeDeviceStatus(bluetoothDevice);
                o();
            }
        }
        onConnection(bluetoothDevice, i2);
    }

    private void i() {
        if (a("exitUpdateMode")) {
            return;
        }
        TargetInfoResponse deviceInfo = getDeviceInfo();
        if (deviceInfo != null && deviceInfo.isSupportDoubleBackup()) {
            c(false);
            this.v.exitUpdateMode(new IActionCallback<Integer>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.13
                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onError(BaseError baseError) {
                    BluetoothOTAManager.this.c(true);
                    BluetoothOTAManager.this.a("exitUpdateMode", baseError);
                }

                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onSuccess(Integer num) {
                    JL_Log.d(BluetoothOTAManager.this.TAG, "exitUpdateMode : onSuccess >>>" + num);
                    if (num.intValue() == 0) {
                        BluetoothOTAManager.this.e();
                        return;
                    }
                    onError(OTAError.buildError(16385, num.intValue(), "Device return a bad code : " + num));
                }
            });
        } else {
            JL_Log.i(this.TAG, CommonUtil.formatString("exitUpdateMode : device[%s] is single flash ota, so ota progress cannot be interrupted.", getConnectedBtDevice()));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void g() {
        JL_Log.i(this.TAG, "callbackStopOTA : ");
        r();
        this.y.onStopOTA();
        this.J.postDelayed(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda2
            @Override // java.lang.Runnable
            public final void run() {
                BluetoothOTAManager.this.m();
            }
        }, 100L);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void e(BluetoothDevice bluetoothDevice) {
        if (a("checkUpgradeEnvironment")) {
            return;
        }
        TargetInfoResponse deviceInfo = getDeviceInfo(bluetoothDevice);
        JL_Log.d(this.TAG, CommonUtil.formatString("checkUpgradeEnvironment >> device : %s, deviceInfo ：%s", printBtDeviceInfo(bluetoothDevice), deviceInfo));
        if (deviceInfo == null) {
            a("checkUpgradeEnvironment", OTAError.buildError(4114));
            return;
        }
        if (deviceInfo.isSupportDoubleBackup()) {
            q();
            v();
        } else if (deviceInfo.isNeedBootLoader()) {
            d(bluetoothDevice);
            t();
        } else if (deviceInfo.isMandatoryUpgrade()) {
            v();
        } else {
            k(bluetoothDevice);
        }
    }

    private void h() {
        this.J.removeMessages(Q);
        this.J.sendEmptyMessageDelayed(Q, 1000L);
    }

    private void f() {
        JL_Log.i(this.TAG, "callbackStartOTA : ");
        resetTotalTime();
        this.y.onStartOTA();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(ReconnectParam reconnectParam) {
        this.I = reconnectParam;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void l() {
        this.y.setUpgradeCallback(null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(final int i2, final int i3, final IActionCallback iActionCallback) {
        try {
            final byte[] bArr = new byte[i2];
            this.C.seek(i3);
            final int read = this.C.read(bArr);
            if (read != i2) {
                final long length = this.C.length();
                this.J.post(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda5
                    @Override // java.lang.Runnable
                    public final void run() {
                        BluetoothOTAManager.a(IActionCallback.this, i3, i2, read, length);
                    }
                });
            } else {
                this.J.post(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda6
                    @Override // java.lang.Runnable
                    public final void run() {
                        BluetoothOTAManager.a(IActionCallback.this, bArr, read);
                    }
                });
            }
        } catch (IOException e2) {
            e2.printStackTrace();
            this.J.post(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda7
                @Override // java.lang.Runnable
                public final void run() {
                    BluetoothOTAManager.a(IActionCallback.this, e2);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void c(BluetoothDevice bluetoothDevice) {
        c(bluetoothDevice, 1);
        TargetInfoResponse deviceInfo = getDeviceInfo(bluetoothDevice);
        if (deviceInfo == null || isOTA()) {
            return;
        }
        if (deviceInfo.isMandatoryUpgrade() || deviceInfo.getRequestOtaFlag() == 1) {
            this.mBtEventCbHelper.onMandatoryUpgrade(bluetoothDevice);
        }
    }

    private void d(boolean z) {
        if (this.E > 0) {
            this.F = CommonUtil.getCurrentTime() - this.E;
            if (z) {
                this.E = 0L;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void d(BluetoothDevice bluetoothDevice) {
        if (this.mDeviceStatusCache.getMaxCommunicationMtu(bluetoothDevice) < 530) {
            this.mDeviceStatusCache.updateDeviceMaxCommunicationMtu(bluetoothDevice, 530);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static /* synthetic */ void a(IActionCallback iActionCallback, int i2, int i3, int i4, long j2) {
        if (iActionCallback != null) {
            iActionCallback.onError(OTAError.buildError(16388, CommonUtil.formatString("readBlockData :: Can not read file data by RandomAccessFile. offset = %d, len = %d, read data size = %d, file data length = %d.", Integer.valueOf(i2), Integer.valueOf(i3), Integer.valueOf(i4), Long.valueOf(j2))));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static /* synthetic */ void a(IActionCallback iActionCallback, byte[] bArr, int i2) {
        if (iActionCallback != null) {
            iActionCallback.onSuccess(Arrays.copyOfRange(bArr, 0, i2));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static /* synthetic */ void a(IActionCallback iActionCallback, IOException iOException) {
        if (iActionCallback != null) {
            iActionCallback.onError(OTAError.buildError(ErrorCode.SUB_ERR_IO_EXCEPTION, "readBlockData :: failed. " + iOException.getMessage()));
        }
    }

    private float a(int i2) {
        int i3 = this.G;
        if (i3 <= 0) {
            return 0.0f;
        }
        float f2 = (i2 * 100.0f) / i3;
        if (f2 >= 100.0f) {
            return 99.9f;
        }
        return f2;
    }

    private void a(final BluetoothDevice bluetoothDevice, String str) {
        if (!j()) {
            a("startReadFileThread", OTAError.buildError(4114));
            return;
        }
        f();
        final File file = new File(str);
        if (!file.exists() || !file.isFile()) {
            a("startReadFileThread", OTAError.buildError(ErrorCode.SUB_ERR_FILE_NOT_FOUND));
        } else if (file.length() <= FILE_CACHE_DATA_LIMIT) {
            this.z.execute(new ReadFileThread(str, new IActionCallback<byte[]>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.3
                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onError(BaseError baseError) {
                    BluetoothOTAManager.this.a("ReadFileThread", baseError);
                }

                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onSuccess(byte[] bArr) {
                    String str2 = BluetoothOTAManager.this.TAG;
                    StringBuilder sb = new StringBuilder("ReadFileThread >>> onSuccess, length = ");
                    sb.append(bArr == null ? 0 : bArr.length);
                    JL_Log.i(str2, sb.toString());
                    BluetoothOTAManager.this.B = bArr;
                    BluetoothOTAManager.this.m(bluetoothDevice);
                }
            }));
        } else {
            this.z.execute(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda4
                @Override // java.lang.Runnable
                public final void run() {
                    BluetoothOTAManager.this.a(file, bluetoothDevice);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b(BluetoothDevice bluetoothDevice, int i2) {
        if (bluetoothDevice == null) {
            JL_Log.e(this.TAG, "-handleConnectedEvent- device is null.");
            return;
        }
        JL_Log.d(this.TAG, CommonUtil.formatString("-handleConnectedEvent- device : %s, way = %d", printBtDeviceInfo(bluetoothDevice), Integer.valueOf(i2)));
        if (i2 == 0) {
            this.J.removeMessages(P);
        }
        setConnectedBtDevice(bluetoothDevice);
        g(bluetoothDevice);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b(final BluetoothDevice bluetoothDevice, int i2, int i3) {
        if (a("upgradeStep02")) {
            return;
        }
        if (i3 < 0 || i2 < 0) {
            a("upgradeStep02", OTAError.buildError(4097, CommonUtil.formatString("upgradeStep02: offset = %d, len = %d", Integer.valueOf(i2), Integer.valueOf(i3))));
        } else if (i2 == 0 && i3 == 0) {
            a(bluetoothDevice, new byte[]{CHexConver.intToByte(this.mBluetoothOption.getPriority())});
        } else {
            b(i2, i3, new IActionCallback<byte[]>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.7
                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onError(BaseError baseError) {
                    BluetoothOTAManager.this.a("upgradeStep02", baseError);
                }

                @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
                public void onSuccess(byte[] bArr) {
                    BluetoothOTAManager.this.a(bluetoothDevice, bArr);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(File file, BluetoothDevice bluetoothDevice) {
        try {
            this.C = new RandomAccessFile(file, "r");
            m(bluetoothDevice);
        } catch (Exception e2) {
            e2.printStackTrace();
            this.J.post(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda1
                @Override // java.lang.Runnable
                public final void run() {
                    BluetoothOTAManager.this.n();
                }
            });
        }
    }

    private String a(BluetoothDevice bluetoothDevice, int i2) {
        String address = bluetoothDevice.getAddress();
        TargetInfoResponse deviceInfo = getDeviceInfo(bluetoothDevice);
        if (deviceInfo == null || deviceInfo.isSupportDoubleBackup()) {
            return address;
        }
        String edrAddr = i2 == 1 ? deviceInfo.getEdrAddr() : deviceInfo.getBleAddr();
        return (!BluetoothAdapter.checkBluetoothAddress(edrAddr) || edrAddr.equals(address)) ? address : edrAddr;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(final BluetoothDevice bluetoothDevice, ReconnectParam reconnectParam) {
        JL_Log.d(this.TAG, CommonUtil.formatString("-startUpgradeReConnect- device : %s, ReconnectParam = %s", printBtDeviceInfo(bluetoothDevice), reconnectParam));
        if (bluetoothDevice == null || reconnectParam == null) {
            return;
        }
        boolean isConnectedDevice = isConnectedDevice(bluetoothDevice);
        JL_Log.i(this.TAG, "-startUpgradeReConnect- isConnectedDevice = " + isConnectedDevice);
        if (!isConnectedDevice) {
            h();
            return;
        }
        boolean i2 = i(bluetoothDevice);
        JL_Log.i(this.TAG, "-startUpgradeReConnect- isBLEConnected = " + i2);
        if (i2) {
            JL_Log.d(this.TAG, "-startUpgradeReConnect- waiting for ble disconnect... ");
            h();
            return;
        }
        boolean z = isConnectedByProfile(bluetoothDevice) == 2;
        JL_Log.d(this.TAG, "-startUpgradeReConnect- isEDRConnected : " + z);
        if (!z) {
            JL_Log.d(this.TAG, "-startUpgradeReConnect- disconnectBluetoothDevice >>> ");
            disconnectBluetoothDevice(bluetoothDevice);
            return;
        }
        boolean disconnectByProfiles = disconnectByProfiles(bluetoothDevice);
        JL_Log.i(this.TAG, "-startUpgradeReConnect- disconnectEdrRet : " + disconnectByProfiles);
        if (disconnectByProfiles) {
            return;
        }
        JL_Log.i(this.TAG, "-startUpgradeReConnect- disconnect edr failed. disconnectSPPDevice.");
        disconnectBluetoothDevice(bluetoothDevice);
        this.J.postDelayed(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda8
            @Override // java.lang.Runnable
            public final void run() {
                BluetoothOTAManager.this.j(bluetoothDevice);
            }
        }, 300L);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(String str, boolean z) {
        if (a("callbackReconnectEvent")) {
            return;
        }
        JL_Log.i(this.TAG, "callbackReconnectEvent : " + str + ", " + z);
        this.y.onNeedReconnect(str, z);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, float f2) {
        if (a("callbackProgress")) {
            return;
        }
        TargetInfoResponse deviceInfo = getDeviceInfo(bluetoothDevice);
        a((deviceInfo == null || deviceInfo.isNeedBootLoader()) ? 0 : 1, f2);
    }

    private void a(int i2, float f2) {
        if (a("callbackProgress")) {
            return;
        }
        JL_Log.d(this.TAG, "callbackProgress : type = " + i2 + ", progress = " + f2);
        d(false);
        this.y.onProgress(i2, f2);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(String str, BaseError baseError) {
        if (a("callbackError") || baseError == null) {
            return;
        }
        JL_Log.e(this.TAG, CommonUtil.formatString("callbackError : %s --> %s", str, baseError));
        r();
        this.y.onError(baseError);
        this.J.postDelayed(new Runnable() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager$$ExternalSyntheticLambda0
            @Override // java.lang.Runnable
            public final void run() {
                BluetoothOTAManager.this.l();
            }
        }, 100L);
    }

    private void a(BluetoothDevice bluetoothDevice, int i2, int i3) {
        if (bluetoothDevice == null || i3 != 0) {
            return;
        }
        boolean z = true;
        if (i2 != 1 ? !(i2 != 2 || isConnectedByHfp(bluetoothDevice) == 0) : isConnectedByA2dp(bluetoothDevice) != 0) {
            z = false;
        }
        if (z && this.J.hasMessages(S)) {
            h(bluetoothDevice);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(final BluetoothDevice bluetoothDevice, byte[] bArr) {
        this.v.inquiryDeviceCanOTA(bArr, new IActionCallback<Integer>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.8
            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onError(BaseError baseError) {
                BluetoothOTAManager.this.a("upgradeStep02", baseError);
            }

            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onSuccess(Integer num) {
                BaseError buildError;
                JL_Log.i(BluetoothOTAManager.this.TAG, CommonUtil.formatString("Step2.发送升级文件校验信息，确认是否可以升级, 结果: %d", num));
                if (num.intValue() == 0) {
                    BluetoothOTAManager.this.e(bluetoothDevice);
                    return;
                }
                int intValue = num.intValue();
                if (intValue == 1) {
                    buildError = OTAError.buildError(16386);
                } else if (intValue == 2) {
                    buildError = OTAError.buildError(16387, "Command E2, result = " + num);
                } else if (intValue == 3) {
                    buildError = OTAError.buildError(ErrorCode.SUB_ERR_UPGRADE_FILE_VERSION_SAME);
                } else if (intValue == 4) {
                    buildError = OTAError.buildError(ErrorCode.SUB_ERR_TWS_NOT_CONNECT);
                } else if (intValue != 5) {
                    buildError = OTAError.buildError(16385, num.intValue(), "upgradeStep2 :: Unknown error : " + num);
                } else {
                    buildError = OTAError.buildError(ErrorCode.SUB_ERR_HEADSET_NOT_IN_CHARGING_BIN);
                }
                onError(buildError);
            }
        });
    }

    private void a(final FirmwareUpdateBlockCmd firmwareUpdateBlockCmd, final int i2, final int i3) {
        if (a("upgradeStep04")) {
            return;
        }
        u();
        if (i2 == 0 && i3 == 0) {
            JL_Log.i(this.TAG, "read data over.");
            firmwareUpdateBlockCmd.setParam(null);
            firmwareUpdateBlockCmd.setStatus(0);
            sendCommandResponse(firmwareUpdateBlockCmd);
            w();
            return;
        }
        b(i2, i3, new IActionCallback<byte[]>() { // from class: com.jieli.jl_bt_ota.impl.BluetoothOTAManager.11
            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onError(BaseError baseError) {
                BluetoothOTAManager.this.a("upgradeStep04", baseError);
            }

            @Override // com.jieli.jl_bt_ota.interfaces.IActionCallback
            public void onSuccess(byte[] bArr) {
                JL_Log.i(BluetoothOTAManager.this.TAG, "read data, offset = " + i2 + ", length = " + i3 + ", data len = " + bArr.length);
                if (bArr.length > 0) {
                    firmwareUpdateBlockCmd.setParam(new FirmwareUpdateBlockResponseParam(bArr));
                    firmwareUpdateBlockCmd.setStatus(0);
                    BluetoothOTAManager.this.sendCommandResponse(firmwareUpdateBlockCmd);
                    BluetoothOTAManager.this.t();
                    return;
                }
                BluetoothOTAManager.this.a("upgradeStep04", OTAError.buildError(16388, "offset = " + i2 + ", length = " + i3));
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, BaseError baseError) {
        JL_Log.i(this.TAG, "-callbackConnectFailed- device ：" + printBtDeviceInfo(bluetoothDevice) + " , error : " + baseError);
        c(bluetoothDevice, 2);
        a("callbackConnectFailed", baseError);
    }

    private boolean a(String str) {
        if (isOTA()) {
            return false;
        }
        JL_Log.w(this.TAG, str + ": OTA process has exited.");
        return true;
    }

    /* JADX WARN: Multi-variable type inference failed */
    private void a(BluetoothDevice bluetoothDevice, CommandBase commandBase, boolean z) {
        int id = commandBase.getId();
        if (id == 194) {
            boolean isOTA = isOTA();
            boolean hasMessages = this.J.hasMessages(R);
            JL_Log.d(this.TAG, "Receive C2 command : isOTA = " + isOTA + ", hasStopAdvNotify = " + hasMessages);
            if (!isOTA || hasMessages) {
                return;
            }
            this.J.sendEmptyMessageDelayed(R, 3000L);
            this.v.stopADVInfo(null);
            return;
        }
        if (id == 209) {
            SettingsMtuCmd settingsMtuCmd = (SettingsMtuCmd) commandBase;
            SettingsMtuParam settingsMtuParam = (SettingsMtuParam) settingsMtuCmd.getParam();
            if (settingsMtuParam == null) {
                JL_Log.d(this.TAG, "Receive D1 command : command is error.");
                if (z) {
                    settingsMtuCmd.setStatus(1);
                    sendCommandResponse(settingsMtuCmd);
                    return;
                }
                return;
            }
            int mtu = settingsMtuParam.getMtu();
            int maxCommunicationMtu = this.mDeviceStatusCache.getMaxCommunicationMtu(bluetoothDevice);
            if (mtu >= 530) {
                this.mDeviceStatusCache.updateDeviceMaxCommunicationMtu(bluetoothDevice, mtu);
            } else {
                mtu = maxCommunicationMtu;
            }
            if (z) {
                settingsMtuParam.setMtu(mtu);
                settingsMtuCmd.setStatus(0);
                sendCommandResponse(settingsMtuCmd);
                return;
            }
            return;
        }
        if (id == 229) {
            u();
            FirmwareUpdateBlockCmd firmwareUpdateBlockCmd = (FirmwareUpdateBlockCmd) commandBase;
            if (a("Receive E5 command")) {
                firmwareUpdateBlockCmd.setParam(null);
                firmwareUpdateBlockCmd.setStatus(1);
                sendCommandResponse(firmwareUpdateBlockCmd);
                return;
            }
            FirmwareUpdateBlockParam firmwareUpdateBlockParam = (FirmwareUpdateBlockParam) firmwareUpdateBlockCmd.getParam();
            if (firmwareUpdateBlockParam == null) {
                JL_Log.d(this.TAG, "Receive E5 command : command is error.");
                firmwareUpdateBlockCmd.setStatus(1);
                sendCommandResponse(firmwareUpdateBlockCmd);
                a("Receive E5 command", OTAError.buildError(12293, "E5 command"));
                return;
            }
            int nextUpdateBlockOffsetAddr = firmwareUpdateBlockParam.getNextUpdateBlockOffsetAddr();
            int nextUpdateBlockLen = firmwareUpdateBlockParam.getNextUpdateBlockLen();
            if (this.G > 0) {
                int i2 = this.H + nextUpdateBlockLen;
                this.H = i2;
                a(bluetoothDevice, a(i2));
            }
            a(firmwareUpdateBlockCmd, nextUpdateBlockOffsetAddr, nextUpdateBlockLen);
            return;
        }
        if (id != 232) {
            return;
        }
        NotifyUpdateContentSizeCmd notifyUpdateContentSizeCmd = (NotifyUpdateContentSizeCmd) commandBase;
        if (a("Receive E8 command ")) {
            notifyUpdateContentSizeCmd.setParam(null);
            notifyUpdateContentSizeCmd.setStatus(1);
            sendCommandResponse(notifyUpdateContentSizeCmd);
            return;
        }
        JL_Log.e(this.TAG, "Receive E8 command : " + notifyUpdateContentSizeCmd);
        NotifyUpdateContentSizeParam notifyUpdateContentSizeParam = (NotifyUpdateContentSizeParam) notifyUpdateContentSizeCmd.getParam();
        if (notifyUpdateContentSizeParam == null) {
            JL_Log.d(this.TAG, "Receive E8 command : command is error.");
            notifyUpdateContentSizeCmd.setStatus(1);
            sendCommandResponse(notifyUpdateContentSizeCmd);
            a("Receive E8 command", OTAError.buildError(12293, "E8 command"));
            return;
        }
        int contentSize = notifyUpdateContentSizeParam.getContentSize();
        if (contentSize >= 0) {
            this.E = CommonUtil.getCurrentTime();
            int currentProgress = notifyUpdateContentSizeParam.getCurrentProgress();
            this.H = currentProgress;
            this.G = contentSize;
            a(bluetoothDevice, a(currentProgress));
            notifyUpdateContentSizeCmd.setStatus(0);
            notifyUpdateContentSizeCmd.setParam(null);
            sendCommandResponse(notifyUpdateContentSizeCmd);
            return;
        }
        JL_Log.w(this.TAG, "Receive E8 command : length = " + contentSize);
        a("Receive E8 command", OTAError.buildError(4097, "Update content size is error. " + contentSize));
    }

    /* JADX WARN: Multi-variable type inference failed */
    private void a(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
        if (commandBase.getStatus() != 0) {
            return;
        }
        int id = commandBase.getId();
        if (id == 209) {
            SettingsMtuResponse settingsMtuResponse = (SettingsMtuResponse) ((SettingsMtuCmd) commandBase).getResponse();
            if (settingsMtuResponse != null) {
                this.mDeviceStatusCache.updateDeviceMaxCommunicationMtu(bluetoothDevice, settingsMtuResponse.getRealMtu());
                return;
            }
            return;
        }
        if (id != 227) {
            if (id != 231) {
                return;
            }
            JL_Log.e(this.TAG, "handleResponseCommand :: reboot >>> ");
            disconnectBluetoothDevice(bluetoothDevice);
            return;
        }
        EnterUpdateModeResponse enterUpdateModeResponse = (EnterUpdateModeResponse) ((EnterUpdateModeCmd) commandBase).getResponse();
        if (enterUpdateModeResponse == null || enterUpdateModeResponse.getCanUpdateFlag() != 0) {
            return;
        }
        d(bluetoothDevice);
    }
}
