package com.jieli.jl_bt_ota.tool;

import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import com.jieli.jl_bt_ota.constant.ErrorCode;
import com.jieli.jl_bt_ota.impl.BluetoothOTAManager;
import com.jieli.jl_bt_ota.interfaces.CommandCallback;
import com.jieli.jl_bt_ota.model.DataInfo;
import com.jieli.jl_bt_ota.model.OTAError;
import com.jieli.jl_bt_ota.model.base.BaseError;
import com.jieli.jl_bt_ota.model.base.BasePacket;
import com.jieli.jl_bt_ota.model.base.CommandBase;
import com.jieli.jl_bt_ota.tool.DataHandler;
import com.jieli.jl_bt_ota.util.CHexConver;
import com.jieli.jl_bt_ota.util.JL_Log;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.LinkedBlockingQueue;

/* loaded from: classes3.dex */
public class DataHandler implements IDataHandler {

    /* renamed from: e, reason: collision with root package name */
    private static final String f3386e = "DataHandler";

    /* renamed from: a, reason: collision with root package name */
    private final BluetoothOTAManager f3387a;

    /* renamed from: b, reason: collision with root package name */
    private final Handler f3388b = new Handler(Looper.getMainLooper());

    /* renamed from: c, reason: collision with root package name */
    private WorkThread f3389c;

    /* renamed from: d, reason: collision with root package name */
    private DataHandlerThread f3390d;

    /* JADX INFO: Access modifiers changed from: private */
    class DataHandlerThread extends Thread {

        /* renamed from: a, reason: collision with root package name */
        private volatile boolean f3391a;

        /* renamed from: b, reason: collision with root package name */
        private volatile boolean f3392b;

        /* renamed from: c, reason: collision with root package name */
        private ArrayList<BasePacket> f3393c;

        /* renamed from: d, reason: collision with root package name */
        private final LinkedBlockingQueue<DataInfo> f3394d;

        /* renamed from: e, reason: collision with root package name */
        private final List<DataInfo> f3395e;

        /* renamed from: f, reason: collision with root package name */
        private final List<DataInfo> f3396f;

        /* renamed from: g, reason: collision with root package name */
        private TimerThread f3397g;

        public DataHandlerThread() {
            super("DataHandlerThread");
            this.f3394d = new LinkedBlockingQueue<>();
            this.f3395e = Collections.synchronizedList(new ArrayList());
            this.f3396f = Collections.synchronizedList(new ArrayList());
        }

        private void c() {
            a();
            DataInfo d2 = d();
            if (d2 != null) {
                e(d2);
                return;
            }
            if (this.f3396f.size() > 0) {
                a(500);
            } else if (this.f3395e.size() > 0) {
                a(500);
            } else {
                e();
            }
        }

        private void d(DataInfo dataInfo) {
            final BasePacket basePacket = dataInfo.getBasePacket();
            if (basePacket == null) {
                return;
            }
            if (basePacket.getHasResponse() == 1) {
                this.f3396f.remove(dataInfo);
            } else {
                this.f3395e.remove(dataInfo);
            }
            final CommandCallback callback = dataInfo.getCallback();
            DataHandler.this.f3388b.post(new Runnable() { // from class: com.jieli.jl_bt_ota.tool.DataHandler$DataHandlerThread$$ExternalSyntheticLambda3
                @Override // java.lang.Runnable
                public final void run() {
                    DataHandler.DataHandlerThread.this.a(basePacket, callback);
                }
            });
        }

        private void e() {
            TimerThread timerThread = this.f3397g;
            if (timerThread == null || !timerThread.f3401b) {
                return;
            }
            JL_Log.i(DataHandler.f3386e, "-stopTimer- >>> ");
            this.f3397g.a();
        }

        /* JADX INFO: Access modifiers changed from: private */
        public void f() {
            if (this.f3392b) {
                synchronized (this.f3394d) {
                    if (this.f3392b) {
                        JL_Log.i(DataHandler.f3386e, "wakeUpThread:: notifyAll");
                        this.f3394d.notifyAll();
                    }
                }
            }
        }

        @Override // java.lang.Thread, java.lang.Runnable
        public void run() {
            synchronized (this.f3394d) {
                while (this.f3391a) {
                    if (this.f3394d.isEmpty()) {
                        this.f3392b = true;
                        c();
                        JL_Log.d(DataHandler.f3386e, "DataHandlerThread is waiting...");
                        try {
                            this.f3394d.wait();
                        } catch (InterruptedException e2) {
                            e2.printStackTrace();
                        }
                    } else {
                        this.f3392b = false;
                        c(this.f3394d.poll());
                        c();
                    }
                }
            }
            JL_Log.e(DataHandler.f3386e, "-DataHandlerThread- exit...");
            this.f3395e.clear();
            this.f3396f.clear();
            this.f3394d.clear();
            this.f3391a = false;
            e();
            DataHandler.this.f3390d = null;
        }

        @Override // java.lang.Thread
        public synchronized void start() {
            this.f3391a = true;
            super.start();
            JL_Log.i(DataHandler.f3386e, "DataHandlerThread start....");
        }

        public void stopThread() {
            JL_Log.w(DataHandler.f3386e, "-stopThread-");
            this.f3391a = false;
            f();
        }

        public void tryToAddRecvData(DataInfo dataInfo) {
            JL_Log.d(DataHandler.f3386e, "-tryToAddRecvData-  ret : " + a(dataInfo) + ",isWaiting = " + this.f3392b);
        }

        public void tryToAddSendData(DataInfo dataInfo) {
            JL_Log.d(DataHandler.f3386e, "-tryToAddSendData-  ret : " + a(dataInfo) + ",isWaiting = " + this.f3392b);
        }

        private int b(BluetoothDevice bluetoothDevice) {
            return DataHandler.this.f3387a.getReceiveMtu(bluetoothDevice);
        }

        private void a(int i2) {
            TimerThread timerThread = this.f3397g;
            if (timerThread != null) {
                if (timerThread.f3401b) {
                    return;
                }
                this.f3397g.f3401b = true;
            } else {
                TimerThread timerThread2 = DataHandler.this.new TimerThread(i2, new ThreadStateListener() { // from class: com.jieli.jl_bt_ota.tool.DataHandler.DataHandlerThread.1
                    @Override // com.jieli.jl_bt_ota.tool.DataHandler.ThreadStateListener
                    public void onFinish(long j2) {
                        if (DataHandlerThread.this.f3397g == null || DataHandlerThread.this.f3397g.getId() != j2) {
                            return;
                        }
                        DataHandlerThread.this.f3397g = null;
                    }

                    @Override // com.jieli.jl_bt_ota.tool.DataHandler.ThreadStateListener
                    public void onStart(long j2) {
                    }
                });
                this.f3397g = timerThread2;
                timerThread2.start();
            }
        }

        private ArrayList<DataInfo> b() {
            if (this.f3396f.size() <= 0) {
                return null;
            }
            ArrayList<DataInfo> arrayList = new ArrayList<>();
            for (DataInfo dataInfo : this.f3396f) {
                if (dataInfo.isSend()) {
                    arrayList.add(dataInfo);
                }
            }
            return arrayList;
        }

        private void e(DataInfo dataInfo) {
            byte[] packSendBasePacket = ParseHelper.packSendBasePacket(dataInfo.getBasePacket());
            if (packSendBasePacket == null) {
                JL_Log.i(DataHandler.f3386e, "send data :: pack data error.");
                d(dataInfo);
                return;
            }
            int a2 = a(dataInfo.getDevice());
            JL_Log.i(DataHandler.f3386e, "send data : [" + CHexConver.byte2HexStr(packSendBasePacket) + "], sendMtu = " + a2);
            if (packSendBasePacket.length > a2 + 8) {
                JL_Log.e(DataHandler.f3386e, "send data over communication mtu [" + a2 + "] limit.");
                d(dataInfo);
                return;
            }
            boolean z = false;
            for (int i2 = 0; i2 < 3; i2++) {
                if (DataHandler.this.f3387a != null) {
                    z = DataHandler.this.f3387a.sendDataToDevice(DataHandler.this.f3387a.getConnectedDevice(), packSendBasePacket);
                }
                if (z) {
                    break;
                }
                try {
                    Thread.sleep(10L);
                } catch (InterruptedException e2) {
                    e2.printStackTrace();
                }
            }
            JL_Log.i(DataHandler.f3386e, "send ret : " + z);
            if (!z) {
                d(dataInfo);
                return;
            }
            if (dataInfo.getBasePacket().getHasResponse() == 1) {
                dataInfo.setSend(true);
                dataInfo.setSendTime(Calendar.getInstance().getTimeInMillis());
            } else {
                final CommandCallback callback = dataInfo.getCallback();
                if (callback != null) {
                    DataHandler.this.f3388b.post(new Runnable() { // from class: com.jieli.jl_bt_ota.tool.DataHandler$DataHandlerThread$$ExternalSyntheticLambda2
                        @Override // java.lang.Runnable
                        public final void run() {
                            CommandCallback.this.onCommandResponse(null);
                        }
                    });
                }
                this.f3395e.remove(dataInfo);
            }
        }

        private void b(DataInfo dataInfo) {
            final CommandCallback callback = dataInfo.getCallback();
            DataHandler.this.f3387a.removeCacheCommand(dataInfo.getDevice(), dataInfo.getBasePacket());
            DataHandler.this.f3388b.post(new Runnable() { // from class: com.jieli.jl_bt_ota.tool.DataHandler$DataHandlerThread$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    DataHandler.DataHandlerThread.this.a(callback);
                }
            });
        }

        private DataInfo d() {
            int i2 = 0;
            if (this.f3395e.size() > 0) {
                while (i2 < this.f3395e.size()) {
                    DataInfo dataInfo = this.f3395e.get(i2);
                    if (!dataInfo.isSend()) {
                        return dataInfo;
                    }
                    i2++;
                }
            } else if (this.f3396f.size() > 0) {
                while (i2 < this.f3396f.size()) {
                    DataInfo dataInfo2 = this.f3396f.get(i2);
                    if (!dataInfo2.isSend()) {
                        return dataInfo2;
                    }
                    i2++;
                }
            }
            return null;
        }

        private void c(DataInfo dataInfo) {
            if (dataInfo != null) {
                if (dataInfo.getType() == 1) {
                    ArrayList<BasePacket> findPacketData = ParseHelper.findPacketData(dataInfo.getDevice(), b(dataInfo.getDevice()), dataInfo.getRecvData());
                    if (findPacketData != null) {
                        ArrayList<BasePacket> arrayList = this.f3393c;
                        if (arrayList != null && arrayList.size() != 0) {
                            this.f3393c.addAll(findPacketData);
                        } else {
                            this.f3393c = findPacketData;
                        }
                        Iterator<BasePacket> it2 = findPacketData.iterator();
                        while (it2.hasNext()) {
                            JL_Log.d(DataHandler.f3386e, "-handlerQueue- opCode : " + it2.next().getOpCode());
                        }
                        f();
                        return;
                    }
                    JL_Log.e(DataHandler.f3386e, "-handlerQueue- findPacketData not found. ");
                    return;
                }
                if (dataInfo.getBasePacket() != null) {
                    if (dataInfo.getBasePacket().getHasResponse() == 1) {
                        if (this.f3396f.size() < 30) {
                            this.f3396f.add(dataInfo);
                            return;
                        } else {
                            JL_Log.i(DataHandler.f3386e, "-handlerQueue- haveResponseDataList is busy. ");
                            DataHandler.this.f3387a.errorEventCallback(OTAError.buildError(12291));
                            return;
                        }
                    }
                    if (this.f3395e.size() < 60) {
                        this.f3395e.add(dataInfo);
                    } else {
                        JL_Log.i(DataHandler.f3386e, "-handlerQueue- noResponseDataList is busy. ");
                        DataHandler.this.f3387a.errorEventCallback(OTAError.buildError(12291));
                    }
                }
            }
        }

        private int a(BluetoothDevice bluetoothDevice) {
            return DataHandler.this.f3387a.getCommunicationMtu(bluetoothDevice);
        }

        /* JADX INFO: Access modifiers changed from: private */
        public /* synthetic */ void a(BasePacket basePacket, CommandCallback commandCallback) {
            BaseError buildError = OTAError.buildError(12290);
            buildError.setOpCode(basePacket.getOpCode());
            if (commandCallback != null) {
                commandCallback.onErrCode(buildError);
            }
            DataHandler.this.f3387a.errorEventCallback(buildError);
        }

        /* JADX WARN: Removed duplicated region for block: B:4:0x0014  */
        /*
            Code decompiled incorrectly, please refer to instructions dump.
            To view partially-correct code enable 'Show inconsistent code' option in preferences
        */
        private boolean a(com.jieli.jl_bt_ota.model.DataInfo r5) {
            /*
                r4 = this;
                if (r5 == 0) goto L11
                java.util.concurrent.LinkedBlockingQueue<com.jieli.jl_bt_ota.model.DataInfo> r0 = r4.f3394d     // Catch: java.lang.InterruptedException -> Ld
                java.util.concurrent.TimeUnit r1 = java.util.concurrent.TimeUnit.SECONDS     // Catch: java.lang.InterruptedException -> Ld
                r2 = 3
                boolean r5 = r0.offer(r5, r2, r1)     // Catch: java.lang.InterruptedException -> Ld
                goto L12
            Ld:
                r5 = move-exception
                r5.printStackTrace()
            L11:
                r5 = 0
            L12:
                if (r5 == 0) goto L17
                r4.f()
            L17:
                return r5
            */
            throw new UnsupportedOperationException("Method not decompiled: com.jieli.jl_bt_ota.tool.DataHandler.DataHandlerThread.a(com.jieli.jl_bt_ota.model.DataInfo):boolean");
        }

        private void a() {
            ArrayList<BasePacket> arrayList = new ArrayList<>();
            ArrayList<BasePacket> arrayList2 = this.f3393c;
            if (arrayList2 != null && arrayList2.size() > 0) {
                ArrayList arrayList3 = new ArrayList();
                ArrayList arrayList4 = new ArrayList();
                Iterator it2 = new ArrayList(this.f3393c).iterator();
                while (it2.hasNext()) {
                    BasePacket basePacket = (BasePacket) it2.next();
                    byte[] packSendBasePacket = ParseHelper.packSendBasePacket(basePacket);
                    if (packSendBasePacket != null) {
                        if (DataHandler.this.f3387a != null) {
                            DataHandler.this.f3387a.receiveDataFromDevice(DataHandler.this.f3387a.getConnectedDevice(), packSendBasePacket);
                        }
                        if (basePacket.getType() == 1) {
                            arrayList3.add(basePacket);
                        } else {
                            arrayList.add(basePacket);
                        }
                    } else {
                        arrayList4.add(basePacket);
                    }
                }
                if (!arrayList3.isEmpty()) {
                    this.f3393c.removeAll(arrayList3);
                }
                if (arrayList4.size() > 0) {
                    this.f3393c.removeAll(arrayList4);
                }
                a(arrayList);
                return;
            }
            a((ArrayList<BasePacket>) null);
        }

        private void a(ArrayList<BasePacket> arrayList) {
            String str;
            ArrayList<DataInfo> arrayList2;
            int i2;
            ArrayList<DataInfo> arrayList3;
            if (this.f3396f.size() > 0) {
                ArrayList<DataInfo> b2 = b();
                StringBuilder sb = new StringBuilder("-checkHaveResponseList- waitList size : ");
                sb.append(b2 == null ? 0 : b2.size());
                JL_Log.w(DataHandler.f3386e, sb.toString());
                if (b2 == null || b2.size() <= 0) {
                    return;
                }
                ArrayList arrayList4 = new ArrayList();
                ArrayList arrayList5 = new ArrayList();
                long timeInMillis = Calendar.getInstance().getTimeInMillis();
                String str2 = ", data : ";
                if (arrayList == null || arrayList.size() <= 0) {
                    str = ", data : ";
                    arrayList2 = b2;
                    i2 = 500;
                } else {
                    Iterator<BasePacket> it2 = arrayList.iterator();
                    while (it2.hasNext()) {
                        final BasePacket next = it2.next();
                        JL_Log.w(DataHandler.f3386e, "-checkHaveResponseList- opCode : " + next.getOpCode() + ", sn : " + next.getOpCodeSn());
                        Iterator<DataInfo> it3 = b2.iterator();
                        while (true) {
                            if (!it3.hasNext()) {
                                break;
                            }
                            final DataInfo next2 = it3.next();
                            final BasePacket basePacket = next2.getBasePacket();
                            if (basePacket != null) {
                                JL_Log.w(DataHandler.f3386e, "-checkHaveResponseList- packet opCode : " + basePacket.getOpCode() + ", packet sn : " + basePacket.getOpCodeSn());
                            }
                            if (basePacket != null && basePacket.getOpCode() == next.getOpCode() && basePacket.getOpCodeSn() == next.getOpCodeSn()) {
                                JL_Log.w(DataHandler.f3386e, "-checkHaveResponseList- callback");
                                final CommandCallback callback = next2.getCallback();
                                DataHandler.this.f3388b.post(new Runnable() { // from class: com.jieli.jl_bt_ota.tool.DataHandler$DataHandlerThread$$ExternalSyntheticLambda1
                                    @Override // java.lang.Runnable
                                    public final void run() {
                                        DataHandler.DataHandlerThread.this.a(callback, next, next2, basePacket);
                                    }
                                });
                                arrayList4.add(next);
                                arrayList5.add(next2);
                                b2 = b2;
                                str2 = str2;
                                break;
                            }
                            BasePacket basePacket2 = next;
                            String str3 = str2;
                            ArrayList<DataInfo> arrayList6 = b2;
                            if (next2.getTimeoutMs() < 500) {
                                next2.setTimeoutMs(500);
                            }
                            if (timeInMillis - next2.getSendTime() > next2.getTimeoutMs()) {
                                int reSendCount = next2.getReSendCount();
                                JL_Log.e(DataHandler.f3386e, "wait for response timeout !!! reSend count : " + reSendCount + str3 + next2);
                                if (reSendCount >= 3) {
                                    JL_Log.e(DataHandler.f3386e, "retry count over time, callbackTimeOutError.");
                                    b(next2);
                                    arrayList4.add(basePacket2);
                                    arrayList5.add(next2);
                                } else {
                                    next2.setReSendCount(reSendCount + 1);
                                    next2.setSend(false);
                                }
                                str2 = str3;
                                next = basePacket2;
                                b2 = arrayList6;
                            } else {
                                next = basePacket2;
                                b2 = arrayList6;
                                str2 = str3;
                            }
                        }
                    }
                    str = str2;
                    arrayList2 = b2;
                    i2 = 500;
                    if (arrayList4.size() > 0 && this.f3393c != null) {
                        arrayList.removeAll(arrayList4);
                        this.f3393c.removeAll(arrayList4);
                    }
                    if (arrayList.size() > 0 && this.f3393c != null) {
                        JL_Log.e(DataHandler.f3386e, "-checkHaveResponseList- remove unused response.");
                        this.f3393c.removeAll(arrayList);
                    }
                    if (arrayList5.size() > 0) {
                        this.f3396f.removeAll(arrayList5);
                        arrayList5.clear();
                        arrayList3 = b();
                        if (arrayList3 != null || arrayList3.size() <= 0) {
                            return;
                        }
                        Iterator<DataInfo> it4 = arrayList3.iterator();
                        while (it4.hasNext()) {
                            DataInfo next3 = it4.next();
                            if (next3.getTimeoutMs() < i2) {
                                next3.setTimeoutMs(i2);
                            }
                            if (timeInMillis - next3.getSendTime() > next3.getTimeoutMs()) {
                                int reSendCount2 = next3.getReSendCount();
                                JL_Log.e(DataHandler.f3386e, "wait for response timeout 222222 !!! reSend count : " + reSendCount2 + str + next3);
                                if (reSendCount2 >= 3) {
                                    JL_Log.e(DataHandler.f3386e, "retry count over time 222222, callbackTimeOutError.");
                                    b(next3);
                                    arrayList5.add(next3);
                                } else {
                                    next3.setReSendCount(reSendCount2 + 1);
                                    next3.setSend(false);
                                }
                            }
                        }
                        if (arrayList5.size() > 0) {
                            this.f3396f.removeAll(arrayList5);
                            return;
                        }
                        return;
                    }
                }
                arrayList3 = arrayList2;
                if (arrayList3 != null) {
                    return;
                } else {
                    return;
                }
            }
            if (arrayList == null || arrayList.size() <= 0 || this.f3393c == null) {
                return;
            }
            JL_Log.e(DataHandler.f3386e, "-checkHaveResponseList- 22222 remove unused response.");
            this.f3393c.removeAll(arrayList);
        }

        /* JADX INFO: Access modifiers changed from: private */
        public /* synthetic */ void a(CommandCallback commandCallback, BasePacket basePacket, DataInfo dataInfo, BasePacket basePacket2) {
            if (commandCallback != null) {
                CommandBase convert2Command = ParseHelper.convert2Command(basePacket, DataHandler.this.f3387a.getCacheCommand(dataInfo.getDevice(), basePacket));
                if (convert2Command == null) {
                    commandCallback.onErrCode(OTAError.buildError(12293));
                } else {
                    commandCallback.onCommandResponse(convert2Command);
                }
            }
            DataHandler.this.f3387a.removeCacheCommand(dataInfo.getDevice(), basePacket2);
        }

        /* JADX INFO: Access modifiers changed from: private */
        public /* synthetic */ void a(CommandCallback commandCallback) {
            BaseError buildError = OTAError.buildError(ErrorCode.SUB_ERR_SEND_TIMEOUT);
            if (commandCallback != null) {
                commandCallback.onErrCode(buildError);
            }
            DataHandler.this.f3387a.errorEventCallback(buildError);
        }
    }

    public interface ThreadStateListener {
        void onFinish(long j2);

        void onStart(long j2);
    }

    private class TimerThread extends Thread {

        /* renamed from: a, reason: collision with root package name */
        private final long f3400a;

        /* renamed from: b, reason: collision with root package name */
        private volatile boolean f3401b;

        /* renamed from: c, reason: collision with root package name */
        private final ThreadStateListener f3402c;

        TimerThread(long j2, ThreadStateListener threadStateListener) {
            super("TimerThread");
            this.f3400a = j2;
            this.f3402c = threadStateListener;
        }

        @Override // java.lang.Thread, java.lang.Runnable
        public void run() {
            while (this.f3401b) {
                try {
                    Thread.sleep(this.f3400a);
                } catch (InterruptedException e2) {
                    e2.printStackTrace();
                }
                if (DataHandler.this.f3390d == null) {
                    break;
                } else {
                    DataHandler.this.f3390d.f();
                }
            }
            this.f3401b = false;
            JL_Log.w(DataHandler.f3386e, "TimerThread is end....name : " + getName());
            ThreadStateListener threadStateListener = this.f3402c;
            if (threadStateListener != null) {
                threadStateListener.onFinish(getId());
            }
        }

        @Override // java.lang.Thread
        public synchronized void start() {
            this.f3401b = true;
            super.start();
            JL_Log.w(DataHandler.f3386e, "TimerThread is start....name : " + getName());
            ThreadStateListener threadStateListener = this.f3402c;
            if (threadStateListener != null) {
                threadStateListener.onStart(getId());
            }
        }

        synchronized void a() {
            this.f3401b = false;
        }
    }

    public class WorkThread extends HandlerThread implements Handler.Callback {

        /* renamed from: c, reason: collision with root package name */
        private static final int f3404c = 1;

        /* renamed from: d, reason: collision with root package name */
        private static final int f3405d = 2;

        /* renamed from: a, reason: collision with root package name */
        private Handler f3406a;

        public WorkThread(String str) {
            super(str, 10);
        }

        public Handler getWorkHandler() {
            if (this.f3406a == null) {
                this.f3406a = new Handler(getLooper(), this);
            }
            return this.f3406a;
        }

        @Override // android.os.Handler.Callback
        public boolean handleMessage(Message message) {
            int i2 = message.what;
            if (i2 == 1) {
                DataInfo dataInfo = (DataInfo) message.obj;
                if (DataHandler.this.f3390d == null) {
                    return false;
                }
                DataHandler.this.f3390d.tryToAddSendData(dataInfo);
                return false;
            }
            if (i2 != 2) {
                return false;
            }
            DataInfo dataInfo2 = (DataInfo) message.obj;
            if (DataHandler.this.f3390d == null || dataInfo2 == null) {
                return false;
            }
            DataHandler.this.f3390d.tryToAddRecvData(dataInfo2);
            return false;
        }

        @Override // android.os.HandlerThread
        protected void onLooperPrepared() {
            super.onLooperPrepared();
            this.f3406a = new Handler(getLooper(), this);
        }

        public void tryToAddRecvData(DataInfo dataInfo) {
            if (this.f3406a == null) {
                this.f3406a = new Handler(getLooper(), this);
            }
            Message obtainMessage = this.f3406a.obtainMessage();
            obtainMessage.what = 2;
            obtainMessage.obj = dataInfo;
            this.f3406a.sendMessage(obtainMessage);
        }

        public void tryToAddSendData(DataInfo dataInfo) {
            if (this.f3406a == null) {
                this.f3406a = new Handler(getLooper(), this);
            }
            Message obtainMessage = this.f3406a.obtainMessage();
            obtainMessage.what = 1;
            obtainMessage.obj = dataInfo;
            this.f3406a.sendMessage(obtainMessage);
        }
    }

    public DataHandler(BluetoothOTAManager bluetoothOTAManager) {
        this.f3387a = bluetoothOTAManager;
        a();
    }

    private void d() {
        WorkThread workThread = this.f3389c;
        if (workThread != null) {
            workThread.quitSafely();
            this.f3389c = null;
        }
    }

    @Override // com.jieli.jl_bt_ota.tool.IDataHandler
    public void addRecvData(DataInfo dataInfo) {
        if (this.f3389c == null) {
            a();
        }
        this.f3389c.tryToAddRecvData(dataInfo);
    }

    @Override // com.jieli.jl_bt_ota.tool.IDataHandler
    public void addSendData(DataInfo dataInfo) {
        if (this.f3389c == null) {
            a();
        }
        this.f3389c.tryToAddSendData(dataInfo);
    }

    @Override // com.jieli.jl_bt_ota.tool.IDataHandler
    public void release() {
        JL_Log.e(f3386e, "-release-");
        c();
    }

    private void b() {
        if (this.f3389c == null) {
            this.f3389c = new WorkThread("Work_Thread");
        }
        this.f3389c.start();
    }

    private void c() {
        DataHandlerThread dataHandlerThread = this.f3390d;
        if (dataHandlerThread != null) {
            dataHandlerThread.stopThread();
        }
        d();
    }

    private void a() {
        if (this.f3390d == null) {
            DataHandlerThread dataHandlerThread = new DataHandlerThread();
            this.f3390d = dataHandlerThread;
            dataHandlerThread.start();
            b();
        }
    }
}
