package com.jieli.jl_bt_ota.tool;

import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import com.jieli.jl_bt_ota.constant.ErrorCode;
import com.jieli.jl_bt_ota.impl.BluetoothOTAManager;
import com.jieli.jl_bt_ota.model.DataInfo;
import com.jieli.jl_bt_ota.model.OTAError;
import com.jieli.jl_bt_ota.model.base.BaseError;
import com.jieli.jl_bt_ota.model.base.BasePacket;
import com.jieli.jl_bt_ota.model.base.CommandBase;
import com.jieli.jl_bt_ota.util.CHexConver;
import com.jieli.jl_bt_ota.util.JL_Log;
import java.util.ArrayList;
import java.util.Iterator;

/* loaded from: classes3.dex */
public class DataHandlerModify implements IDataHandler {

    /* renamed from: b, reason: collision with root package name */
    private final BluetoothOTAManager f3409b;

    /* renamed from: c, reason: collision with root package name */
    private final RcspParser f3410c;

    /* renamed from: e, reason: collision with root package name */
    private final HandlerThread f3412e;

    /* renamed from: f, reason: collision with root package name */
    private final Handler f3413f;

    /* renamed from: g, reason: collision with root package name */
    private final Handler f3414g;

    /* renamed from: a, reason: collision with root package name */
    private final String f3408a = "DataHandlerModify";

    /* renamed from: d, reason: collision with root package name */
    private final DataInfoCache f3411d = new DataInfoCache();

    private class TimeOutCheck implements Runnable {

        /* renamed from: a, reason: collision with root package name */
        private final DataInfo f3415a;

        public TimeOutCheck(DataInfo dataInfo) {
            this.f3415a = dataInfo;
            dataInfo.setSendTime(System.currentTimeMillis());
        }

        @Override // java.lang.Runnable
        public void run() {
            JL_Log.w(DataHandlerModify.this.f3408a, "send data timeout  --> " + this.f3415a);
            if (this.f3415a.getReSendCount() < 3) {
                DataInfo dataInfo = this.f3415a;
                dataInfo.setReSendCount(dataInfo.getReSendCount() + 1);
                DataHandlerModify.this.f3411d.remove(this.f3415a);
                DataHandlerModify.this.addSendData(this.f3415a);
                return;
            }
            DataHandlerModify.this.f3411d.remove(this.f3415a);
            DataHandlerModify.this.f3409b.removeCacheCommand(this.f3415a.getDevice(), this.f3415a.getBasePacket());
            DataHandlerModify.this.a(this.f3415a, OTAError.buildError(ErrorCode.SUB_ERR_SEND_TIMEOUT));
        }
    }

    public DataHandlerModify(BluetoothOTAManager bluetoothOTAManager) {
        HandlerThread handlerThread = new HandlerThread("DataHandlerModify");
        this.f3412e = handlerThread;
        this.f3414g = new Handler(Looper.getMainLooper());
        this.f3409b = bluetoothOTAManager;
        this.f3410c = new RcspParser();
        handlerThread.start();
        this.f3413f = new Handler(handlerThread.getLooper(), new Handler.Callback() { // from class: com.jieli.jl_bt_ota.tool.DataHandlerModify$$ExternalSyntheticLambda1
            @Override // android.os.Handler.Callback
            public final boolean handleMessage(Message message) {
                boolean a2;
                a2 = DataHandlerModify.a(message);
                return a2;
            }
        });
    }

    private int d(DataInfo dataInfo) {
        if (dataInfo == null) {
            return Integer.MAX_VALUE;
        }
        return dataInfo.getBasePacket().getOpCode() | (dataInfo.getBasePacket().getOpCodeSn() << 16);
    }

    @Override // com.jieli.jl_bt_ota.tool.IDataHandler
    public void addRecvData(final DataInfo dataInfo) {
        this.f3413f.post(new Runnable() { // from class: com.jieli.jl_bt_ota.tool.DataHandlerModify$$ExternalSyntheticLambda2
            @Override // java.lang.Runnable
            public final void run() {
                DataHandlerModify.this.a(dataInfo);
            }
        });
    }

    @Override // com.jieli.jl_bt_ota.tool.IDataHandler
    public void addSendData(final DataInfo dataInfo) {
        dataInfo.setSendTime(a());
        this.f3413f.post(new Runnable() { // from class: com.jieli.jl_bt_ota.tool.DataHandlerModify$$ExternalSyntheticLambda3
            @Override // java.lang.Runnable
            public final void run() {
                DataHandlerModify.this.b(dataInfo);
            }
        });
    }

    @Override // com.jieli.jl_bt_ota.tool.IDataHandler
    public void release() {
        this.f3413f.removeCallbacksAndMessages(null);
        this.f3410c.release();
        this.f3411d.clear();
        if (this.f3412e.isInterrupted()) {
            return;
        }
        this.f3412e.quitSafely();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void b(DataInfo dataInfo) {
        if (!c(dataInfo)) {
            a(dataInfo, OTAError.buildError(12290));
            return;
        }
        if (dataInfo.getBasePacket().getHasResponse() == 1) {
            this.f3411d.add(dataInfo);
            Handler handler = this.f3413f;
            handler.sendMessageDelayed(handler.obtainMessage(d(dataInfo), new TimeOutCheck(dataInfo)), dataInfo.getTimeoutMs());
            return;
        }
        BasePacket basePacket = dataInfo.getBasePacket();
        int opCodeSn = basePacket.getOpCodeSn();
        basePacket.setOpCodeSn(256);
        CommandBase convert2Command = ParseHelper.convert2Command(basePacket, this.f3409b.getCacheCommand(dataInfo.getDevice(), basePacket));
        if (convert2Command != null) {
            convert2Command.setOpCodeSn(opCodeSn);
        }
        a(dataInfo, convert2Command);
    }

    private boolean c(DataInfo dataInfo) {
        byte[] packSendBasePacket = ParseHelper.packSendBasePacket(dataInfo.getBasePacket());
        if (packSendBasePacket == null) {
            JL_Log.i(this.f3408a, "send data :: pack data error.");
            return false;
        }
        int a2 = a(dataInfo.getDevice());
        if (packSendBasePacket.length > a2) {
            JL_Log.e(this.f3408a, "send data over communication mtu [" + a2 + "] limit.");
            return false;
        }
        boolean z = false;
        for (int i2 = 0; i2 < 3 && !(z = this.f3409b.sendDataToDevice(dataInfo.getDevice(), packSendBasePacket)); i2++) {
            try {
                Thread.sleep(10L);
            } catch (InterruptedException e2) {
                e2.printStackTrace();
            }
        }
        JL_Log.i(this.f3408a, "send ret : " + z);
        return z;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static /* synthetic */ boolean a(Message message) {
        Object obj = message.obj;
        if (!(obj instanceof Runnable)) {
            return true;
        }
        ((Runnable) obj).run();
        return true;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(DataInfo dataInfo) {
        ArrayList<BasePacket> findPacketData = this.f3410c.findPacketData(b(dataInfo.getDevice()), dataInfo.getRecvData());
        if (findPacketData != null && !findPacketData.isEmpty()) {
            Iterator<BasePacket> it2 = findPacketData.iterator();
            while (it2.hasNext()) {
                BasePacket next = it2.next();
                byte[] packSendBasePacket = ParseHelper.packSendBasePacket(next);
                if (next.getType() == 1) {
                    this.f3409b.receiveDataFromDevice(dataInfo.getDevice(), packSendBasePacket);
                } else {
                    DataInfo dataInfo2 = this.f3411d.getDataInfo(next);
                    if (dataInfo2 == null) {
                        JL_Log.w(this.f3408a, "addRecvData : not found cache data info. " + next);
                    } else {
                        CommandBase convert2Command = ParseHelper.convert2Command(next, this.f3409b.getCacheCommand(dataInfo.getDevice(), next));
                        if (convert2Command == null) {
                            BaseError buildError = OTAError.buildError(12293);
                            buildError.setOpCode(next.getOpCode());
                            a(dataInfo2, buildError);
                        } else {
                            this.f3409b.receiveDataFromDevice(dataInfo.getDevice(), packSendBasePacket);
                        }
                        this.f3411d.remove(dataInfo2);
                        this.f3413f.removeMessages(d(dataInfo2));
                        a(dataInfo2, convert2Command);
                        this.f3409b.removeCacheCommand(dataInfo.getDevice(), next);
                    }
                }
            }
            return;
        }
        JL_Log.w(this.f3408a, "addRecvData : not found cmd. " + CHexConver.byte2HexStr(dataInfo.getRecvData()));
    }

    private int b(BluetoothDevice bluetoothDevice) {
        return this.f3409b.getReceiveMtu(bluetoothDevice);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void b(DataInfo dataInfo, BaseError baseError) {
        if (dataInfo.getCallback() != null) {
            dataInfo.getCallback().onErrCode(baseError);
        }
        this.f3409b.errorEventCallback(baseError);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static /* synthetic */ void b(DataInfo dataInfo, CommandBase commandBase) {
        dataInfo.getCallback().onCommandResponse(commandBase);
    }

    private long a() {
        return System.currentTimeMillis();
    }

    private int a(BluetoothDevice bluetoothDevice) {
        return this.f3409b.getCommunicationMtu(bluetoothDevice);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(final DataInfo dataInfo, final BaseError baseError) {
        if (dataInfo == null) {
            JL_Log.d(this.f3408a, "callError : param is null");
            return;
        }
        if (dataInfo.getBasePacket() != null) {
            baseError.setOpCode(dataInfo.getBasePacket().getOpCode());
        }
        JL_Log.w(this.f3408a, "callError : " + baseError);
        this.f3414g.post(new Runnable() { // from class: com.jieli.jl_bt_ota.tool.DataHandlerModify$$ExternalSyntheticLambda4
            @Override // java.lang.Runnable
            public final void run() {
                DataHandlerModify.this.b(dataInfo, baseError);
            }
        });
    }

    private void a(final DataInfo dataInfo, final CommandBase commandBase) {
        if (dataInfo != null && dataInfo.getCallback() != null && commandBase != null) {
            this.f3414g.post(new Runnable() { // from class: com.jieli.jl_bt_ota.tool.DataHandlerModify$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    DataHandlerModify.b(DataInfo.this, commandBase);
                }
            });
            return;
        }
        JL_Log.d(this.f3408a, " callbackCmd : param is null. " + dataInfo);
    }
}
