package com.jieli.jl_bt_ota.tool;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.os.SystemClock;
import com.jieli.jl_bt_ota.constant.ErrorCode;
import com.jieli.jl_bt_ota.constant.JL_Constant;
import com.jieli.jl_bt_ota.impl.BluetoothOTAManager;
import com.jieli.jl_bt_ota.interfaces.BtEventCallback;
import com.jieli.jl_bt_ota.model.BleScanMessage;
import com.jieli.jl_bt_ota.model.OTAError;
import com.jieli.jl_bt_ota.model.ReConnectDevMsg;
import com.jieli.jl_bt_ota.model.base.BaseError;
import com.jieli.jl_bt_ota.util.BluetoothUtil;
import com.jieli.jl_bt_ota.util.CHexConver;
import com.jieli.jl_bt_ota.util.CommonUtil;
import com.jieli.jl_bt_ota.util.JL_Log;
import com.jieli.jl_bt_ota.util.ParseDataUtil;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* loaded from: classes3.dex */
public class DeviceReConnectManager {
    public static long RECONNECT_TIMEOUT = 65000;

    /* renamed from: h, reason: collision with root package name */
    private static final String f3417h = "DeviceReConnectManager";

    /* renamed from: i, reason: collision with root package name */
    private static final int f3418i = 3000;

    /* renamed from: j, reason: collision with root package name */
    private static final int f3419j = 20000;
    private static final int k = 2;
    private static final int l = 30000;
    private static final int m = 2000;
    private static final int n = 37973;
    private static final int o = 37974;
    private static final int p = 37975;

    /* renamed from: a, reason: collision with root package name */
    private final Context f3420a;

    /* renamed from: b, reason: collision with root package name */
    private final BluetoothOTAManager f3421b;

    /* renamed from: c, reason: collision with root package name */
    private volatile ReConnectDevMsg f3422c;

    /* renamed from: d, reason: collision with root package name */
    private long f3423d = 0;

    /* renamed from: e, reason: collision with root package name */
    private final Map<String, BleScanMessage> f3424e = new HashMap();

    /* renamed from: f, reason: collision with root package name */
    private final Handler f3425f = new Handler(Looper.getMainLooper(), new Handler.Callback() { // from class: com.jieli.jl_bt_ota.tool.DeviceReConnectManager.1
        @Override // android.os.Handler.Callback
        public boolean handleMessage(Message message) {
            switch (message.what) {
                case DeviceReConnectManager.n /* 37973 */:
                    DeviceReConnectManager.this.b();
                    break;
                case DeviceReConnectManager.o /* 37974 */:
                    JL_Log.w(DeviceReConnectManager.f3417h, "MSG_RECONNECT_DEVICE_TIMEOUT >>>>> " + DeviceReConnectManager.this.f3422c);
                    if (DeviceReConnectManager.this.f3422c != null) {
                        DeviceReConnectManager.this.f3422c.setState(0);
                        DeviceReConnectManager deviceReConnectManager = DeviceReConnectManager.this;
                        deviceReConnectManager.a(OTAError.buildError(ErrorCode.SUB_ERR_RECONNECT_TIMEOUT, deviceReConnectManager.f3422c.toString()));
                        break;
                    }
                    break;
                case DeviceReConnectManager.p /* 37975 */:
                    JL_Log.w(DeviceReConnectManager.f3417h, "MSG_CONNECT_DEVICE_TIMEOUT >>>>> " + DeviceReConnectManager.this.f3422c);
                    if (DeviceReConnectManager.this.f3422c != null) {
                        DeviceReConnectManager.this.f3422c.setState(0);
                        DeviceReConnectManager deviceReConnectManager2 = DeviceReConnectManager.this;
                        deviceReConnectManager2.a(deviceReConnectManager2.f3422c.getAddress());
                        break;
                    }
                    break;
            }
            return true;
        }
    });

    /* renamed from: g, reason: collision with root package name */
    private final BtEventCallback f3426g;

    public DeviceReConnectManager(Context context, BluetoothOTAManager bluetoothOTAManager) {
        BtEventCallback btEventCallback = new BtEventCallback() { // from class: com.jieli.jl_bt_ota.tool.DeviceReConnectManager.2
            @Override // com.jieli.jl_bt_ota.interfaces.BtEventCallback, com.jieli.jl_bt_ota.interfaces.IBluetoothCallback
            public void onAdapterStatus(boolean z, boolean z2) {
                if (z || !DeviceReConnectManager.this.isDeviceReconnecting()) {
                    return;
                }
                JL_Log.d(DeviceReConnectManager.f3417h, "onAdapterStatus : bluetooth close.");
            }

            @Override // com.jieli.jl_bt_ota.interfaces.BtEventCallback, com.jieli.jl_bt_ota.interfaces.IBluetoothCallback
            public void onConnection(BluetoothDevice bluetoothDevice, int i2) {
                byte[] bArr;
                if (bluetoothDevice == null || !DeviceReConnectManager.this.isDeviceReconnecting() || i2 == 3) {
                    return;
                }
                boolean z = DeviceReConnectManager.this.f3425f.hasMessages(DeviceReConnectManager.p) || DeviceReConnectManager.this.f();
                JL_Log.d(DeviceReConnectManager.f3417h, "-onConnection- isConnecting: " + z + ", status = " + i2);
                if (z) {
                    BleScanMessage bleScanMessage = (BleScanMessage) DeviceReConnectManager.this.f3424e.get(bluetoothDevice.getAddress());
                    if (bleScanMessage != null) {
                        JL_Log.d(DeviceReConnectManager.f3417h, "-onConnection- bleScanMessage: " + bleScanMessage);
                        bArr = bleScanMessage.getRawData();
                    } else {
                        bArr = null;
                    }
                    boolean a2 = DeviceReConnectManager.this.a(bluetoothDevice, bArr);
                    JL_Log.w(DeviceReConnectManager.f3417h, CommonUtil.formatString("-onConnection- device : %s, status : %d, isReConnectDevice : %s", DeviceReConnectManager.this.b(bluetoothDevice), Integer.valueOf(i2), Boolean.valueOf(a2)));
                    if (a2) {
                        if (DeviceReConnectManager.this.f3422c != null) {
                            DeviceReConnectManager.this.f3422c.setState(0);
                        }
                        DeviceReConnectManager.this.f3425f.removeMessages(DeviceReConnectManager.p);
                        if (i2 == 1 || i2 == 4) {
                            JL_Log.d(DeviceReConnectManager.f3417h, "-onConnection- reconnect device success.");
                            DeviceReConnectManager.this.stopReconnectTask();
                        } else if (i2 == 2 || i2 == 0) {
                            JL_Log.i(DeviceReConnectManager.f3417h, "-onConnection- connect device failed.");
                            DeviceReConnectManager.this.a(bluetoothDevice.getAddress());
                        }
                    }
                }
            }

            @Override // com.jieli.jl_bt_ota.interfaces.BtEventCallback, com.jieli.jl_bt_ota.interfaces.IBluetoothCallback
            public void onDiscovery(BluetoothDevice bluetoothDevice, BleScanMessage bleScanMessage) {
                byte[] bArr;
                if (bluetoothDevice == null || !DeviceReConnectManager.this.isDeviceReconnecting()) {
                    return;
                }
                if (bleScanMessage != null) {
                    DeviceReConnectManager.this.f3424e.put(bluetoothDevice.getAddress(), bleScanMessage);
                    bArr = bleScanMessage.getRawData();
                } else {
                    bArr = null;
                }
                boolean a2 = DeviceReConnectManager.this.a(bluetoothDevice, bArr);
                JL_Log.i(DeviceReConnectManager.f3417h, CommonUtil.formatString("-onDiscovery- isReConnectDevice : %s, device : %s", Boolean.valueOf(a2), DeviceReConnectManager.this.b(bluetoothDevice)));
                if (a2) {
                    DeviceReConnectManager.this.a(bluetoothDevice);
                    DeviceReConnectManager.this.h();
                }
            }

            @Override // com.jieli.jl_bt_ota.interfaces.BtEventCallback, com.jieli.jl_bt_ota.interfaces.IBluetoothCallback
            public void onDiscoveryStatus(boolean z, boolean z2) {
                JL_Log.d(DeviceReConnectManager.f3417h, "onDiscoveryStatus : " + z2);
                if (!DeviceReConnectManager.this.isDeviceReconnecting() || DeviceReConnectManager.this.f()) {
                    return;
                }
                if (!z2) {
                    JL_Log.d(DeviceReConnectManager.f3417h, "onDiscoveryStatus : ready start scan");
                    DeviceReConnectManager.this.f3425f.removeMessages(DeviceReConnectManager.n);
                    DeviceReConnectManager.this.f3425f.sendEmptyMessageDelayed(DeviceReConnectManager.n, 1000L);
                } else {
                    if (DeviceReConnectManager.this.f3422c == null || DeviceReConnectManager.this.f3422c.getState() != 0) {
                        return;
                    }
                    DeviceReConnectManager.this.f3422c.setState(1);
                }
            }
        };
        this.f3426g = btEventCallback;
        this.f3420a = context;
        this.f3421b = bluetoothOTAManager;
        bluetoothOTAManager.registerBluetoothCallback(btEventCallback);
    }

    private boolean g() {
        BluetoothOTAManager bluetoothOTAManager = this.f3421b;
        return (bluetoothOTAManager == null || bluetoothOTAManager.getConnectedDevice() == null) ? false : true;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void h() {
        JL_Log.d(f3417h, "-stopScan- >>>>>>stopBLEScan ");
        this.f3421b.stopBLEScan();
        this.f3421b.stopDeviceScan();
    }

    public String getReconnectAddress() {
        ReConnectDevMsg e2 = e();
        if (e2 == null) {
            return null;
        }
        return e2.getAddress();
    }

    public boolean isDeviceReconnecting() {
        return this.f3425f.hasMessages(o);
    }

    public boolean isWaitingForUpdate() {
        return e() != null;
    }

    public void release() {
        setReConnectDevMsg(null);
        stopReconnectTask();
        this.f3421b.unregisterBluetoothCallback(this.f3426g);
        this.f3425f.removeCallbacksAndMessages(null);
    }

    public void setReConnectDevMsg(ReConnectDevMsg reConnectDevMsg) {
        if (this.f3422c != reConnectDevMsg) {
            this.f3422c = reConnectDevMsg;
            this.f3424e.clear();
            JL_Log.d(f3417h, "setReConnectDevMsg : " + reConnectDevMsg);
        }
    }

    public void setReconnectAddress(String str) {
        if (!BluetoothAdapter.checkBluetoothAddress(str)) {
            setReConnectDevMsg(null);
            return;
        }
        if (this.f3422c == null) {
            setReConnectDevMsg(new ReConnectDevMsg(this.f3421b.getBluetoothOption().getPriority(), str));
            return;
        }
        this.f3422c.setAddress(str);
        JL_Log.d(f3417h, "setReconnectAddress : " + this.f3422c);
    }

    public void setReconnectUseADV(boolean z) {
        if (this.f3422c != null) {
            this.f3422c.setUseADV(z);
        }
    }

    public void startReconnectTask() {
        if (isDeviceReconnecting()) {
            return;
        }
        String str = f3417h;
        JL_Log.i(str, "-startReconnectTask- start....");
        a(c());
        JL_Log.i(str, "-startReconnectTask- timeout = " + RECONNECT_TIMEOUT);
        this.f3425f.sendEmptyMessageDelayed(o, RECONNECT_TIMEOUT);
        this.f3425f.sendEmptyMessage(n);
    }

    public void stopReconnectTask() {
        boolean isDeviceReconnecting = isDeviceReconnecting();
        boolean isWaitingForUpdate = isWaitingForUpdate();
        JL_Log.i(f3417h, "--> stopReconnectTask ---------> " + isDeviceReconnecting + ", isWaitingForUpdate = " + isWaitingForUpdate);
        a(0L);
        setReConnectDevMsg(null);
        h();
        this.f3425f.removeCallbacksAndMessages(null);
    }

    private long c() {
        return Calendar.getInstance().getTimeInMillis();
    }

    private long d() {
        long c2 = RECONNECT_TIMEOUT - (c() - this.f3423d);
        if (c2 < 0) {
            return 0L;
        }
        return c2;
    }

    private ReConnectDevMsg e() {
        if (this.f3422c == null) {
            return null;
        }
        return this.f3422c.cloneObject();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean f() {
        return e() != null && e().getState() == 2;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b() {
        int startBLEScan;
        ReConnectDevMsg e2 = e();
        if (e2 == null) {
            JL_Log.w(f3417h, "doReconnectTask >>> reConnectDevMsg is null.");
            stopReconnectTask();
            return;
        }
        if (!BluetoothUtil.isBluetoothEnable()) {
            JL_Log.w(f3417h, "doReconnectTask >>> Bluetooth is close.");
            this.f3425f.removeMessages(n);
            this.f3425f.sendEmptyMessageDelayed(n, 3000L);
            return;
        }
        if (e2.getState() == 2) {
            JL_Log.w(f3417h, "doReconnectTask >>> Task is connecting. " + e2);
            if (this.f3425f.hasMessages(p)) {
                return;
            }
            this.f3425f.sendEmptyMessageDelayed(p, 30000L);
            return;
        }
        if (g()) {
            JL_Log.i(f3417h, "doReconnectTask >>> device is connected. " + e2 + ", device = " + this.f3421b.getConnectedDevice());
            return;
        }
        String str = f3417h;
        JL_Log.i(str, "doReconnectTask >>> " + e2 + ", isDevConnected : " + g());
        BluetoothDevice b2 = b(e2.getAddress());
        StringBuilder sb = new StringBuilder("doReconnectTask >>> connectedDevice : ");
        sb.append(b(b2));
        JL_Log.w(str, sb.toString());
        if (b2 != null) {
            a(b2);
            return;
        }
        if (e2.isUseADV() && e2.getWay() != 0) {
            e2.setWay(0);
        }
        if (this.f3421b.isScanning()) {
            int scanType = this.f3421b.getScanType();
            boolean z = scanType == 2;
            if (!z) {
                z = (e2.getWay() == 1 && scanType == 1) || (e2.getWay() == 0 && scanType == 0);
            }
            JL_Log.i(str, "doReconnectTask >>> isScanOk : " + z + ", scanType = " + scanType);
            if (z) {
                return;
            }
            h();
            SystemClock.sleep(100L);
        }
        long d2 = d();
        JL_Log.d(str, "doReconnectTask >>> leftTime ： " + d2 + ", beginTaskTime : " + this.f3423d);
        if (d2 < RECONNECT_TIMEOUT - 40000 && !e2.isUseADV()) {
            int i2 = e2.getWay() == 1 ? 0 : 2;
            long j2 = d2 - 3000;
            if (j2 > 0) {
                d2 = j2;
            }
            startBLEScan = this.f3421b.startDeviceScan(d2, i2);
            JL_Log.i(str, "doReconnectTask >>> startDeviceScan : " + startBLEScan + ", way = " + i2 + ", timeout = " + d2);
        } else {
            long min = Math.min(d2, 20000L);
            if (e2.getWay() == 1) {
                startBLEScan = this.f3421b.startDeviceScan(min, 1);
                JL_Log.i(str, "doReconnectTask >>> startDeviceScan : " + startBLEScan + ", scanTime = " + min);
            } else {
                startBLEScan = this.f3421b.startBLEScan(min);
                JL_Log.i(str, "doReconnectTask >>> startBLEScan : " + startBLEScan + ", scanTime = " + min);
            }
        }
        if (startBLEScan != 0) {
            this.f3425f.removeMessages(n);
            this.f3425f.sendEmptyMessageDelayed(n, 3000L);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean a(BluetoothDevice bluetoothDevice, byte[] bArr) {
        ReConnectDevMsg e2;
        if (bluetoothDevice == null || (e2 = e()) == null) {
            return false;
        }
        String address = e2.getAddress();
        if (!BluetoothAdapter.checkBluetoothAddress(address)) {
            return false;
        }
        String str = f3417h;
        JL_Log.i(str, "-checkIsReconnectDevice- device : " + b(bluetoothDevice));
        if (!e2.isUseADV()) {
            return address.equals(bluetoothDevice.getAddress());
        }
        JL_Log.d(str, "-checkIsReconnectDevice- advertiseRawData : " + CHexConver.byte2HexStr(bArr));
        BleScanMessage parseOTAFlagFilterWithBroad = ParseDataUtil.parseOTAFlagFilterWithBroad(bArr, JL_Constant.OTA_IDENTIFY);
        if (parseOTAFlagFilterWithBroad == null) {
            return false;
        }
        JL_Log.i(str, "-checkIsReconnectDevice- " + parseOTAFlagFilterWithBroad);
        return address.equalsIgnoreCase(parseOTAFlagFilterWithBroad.getOldBleAddress());
    }

    private void a(long j2) {
        this.f3423d = j2;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice) {
        String str = f3417h;
        JL_Log.d(str, "connectBtDevice :: " + this.f3422c + ", " + bluetoothDevice);
        if (this.f3422c == null || this.f3422c.getState() == 2) {
            return;
        }
        this.f3422c.setState(2);
        long d2 = d();
        JL_Log.i(str, "connectBtDevice :: left time = " + d2);
        if (d2 <= 2000) {
            this.f3425f.removeMessages(o);
            this.f3425f.sendEmptyMessageDelayed(o, 31000L);
            JL_Log.i(str, "connectBtDevice :: reset time >>> ");
        }
        this.f3425f.removeMessages(p);
        this.f3425f.sendEmptyMessageDelayed(p, 30000L);
        this.f3421b.connectBluetoothDevice(bluetoothDevice);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BaseError baseError) {
        if (baseError == null) {
            return;
        }
        if (this.f3421b.isOTA()) {
            this.f3421b.errorEventCallback(baseError);
        }
        stopReconnectTask();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(String str) {
        long d2 = d();
        String str2 = f3417h;
        JL_Log.d(str2, "dealWithConnectFailed >> " + str + ", Left Time = " + d2);
        if (d2 <= 2000) {
            JL_Log.i(str2, "-dealWithConnectFailed- time not enough.");
            a(OTAError.buildError(ErrorCode.SUB_ERR_RECONNECT_FAILED, str));
        } else {
            JL_Log.i(str2, "-dealWithConnectFailed- resume reconnect task.");
            this.f3425f.removeMessages(n);
            this.f3425f.sendEmptyMessage(n);
        }
    }

    private BluetoothDevice b(String str) {
        List<BluetoothDevice> systemConnectedBtDeviceList;
        if (BluetoothAdapter.checkBluetoothAddress(str) && (systemConnectedBtDeviceList = BluetoothUtil.getSystemConnectedBtDeviceList(this.f3420a)) != null && !systemConnectedBtDeviceList.isEmpty()) {
            for (BluetoothDevice bluetoothDevice : systemConnectedBtDeviceList) {
                if (str.equals(bluetoothDevice.getAddress())) {
                    return bluetoothDevice;
                }
            }
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String b(BluetoothDevice bluetoothDevice) {
        return BluetoothUtil.printBtDeviceInfo(this.f3420a, bluetoothDevice);
    }
}
