package com.jieli.jl_rcsp.impl;

import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import com.jieli.jl_rcsp.constant.RcspErrorCode;
import com.jieli.jl_rcsp.constant.WatchError;
import com.jieli.jl_rcsp.interfaces.IHandleResult;
import com.jieli.jl_rcsp.interfaces.OnOperationCallback;
import com.jieli.jl_rcsp.interfaces.data.IDataTransferOp;
import com.jieli.jl_rcsp.interfaces.data.OnDataEventCallback;
import com.jieli.jl_rcsp.interfaces.data.OnDataTransferListener;
import com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.base.CommandBase;
import com.jieli.jl_rcsp.model.command.data.DataTransferCmd;
import com.jieli.jl_rcsp.model.data.DataParams;
import com.jieli.jl_rcsp.model.data.ReadDataCache;
import com.jieli.jl_rcsp.model.data.ReadParams;
import com.jieli.jl_rcsp.model.data.SendDataCache;
import com.jieli.jl_rcsp.model.data.SendParams;
import com.jieli.jl_rcsp.tool.CustomRcspActionCallback;
import com.jieli.jl_rcsp.tool.DeviceStatusManager;
import com.jieli.jl_rcsp.util.CHexConver;
import com.jieli.jl_rcsp.util.CryptoUtil;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;

/* loaded from: classes3.dex */
public class DataTransferOpImpl implements IDataTransferOp {

    /* renamed from: h, reason: collision with root package name */
    private static final int f3531h = 20000;

    /* renamed from: i, reason: collision with root package name */
    private static final int f3532i = 5237;

    /* renamed from: b, reason: collision with root package name */
    private final RcspOpImpl f3534b;

    /* renamed from: c, reason: collision with root package name */
    private final OnDataTransferListener f3535c;

    /* renamed from: d, reason: collision with root package name */
    private volatile SendDataCache f3536d;

    /* renamed from: e, reason: collision with root package name */
    private volatile ReadDataCache f3537e;

    /* renamed from: g, reason: collision with root package name */
    private final OnRcspCallback f3539g;

    /* renamed from: a, reason: collision with root package name */
    private final String f3533a = "DataTransferOpImpl";

    /* renamed from: f, reason: collision with root package name */
    private final Handler f3538f = new Handler(Looper.getMainLooper(), new Handler.Callback() { // from class: com.jieli.jl_rcsp.impl.DataTransferOpImpl$$ExternalSyntheticLambda0
        @Override // android.os.Handler.Callback
        public final boolean handleMessage(Message message) {
            boolean a2;
            a2 = DataTransferOpImpl.this.a(message);
            return a2;
        }
    });

    public DataTransferOpImpl(RcspOpImpl rcspOpImpl, OnDataTransferListener onDataTransferListener) {
        OnRcspCallback onRcspCallback = new OnRcspCallback() { // from class: com.jieli.jl_rcsp.impl.DataTransferOpImpl.7
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onConnectStateChange(BluetoothDevice bluetoothDevice, int i2) {
                if (i2 != 1) {
                    DataTransferOpImpl.this.a(new BaseError(8192, "Device is not connected."));
                }
            }

            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspCommand(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
                if (commandBase == null || commandBase.getId() != 48) {
                    return;
                }
                DataTransferCmd dataTransferCmd = (DataTransferCmd) commandBase;
                JL_Log.d(DataTransferOpImpl.this.f3533a, "onRcspCommand >> " + dataTransferCmd);
                if (dataTransferCmd.getParam() instanceof DataTransferCmd.SendDataParam) {
                    DataTransferOpImpl.this.a(bluetoothDevice, dataTransferCmd, (DataTransferCmd.SendDataParam) dataTransferCmd.getParam());
                } else if (!(dataTransferCmd.getParam() instanceof DataTransferCmd.ReadDataParam) && (dataTransferCmd.getParam() instanceof DataTransferCmd.DataTransferParam)) {
                    DataTransferOpImpl.this.a(bluetoothDevice, dataTransferCmd, (DataTransferCmd.DataTransferParam) dataTransferCmd.getParam());
                }
            }
        };
        this.f3539g = onRcspCallback;
        if (rcspOpImpl == null) {
            throw new NullPointerException("RcspOpImpl can not be null.");
        }
        if (onDataTransferListener == null) {
            throw new NullPointerException("OnDataTransferListener can not be null.");
        }
        this.f3534b = rcspOpImpl;
        this.f3535c = onDataTransferListener;
        rcspOpImpl.registerOnRcspCallback(onRcspCallback);
    }

    private static String a(int i2) {
        switch (i2) {
            case 0:
                return "Successful.";
            case 1:
                return "CRC error.";
            case 2:
                return "Sequence error.";
            case 3:
                return "Data type is not supported.";
            case 4:
                return "Transfer way is not supported.";
            case 5:
                return "Data length is out of bounds.";
            case 6:
                return "Read/write Data Exception.";
            case 7:
                return "Missing parameter configuration.";
            default:
                return "";
        }
    }

    public void destroy() {
        this.f3538f.removeMessages(f3532i);
        this.f3538f.removeCallbacksAndMessages(null);
        this.f3534b.unregisterOnRcspCallback(this.f3539g);
        a(new BaseError(4098, "Cancel send data task."));
    }

    public RcspOpImpl getRcspOp() {
        return this.f3534b;
    }

    @Override // com.jieli.jl_rcsp.interfaces.data.IDataTransferOp
    public void readLargeData(DataParams dataParams, final OnDataEventCallback onDataEventCallback) {
        if (dataParams == null) {
            if (onDataEventCallback != null) {
                onDataEventCallback.onError(new BaseError(4097, "ReadParams can not be null."));
            }
        } else if (b() || a()) {
            if (onDataEventCallback != null) {
                onDataEventCallback.onError(new BaseError(4352, "Data task is in progress."));
            }
        } else {
            DataTransferCmd.ReadDataParam readDataParam = new DataTransferCmd.ReadDataParam(dataParams.getDataType(), dataParams.getVersion(), dataParams.getSendLimit(), dataParams.getReceiveLimit());
            final BluetoothDevice connectedDevice = this.f3534b.getConnectedDevice();
            a(readDataParam, new OnOperationCallback<DataTransferCmd.ReadDataResponse>() { // from class: com.jieli.jl_rcsp.impl.DataTransferOpImpl.2
                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onFailed(BaseError baseError) {
                    OnDataEventCallback onDataEventCallback2 = onDataEventCallback;
                    if (onDataEventCallback2 != null) {
                        onDataEventCallback2.onError(baseError);
                    }
                }

                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onSuccess(DataTransferCmd.ReadDataResponse readDataResponse) {
                    if (readDataResponse.getResult() != 0) {
                        onFailed(RcspErrorCode.buildJsonError(48, 12293, readDataResponse.getResult(), null));
                        return;
                    }
                    int maxReceiveMtu = DeviceStatusManager.getInstance().getMaxReceiveMtu(DataTransferOpImpl.this.f3534b.getConnectedDevice());
                    if (readDataResponse.getSendDataLimit() >= maxReceiveMtu) {
                        DataTransferOpImpl.this.a(new BaseError(4097, RcspUtil.formatString("Data sending limit exceeded the protocol MTU[%d] range.", Integer.valueOf(maxReceiveMtu))));
                        return;
                    }
                    DataTransferOpImpl.this.f3537e = new ReadDataCache(new ReadParams(readDataResponse.getType(), readDataResponse.getVersion(), readDataResponse.getSendDataLimit(), readDataResponse.getReceiveDataLimit(), readDataResponse.getDataLen(), readDataResponse.getCrc()));
                    DataTransferOpImpl.this.f3537e.setCallback(onDataEventCallback);
                    if (DataTransferOpImpl.this.f3536d.getCallback() != null) {
                        DataTransferOpImpl.this.f3536d.getCallback().onBegin(0);
                    }
                    DataTransferOpImpl.this.f3538f.sendMessageDelayed(DataTransferOpImpl.this.f3538f.obtainMessage(DataTransferOpImpl.f3532i, connectedDevice), 20000L);
                }
            });
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.data.IDataTransferOp
    public void sendLargeData(SendParams sendParams, OnDataEventCallback onDataEventCallback) {
        if (sendParams == null) {
            if (onDataEventCallback != null) {
                onDataEventCallback.onError(new BaseError(4097, "SendDataParam can not be null."));
            }
        } else if (!b()) {
            this.f3536d = new SendDataCache(sendParams, onDataEventCallback);
            a(new DataTransferCmd.SendDataParam(sendParams.getDataType(), sendParams.getVersion(), sendParams.getDataLen(), sendParams.getDataCrc(), sendParams.getSendLimit(), sendParams.getReceiveLimit()), new OnOperationCallback<DataTransferCmd.SendDataResponse>() { // from class: com.jieli.jl_rcsp.impl.DataTransferOpImpl.1
                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onFailed(BaseError baseError) {
                    DataTransferOpImpl.this.a(baseError);
                }

                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onSuccess(DataTransferCmd.SendDataResponse sendDataResponse) {
                    if (sendDataResponse.getResult() != 0) {
                        onFailed(RcspErrorCode.buildJsonError(48, 12293, sendDataResponse.getResult(), null));
                        return;
                    }
                    if (DataTransferOpImpl.this.b()) {
                        int maxReceiveMtu = DeviceStatusManager.getInstance().getMaxReceiveMtu(DataTransferOpImpl.this.f3534b.getConnectedDevice());
                        if (sendDataResponse.getReceiveDataLimit() >= maxReceiveMtu) {
                            DataTransferOpImpl.this.a(new BaseError(4097, RcspUtil.formatString("Data Receiving limit exceeded the protocol MTU[%d] range.", Integer.valueOf(maxReceiveMtu))));
                            return;
                        }
                        DataTransferOpImpl.this.f3536d.setSendLimit(sendDataResponse.getSendDataLimit());
                        DataTransferOpImpl.this.f3536d.setReceiveLimit(sendDataResponse.getReceiveDataLimit());
                        DataTransferOpImpl.this.f3536d.setOffset(0);
                        DataTransferOpImpl.this.f3536d.setSeq(-1);
                        if (DataTransferOpImpl.this.f3536d.getCallback() != null) {
                            DataTransferOpImpl.this.f3536d.getCallback().onBegin(1);
                        }
                        DataTransferOpImpl dataTransferOpImpl = DataTransferOpImpl.this;
                        dataTransferOpImpl.a(dataTransferOpImpl.f3536d);
                    }
                }
            });
        } else if (onDataEventCallback != null) {
            onDataEventCallback.onError(new BaseError(4352, WatchError.getErrorDesc(4352)));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean b() {
        return this.f3536d != null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ boolean a(Message message) {
        if (message == null) {
            return false;
        }
        if (f3532i != message.what) {
            return true;
        }
        Object obj = message.obj;
        if (!(obj instanceof BluetoothDevice)) {
            return true;
        }
        a((BluetoothDevice) obj, new BaseError(12290, "Waiting for data timeout."));
        return true;
    }

    private boolean a() {
        return this.f3537e != null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BaseError baseError) {
        if (baseError != null && b()) {
            if (this.f3536d.getCallback() != null) {
                this.f3536d.getCallback().onError(baseError);
            }
            this.f3536d = null;
        }
    }

    private void a(BluetoothDevice bluetoothDevice, BaseError baseError) {
        if (baseError != null && a()) {
            if (this.f3537e.getListener() != null) {
                this.f3537e.getListener().onError(bluetoothDevice, baseError);
            }
            if (this.f3537e.getCallback() != null) {
                this.f3537e.getCallback().onError(baseError);
            }
            this.f3538f.removeMessages(f3532i);
            this.f3537e = null;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(SendDataCache sendDataCache) {
        if (sendDataCache == null) {
            return;
        }
        int receiveLimit = sendDataCache.getReceiveLimit();
        boolean z = sendDataCache.getOffset() + receiveLimit >= sendDataCache.getDataLen();
        int min = Math.min(sendDataCache.getDataLen() - sendDataCache.getOffset(), receiveLimit);
        byte[] bArr = new byte[min];
        System.arraycopy(sendDataCache.getData(), sendDataCache.getOffset(), bArr, 0, min);
        short CRC16 = CryptoUtil.CRC16(bArr, (short) 0);
        sendDataCache.setSeq(sendDataCache.getSeq() + 1);
        DataTransferCmd.DataTransferParam dataTransferParam = new DataTransferCmd.DataTransferParam(sendDataCache.getDataType(), z, sendDataCache.getSeq(), CRC16, sendDataCache.getOffset(), bArr);
        sendDataCache.setOffset(sendDataCache.getOffset() + min);
        a(dataTransferParam, new OnOperationCallback<DataTransferCmd.DataTransferResponse>() { // from class: com.jieli.jl_rcsp.impl.DataTransferOpImpl.3
            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onFailed(BaseError baseError) {
                DataTransferOpImpl.this.a(baseError);
            }

            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onSuccess(DataTransferCmd.DataTransferResponse dataTransferResponse) {
                String str;
                if (dataTransferResponse.getResult() != 0) {
                    try {
                    } catch (Exception e2) {
                        e2.printStackTrace();
                    }
                    if (dataTransferResponse.getMessage() != null && dataTransferResponse.getMessage().length > 0) {
                        str = new String(dataTransferResponse.getMessage());
                        onFailed(RcspErrorCode.buildJsonError(48, 12293, dataTransferResponse.getResult(), str));
                        return;
                    }
                    str = "";
                    onFailed(RcspErrorCode.buildJsonError(48, 12293, dataTransferResponse.getResult(), str));
                    return;
                }
                if (dataTransferResponse.isEnd()) {
                    if (DataTransferOpImpl.this.f3536d.getCallback() != null) {
                        DataTransferOpImpl.this.f3536d.getCallback().onProgress(100.0f);
                        DataTransferOpImpl.this.f3536d.getCallback().onStop(DataTransferOpImpl.this.f3536d.getDataType(), DataTransferOpImpl.this.f3536d.getData());
                    }
                    DataTransferOpImpl.this.f3536d = null;
                    return;
                }
                if (DataTransferOpImpl.this.f3536d.getDataLen() > 0) {
                    float offset = (DataTransferOpImpl.this.f3536d.getOffset() * 100.0f) / DataTransferOpImpl.this.f3536d.getDataLen();
                    if (DataTransferOpImpl.this.f3536d.getCallback() != null) {
                        DataTransferOpImpl.this.f3536d.getCallback().onProgress(offset);
                    }
                }
                DataTransferOpImpl dataTransferOpImpl = DataTransferOpImpl.this;
                dataTransferOpImpl.a(dataTransferOpImpl.f3536d);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, DataTransferCmd dataTransferCmd, DataTransferCmd.SendDataParam sendDataParam) {
        if (dataTransferCmd == null || sendDataParam == null) {
            return;
        }
        if (a()) {
            dataTransferCmd.setParam(null);
            dataTransferCmd.setStatus(3);
            this.f3534b.sendCommandResponse(bluetoothDevice, dataTransferCmd, null);
            return;
        }
        JL_Log.d(this.f3533a, "handleDataParam >> param = " + sendDataParam);
        DataTransferCmd.SendDataResponse sendDataResponse = new DataTransferCmd.SendDataResponse(sendDataParam.getWay(), sendDataParam.getType(), sendDataParam.getVersion(), 0, sendDataParam.getSendDataLimit(), sendDataParam.getReceiveDataLimit());
        JL_Log.d(this.f3533a, "handleDataParam >> " + sendDataResponse + "\n data = " + CHexConver.byte2HexStr(sendDataResponse.getParamData()));
        dataTransferCmd.setParam(new DataTransferCmd.CustomReplyParam(sendDataResponse.getParamData()));
        dataTransferCmd.setStatus(0);
        this.f3534b.sendCommandResponse(bluetoothDevice, dataTransferCmd, null);
        this.f3537e = new ReadDataCache(new ReadParams(sendDataParam.getType(), sendDataParam.getVersion(), sendDataParam.getSendDataLimit(), sendDataParam.getReceiveDataLimit(), sendDataParam.getDataLen(), sendDataParam.getCrc()));
        this.f3537e.setListener(this.f3535c);
        Handler handler = this.f3538f;
        handler.sendMessageDelayed(handler.obtainMessage(f3532i, bluetoothDevice), 20000L);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x0136, code lost:
    
        if (r7 == r19.f3537e.getCrc()) goto L20;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public void a(android.bluetooth.BluetoothDevice r20, com.jieli.jl_rcsp.model.command.data.DataTransferCmd r21, com.jieli.jl_rcsp.model.command.data.DataTransferCmd.DataTransferParam r22) {
        /*
            Method dump skipped, instructions count: 527
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jieli.jl_rcsp.impl.DataTransferOpImpl.a(android.bluetooth.BluetoothDevice, com.jieli.jl_rcsp.model.command.data.DataTransferCmd, com.jieli.jl_rcsp.model.command.data.DataTransferCmd$DataTransferParam):void");
    }

    private void a(DataTransferCmd.SendDataParam sendDataParam, OnOperationCallback<DataTransferCmd.SendDataResponse> onOperationCallback) {
        if (sendDataParam != null) {
            RcspOpImpl rcspOpImpl = this.f3534b;
            rcspOpImpl.sendRcspCommand(rcspOpImpl.getConnectedDevice(), new DataTransferCmd(sendDataParam), new CustomRcspActionCallback("sendDataParam", onOperationCallback, new IHandleResult<DataTransferCmd.SendDataResponse, DataTransferCmd>() { // from class: com.jieli.jl_rcsp.impl.DataTransferOpImpl.4
                @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
                public int hasResult(BluetoothDevice bluetoothDevice, DataTransferCmd dataTransferCmd) {
                    return 0;
                }

                @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
                public DataTransferCmd.SendDataResponse handleResult(BluetoothDevice bluetoothDevice, DataTransferCmd dataTransferCmd) {
                    if (dataTransferCmd != null && dataTransferCmd.getStatus() == 0 && (dataTransferCmd.getResponse() instanceof DataTransferCmd.SendDataResponse)) {
                        return (DataTransferCmd.SendDataResponse) dataTransferCmd.getResponse();
                    }
                    return null;
                }
            }));
        } else if (onOperationCallback != null) {
            onOperationCallback.onFailed(new BaseError(4097, "SendDataParam can not be null."));
        }
    }

    private void a(DataTransferCmd.ReadDataParam readDataParam, OnOperationCallback<DataTransferCmd.ReadDataResponse> onOperationCallback) {
        if (readDataParam != null) {
            RcspOpImpl rcspOpImpl = this.f3534b;
            rcspOpImpl.sendRcspCommand(rcspOpImpl.getConnectedDevice(), new DataTransferCmd(readDataParam), new CustomRcspActionCallback("readDataParam", onOperationCallback, new IHandleResult<DataTransferCmd.ReadDataResponse, DataTransferCmd>() { // from class: com.jieli.jl_rcsp.impl.DataTransferOpImpl.5
                @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
                public int hasResult(BluetoothDevice bluetoothDevice, DataTransferCmd dataTransferCmd) {
                    return 0;
                }

                @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
                public DataTransferCmd.ReadDataResponse handleResult(BluetoothDevice bluetoothDevice, DataTransferCmd dataTransferCmd) {
                    if (dataTransferCmd != null && dataTransferCmd.getStatus() == 0 && (dataTransferCmd.getResponse() instanceof DataTransferCmd.ReadDataResponse)) {
                        return (DataTransferCmd.ReadDataResponse) dataTransferCmd.getResponse();
                    }
                    return null;
                }
            }));
        } else if (onOperationCallback != null) {
            onOperationCallback.onFailed(new BaseError(4097, "ReadDataParam can not be null."));
        }
    }

    private void a(DataTransferCmd.DataTransferParam dataTransferParam, OnOperationCallback<DataTransferCmd.DataTransferResponse> onOperationCallback) {
        if (dataTransferParam != null) {
            RcspOpImpl rcspOpImpl = this.f3534b;
            rcspOpImpl.sendRcspCommand(rcspOpImpl.getConnectedDevice(), new DataTransferCmd(dataTransferParam), new CustomRcspActionCallback("sendDataBlock", onOperationCallback, new IHandleResult<DataTransferCmd.DataTransferResponse, DataTransferCmd>() { // from class: com.jieli.jl_rcsp.impl.DataTransferOpImpl.6
                @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
                public int hasResult(BluetoothDevice bluetoothDevice, DataTransferCmd dataTransferCmd) {
                    return 0;
                }

                @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
                public DataTransferCmd.DataTransferResponse handleResult(BluetoothDevice bluetoothDevice, DataTransferCmd dataTransferCmd) {
                    if (dataTransferCmd != null && dataTransferCmd.getStatus() == 0 && (dataTransferCmd.getResponse() instanceof DataTransferCmd.DataTransferResponse)) {
                        return (DataTransferCmd.DataTransferResponse) dataTransferCmd.getResponse();
                    }
                    return null;
                }
            }));
        } else if (onOperationCallback != null) {
            onOperationCallback.onFailed(new BaseError(4097, "DataTransferParam can not be null."));
        }
    }
}
