package com.jieli.jl_rcsp.impl;

import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import com.dd.plist.ASCIIPropertyListParser;
import com.jieli.jl_rcsp.constant.RcspConstant;
import com.jieli.jl_rcsp.interfaces.listener.LibLoader;
import com.jieli.jl_rcsp.util.CHexConver;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/* loaded from: classes3.dex */
public class RcspAuth {
    public static final int ERR_AUTH_DATA_CHECK = 40980;
    public static final int ERR_AUTH_DATA_SEND = 40979;
    public static final int ERR_AUTH_DEVICE_TIMEOUT = 40977;
    public static final int ERR_AUTH_USER_STOP = 40978;
    public static final int ERR_NONE = 0;

    /* renamed from: f, reason: collision with root package name */
    private static final String f3610f = "RcspAuth";

    /* renamed from: g, reason: collision with root package name */
    private static volatile boolean f3611g = false;

    /* renamed from: h, reason: collision with root package name */
    private static final int f3612h = 2;

    /* renamed from: i, reason: collision with root package name */
    private static final long f3613i = 3000;

    /* renamed from: j, reason: collision with root package name */
    private static long f3614j = 3000;
    private static final int k = 17;
    private static final int l = 18;
    public static final LibLoader sLocalLibLoader = new LibLoader() { // from class: com.jieli.jl_rcsp.impl.RcspAuth$$ExternalSyntheticLambda1
        @Override // com.jieli.jl_rcsp.interfaces.listener.LibLoader
        public final void loadLibrary(String str) {
            System.loadLibrary(str);
        }
    };

    /* renamed from: a, reason: collision with root package name */
    private boolean f3615a;

    /* renamed from: b, reason: collision with root package name */
    private final IRcspAuthOp f3616b;

    /* renamed from: c, reason: collision with root package name */
    private final OnRcspAuthListener f3617c;

    /* renamed from: d, reason: collision with root package name */
    private final Map<String, AuthTask> f3618d = Collections.synchronizedMap(new HashMap());

    /* renamed from: e, reason: collision with root package name */
    private final Handler f3619e = new Handler(Looper.getMainLooper(), new Handler.Callback() { // from class: com.jieli.jl_rcsp.impl.RcspAuth.1
        @Override // android.os.Handler.Callback
        public boolean handleMessage(Message message) {
            if (message == null) {
                return false;
            }
            int i2 = message.what;
            if (i2 == 17) {
                BluetoothDevice bluetoothDevice = (BluetoothDevice) message.obj;
                AuthTask authTask = (AuthTask) RcspAuth.this.f3618d.get(bluetoothDevice.getAddress());
                if (authTask == null) {
                    return false;
                }
                if (authTask.getRetryNum() < 2) {
                    authTask.setRetryNum(authTask.getRetryNum() + 1);
                    RcspAuth.this.f3616b.sendAuthDataToDevice(authTask.getDevice(), authTask.getRandomData());
                    RcspAuth.this.f3619e.removeMessages(18);
                    RcspAuth.this.f3619e.sendMessageDelayed(RcspAuth.this.f3619e.obtainMessage(17, bluetoothDevice), RcspAuth.f3614j);
                } else {
                    RcspAuth.this.a(bluetoothDevice, 40977);
                }
            } else if (i2 == 18) {
                BluetoothDevice bluetoothDevice2 = (BluetoothDevice) message.obj;
                AuthTask authTask2 = (AuthTask) RcspAuth.this.f3618d.get(bluetoothDevice2.getAddress());
                if (authTask2 != null && !authTask2.isAuthDevice()) {
                    RcspAuth.this.a(bluetoothDevice2, 40977);
                }
            }
            return true;
        }
    });

    public static class AuthTask {

        /* renamed from: a, reason: collision with root package name */
        private BluetoothDevice f3621a;

        /* renamed from: b, reason: collision with root package name */
        private boolean f3622b;

        /* renamed from: c, reason: collision with root package name */
        private boolean f3623c;

        /* renamed from: d, reason: collision with root package name */
        private byte[] f3624d;

        /* renamed from: e, reason: collision with root package name */
        private int f3625e;

        private AuthTask() {
        }

        public BluetoothDevice getDevice() {
            return this.f3621a;
        }

        public byte[] getRandomData() {
            return this.f3624d;
        }

        public int getRetryNum() {
            return this.f3625e;
        }

        public boolean isAuthDevice() {
            return this.f3623c;
        }

        public boolean isAuthProgressResult() {
            return this.f3622b;
        }

        public void setAuthDevice(boolean z) {
            this.f3623c = z;
        }

        public void setAuthProgressResult(boolean z) {
            this.f3622b = z;
        }

        public AuthTask setDevice(BluetoothDevice bluetoothDevice) {
            this.f3621a = bluetoothDevice;
            return this;
        }

        public AuthTask setRandomData(byte[] bArr) {
            this.f3624d = bArr;
            return this;
        }

        public void setRetryNum(int i2) {
            this.f3625e = i2;
        }

        public String toString() {
            return "AuthTask{device=" + this.f3621a + ", isAuthProgressResult=" + this.f3622b + ", isAuthDevice=" + this.f3623c + ", randomData=" + CHexConver.byte2HexStr(this.f3624d) + ", retryNum=" + this.f3625e + ASCIIPropertyListParser.DICTIONARY_END_TOKEN;
        }
    }

    public interface IRcspAuthOp {
        boolean sendAuthDataToDevice(BluetoothDevice bluetoothDevice, byte[] bArr);
    }

    public interface OnRcspAuthListener {
        void onAuthFailed(BluetoothDevice bluetoothDevice, int i2, String str);

        void onAuthSuccess(BluetoothDevice bluetoothDevice);

        void onInitResult(boolean z);
    }

    public RcspAuth(IRcspAuthOp iRcspAuthOp, OnRcspAuthListener onRcspAuthListener) {
        if (iRcspAuthOp == null) {
            throw new IllegalArgumentException("IRcspAuthOp can not be null.");
        }
        this.f3616b = iRcspAuthOp;
        this.f3617c = onRcspAuthListener;
        loadLibrariesOnce(null);
        boolean nativeInit = nativeInit();
        this.f3615a = nativeInit;
        a(nativeInit);
    }

    private String a(int i2) {
        switch (i2) {
            case 40977:
                return "Auth device timeout.";
            case 40978:
                return "User stop auth device.";
            case 40979:
                return "Failed to send data.";
            case 40980:
                return "Check auth data error.";
            default:
                return "";
        }
    }

    public static void loadLibrariesOnce(LibLoader libLoader) {
        synchronized (RcspAuth.class) {
            if (!f3611g) {
                if (libLoader == null) {
                    libLoader = sLocalLibLoader;
                }
                libLoader.loadLibrary(RcspConstant.JL_RCSP_LIB);
                f3611g = true;
            }
        }
    }

    public static boolean setAuthTimeout(long j2) {
        if (j2 >= f3613i) {
            f3614j = j2;
            return true;
        }
        JL_Log.d(f3610f, "setAuthTimeout >> false. " + j2);
        return false;
    }

    @Deprecated
    public void addListener(OnRcspAuthListener onRcspAuthListener) {
    }

    public void destroy() {
        this.f3619e.removeCallbacksAndMessages(null);
        this.f3618d.clear();
        this.f3615a = false;
        f3611g = false;
    }

    public byte[] getAuthData(byte[] bArr) {
        if (bArr == null) {
            return null;
        }
        return getEncryptedAuthData(bArr);
    }

    public byte[] getAuthOkData() {
        return new byte[]{2, 112, 97, 115, 115};
    }

    public native byte[] getEncryptedAuthData(byte[] bArr);

    public native byte[] getRandomAuthData();

    public byte[] getRandomData() {
        return getRandomAuthData();
    }

    /* JADX WARN: Code restructure failed: missing block: B:21:0x0066, code lost:
    
        if (r7.f3616b.sendAuthDataToDevice(r8, getAuthOkData()) != false) goto L40;
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x00ac, code lost:
    
        r9 = 40979;
     */
    /* JADX WARN: Code restructure failed: missing block: B:44:0x00a9, code lost:
    
        if (r7.f3616b.sendAuthDataToDevice(r8, r9) != false) goto L40;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public void handleAuthData(android.bluetooth.BluetoothDevice r8, byte[] r9) {
        /*
            r7 = this;
            if (r8 == 0) goto Lf2
            boolean r0 = r7.f3615a
            if (r0 == 0) goto Lf2
            boolean r0 = r7.a(r9)
            if (r0 != 0) goto Le
            goto Lf2
        Le:
            java.util.Map<java.lang.String, com.jieli.jl_rcsp.impl.RcspAuth$AuthTask> r0 = r7.f3618d
            java.lang.String r1 = r8.getAddress()
            java.lang.Object r0 = r0.get(r1)
            com.jieli.jl_rcsp.impl.RcspAuth$AuthTask r0 = (com.jieli.jl_rcsp.impl.RcspAuth.AuthTask) r0
            if (r0 == 0) goto Lf2
            boolean r1 = r0.isAuthDevice()
            if (r1 == 0) goto L24
            goto Lf2
        L24:
            java.lang.String r1 = com.jieli.jl_rcsp.impl.RcspAuth.f3610f
            r2 = 2
            java.lang.Object[] r2 = new java.lang.Object[r2]
            r3 = 0
            r2[r3] = r8
            java.lang.String r4 = com.jieli.jl_rcsp.util.CHexConver.byte2HexStr(r9)
            r5 = 1
            r2[r5] = r4
            java.lang.String r4 = "-handleAuthData- device : %s, data : %s"
            java.lang.String r2 = com.jieli.jl_rcsp.util.RcspUtil.formatString(r4, r2)
            com.jieli.jl_rcsp.util.JL_Log.d(r1, r2)
            boolean r2 = r0.isAuthProgressResult()
            r4 = 17
            if (r2 != 0) goto L83
            int r2 = r9.length
            if (r2 != r4) goto L82
            r2 = r9[r3]
            if (r2 == r5) goto L4c
            goto L82
        L4c:
            byte[] r2 = r0.getRandomData()
            byte[] r2 = r7.getAuthData(r2)
            if (r2 == 0) goto L69
            boolean r9 = java.util.Arrays.equals(r2, r9)
            if (r9 == 0) goto L69
            com.jieli.jl_rcsp.impl.RcspAuth$IRcspAuthOp r9 = r7.f3616b
            byte[] r1 = r7.getAuthOkData()
            boolean r9 = r9.sendAuthDataToDevice(r8, r1)
            if (r9 == 0) goto Lac
            goto Lab
        L69:
            java.lang.StringBuilder r9 = new java.lang.StringBuilder
            java.lang.String r6 = "-handleAuthData- data not match. authData : "
            r9.<init>(r6)
            java.lang.String r2 = com.jieli.jl_rcsp.util.CHexConver.byte2HexStr(r2)
            r9.append(r2)
            java.lang.String r9 = r9.toString()
            com.jieli.jl_rcsp.util.JL_Log.w(r1, r9)
            r9 = 40980(0xa014, float:5.7425E-41)
            goto Lc1
        L82:
            return
        L83:
            int r2 = r9.length
            if (r2 != r4) goto Lb0
            r2 = r9[r3]
            if (r2 != 0) goto Lb0
            byte[] r9 = r7.getAuthData(r9)
            java.lang.StringBuilder r2 = new java.lang.StringBuilder
            java.lang.String r6 = "-handleAuthData- devAuthData : "
            r2.<init>(r6)
            java.lang.String r6 = com.jieli.jl_rcsp.util.CHexConver.byte2HexStr(r9)
            r2.append(r6)
            java.lang.String r2 = r2.toString()
            com.jieli.jl_rcsp.util.JL_Log.i(r1, r2)
            com.jieli.jl_rcsp.impl.RcspAuth$IRcspAuthOp r1 = r7.f3616b
            boolean r9 = r1.sendAuthDataToDevice(r8, r9)
            if (r9 == 0) goto Lac
        Lab:
            goto Lc0
        Lac:
            r9 = 40979(0xa013, float:5.7424E-41)
            goto Lc1
        Lb0:
            byte[] r1 = r7.getAuthOkData()
            boolean r9 = java.util.Arrays.equals(r9, r1)
            if (r9 == 0) goto Lf2
            r0.setAuthDevice(r5)
            r7.a(r8)
        Lc0:
            r9 = r3
        Lc1:
            if (r9 != 0) goto Lc4
            goto Lc5
        Lc4:
            r5 = r3
        Lc5:
            r0.setAuthProgressResult(r5)
            if (r9 == 0) goto Ld5
            r0.setAuthDevice(r3)
            java.lang.String r0 = r7.a(r9)
            r7.a(r8, r9, r0)
            goto Lf2
        Ld5:
            android.os.Handler r9 = r7.f3619e
            r9.removeMessages(r4)
            android.os.Handler r9 = r7.f3619e
            r1 = 18
            r9.removeMessages(r1)
            boolean r9 = r0.isAuthDevice()
            if (r9 != 0) goto Lf2
            android.os.Handler r9 = r7.f3619e
            android.os.Message r8 = r9.obtainMessage(r1, r8)
            long r0 = com.jieli.jl_rcsp.impl.RcspAuth.f3614j
            r9.sendMessageDelayed(r8, r0)
        Lf2:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jieli.jl_rcsp.impl.RcspAuth.handleAuthData(android.bluetooth.BluetoothDevice, byte[]):void");
    }

    public native boolean nativeInit();

    @Deprecated
    public void removeListener(OnRcspAuthListener onRcspAuthListener) {
    }

    public int setDeviceConnectionLinkKey(byte[] bArr) {
        return setLinkKey(bArr);
    }

    public native int setLinkKey(byte[] bArr);

    public boolean startAuth(final BluetoothDevice bluetoothDevice) {
        if (bluetoothDevice == null || !this.f3615a) {
            return false;
        }
        if (this.f3618d.containsKey(bluetoothDevice.getAddress())) {
            AuthTask authTask = this.f3618d.get(bluetoothDevice.getAddress());
            if (authTask != null && (authTask.isAuthDevice() || this.f3619e.hasMessages(18))) {
                JL_Log.i(f3610f, "-startAuth- The device has been certified or certification of device is in progress.");
                return true;
            }
            this.f3618d.remove(bluetoothDevice.getAddress());
        }
        JL_Log.i(f3610f, "-startAuth- device = " + RcspUtil.printBtDeviceInfo(bluetoothDevice));
        final AuthTask randomData = new AuthTask().setDevice(bluetoothDevice).setRandomData(getRandomData());
        this.f3618d.put(bluetoothDevice.getAddress(), randomData);
        boolean sendAuthDataToDevice = this.f3616b.sendAuthDataToDevice(bluetoothDevice, b());
        if (sendAuthDataToDevice) {
            this.f3619e.postDelayed(new Runnable() { // from class: com.jieli.jl_rcsp.impl.RcspAuth$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    RcspAuth.this.a(bluetoothDevice, randomData);
                }
            }, 500L);
        }
        return sendAuthDataToDevice;
    }

    public void stopAuth(BluetoothDevice bluetoothDevice) {
        stopAuth(bluetoothDevice, true);
    }

    private byte[] b() {
        return CHexConver.hexStr2Bytes("FEDCBAC00600020001EF");
    }

    public void stopAuth(BluetoothDevice bluetoothDevice, boolean z) {
        if (bluetoothDevice == null || !this.f3615a) {
            return;
        }
        AuthTask remove = this.f3618d.remove(bluetoothDevice.getAddress());
        if (z) {
            if (remove != null) {
                a(bluetoothDevice, 40978);
            }
            this.f3619e.removeMessages(17);
            this.f3619e.removeMessages(18);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(BluetoothDevice bluetoothDevice, AuthTask authTask) {
        if (this.f3616b.sendAuthDataToDevice(bluetoothDevice, authTask.getRandomData())) {
            this.f3619e.removeMessages(17);
            Handler handler = this.f3619e;
            handler.sendMessageDelayed(handler.obtainMessage(17, bluetoothDevice), f3614j);
            return;
        }
        a(bluetoothDevice, 40979, "Failed to send data.");
    }

    private boolean a(byte[] bArr) {
        if (bArr == null || bArr.length == 0) {
            return false;
        }
        if (bArr.length != 5 || bArr[0] != 2) {
            if (bArr.length != 17) {
                return false;
            }
            byte b2 = bArr[0];
            if (b2 != 0 && b2 != 1) {
                return false;
            }
        }
        return true;
    }

    private void a(boolean z) {
        OnRcspAuthListener onRcspAuthListener = this.f3617c;
        if (onRcspAuthListener != null) {
            onRcspAuthListener.onInitResult(z);
        }
    }

    private void a(BluetoothDevice bluetoothDevice) {
        JL_Log.w(f3610f, RcspUtil.formatString("-onAuthSuccess- device = %s,  auth ok.", bluetoothDevice));
        if (bluetoothDevice != null) {
            this.f3618d.remove(bluetoothDevice.getAddress());
        }
        OnRcspAuthListener onRcspAuthListener = this.f3617c;
        if (onRcspAuthListener != null) {
            onRcspAuthListener.onAuthSuccess(bluetoothDevice);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, int i2) {
        a(bluetoothDevice, i2, a(i2));
    }

    private void a(BluetoothDevice bluetoothDevice, int i2, String str) {
        JL_Log.e(f3610f, RcspUtil.formatString("-onAuthFailed- device = %s,  code = %d, message = %s.", bluetoothDevice, Integer.valueOf(i2), str));
        this.f3619e.removeMessages(17);
        this.f3619e.removeMessages(18);
        if (bluetoothDevice != null) {
            this.f3618d.remove(bluetoothDevice.getAddress());
        }
        OnRcspAuthListener onRcspAuthListener = this.f3617c;
        if (onRcspAuthListener != null) {
            onRcspAuthListener.onAuthFailed(bluetoothDevice, i2, str);
        }
    }
}
