package com.jieli.jl_rcsp.impl;

import android.bluetooth.BluetoothDevice;
import com.jieli.jl_rcsp.interfaces.OnOperationCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback;
import com.jieli.jl_rcsp.interfaces.record.IRecordOp;
import com.jieli.jl_rcsp.interfaces.record.OnRecordStateCallback;
import com.jieli.jl_rcsp.model.RecordParam;
import com.jieli.jl_rcsp.model.RecordState;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.base.CommandBase;
import com.jieli.jl_rcsp.model.command.data.DataCmd;
import com.jieli.jl_rcsp.model.command.data.DataHasResponseCmd;
import com.jieli.jl_rcsp.model.command.speech.StartSpeechCmd;
import com.jieli.jl_rcsp.model.command.speech.StopSpeechCmd;
import com.jieli.jl_rcsp.model.parameter.DataParam;
import com.jieli.jl_rcsp.model.parameter.StartSpeechParam;
import com.jieli.jl_rcsp.model.parameter.StopSpeechParam;
import com.jieli.jl_rcsp.tool.BooleanRcspActionCallback;
import com.jieli.jl_rcsp.tool.RecordStateCallbackHelper;
import com.jieli.jl_rcsp.util.CHexConver;
import com.jieli.jl_rcsp.util.JL_Log;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

/* loaded from: classes3.dex */
public class RecordOpImpl implements IRecordOp {

    /* renamed from: b, reason: collision with root package name */
    private final RcspOpImpl f3635b;

    /* renamed from: c, reason: collision with root package name */
    private final RecordState f3636c;

    /* renamed from: d, reason: collision with root package name */
    private final RecordStateCallbackHelper f3637d;

    /* renamed from: f, reason: collision with root package name */
    private final OnRcspCallback f3639f;

    /* renamed from: a, reason: collision with root package name */
    private final String f3634a = "RecordOpImpl";

    /* renamed from: e, reason: collision with root package name */
    private final RcspCommandCallback<CommandBase> f3638e = new RcspCommandCallback<CommandBase>() { // from class: com.jieli.jl_rcsp.impl.RecordOpImpl.3
        @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
        public void onCommandResponse(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
        }

        @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
        public void onErrCode(BluetoothDevice bluetoothDevice, BaseError baseError) {
            if (baseError == null) {
                return;
            }
            RecordOpImpl.this.a(bluetoothDevice, baseError.getSubCode(), baseError.getMessage());
        }
    };

    public RecordOpImpl(RcspOpImpl rcspOpImpl) {
        OnRcspCallback onRcspCallback = new OnRcspCallback() { // from class: com.jieli.jl_rcsp.impl.RecordOpImpl.4
            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspCommand(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
                if (commandBase == null) {
                    return;
                }
                int id = commandBase.getId();
                if (id == 4) {
                    if (RecordOpImpl.this.a()) {
                        return;
                    }
                    StartSpeechCmd startSpeechCmd = (StartSpeechCmd) commandBase;
                    StartSpeechParam startSpeechParam = (StartSpeechParam) startSpeechCmd.getParam();
                    if (startSpeechParam == null) {
                        return;
                    }
                    RecordOpImpl.this.a(bluetoothDevice, new RecordParam(startSpeechParam.getType(), startSpeechParam.getFreq(), startSpeechParam.getWay()));
                    startSpeechCmd.setParam(null);
                    startSpeechCmd.setStatus(0);
                    RecordOpImpl.this.f3635b.sendCommandResponse(bluetoothDevice, startSpeechCmd, RecordOpImpl.this.f3638e);
                    return;
                }
                if (id == 5 && RecordOpImpl.this.a()) {
                    StopSpeechCmd stopSpeechCmd = (StopSpeechCmd) commandBase;
                    StopSpeechParam stopSpeechParam = (StopSpeechParam) stopSpeechCmd.getParam();
                    if (stopSpeechParam == null) {
                        return;
                    }
                    RecordOpImpl.this.a(bluetoothDevice, stopSpeechParam.getReason());
                    stopSpeechCmd.setParam(null);
                    stopSpeechCmd.setStatus(0);
                    RecordOpImpl.this.f3635b.sendCommandResponse(bluetoothDevice, stopSpeechCmd, RecordOpImpl.this.f3638e);
                }
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspDataCmd(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
                if (commandBase != null) {
                    if (commandBase.getId() != 1) {
                        return;
                    }
                    boolean z = commandBase.getType() == 2;
                    DataParam dataParam = z ? (DataParam) ((DataHasResponseCmd) commandBase).getParam() : (DataParam) ((DataCmd) commandBase).getParam();
                    if (dataParam == null || dataParam.getXmOpCode() != 4) {
                        return;
                    }
                    RecordOpImpl.this.a(bluetoothDevice, dataParam.getData());
                    if (z) {
                        ((DataHasResponseCmd) commandBase).setParam(null);
                        commandBase.setStatus(0);
                        RecordOpImpl.this.f3635b.sendCommandResponse(bluetoothDevice, commandBase, RecordOpImpl.this.f3638e);
                    }
                }
            }
        };
        this.f3639f = onRcspCallback;
        if (rcspOpImpl == null) {
            throw new NullPointerException("RcspOpImpl can not be null.");
        }
        this.f3635b = rcspOpImpl;
        this.f3636c = new RecordState();
        this.f3637d = new RecordStateCallbackHelper();
        rcspOpImpl.registerOnRcspCallback(onRcspCallback);
    }

    @Override // com.jieli.jl_rcsp.interfaces.record.IRecordOp
    public void addOnRecordStateCallback(OnRecordStateCallback onRecordStateCallback) {
        this.f3637d.addOnRecordStateCallback(onRecordStateCallback);
    }

    public BluetoothDevice getConnectedDevice() {
        return this.f3635b.getConnectedDevice();
    }

    public RcspOpImpl getRcspOp() {
        return this.f3635b;
    }

    @Override // com.jieli.jl_rcsp.interfaces.record.IRecordOp
    public RecordState getRecordState() {
        return this.f3636c;
    }

    @Override // com.jieli.jl_rcsp.interfaces.record.IRecordOp
    public void release() {
        stopRecord(this.f3635b.getConnectedDevice(), 1, null);
        this.f3635b.unregisterOnRcspCallback(this.f3639f);
        this.f3637d.release();
    }

    @Override // com.jieli.jl_rcsp.interfaces.record.IRecordOp
    public void removeOnRecordStateCallback(OnRecordStateCallback onRecordStateCallback) {
        this.f3637d.removeOnRecordStateCallback(onRecordStateCallback);
    }

    @Override // com.jieli.jl_rcsp.interfaces.record.IRecordOp
    public void startRecord(final BluetoothDevice bluetoothDevice, RecordParam recordParam, final OnOperationCallback<Boolean> onOperationCallback) {
        if (recordParam == null) {
            if (onOperationCallback != null) {
                onOperationCallback.onFailed(new BaseError(4097, "startRecord : RecordParam is null."));
            }
        } else if (!a()) {
            a(bluetoothDevice, recordParam);
            this.f3635b.sendRcspCommand(bluetoothDevice, new StartSpeechCmd(new StartSpeechParam(CHexConver.intToByte(recordParam.getVoiceType()), CHexConver.intToByte(recordParam.getSampleRate()), CHexConver.intToByte(recordParam.getVadWay()))), new BooleanRcspActionCallback("startRecord", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.impl.RecordOpImpl.1
                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onFailed(BaseError baseError) {
                    OnOperationCallback onOperationCallback2 = onOperationCallback;
                    if (onOperationCallback2 != null) {
                        onOperationCallback2.onFailed(baseError);
                    }
                    RecordOpImpl.this.a(bluetoothDevice, baseError.getSubCode(), baseError.getMessage());
                }

                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onSuccess(Boolean bool) {
                    OnOperationCallback onOperationCallback2 = onOperationCallback;
                    if (onOperationCallback2 != null) {
                        onOperationCallback2.onSuccess(bool);
                    }
                }
            }));
        } else if (onOperationCallback != null) {
            onOperationCallback.onFailed(new BaseError(12291, "startRecord : Recording"));
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.record.IRecordOp
    public void stopRecord(final BluetoothDevice bluetoothDevice, final int i2, final OnOperationCallback<Boolean> onOperationCallback) {
        if (a()) {
            StopSpeechParam stopSpeechParam = new StopSpeechParam();
            stopSpeechParam.setReason(CHexConver.intToByte(i2));
            this.f3635b.sendRcspCommand(bluetoothDevice, new StopSpeechCmd(stopSpeechParam), new BooleanRcspActionCallback("stopRecord", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.impl.RecordOpImpl.2
                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onFailed(BaseError baseError) {
                    OnOperationCallback onOperationCallback2 = onOperationCallback;
                    if (onOperationCallback2 != null) {
                        onOperationCallback2.onFailed(baseError);
                    }
                    RecordOpImpl.this.a(bluetoothDevice, baseError.getSubCode(), baseError.getMessage());
                }

                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onSuccess(Boolean bool) {
                    OnOperationCallback onOperationCallback2 = onOperationCallback;
                    if (onOperationCallback2 != null) {
                        onOperationCallback2.onSuccess(bool);
                    }
                    RecordOpImpl.this.a(bluetoothDevice, i2);
                }
            }));
        } else if (onOperationCallback != null) {
            onOperationCallback.onFailed(new BaseError(4097, "Recording is not started."));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean a() {
        return this.f3636c.getState() != 0;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, RecordParam recordParam) {
        if (recordParam != null && !a()) {
            this.f3636c.setState(1).setRecordParam(recordParam).setVoiceData(new byte[0]);
            this.f3637d.onStateChange(bluetoothDevice, this.f3636c);
        } else {
            JL_Log.w(this.f3634a, "cbRecordStart : RecordParam is null or state error. " + this.f3636c.getState());
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, byte[] bArr) {
        if (bArr != null && bArr.length != 0 && a()) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                if (this.f3636c.getVoiceData() != null && this.f3636c.getVoiceData().length > 0) {
                    byteArrayOutputStream.write(this.f3636c.getVoiceData());
                }
                byteArrayOutputStream.write(bArr);
            } catch (IOException e2) {
                e2.printStackTrace();
            }
            this.f3636c.setState(2).setVoiceDataBlock(bArr).setVoiceData(byteArrayOutputStream.toByteArray());
            this.f3637d.onStateChange(bluetoothDevice, this.f3636c);
            return;
        }
        JL_Log.w(this.f3634a, "cbRecordWorking : data is null or state error. " + this.f3636c.getState());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, int i2) {
        if (!a()) {
            JL_Log.w(this.f3634a, "cbRecordStop : state error. " + this.f3636c.getState() + ", reason = " + i2);
            return;
        }
        this.f3636c.setState(0).setVoiceDataBlock(new byte[0]).setReason(i2);
        this.f3637d.onStateChange(bluetoothDevice, this.f3636c);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, int i2, String str) {
        if (!a()) {
            JL_Log.w(this.f3634a, "cbRecordError : state error. " + this.f3636c.getState() + ", code = " + i2 + ", explain = " + str);
            return;
        }
        this.f3636c.setState(0).setVoiceDataBlock(new byte[0]).setVoiceData(new byte[0]).setReason(i2).setMessage(str);
        this.f3637d.onStateChange(bluetoothDevice, this.f3636c);
    }
}
