package com.jieli.jl_rcsp.impl;

import android.bluetooth.BluetoothDevice;
import com.jieli.jl_fatfs.interfaces.OnFatFileProgressListener;
import com.jieli.jl_fatfs.model.FatFile;
import com.jieli.jl_filebrowse.FileBrowseManager;
import com.jieli.jl_rcsp.constant.WatchConstant;
import com.jieli.jl_rcsp.constant.WatchError;
import com.jieli.jl_rcsp.interfaces.OnOperationCallback;
import com.jieli.jl_rcsp.interfaces.data.IDataTransferOp;
import com.jieli.jl_rcsp.interfaces.data.OnDataEventCallback;
import com.jieli.jl_rcsp.interfaces.data.OnDataTransferListener;
import com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.OnRcspEventListener;
import com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback;
import com.jieli.jl_rcsp.interfaces.watch.IWatchManager;
import com.jieli.jl_rcsp.interfaces.watch.IWatchOp;
import com.jieli.jl_rcsp.interfaces.watch.OnUpdateResourceCallback;
import com.jieli.jl_rcsp.interfaces.watch.OnWatchCallback;
import com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback;
import com.jieli.jl_rcsp.model.NotificationMsg;
import com.jieli.jl_rcsp.model.WatchFileContent;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.base.BasePacket;
import com.jieli.jl_rcsp.model.base.CommandBase;
import com.jieli.jl_rcsp.model.command.external_flash.ExtFlashIOCtrlNoResponseCmd;
import com.jieli.jl_rcsp.model.command.external_flash.GetExternalFlashMsgCmd;
import com.jieli.jl_rcsp.model.command.watch.PushInfoDataToDeviceCmd;
import com.jieli.jl_rcsp.model.data.DataParams;
import com.jieli.jl_rcsp.model.data.SendParams;
import com.jieli.jl_rcsp.model.device.BatteryInfo;
import com.jieli.jl_rcsp.model.device.DeviceInfo;
import com.jieli.jl_rcsp.model.parameter.ExternalFlashIOCtrlParam;
import com.jieli.jl_rcsp.model.response.ExternalFlashMsgResponse;
import com.jieli.jl_rcsp.tool.WatchCallbackManager;
import com.jieli.jl_rcsp.tool.datahandles.ParseHelper;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;
import com.jieli.jl_rcsp.watch.WatchBase;
import com.jieli.jl_rcsp.watch.fatfs.FatFsWatch;
import com.jieli.jl_rcsp.watch.rcsp.RcspWatch;
import java.util.ArrayList;

/* loaded from: classes3.dex */
public abstract class WatchOpImpl extends RcspOpImpl implements IWatchOp, IDataTransferOp {
    public static final int FUNC_FILE_BROWSE = 2;
    public static final int FUNC_RCSP = 0;
    public static final int FUNC_WATCH = 1;

    /* renamed from: g, reason: collision with root package name */
    private static final String f3649g = "WatchOpImpl";

    /* renamed from: a, reason: collision with root package name */
    private final WatchCallbackManager f3650a;

    /* renamed from: b, reason: collision with root package name */
    private final int f3651b;

    /* renamed from: c, reason: collision with root package name */
    private IWatchManager f3652c;

    /* renamed from: d, reason: collision with root package name */
    private final DataTransferOpImpl f3653d;

    /* renamed from: e, reason: collision with root package name */
    private final OnRcspCallback f3654e;

    /* renamed from: f, reason: collision with root package name */
    private final OnRcspEventListener f3655f;

    public final class RcspProgressListener implements OnFatFileProgressListener {

        /* renamed from: a, reason: collision with root package name */
        private final OnFatFileProgressListener f3661a;

        public RcspProgressListener(OnFatFileProgressListener onFatFileProgressListener) {
            this.f3661a = onFatFileProgressListener;
        }

        @Override // com.jieli.jl_fatfs.interfaces.OnFatFileProgressListener
        public void onProgress(float f2) {
            OnFatFileProgressListener onFatFileProgressListener = this.f3661a;
            if (onFatFileProgressListener != null) {
                onFatFileProgressListener.onProgress(f2);
            }
        }

        @Override // com.jieli.jl_fatfs.interfaces.OnFatFileProgressListener
        public void onStart(String str) {
            OnFatFileProgressListener onFatFileProgressListener = this.f3661a;
            if (onFatFileProgressListener != null) {
                onFatFileProgressListener.onStart(str);
            }
        }

        @Override // com.jieli.jl_fatfs.interfaces.OnFatFileProgressListener
        public void onStop(int i2) {
            if (!(WatchOpImpl.this.f3652c instanceof RcspWatch)) {
                OnFatFileProgressListener onFatFileProgressListener = this.f3661a;
                if (onFatFileProgressListener != null) {
                    onFatFileProgressListener.onStop(i2);
                    return;
                }
                return;
            }
            if (i2 == 0) {
                ((RcspWatch) WatchOpImpl.this.f3652c).reLoadFolder(new OnWatchOpCallback<ArrayList<FatFile>>() { // from class: com.jieli.jl_rcsp.impl.WatchOpImpl.RcspProgressListener.1
                    @Override // com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback
                    public void onFailed(BaseError baseError) {
                        if (RcspProgressListener.this.f3661a != null) {
                            RcspProgressListener.this.f3661a.onStop(baseError.getSubCode());
                        }
                    }

                    @Override // com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback
                    public void onSuccess(ArrayList<FatFile> arrayList) {
                        if (RcspProgressListener.this.f3661a != null) {
                            RcspProgressListener.this.f3661a.onStop(0);
                        }
                    }
                });
                JL_Log.w(WatchOpImpl.f3649g, "-RcspHandProgressListener- reLoadFolder >>>> ");
            } else {
                OnFatFileProgressListener onFatFileProgressListener2 = this.f3661a;
                if (onFatFileProgressListener2 != null) {
                    onFatFileProgressListener2.onStop(i2);
                }
            }
        }
    }

    public WatchOpImpl(int i2) {
        OnRcspCallback onRcspCallback = new OnRcspCallback() { // from class: com.jieli.jl_rcsp.impl.WatchOpImpl.3
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onConnectStateChange(BluetoothDevice bluetoothDevice, int i3) {
                BluetoothDevice targetDevice = WatchOpImpl.this.getTargetDevice();
                WatchOpImpl.this.f3650a.onConnectStateChange(bluetoothDevice, i3);
                JL_Log.w(WatchOpImpl.f3649g, "-onConnectStateChange- device = " + RcspUtil.printBtDeviceInfo(bluetoothDevice) + ", connectedDevice = " + RcspUtil.printBtDeviceInfo(targetDevice) + ", status = " + i3);
                if (RcspUtil.deviceEquals(bluetoothDevice, targetDevice) && (i3 == 2 || i3 == 0)) {
                    WatchOpImpl.this.b();
                }
                super.onConnectStateChange(bluetoothDevice, i3);
            }

            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onMandatoryUpgrade(BluetoothDevice bluetoothDevice) {
                WatchOpImpl.this.f3650a.onMandatoryUpgrade(bluetoothDevice);
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspCommand(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
                WatchOpImpl.this.f3650a.onRcspCommand(bluetoothDevice, commandBase);
                if (commandBase.getId() == 26 && (commandBase instanceof ExtFlashIOCtrlNoResponseCmd)) {
                    ExternalFlashIOCtrlParam externalFlashIOCtrlParam = (ExternalFlashIOCtrlParam) ((ExtFlashIOCtrlNoResponseCmd) commandBase).getParam();
                    if (externalFlashIOCtrlParam.getOp() == 3 && externalFlashIOCtrlParam.getWatchOp() == 2) {
                        WatchOpImpl.this.f3650a.onCurrentWatchInfo(bluetoothDevice, externalFlashIOCtrlParam.getFilePath());
                    }
                }
            }

            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspDataCmd(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
                WatchOpImpl.this.f3650a.onRcspDataCmd(bluetoothDevice, commandBase);
            }

            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspError(BluetoothDevice bluetoothDevice, BaseError baseError) {
                WatchOpImpl.this.f3650a.onRcspError(bluetoothDevice, baseError);
            }

            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspInit(BluetoothDevice bluetoothDevice, boolean z) {
                JL_Log.i(WatchOpImpl.f3649g, "-onRcspInit- device = " + RcspUtil.printBtDeviceInfo(bluetoothDevice) + ", isInit = " + z);
                WatchOpImpl.this.f3650a.onRcspInit(bluetoothDevice, z);
                if (z) {
                    WatchOpImpl.this.b();
                    WatchOpImpl.this.a(bluetoothDevice);
                }
            }
        };
        this.f3654e = onRcspCallback;
        this.f3655f = new OnRcspEventListener() { // from class: com.jieli.jl_rcsp.impl.WatchOpImpl.4
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspEventListener
            public void onBatteryChange(BluetoothDevice bluetoothDevice, BatteryInfo batteryInfo) {
                WatchOpImpl.this.f3650a.onDevicePower(bluetoothDevice, batteryInfo);
            }
        };
        this.f3650a = new WatchCallbackManager();
        this.f3651b = i2;
        JL_Log.i(f3649g, "init WatchOpImpl. Lib name = " + WatchConstant.getLibVersionName() + ", func = " + i2);
        if (i2 == 1) {
            registerOnRcspCallback(onRcspCallback);
            if (!FileBrowseManager.getInstance().isInit()) {
                FileBrowseManager.getInstance().init(this);
            }
        } else if (i2 == 2 && !FileBrowseManager.getInstance().isInit()) {
            FileBrowseManager.getInstance().init(this);
        }
        this.f3653d = new DataTransferOpImpl(this, new OnDataTransferListener() { // from class: com.jieli.jl_rcsp.impl.WatchOpImpl.1
            @Override // com.jieli.jl_rcsp.interfaces.data.OnDataTransferListener
            public void onError(BluetoothDevice bluetoothDevice, BaseError baseError) {
                WatchOpImpl.this.f3650a.onBigDataError(bluetoothDevice, baseError);
            }

            @Override // com.jieli.jl_rcsp.interfaces.data.OnDataTransferListener
            public void onReceiveData(BluetoothDevice bluetoothDevice, int i3, byte[] bArr) {
                WatchOpImpl.this.f3650a.onReceiveBigData(bluetoothDevice, i3, bArr);
                if (i3 == 2) {
                    WatchOpImpl watchOpImpl = WatchOpImpl.this;
                    RTCOpImpl.parseRTCBigData(watchOpImpl, watchOpImpl.mRcspEventListenerManager, bArr);
                }
            }
        });
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public boolean cancelTransfer() {
        IWatchManager iWatchManager = this.f3652c;
        if (iWatchManager == null) {
            return false;
        }
        return iWatchManager.cancelTransfer();
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void createWatchFile(String str, boolean z, OnFatFileProgressListener onFatFileProgressListener) {
        if (!a(onFatFileProgressListener) || a("createWatchFile", onFatFileProgressListener)) {
            return;
        }
        this.f3652c.createWatchFile(str, z, new RcspProgressListener(onFatFileProgressListener));
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void deleteWatchFile(String str, OnFatFileProgressListener onFatFileProgressListener) {
        if (!a(onFatFileProgressListener) || a("deleteWatchFile", onFatFileProgressListener)) {
            return;
        }
        this.f3652c.deleteWatchFile(str, onFatFileProgressListener);
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void enableCustomWatchBg(String str, OnWatchOpCallback<FatFile> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.enableCustomWatchBg(str, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public String getCurrentBrowsePath() {
        IWatchManager iWatchManager = this.f3652c;
        if (iWatchManager == null) {
            return null;
        }
        return iWatchManager.getCurrentBrowsePath();
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void getCurrentWatchInfo(OnWatchOpCallback<FatFile> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.getCurrentWatchInfo(onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void getCustomWatchBgInfo(String str, OnWatchOpCallback<String> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.getCustomWatchBgInfo(str, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void getWatchFileSize(String str, OnWatchOpCallback<WatchFileContent> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.getWatchFileSize(str, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void getWatchMessage(String str, OnWatchOpCallback<String> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.getWatchMessage(str, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void getWatchSysLeftSize(OnWatchOpCallback<Long> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.getWatchSysLeftSize(onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.bluetooth.IBluetoothProxy
    public boolean isDeviceConnected(BluetoothDevice bluetoothDevice) {
        return RcspUtil.deviceEquals(bluetoothDevice, getConnectedDevice());
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public boolean isOTAResource() {
        IWatchManager iWatchManager = this.f3652c;
        return iWatchManager != null && iWatchManager.isOTAResource();
    }

    public boolean isWatchSystemOk() {
        IWatchManager iWatchManager = this.f3652c;
        return iWatchManager != null && iWatchManager.isInit();
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void jumpToUpdateResource(boolean z, OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.jumpToUpdateResource(z, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void listWatchList(OnWatchOpCallback<ArrayList<FatFile>> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.listWatchList(onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void openWatchFile(String str, OnWatchOpCallback<byte[]> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            if (!c()) {
                this.f3652c.openWatchFile(str, onWatchOpCallback);
                return;
            }
            JL_Log.w(f3649g, "openWatchFile : The device is busy.");
            if (onWatchOpCallback != null) {
                onWatchOpCallback.onFailed(new BaseError(12545, WatchError.getErrorDesc(12545)));
            }
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void pushMessageInfo(NotificationMsg notificationMsg, OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.pushMessageInfo(notificationMsg, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.data.IDataTransferOp
    public void readLargeData(DataParams dataParams, OnDataEventCallback onDataEventCallback) {
        this.f3653d.readLargeData(dataParams, onDataEventCallback);
    }

    @Override // com.jieli.jl_rcsp.impl.RcspOpImpl, com.jieli.jl_rcsp.interfaces.bluetooth.IBluetoothProxy
    public void receiveDataFromDevice(BluetoothDevice bluetoothDevice, BasePacket basePacket) {
        super.receiveDataFromDevice(bluetoothDevice, basePacket);
        a(bluetoothDevice, basePacket);
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void registerOnWatchCallback(OnWatchCallback onWatchCallback) {
        this.f3650a.registerWatchCallback(onWatchCallback);
        BluetoothDevice targetDevice = getTargetDevice();
        if (targetDevice != null) {
            DeviceInfo deviceInfo = this.mStatusManager.getDeviceInfo(targetDevice);
            ExternalFlashMsgResponse extFlashMsg = this.mStatusManager.getExtFlashMsg(targetDevice);
            if (deviceInfo != null) {
                if (deviceInfo.isMandatoryUpgrade()) {
                    onWatchCallback.onMandatoryUpgrade(targetDevice);
                    return;
                }
                if (extFlashMsg != null && extFlashMsg.getSysStatus() != 0) {
                    onWatchCallback.onWatchSystemException(targetDevice, extFlashMsg.getSysStatus());
                } else if (deviceInfo.getExpandMode() == 1) {
                    JL_Log.w(f3649g, "-registerOnWatchCallback- onResourceUpdateUnfinished >>> ");
                    onWatchCallback.onResourceUpdateUnfinished(targetDevice);
                }
            }
        }
    }

    @Override // com.jieli.jl_rcsp.impl.RcspOpImpl, com.jieli.jl_rcsp.interfaces.rcsp.IRcspOp
    public void release() {
        FileBrowseManager.getInstance().release();
        unregisterOnRcspCallback(this.f3654e);
        super.release();
        b();
        this.f3653d.destroy();
        this.f3650a.release();
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void removeMessageInfo(NotificationMsg notificationMsg, OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.removeMessageInfo(notificationMsg, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void replaceWatchFile(String str, OnFatFileProgressListener onFatFileProgressListener) {
        if (!a(onFatFileProgressListener) || a("replaceWatchFile", onFatFileProgressListener)) {
            return;
        }
        this.f3652c.replaceWatchFile(str, new RcspProgressListener(onFatFileProgressListener));
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void requestDevicePower(OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.requestDevicePower(onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void restoreWatchSystem(OnFatFileProgressListener onFatFileProgressListener) {
        if (a(onFatFileProgressListener)) {
            this.f3652c.restoreWatchSystem(onFatFileProgressListener);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.data.IDataTransferOp
    public void sendLargeData(SendParams sendParams, OnDataEventCallback onDataEventCallback) {
        this.f3653d.sendLargeData(sendParams, onDataEventCallback);
    }

    public void sendRcspCommand(CommandBase commandBase, RcspCommandCallback rcspCommandCallback) {
        sendRcspCommand(getConnectedDevice(), commandBase, rcspCommandCallback);
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void setCurrentWatchInfo(String str, OnWatchOpCallback<FatFile> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.setCurrentWatchInfo(str, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void syncWeatherInfo(PushInfoDataToDeviceCmd.Weather weather, OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.syncWeatherInfo(weather, onWatchOpCallback);
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void unregisterOnWatchCallback(OnWatchCallback onWatchCallback) {
        this.f3650a.unregisterWatchCallback(onWatchCallback);
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void updateWatchResource(String str, OnUpdateResourceCallback onUpdateResourceCallback) {
        IWatchManager iWatchManager = this.f3652c;
        if (iWatchManager != null) {
            iWatchManager.updateWatchResource(str, onUpdateResourceCallback);
        } else if (onUpdateResourceCallback != null) {
            onUpdateResourceCallback.onError(WatchError.ERR_FAT_JNI_INIT, WatchError.getErrorDesc(WatchError.ERR_FAT_JNI_INIT));
        }
    }

    @Override // com.jieli.jl_rcsp.interfaces.watch.IWatchOp
    public void writeResourceOTAFlag(boolean z, OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (a(onWatchOpCallback)) {
            this.f3652c.writeResourceOTAFlag(z, onWatchOpCallback);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b() {
        if (this.f3652c != null) {
            unregisterOnRcspEventListener(this.f3655f);
            this.f3652c.destroy();
            this.f3652c = null;
        }
    }

    private boolean c() {
        DeviceInfo deviceInfo = getDeviceInfo();
        return deviceInfo != null && deviceInfo.getPhoneStatus() == 1;
    }

    private void a(OnOperationCallback<ExternalFlashMsgResponse> onOperationCallback) {
        WatchBase.queryExtFlashMsgForDevice(this, onOperationCallback);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(final BluetoothDevice bluetoothDevice) {
        if (this.f3651b != 1) {
            return;
        }
        DeviceInfo deviceInfo = this.mStatusManager.getDeviceInfo(bluetoothDevice);
        String str = f3649g;
        JL_Log.d(str, "handleRcspInit : " + RcspUtil.printBtDeviceInfo(bluetoothDevice) + ", " + deviceInfo);
        if (deviceInfo != null) {
            if (deviceInfo.isSupportExternalFlashTransfer()) {
                ExternalFlashMsgResponse extFlashMsg = this.mStatusManager.getExtFlashMsg(bluetoothDevice);
                JL_Log.d(str, "-getExtFlashMsg- flashMsg = " + extFlashMsg);
                if (extFlashMsg == null) {
                    a(new OnOperationCallback<ExternalFlashMsgResponse>() { // from class: com.jieli.jl_rcsp.impl.WatchOpImpl.2
                        @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                        public void onFailed(BaseError baseError) {
                            WatchOpImpl.this.f3650a.onWatchSystemInit(baseError.getSubCode());
                        }

                        @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                        public void onSuccess(ExternalFlashMsgResponse externalFlashMsgResponse) {
                            if (WatchOpImpl.this.mStatusManager.getExtFlashMsg(bluetoothDevice) == null) {
                                WatchOpImpl.this.mStatusManager.updateExtFlashMsg(bluetoothDevice, externalFlashMsgResponse);
                            }
                            WatchOpImpl.this.a(bluetoothDevice);
                        }
                    });
                    return;
                }
                if (extFlashMsg.getSystem() == 0) {
                    this.f3652c = new FatFsWatch(this, this.f3650a);
                } else {
                    this.f3652c = new RcspWatch(this, this.f3650a);
                }
                this.f3652c.init();
                JL_Log.w(str, "init WatchManager....SysStatus = " + extFlashMsg.getSysStatus());
                registerOnRcspEventListener(this.f3655f);
                return;
            }
            JL_Log.w(str, "handleRcspInit :: device does not support flash to transfer data.");
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    private void a(final BluetoothDevice bluetoothDevice, BasePacket basePacket) {
        final ExternalFlashMsgResponse externalFlashMsgResponse;
        int opCode = basePacket.getOpCode();
        boolean z = basePacket.getType() == 1;
        CommandBase convert2Command = ParseHelper.convert2Command(bluetoothDevice, basePacket);
        if (convert2Command == null) {
            BaseError baseError = new BaseError(12289, "Failed to parse RCSP data.");
            baseError.setOpCode(basePacket.getOpCode());
            this.f3650a.onRcspError(bluetoothDevice, baseError);
            return;
        }
        if (z || opCode != 214 || basePacket.getStatus() != 0 || (externalFlashMsgResponse = (ExternalFlashMsgResponse) ((GetExternalFlashMsgCmd) convert2Command).getResponse()) == null) {
            return;
        }
        JL_Log.i(f3649g, "getDevExtFlashMsg ok, response : " + externalFlashMsgResponse);
        this.mStatusManager.updateExtFlashMsg(bluetoothDevice, externalFlashMsgResponse);
        this.f3650a.onExternalFlashMsg(bluetoothDevice, externalFlashMsgResponse);
        if (externalFlashMsgResponse.getSysStatus() != 0) {
            if (this.f3652c == null) {
                this.mHandler.postDelayed(new Runnable() { // from class: com.jieli.jl_rcsp.impl.WatchOpImpl$$ExternalSyntheticLambda0
                    @Override // java.lang.Runnable
                    public final void run() {
                        WatchOpImpl.this.a(bluetoothDevice, externalFlashMsgResponse);
                    }
                }, 100L);
            } else {
                this.f3650a.onWatchSystemException(bluetoothDevice, externalFlashMsgResponse.getSysStatus());
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(BluetoothDevice bluetoothDevice, ExternalFlashMsgResponse externalFlashMsgResponse) {
        this.f3650a.onWatchSystemException(bluetoothDevice, externalFlashMsgResponse.getSysStatus());
    }

    private boolean a(OnFatFileProgressListener onFatFileProgressListener) {
        if (this.f3652c != null) {
            return true;
        }
        JL_Log.e(f3649g, "checkWatchManagerIsInit : Watch system has not been initialized.");
        if (onFatFileProgressListener == null) {
            return false;
        }
        onFatFileProgressListener.onStop(WatchError.ERR_FAT_JNI_INIT);
        return false;
    }

    private boolean a(String str, OnFatFileProgressListener onFatFileProgressListener) {
        if (!c()) {
            return false;
        }
        JL_Log.w(f3649g, str + " : " + WatchError.getErrorDesc(12545));
        if (onFatFileProgressListener == null) {
            return true;
        }
        onFatFileProgressListener.onStop(12545);
        return true;
    }

    private <T> boolean a(OnWatchOpCallback<T> onWatchOpCallback) {
        if (this.f3652c != null) {
            return true;
        }
        if (onWatchOpCallback == null) {
            return false;
        }
        onWatchOpCallback.onFailed(new BaseError(WatchError.ERR_FAT_JNI_INIT, WatchError.getErrorDesc(WatchError.ERR_FAT_JNI_INIT)));
        return false;
    }
}
