package com.jieli.jl_rcsp.model.command.nfc;

import com.jieli.jl_rcsp.model.base.BaseParameter;
import com.jieli.jl_rcsp.model.base.CommandWithParamAndResponse;
import com.jieli.jl_rcsp.model.base.CommonResponse;
import com.jieli.jl_rcsp.util.CHexConver;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

/* loaded from: classes3.dex */
public class NFCOperationCmd extends CommandWithParamAndResponse<Param, Response> {

    public static class DefaultNfcParam extends Param {
        private final int flag;
        private final byte[] value;

        public DefaultNfcParam(int i2, int i3, byte[] bArr) {
            super(i2, 5);
            this.flag = i3;
            this.value = bArr;
        }

        public int getFlag() {
            return this.flag;
        }

        @Override // com.jieli.jl_rcsp.model.command.nfc.NFCOperationCmd.Param, com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                byteArrayOutputStream.write(super.getParamData());
                byteArrayOutputStream.write((byte) this.flag);
                byte[] bArr = this.value;
                if (bArr != null && bArr.length > 0) {
                    byteArrayOutputStream.write(bArr);
                }
            } catch (IOException e2) {
                e2.printStackTrace();
            }
            return byteArrayOutputStream.toByteArray();
        }

        public byte[] getValue() {
            return this.value;
        }
    }

    public static class DeleteMsgParam extends Param {
        private final short id;

        public DeleteMsgParam(int i2, short s) {
            super(i2, 3);
            this.id = s;
        }

        public short getId() {
            return this.id;
        }

        @Override // com.jieli.jl_rcsp.model.command.nfc.NFCOperationCmd.Param, com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                byteArrayOutputStream.write(super.getParamData());
                byteArrayOutputStream.write(CHexConver.shortToBigBytes(this.id));
            } catch (IOException e2) {
                e2.printStackTrace();
            }
            return byteArrayOutputStream.toByteArray();
        }
    }

    public static class GetDefaultNfcParam extends DefaultNfcParam {
        public GetDefaultNfcParam(int i2) {
            super(i2, 0, null);
        }
    }

    public static class GetDefaultNfcResponse extends Response {
        private final short id;

        public GetDefaultNfcResponse(int i2, short s) {
            super(i2);
            this.id = s;
        }

        public short getId() {
            return this.id;
        }
    }

    public static class InsertFileEndParam extends Param {
        private final String fileName;

        public InsertFileEndParam(int i2, String str) {
            super(i2, 7);
            this.fileName = str;
        }

        public String getFileName() {
            return this.fileName;
        }

        @Override // com.jieli.jl_rcsp.model.command.nfc.NFCOperationCmd.Param, com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                byteArrayOutputStream.write(super.getParamData());
                String str = this.fileName;
                if (str != null) {
                    byteArrayOutputStream.write(str.getBytes());
                }
            } catch (IOException e2) {
                e2.printStackTrace();
            }
            return byteArrayOutputStream.toByteArray();
        }
    }

    public static class InsertFileParam extends Param {
        private final String fileName;
        private final int fileSize;

        public InsertFileParam(int i2, int i3, String str) {
            super(i2, 6);
            this.fileSize = i3;
            this.fileName = str;
        }

        public String getFileName() {
            return this.fileName;
        }

        public int getFileSize() {
            return this.fileSize;
        }

        @Override // com.jieli.jl_rcsp.model.command.nfc.NFCOperationCmd.Param, com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                byteArrayOutputStream.write(super.getParamData());
                byteArrayOutputStream.write(CHexConver.intToBigBytes(this.fileSize));
                String str = this.fileName;
                if (str != null) {
                    byteArrayOutputStream.write(str.getBytes());
                }
            } catch (IOException e2) {
                e2.printStackTrace();
            }
            return byteArrayOutputStream.toByteArray();
        }
    }

    public static class ModifyMsgParam extends Param {
        private final short id;
        private final int mask;
        private final byte[] value;

        public ModifyMsgParam(int i2, short s, int i3, byte[] bArr) {
            super(i2, 2);
            this.id = s;
            this.mask = i3;
            this.value = bArr;
        }

        public short getId() {
            return this.id;
        }

        public int getMask() {
            return this.mask;
        }

        @Override // com.jieli.jl_rcsp.model.command.nfc.NFCOperationCmd.Param, com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                byteArrayOutputStream.write(super.getParamData());
                byteArrayOutputStream.write(CHexConver.shortToBigBytes(this.id));
                byteArrayOutputStream.write(CHexConver.intToBigBytes(this.mask));
                byte[] bArr = this.value;
                if (bArr != null && bArr.length > 0) {
                    byteArrayOutputStream.write(bArr);
                }
            } catch (IOException e2) {
                e2.printStackTrace();
            }
            return byteArrayOutputStream.toByteArray();
        }

        public byte[] getValue() {
            return this.value;
        }
    }

    public static class NotifyNfcParam extends Param {
        public NotifyNfcParam(int i2) {
            super(i2, 4);
        }

        @Override // com.jieli.jl_rcsp.model.command.nfc.NFCOperationCmd.Param, com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            return super.getParamData();
        }
    }

    public static class Param extends BaseParameter {
        private final int devHandler;
        private final int op;

        public Param(int i2, int i3) {
            this.devHandler = i2;
            this.op = i3;
        }

        public int getDevHandler() {
            return this.devHandler;
        }

        public int getOp() {
            return this.op;
        }

        @Override // com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                byteArrayOutputStream.write(CHexConver.intToBigBytes(this.devHandler));
                byteArrayOutputStream.write((byte) getOp());
            } catch (IOException e2) {
                e2.printStackTrace();
            }
            return byteArrayOutputStream.toByteArray();
        }
    }

    public static class Response extends CommonResponse {
        private final int result;

        public Response(int i2) {
            this.result = i2;
        }

        public int getResult() {
            return this.result;
        }
    }

    public static class SetDefaultNfcParam extends DefaultNfcParam {
        private final short id;

        public SetDefaultNfcParam(int i2, short s) {
            super(i2, 1, CHexConver.shortToBigBytes(s));
            this.id = s;
        }

        public short getId() {
            return this.id;
        }
    }

    public static class StartSyncParam extends Param {
        public StartSyncParam(int i2) {
            super(i2, 0);
        }

        @Override // com.jieli.jl_rcsp.model.command.nfc.NFCOperationCmd.Param, com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            return super.getParamData();
        }
    }

    public NFCOperationCmd(Param param) {
        super(164, "NFCOperationCmd", param);
    }
}
