package com.jieli.jl_rcsp.model.command.watch;

import com.jieli.jl_rcsp.model.base.BaseParameter;
import com.jieli.jl_rcsp.model.base.CommandBase;
import com.jieli.jl_rcsp.model.base.CommonResponse;
import com.jieli.jl_rcsp.util.CHexConver;

/* loaded from: classes3.dex */
public class RequestHealthDataCmd extends CommandBase<Param, Response> {

    public static class Param extends BaseParameter {
        public final int mask;
        public final byte[] subMask;
        public final byte version;

        public Param(int i2, byte b2, byte... bArr) {
            checkMaskAndSubMaskRelation(i2, bArr);
            this.mask = i2;
            this.version = b2;
            this.subMask = bArr;
        }

        private void checkMaskAndSubMaskRelation(int i2, byte[] bArr) {
            int i3 = 0;
            for (int i4 = 0; i4 < 32; i4++) {
                if (CHexConver.getBitByPosition(i2, i4) == 1) {
                    i3++;
                }
            }
            if (i3 == 0) {
                throw new IllegalArgumentException("mask must not be 0x00");
            }
            if (bArr.length != i3) {
                throw new IllegalArgumentException("mask set count not equal to subMask length");
            }
        }

        @Override // com.jieli.jl_rcsp.model.base.BaseParameter, com.jieli.jl_rcsp.interfaces.cmd.IParamBase
        public byte[] getParamData() {
            byte[] bArr = new byte[this.subMask.length + 5];
            byte[] intToBigBytes = CHexConver.intToBigBytes(this.mask);
            System.arraycopy(intToBigBytes, 0, bArr, 0, intToBigBytes.length);
            bArr[4] = this.version;
            byte[] bArr2 = this.subMask;
            System.arraycopy(bArr2, 0, bArr, 5, bArr2.length);
            return bArr;
        }
    }

    public static class Response extends CommonResponse {
        public final byte[] data;
        public final byte flag;
        public final byte ret;

        public Response(byte b2, byte b3, byte[] bArr) {
            this.ret = b2;
            this.flag = b3;
            this.data = bArr;
        }

        public byte[] getData() {
            return this.data;
        }

        public byte getRet() {
            return this.ret;
        }
    }

    public RequestHealthDataCmd(Param param) {
        this(2, param);
    }

    public RequestHealthDataCmd(int i2, Param param) {
        super(160, "RequestHealthDataCmd", i2);
        setParam(param);
    }
}
