package com.jieli.jl_rcsp.task;

import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import com.jieli.jl_rcsp.constant.WatchError;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.IHandleResult;
import com.jieli.jl_rcsp.interfaces.OnOperationCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.base.CommandBase;
import com.jieli.jl_rcsp.model.command.data.DataCmd;
import com.jieli.jl_rcsp.model.command.file_op.ReadFileFromDeviceCmd;
import com.jieli.jl_rcsp.model.device.DeviceInfo;
import com.jieli.jl_rcsp.model.parameter.DataParam;
import com.jieli.jl_rcsp.task.GetFileTask;
import com.jieli.jl_rcsp.tool.BooleanRcspActionCallback;
import com.jieli.jl_rcsp.tool.CustomRcspActionCallback;
import com.jieli.jl_rcsp.util.CHexConver;
import com.jieli.jl_rcsp.util.CryptoUtil;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/* loaded from: classes3.dex */
public abstract class GetFileTask extends TaskBase {
    public static final String BYTE_ARRAY_STREAM = "byte_array_stream";
    public static final int REASON_CRC_ERROR = 2;
    public static final int REASON_LOST_DATA = 1;

    /* renamed from: b, reason: collision with root package name */
    private final String f3670b;

    /* renamed from: c, reason: collision with root package name */
    private OutputStream f3671c;

    /* renamed from: d, reason: collision with root package name */
    private byte[] f3672d;

    /* renamed from: e, reason: collision with root package name */
    private final Param f3673e;

    /* renamed from: f, reason: collision with root package name */
    private final ExecutorService f3674f;

    /* renamed from: g, reason: collision with root package name */
    private final Handler f3675g;

    /* renamed from: h, reason: collision with root package name */
    private final OnRcspCallback f3676h;
    public boolean useCrc;

    /* renamed from: com.jieli.jl_rcsp.task.GetFileTask$4, reason: invalid class name */
    public class AnonymousClass4 extends OnRcspCallback {
        public AnonymousClass4() {
        }

        /* JADX INFO: Access modifiers changed from: private */
        public /* synthetic */ void a(byte[] bArr) {
            GetFileTask.this.a(bArr);
        }

        @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
        public void onConnectStateChange(BluetoothDevice bluetoothDevice, int i2) {
            if (GetFileTask.this.isRun() && i2 != 1) {
                GetFileTask.this.onError(8192);
            }
        }

        /* JADX WARN: Multi-variable type inference failed */
        @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
        public void onRcspCommand(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
            if (GetFileTask.this.isRun() && commandBase.getId() == 36) {
                ReadFileFromDeviceCmd readFileFromDeviceCmd = (ReadFileFromDeviceCmd) commandBase;
                ReadFileFromDeviceCmd.Param param = (ReadFileFromDeviceCmd.Param) readFileFromDeviceCmd.getParam();
                byte b2 = param.op;
                if (b2 == Byte.MIN_VALUE) {
                    byte b3 = ((ReadFileFromDeviceCmd.StopParam) param).ret;
                    if (b3 != 0) {
                        BaseError buildResponseBadResult = GetFileTask.this.buildResponseBadResult(readFileFromDeviceCmd.getId(), b3);
                        GetFileTask.this.onError(buildResponseBadResult.getSubCode(), buildResponseBadResult.getMessage());
                        return;
                    }
                    GetFileTask.this.b();
                } else if (b2 == -127) {
                    GetFileTask.this.b(((ReadFileFromDeviceCmd.CancelParam) param).reason);
                }
                readFileFromDeviceCmd.setParam(param);
                readFileFromDeviceCmd.setOpCodeSn(commandBase.getOpCodeSn());
                readFileFromDeviceCmd.setStatus(0);
                readFileFromDeviceCmd.setParam(new ReadFileFromDeviceCmd.Param(((ReadFileFromDeviceCmd.Param) readFileFromDeviceCmd.getParam()).op));
                GetFileTask.this.mRcspOp.sendCommandResponse(bluetoothDevice, readFileFromDeviceCmd, null);
            }
        }

        /* JADX WARN: Multi-variable type inference failed */
        @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
        public void onRcspDataCmd(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
            if (GetFileTask.this.isRun() && commandBase.getId() == 1) {
                DataCmd dataCmd = (DataCmd) commandBase;
                if (((DataParam) dataCmd.getParam()).getXmOpCode() != 36) {
                    return;
                }
                final byte[] data = ((DataParam) dataCmd.getParam()).getData();
                if (GetFileTask.this.f3674f.isShutdown() || GetFileTask.this.f3674f.isTerminated()) {
                    JL_Log.w(GetFileTask.this.tag, "onRcspDataCmd >> thread pool is close.");
                } else {
                    GetFileTask.this.f3674f.submit(new Runnable() { // from class: com.jieli.jl_rcsp.task.GetFileTask$4$$ExternalSyntheticLambda0
                        @Override // java.lang.Runnable
                        public final void run() {
                            GetFileTask.AnonymousClass4.this.a(data);
                        }
                    });
                }
            }
        }
    }

    public static class Param {
        public short lastCrc;
        public int lastOffset;
        public int lastProgress;
        public int totalSize;

        private Param() {
            this.lastOffset = 0;
            this.lastCrc = (short) 0;
            this.lastProgress = -1;
        }

        public void reset() {
            this.totalSize = 0;
            this.lastOffset = 0;
            this.lastCrc = (short) 0;
            this.lastProgress = -1;
        }
    }

    public GetFileTask(RcspOpImpl rcspOpImpl, String str) {
        super(rcspOpImpl);
        this.f3671c = null;
        this.f3672d = new byte[0];
        this.useCrc = true;
        this.f3674f = Executors.newSingleThreadExecutor();
        this.f3675g = new Handler(Looper.getMainLooper(), new Handler.Callback() { // from class: com.jieli.jl_rcsp.task.GetFileTask$$ExternalSyntheticLambda0
            @Override // android.os.Handler.Callback
            public final boolean handleMessage(Message message) {
                boolean a2;
                a2 = GetFileTask.this.a(message);
                return a2;
            }
        });
        this.f3676h = new AnonymousClass4();
        this.f3670b = str;
        this.f3673e = new Param();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void onError(int i2) {
        onError(i2, null);
    }

    private void release() {
        this.f3673e.reset();
        this.mRcspOp.unregisterOnRcspCallback(this.f3676h);
        this.f3675g.removeCallbacksAndMessages(null);
        if (!this.f3674f.isShutdown()) {
            this.f3674f.shutdownNow();
        }
        OutputStream outputStream = this.f3671c;
        if (outputStream != null) {
            try {
                outputStream.flush();
                this.f3671c.close();
            } catch (IOException e2) {
                e2.printStackTrace();
            } finally {
                this.f3671c = null;
            }
        }
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void cancel(byte b2) {
        if (isRun()) {
            a(0, (String) null);
        }
    }

    public abstract ReadFileFromDeviceCmd.Param createParam(BluetoothDevice bluetoothDevice);

    public byte[] getCacheData() {
        return this.f3672d;
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void start() {
        if (isRun()) {
            JL_Log.w(this.tag, "Task is in progress.");
            return;
        }
        if (a()) {
            onError(12545);
            return;
        }
        c();
        if (BYTE_ARRAY_STREAM.equals(this.f3670b)) {
            this.f3671c = new ByteArrayOutputStream();
        } else {
            try {
                this.f3671c = new FileOutputStream(this.f3670b);
            } catch (FileNotFoundException e2) {
                e2.printStackTrace();
                onError(4097, RcspUtil.formatString("%s File not found.", WatchError.getErrorDesc(4097)));
            }
        }
        if (this.f3671c != null) {
            d();
        }
    }

    private void c() {
        this.f3673e.reset();
        this.f3672d = new byte[0];
        this.mRcspOp.registerOnRcspCallback(this.f3676h);
        callbackBegin();
    }

    private void d() {
        this.mRcspOp.sendRcspCommand(getConnectedDevice(), new ReadFileFromDeviceCmd(createParam(getConnectedDevice())), new CustomRcspActionCallback("ReadFileFromDevice", new OnOperationCallback<ReadFileFromDeviceCmd.StartResponse>() { // from class: com.jieli.jl_rcsp.task.GetFileTask.1
            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onFailed(BaseError baseError) {
                GetFileTask.this.onError(baseError.getSubCode(), baseError.getMessage());
            }

            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onSuccess(ReadFileFromDeviceCmd.StartResponse startResponse) {
                GetFileTask.this.f3673e.totalSize = startResponse.size;
                GetFileTask.this.f3673e.lastCrc = (short) 0;
                GetFileTask.this.f3675g.removeMessages(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT);
                GetFileTask.this.f3675g.sendEmptyMessageDelayed(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT, TaskBase.TIMEOUT);
            }
        }, new IHandleResult<ReadFileFromDeviceCmd.StartResponse, ReadFileFromDeviceCmd>() { // from class: com.jieli.jl_rcsp.task.GetFileTask.2
            @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
            public int hasResult(BluetoothDevice bluetoothDevice, ReadFileFromDeviceCmd readFileFromDeviceCmd) {
                return 0;
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
            public ReadFileFromDeviceCmd.StartResponse handleResult(BluetoothDevice bluetoothDevice, ReadFileFromDeviceCmd readFileFromDeviceCmd) {
                if (readFileFromDeviceCmd != null && readFileFromDeviceCmd.getStatus() == 0 && (readFileFromDeviceCmd.getResponse() instanceof ReadFileFromDeviceCmd.StartResponse)) {
                    return (ReadFileFromDeviceCmd.StartResponse) readFileFromDeviceCmd.getResponse();
                }
                return null;
            }
        }));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void onError(int i2, String str) {
        JL_Log.e(this.tag, "onError : code = " + i2 + ", " + str);
        release();
        if (str == null) {
            callbackError(i2);
        } else {
            callbackError(i2, str);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b(int i2) {
        release();
        callbackCancel(i2);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ boolean a(Message message) {
        if (message.what != 4386) {
            return true;
        }
        JL_Log.e(this.tag, "MSG_WAITING_FOR_DATA_TIMEOUT >>>>");
        onError(12290, "Waiting for data timeout.");
        return true;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b() {
        long length;
        if (isRun()) {
            OutputStream outputStream = this.f3671c;
            if (outputStream instanceof ByteArrayOutputStream) {
                byte[] byteArray = ((ByteArrayOutputStream) outputStream).toByteArray();
                this.f3672d = byteArray;
                length = byteArray.length;
            } else {
                length = outputStream instanceof FileOutputStream ? new File(this.f3670b).length() : 0L;
            }
            if (length != this.f3673e.totalSize) {
                onError(16387, "Data loss. Firmware return data size = " + this.f3673e.totalSize + ", Actual received data size = " + length);
                return;
            }
            release();
            callbackProgress(100);
            callbackFinish();
        }
    }

    private boolean a() {
        DeviceInfo deviceInfo = this.mRcspOp.getDeviceInfo();
        return deviceInfo != null && deviceInfo.getPhoneStatus() == 1;
    }

    private void a(final int i2, final String str) {
        if (isRun()) {
            JL_Log.w(this.tag, "cancel task : " + i2);
            this.mRcspOp.sendRcspCommand(getConnectedDevice(), new ReadFileFromDeviceCmd(new ReadFileFromDeviceCmd.CancelParam(CHexConver.intToByte(i2))), new BooleanRcspActionCallback("cancelBigFileTransfer", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.task.GetFileTask.3
                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onFailed(BaseError baseError) {
                    GetFileTask.this.onError(baseError.getSubCode(), baseError.getMessage());
                }

                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onSuccess(Boolean bool) {
                    int i3 = i2;
                    if (i3 == 0) {
                        GetFileTask.this.b(0);
                    } else {
                        if (i3 != 2) {
                            return;
                        }
                        GetFileTask.this.onError(12544, str);
                    }
                }
            }));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(byte[] bArr) {
        byte[] bArr2;
        ByteBuffer byteBuffer;
        if (!isRun() || bArr == null || bArr.length < 4) {
            return;
        }
        this.f3675g.removeMessages(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT);
        ByteBuffer wrap = ByteBuffer.wrap(bArr);
        int i2 = wrap.getInt();
        Param param = this.f3673e;
        int i3 = param.lastOffset;
        if (i3 != i2) {
            a(1, RcspUtil.formatString("Offset does not match. sdk count offset = %d, firmware return offset = %d.", Integer.valueOf(i3), Integer.valueOf(i2)));
            return;
        }
        final int i4 = (int) (((i3 * 1.0f) / param.totalSize) * 100.0f);
        if (param.lastProgress != i4) {
            param.lastProgress = i4;
            this.f3675g.post(new Runnable() { // from class: com.jieli.jl_rcsp.task.GetFileTask$$ExternalSyntheticLambda1
                @Override // java.lang.Runnable
                public final void run() {
                    GetFileTask.this.a(i4);
                }
            });
        }
        if (this.useCrc) {
            short s = wrap.getShort();
            bArr2 = new byte[wrap.remaining()];
            byteBuffer = wrap.get(bArr2);
            Param param2 = this.f3673e;
            param2.lastCrc = CryptoUtil.CRC16(bArr2, param2.lastCrc);
            short s2 = this.f3673e.lastCrc;
            if (s != s2) {
                a(2, RcspUtil.formatString("CRC error. data crc = %x, firmware return crc = %x", Short.valueOf(s2), Short.valueOf(s)));
                return;
            }
        } else {
            bArr2 = new byte[wrap.remaining()];
            byteBuffer = wrap.get(bArr2);
        }
        try {
            this.f3671c.write(bArr2);
            this.f3673e.lastOffset = i2 + bArr2.length;
            this.f3675g.sendEmptyMessageDelayed(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT, TaskBase.TIMEOUT);
        } catch (IOException e2) {
            e2.printStackTrace();
            a(1, "IO exception : " + e2.getMessage());
        }
        byteBuffer.rewind();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(int i2) {
        callbackProgress(i2);
    }
}
