package com.jieli.jl_rcsp.task;

import android.bluetooth.BluetoothDevice;
import com.jieli.jl_rcsp.constant.RcspErrorCode;
import com.jieli.jl_rcsp.constant.WatchError;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.util.JL_Log;

/* loaded from: classes3.dex */
public abstract class TaskBase implements ITask {
    public static final int ERR_BUSY = 4352;
    public static final int ERR_COMMAND_RESPONSE = 12292;
    public static final int ERR_CRC_CHECK = 12544;
    public static final int ERR_DEVICE_IN_CALL = 12545;
    public static final int ERR_DEVICE_NOT_CONNECT = 8192;
    public static final int ERR_FUNC_NOT_SUPPORT = 4353;
    public static final int ERR_IO_EXCEPTION = 16389;
    public static final int ERR_MISSING_DATA = 16387;
    public static final int ERR_NO_TARGET_STORAGE = 16384;
    public static final int ERR_PARAM = 4097;
    public static final int ERR_RENAME = 16898;
    public static final int ERR_WAIT_DATA_TIMEOUT = 12290;
    public static final int MSG_WAITING_FOR_DATA_TIMEOUT = 4386;
    public static int TIMEOUT = 20000;

    /* renamed from: a, reason: collision with root package name */
    private volatile boolean f3683a;
    public TaskListener listener;
    public final RcspOpImpl mRcspOp;
    public final String tag = getClass().getSimpleName();

    public TaskBase(RcspOpImpl rcspOpImpl) throws RuntimeException {
        if (rcspOpImpl == null) {
            throw new RuntimeException("RcspOpImpl can not be null.");
        }
        this.mRcspOp = rcspOpImpl;
    }

    public BaseError buildResponseBadResult(int i2, int i3) {
        return RcspErrorCode.buildJsonError(i2, 12293, i3, null);
    }

    public BaseError buildResponseBadState(int i2, int i3) {
        return RcspErrorCode.buildJsonError(i2, 12292, i3, null);
    }

    public void callbackBegin() {
        this.f3683a = true;
        TaskListener taskListener = this.listener;
        if (taskListener != null) {
            taskListener.onBegin();
        }
    }

    public void callbackCancel(int i2) {
        this.f3683a = false;
        TaskListener taskListener = this.listener;
        if (taskListener != null) {
            taskListener.onCancel(i2);
        }
    }

    public void callbackError(int i2) {
        callbackError(i2, WatchError.getErrorDesc(i2));
    }

    public void callbackFinish() {
        this.f3683a = false;
        TaskListener taskListener = this.listener;
        if (taskListener != null) {
            taskListener.onFinish();
        }
    }

    public void callbackProgress(int i2) {
        TaskListener taskListener = this.listener;
        if (taskListener != null) {
            taskListener.onProgress(i2);
        }
    }

    public BluetoothDevice getConnectedDevice() {
        return this.mRcspOp.getConnectedDevice();
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public boolean isRun() {
        return this.f3683a;
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void setListener(TaskListener taskListener) {
        this.listener = taskListener;
    }

    public void callbackError(int i2, String str) {
        this.f3683a = false;
        JL_Log.e(this.tag, "callbackError : code = " + i2 + ", " + str);
        TaskListener taskListener = this.listener;
        if (taskListener != null) {
            taskListener.onError(i2, str);
        }
    }
}
