package com.jieli.jl_rcsp.task;

import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import com.dd.plist.ASCIIPropertyListParser;
import com.jieli.jl_filebrowse.FileBrowseManager;
import com.jieli.jl_filebrowse.bean.Folder;
import com.jieli.jl_filebrowse.bean.SDCardBean;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.IHandleResult;
import com.jieli.jl_rcsp.interfaces.OnOperationCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.base.CommandBase;
import com.jieli.jl_rcsp.model.command.NotifyPrepareEnvCmd;
import com.jieli.jl_rcsp.model.command.data.DataCmd;
import com.jieli.jl_rcsp.model.command.file_op.CancelLargeFileTransferCmd;
import com.jieli.jl_rcsp.model.command.file_op.DeviceExtendParamCmd;
import com.jieli.jl_rcsp.model.command.file_op.LargeFileTransferGetNameCmd;
import com.jieli.jl_rcsp.model.command.file_op.LargeFileTransferOpCmd;
import com.jieli.jl_rcsp.model.command.file_op.StartLargeFileTransferCmd;
import com.jieli.jl_rcsp.model.command.file_op.StopLargeFileTransferCmd;
import com.jieli.jl_rcsp.model.device.DeviceInfo;
import com.jieli.jl_rcsp.model.parameter.DataParam;
import com.jieli.jl_rcsp.model.parameter.LargeFileTransferOpParam;
import com.jieli.jl_rcsp.model.parameter.StartLargeFileTransferParam;
import com.jieli.jl_rcsp.model.response.StartLargeFileTransferResponse;
import com.jieli.jl_rcsp.tool.BooleanRcspActionCallback;
import com.jieli.jl_rcsp.tool.CustomRcspActionCallback;
import com.jieli.jl_rcsp.util.CHexConver;
import com.jieli.jl_rcsp.util.CommandBuilder;
import com.jieli.jl_rcsp.util.CryptoUtil;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.LinkedBlockingQueue;

/* loaded from: classes3.dex */
public class TransferTask extends TaskBase {

    /* renamed from: b, reason: collision with root package name */
    private String f3684b;

    /* renamed from: c, reason: collision with root package name */
    private final CacheVar f3685c;

    /* renamed from: d, reason: collision with root package name */
    private final Param f3686d;

    /* renamed from: e, reason: collision with root package name */
    private final Handler f3687e;
    public final ExecutorService executor;

    /* renamed from: f, reason: collision with root package name */
    private final OnRcspCallback f3688f;
    public int maxRenameCount;

    public static class CacheVar {
        public static final int l = 50;

        /* renamed from: a, reason: collision with root package name */
        public RandomAccessFile f3697a;

        /* renamed from: b, reason: collision with root package name */
        public short f3698b;

        /* renamed from: c, reason: collision with root package name */
        public int f3699c;

        /* renamed from: d, reason: collision with root package name */
        public long f3700d;

        /* renamed from: e, reason: collision with root package name */
        public int f3701e;

        /* renamed from: f, reason: collision with root package name */
        public int f3702f;

        /* renamed from: g, reason: collision with root package name */
        public final LinkedBlockingQueue<SendData> f3703g;

        /* renamed from: h, reason: collision with root package name */
        public boolean f3704h;

        /* renamed from: i, reason: collision with root package name */
        public long f3705i;

        /* renamed from: j, reason: collision with root package name */
        public long f3706j;
        public long k;

        private CacheVar() {
            this.f3702f = 0;
            this.f3703g = new LinkedBlockingQueue<>();
            this.f3706j = -1L;
            this.k = 50L;
        }

        public void a() {
            RandomAccessFile randomAccessFile = this.f3697a;
            if (randomAccessFile != null) {
                try {
                    try {
                        randomAccessFile.close();
                    } catch (IOException e2) {
                        throw new RuntimeException(e2);
                    }
                } finally {
                    this.f3697a = null;
                }
            }
        }

        public void b() {
            this.f3699c = 0;
            this.f3700d = 0L;
            this.f3701e = 0;
            this.f3702f = 0;
            this.f3704h = false;
            this.f3705i = 0L;
            this.f3706j = -1L;
            this.k = 50L;
            this.f3703g.clear();
            a();
        }
    }

    public static class Param {
        public int devHandler;
        public boolean appHasCrc16 = true;
        public boolean useFlash = false;
        public boolean isOtherEncode = false;
        public String encodeType = StandardCharsets.UTF_16LE.name();

        /* renamed from: a, reason: collision with root package name */
        private boolean f3707a = false;

        public String toString() {
            return "Param{devHandler=" + this.devHandler + ", appHasCrc16=" + this.appHasCrc16 + ", useFlash=" + this.useFlash + ", firmwareHasCrc16=" + this.f3707a + ", isOtherEncode=" + this.isOtherEncode + ", encodeType=" + this.encodeType + ASCIIPropertyListParser.DICTIONARY_END_TOKEN;
        }
    }

    public static class SendData {

        /* renamed from: a, reason: collision with root package name */
        public int f3708a;

        /* renamed from: b, reason: collision with root package name */
        public byte[] f3709b;

        public SendData(int i2, byte[] bArr) {
            this.f3708a = i2;
            this.f3709b = bArr;
        }
    }

    public TransferTask(RcspOpImpl rcspOpImpl, String str, Param param) throws RuntimeException {
        super(rcspOpImpl);
        this.maxRenameCount = 9;
        this.executor = Executors.newSingleThreadExecutor();
        this.f3687e = new Handler(Looper.getMainLooper(), new Handler.Callback() { // from class: com.jieli.jl_rcsp.task.TransferTask$$ExternalSyntheticLambda6
            @Override // android.os.Handler.Callback
            public final boolean handleMessage(Message message) {
                boolean a2;
                a2 = TransferTask.this.a(message);
                return a2;
            }
        });
        this.f3688f = new OnRcspCallback() { // from class: com.jieli.jl_rcsp.task.TransferTask.8
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onConnectStateChange(BluetoothDevice bluetoothDevice, int i2) {
                if (TransferTask.this.isRun() && i2 != 1) {
                    TransferTask.this.onError(8192, null);
                }
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspCommand(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
                if (!TransferTask.this.isRun() || commandBase == null) {
                    return;
                }
                switch (commandBase.getId()) {
                    case 28:
                        StopLargeFileTransferCmd stopLargeFileTransferCmd = (StopLargeFileTransferCmd) commandBase;
                        int reason = ((StopLargeFileTransferCmd.Param) stopLargeFileTransferCmd.getParam()).getReason();
                        stopLargeFileTransferCmd.setParam(null);
                        stopLargeFileTransferCmd.setStatus(0);
                        TransferTask.this.mRcspOp.sendCommandResponse(bluetoothDevice, stopLargeFileTransferCmd, null);
                        TransferTask.this.a(commandBase.getId(), reason);
                        break;
                    case 29:
                        LargeFileTransferOpCmd largeFileTransferOpCmd = (LargeFileTransferOpCmd) commandBase;
                        if (TransferTask.this.f3685c.f3699c != 0) {
                            TransferTask.this.a(largeFileTransferOpCmd);
                            break;
                        } else {
                            JL_Log.e(TransferTask.this.tag, "mtu is 0");
                            break;
                        }
                    case 30:
                        CancelLargeFileTransferCmd cancelLargeFileTransferCmd = (CancelLargeFileTransferCmd) commandBase;
                        TransferTask.this.h();
                        cancelLargeFileTransferCmd.setParam(null);
                        cancelLargeFileTransferCmd.setStatus(0);
                        TransferTask.this.mRcspOp.sendCommandResponse(bluetoothDevice, cancelLargeFileTransferCmd, null);
                        break;
                    case 32:
                        TransferTask.this.a((LargeFileTransferGetNameCmd) commandBase);
                        break;
                }
            }
        };
        if (param == null) {
            throw new RuntimeException("TransferTask.Param can not be null.");
        }
        this.f3686d = param;
        JL_Log.d(this.tag, "init : " + param + ", class = " + this);
        this.f3685c = new CacheVar();
        setPath(str);
    }

    private void i() {
        this.f3685c.b();
        this.mRcspOp.registerOnRcspCallback(this.f3688f);
        callbackBegin();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void j() {
        this.mRcspOp.sendRcspCommand(getConnectedDevice(), new NotifyPrepareEnvCmd(new NotifyPrepareEnvCmd.NotifyPrepareTransferLargeFileParam()), new BooleanRcspActionCallback("prepareBigFileTransferEnv", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.task.TransferTask.3
            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onFailed(BaseError baseError) {
                TransferTask.this.onError(baseError.getSubCode(), baseError.getMessage());
            }

            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onSuccess(Boolean bool) {
                DeviceInfo deviceInfo = TransferTask.this.mRcspOp.getDeviceInfo();
                if (deviceInfo == null || deviceInfo.isSupportPackageCrc16()) {
                    TransferTask.this.k();
                } else {
                    TransferTask.this.m();
                }
            }
        }));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void k() {
        Param param = this.f3686d;
        this.mRcspOp.sendRcspCommand(getConnectedDevice(), new DeviceExtendParamCmd(new DeviceExtendParamCmd.FileTransferParam(param.devHandler, param.appHasCrc16)), new CustomRcspActionCallback("readExternParam", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.task.TransferTask.4
            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onFailed(BaseError baseError) {
                TransferTask.this.onError(baseError.getSubCode(), baseError.getMessage());
            }

            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onSuccess(Boolean bool) {
                TransferTask.this.f3686d.f3707a = bool.booleanValue();
                TransferTask.this.m();
            }
        }, new IHandleResult<Boolean, DeviceExtendParamCmd>() { // from class: com.jieli.jl_rcsp.task.TransferTask.5
            @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
            public int hasResult(BluetoothDevice bluetoothDevice, DeviceExtendParamCmd deviceExtendParamCmd) {
                return 0;
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
            public Boolean handleResult(BluetoothDevice bluetoothDevice, DeviceExtendParamCmd deviceExtendParamCmd) {
                return (deviceExtendParamCmd == null || !(deviceExtendParamCmd.getResponse() instanceof DeviceExtendParamCmd.FileTransferResponse)) ? Boolean.FALSE : Boolean.valueOf(((DeviceExtendParamCmd.FileTransferResponse) deviceExtendParamCmd.getResponse()).hasCrc16);
            }
        }));
    }

    private void l() {
        JL_Log.i(this.tag, "startFileTransferFlow >> " + this.f3686d);
        if (!this.f3686d.useFlash) {
            j();
            return;
        }
        File file = new File(this.f3684b);
        a("/" + file.getName(), (int) file.length());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void m() {
        JL_Log.d(this.tag, "send start cmd to device. path = " + this.f3684b);
        try {
            this.executor.execute(new Runnable() { // from class: com.jieli.jl_rcsp.task.TransferTask$$ExternalSyntheticLambda5
                @Override // java.lang.Runnable
                public final void run() {
                    TransferTask.this.f();
                }
            });
        } catch (Exception e2) {
            e2.printStackTrace();
            onError(16389, "Exception : " + e2.getMessage());
        }
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void cancel(byte b2) {
        if (isRun()) {
            this.mRcspOp.sendRcspCommand(getConnectedDevice(), new CancelLargeFileTransferCmd(), new BooleanRcspActionCallback("cancel", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.task.TransferTask.1
                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onFailed(BaseError baseError) {
                    TransferTask.this.onError(baseError.getSubCode(), baseError.getMessage());
                }

                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onSuccess(Boolean bool) {
                    TransferTask.this.h();
                }
            }));
        }
    }

    public String getPath() {
        return this.f3684b;
    }

    public void onError(int i2) {
        onError(i2, null);
    }

    public void release() {
        this.f3685c.b();
        this.mRcspOp.unregisterOnRcspCallback(this.f3688f);
        this.f3687e.removeCallbacksAndMessages(null);
        if (this.executor.isShutdown()) {
            return;
        }
        this.executor.shutdownNow();
    }

    public void setPath(String str) {
        this.f3684b = str;
        int lastIndexOf = str.lastIndexOf("/");
        if (lastIndexOf != -1) {
            if (str.length() - (lastIndexOf + 1) > 9) {
                this.maxRenameCount = 999;
            } else {
                this.maxRenameCount = 9;
            }
        }
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void start() {
        if (isRun()) {
            JL_Log.w(this.tag, "Task is in progress.");
        } else if (d()) {
            onError(12545);
        } else {
            i();
            a();
        }
    }

    private long b() {
        return System.currentTimeMillis();
    }

    private SDCardBean c() {
        List<SDCardBean> onlineDev = FileBrowseManager.getInstance().getOnlineDev();
        if (onlineDev != null && !onlineDev.isEmpty()) {
            for (SDCardBean sDCardBean : onlineDev) {
                if (sDCardBean.getDevHandler() == this.f3686d.devHandler) {
                    return sDCardBean;
                }
            }
        }
        return null;
    }

    private boolean d() {
        DeviceInfo deviceInfo = this.mRcspOp.getDeviceInfo();
        return deviceInfo != null && deviceInfo.getPhoneStatus() == 1;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void e() {
        File file = new File(this.f3684b);
        if (file.exists() && !file.isDirectory()) {
            long j2 = 0;
            if (file.length() != 0) {
                long b2 = b();
                FileInputStream fileInputStream = null;
                try {
                    try {
                        try {
                            this.f3685c.f3697a = new RandomAccessFile(file, "r");
                            this.f3685c.f3702f = (int) file.length();
                            FileInputStream fileInputStream2 = new FileInputStream(file);
                            try {
                                long available = fileInputStream2.available();
                                byte[] bArr = new byte[2048];
                                short s = 0;
                                while (true) {
                                    int read = fileInputStream2.read(bArr);
                                    if (read == -1) {
                                        break;
                                    }
                                    byte[] bArr2 = new byte[read];
                                    System.arraycopy(bArr, 0, bArr2, 0, read);
                                    s = CryptoUtil.CRC16(bArr2, s);
                                    j2 += read;
                                }
                                long a2 = a(b2);
                                this.f3685c.f3698b = s;
                                JL_Log.i(this.tag, RcspUtil.formatString("[countFileCrc] Take data time = %d, file len = %d, file size = %d, data size = %d, crc = %x, %d", Long.valueOf(a2), Integer.valueOf(this.f3685c.f3702f), Long.valueOf(available), Long.valueOf(j2), Short.valueOf(s), Short.valueOf(s)));
                                CacheVar cacheVar = this.f3685c;
                                if (cacheVar.f3702f != j2) {
                                    cacheVar.f3702f = (int) j2;
                                }
                                l();
                                fileInputStream2.close();
                            } catch (Exception e2) {
                                e = e2;
                                fileInputStream = fileInputStream2;
                                e.printStackTrace();
                                this.f3687e.post(new Runnable() { // from class: com.jieli.jl_rcsp.task.TransferTask$$ExternalSyntheticLambda2
                                    @Override // java.lang.Runnable
                                    public final void run() {
                                        TransferTask.this.a(e);
                                    }
                                });
                                if (fileInputStream != null) {
                                    fileInputStream.close();
                                    return;
                                }
                                return;
                            } catch (Throwable th) {
                                th = th;
                                fileInputStream = fileInputStream2;
                                if (fileInputStream != null) {
                                    try {
                                        fileInputStream.close();
                                    } catch (IOException e3) {
                                        e3.printStackTrace();
                                    }
                                }
                                throw th;
                            }
                        } catch (Throwable th2) {
                            th = th2;
                        }
                    } catch (Exception e4) {
                        e = e4;
                    }
                    return;
                } catch (IOException e5) {
                    e5.printStackTrace();
                    return;
                }
            }
        }
        onError(4097, RcspUtil.formatString("Path is invalid. path = " + this.f3684b, new Object[0]));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void f() {
        File file = new File(this.f3684b);
        if (!file.exists() || file.isDirectory() || file.length() == 0) {
            onError(4097, RcspUtil.formatString("Path is invalid. path = " + this.f3684b, new Object[0]));
            return;
        }
        String str = RcspUtil.formatString("%08x", Integer.valueOf((file.getName() + file.lastModified()).hashCode())) + ".tmp\u0000";
        JL_Log.d(this.tag, "hash --->" + str.hashCode() + ", crc = " + ((int) this.f3685c.f3698b) + ", task isShutdown = " + this.executor.isShutdown());
        byte[] bytes = str.getBytes();
        CacheVar cacheVar = this.f3685c;
        a(bytes, cacheVar.f3702f, cacheVar.f3698b);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void g() {
        if (!this.f3685c.f3703g.isEmpty()) {
            SendData poll = this.f3685c.f3703g.poll();
            if (poll == null) {
                return;
            }
            a(poll.f3708a, poll.f3709b, new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.task.TransferTask.7
                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onFailed(BaseError baseError) {
                    TransferTask.this.onError(baseError.getSubCode(), baseError.getMessage());
                }

                @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
                public void onSuccess(Boolean bool) {
                    TransferTask.this.g();
                }
            });
            return;
        }
        this.f3685c.f3704h = false;
        if (isRun()) {
            this.f3687e.removeMessages(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT);
            this.f3687e.sendEmptyMessageDelayed(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT, TaskBase.TIMEOUT);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void h() {
        release();
        callbackCancel(0);
    }

    public void onError(int i2, String str) {
        release();
        if (str == null) {
            callbackError(i2);
        } else {
            callbackError(i2, str);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ boolean a(Message message) {
        if (message.what != 4386) {
            return true;
        }
        onError(12290);
        return true;
    }

    private long a(long j2) {
        return b() - j2;
    }

    private boolean a(String str) {
        return !TextUtils.isEmpty(str) && (str.endsWith(".mp3") || str.endsWith(".MP3") || str.endsWith(".wav") || str.endsWith(".WAV") || str.endsWith(".wave") || str.endsWith(".WAVE") || str.endsWith(".aac") || str.endsWith(".AAC") || str.endsWith(".ogg") || str.endsWith(".OGG") || str.endsWith(".amr") || str.endsWith(".AMR") || str.endsWith(".wma") || str.endsWith(".WMA") || str.endsWith(".flac") || str.endsWith(".FLAC") || str.endsWith(".ape") || str.endsWith(".APE"));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(LargeFileTransferGetNameCmd largeFileTransferGetNameCmd) {
        if (isRun()) {
            String name = new File(this.f3684b).getName();
            JL_Log.d(this.tag, "onGetName >>> File name = " + name + ", retryName = " + this.f3685c.f3701e);
            largeFileTransferGetNameCmd.setParam(new LargeFileTransferGetNameCmd.Param(name, this.f3685c.f3701e).setOtherEncode(this.f3686d.isOtherEncode).setEncodeType(this.f3686d.encodeType));
            largeFileTransferGetNameCmd.setStatus(this.f3685c.f3701e >= this.maxRenameCount ? 1 : 0);
            largeFileTransferGetNameCmd.setOpCodeSn(largeFileTransferGetNameCmd.getOpCodeSn());
            this.mRcspOp.sendCommandResponse(getConnectedDevice(), largeFileTransferGetNameCmd, null);
            if (this.f3686d.useFlash) {
                return;
            }
            CacheVar cacheVar = this.f3685c;
            int i2 = cacheVar.f3701e;
            if (i2 >= this.maxRenameCount) {
                onError(16898);
            } else {
                cacheVar.f3701e = i2 + 1;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(int i2, int i3) {
        SDCardBean c2;
        long a2 = a(this.f3685c.f3700d);
        JL_Log.i(this.tag, "Transfer file take time -->" + a2);
        if (i3 != 0) {
            BaseError buildResponseBadResult = buildResponseBadResult(i2, i3);
            onError(buildResponseBadResult.getSubCode(), buildResponseBadResult.getMessage());
            return;
        }
        JL_Log.i(this.tag, "Transfer of large file is complete.");
        if (a(this.f3684b) && (c2 = c()) != null) {
            Folder currentReadFile = FileBrowseManager.getInstance().getCurrentReadFile(c2);
            currentReadFile.setLoadFinished(false);
            currentReadFile.clean();
            FileBrowseManager.getInstance().loadMore(c2);
        }
        release();
        callbackProgress(100);
        callbackFinish();
    }

    private void a() {
        try {
            this.executor.execute(new Runnable() { // from class: com.jieli.jl_rcsp.task.TransferTask$$ExternalSyntheticLambda3
                @Override // java.lang.Runnable
                public final void run() {
                    TransferTask.this.e();
                }
            });
        } catch (Exception e2) {
            e2.printStackTrace();
            onError(16389, "Exception : " + e2.getMessage());
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(Exception exc) {
        onError(16389, "IO Exception : " + exc.getMessage());
    }

    private void a(String str, int i2) {
        this.mRcspOp.sendRcspCommand(getConnectedDevice(), CommandBuilder.buildExternalFlashInsertNewFileStartCmd(str, i2), new BooleanRcspActionCallback("startCreateFlashFile", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.task.TransferTask.2
            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onFailed(BaseError baseError) {
                TransferTask.this.onError(baseError.getSubCode(), baseError.getMessage());
            }

            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onSuccess(Boolean bool) {
                TransferTask.this.j();
            }
        }));
    }

    private void a(byte[] bArr, int i2, short s) {
        JL_Log.d(this.tag, RcspUtil.formatString("startBigFileTransfer >> size = %d, crc16 = %x, %d", Integer.valueOf(i2), Short.valueOf(s), Short.valueOf(s)));
        long b2 = b();
        CacheVar cacheVar = this.f3685c;
        cacheVar.f3700d = b2;
        cacheVar.f3705i = b2;
        this.mRcspOp.sendRcspCommand(getConnectedDevice(), new StartLargeFileTransferCmd(new StartLargeFileTransferParam(bArr, i2, s)), new RcspCommandCallback<StartLargeFileTransferCmd>() { // from class: com.jieli.jl_rcsp.task.TransferTask.6
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onErrCode(BluetoothDevice bluetoothDevice, BaseError baseError) {
                JL_Log.e(TransferTask.this.tag, "startBigFileTransfer >> error = " + baseError);
                TransferTask.this.onError(baseError.getSubCode(), baseError.getMessage());
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onCommandResponse(BluetoothDevice bluetoothDevice, StartLargeFileTransferCmd startLargeFileTransferCmd) {
                if (startLargeFileTransferCmd.getStatus() != 0) {
                    short transferMtu = ((StartLargeFileTransferResponse) startLargeFileTransferCmd.getResponse()).getTransferMtu();
                    onErrCode(bluetoothDevice, transferMtu != 0 ? TransferTask.this.buildResponseBadResult(startLargeFileTransferCmd.getId(), transferMtu) : TransferTask.this.buildResponseBadState(startLargeFileTransferCmd.getId(), startLargeFileTransferCmd.getStatus()));
                    return;
                }
                TransferTask.this.f3685c.f3699c = ((StartLargeFileTransferResponse) startLargeFileTransferCmd.getResponse()).getTransferMtu();
                JL_Log.d(TransferTask.this.tag, "startBigFileTransfer >> transferMtu = " + TransferTask.this.f3685c.f3699c);
                if (TransferTask.this.f3685c.f3699c <= 0) {
                    onErrCode(bluetoothDevice, new BaseError(4097, RcspUtil.formatString("Device[%s] return an invalid mtu : %d.", bluetoothDevice, Integer.valueOf(TransferTask.this.f3685c.f3699c))));
                } else {
                    TransferTask.this.f3687e.removeMessages(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT);
                    TransferTask.this.f3687e.sendEmptyMessageDelayed(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT, TaskBase.TIMEOUT);
                }
            }
        });
    }

    private void a(int i2, byte[] bArr, OnOperationCallback<Boolean> onOperationCallback) {
        DataParam dataParam = new DataParam(bArr);
        dataParam.setXmOpCode(i2);
        this.mRcspOp.sendRcspCommand(getConnectedDevice(), new DataCmd(dataParam), new BooleanRcspActionCallback("sendData", onOperationCallback));
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Multi-variable type inference failed */
    public void a(final LargeFileTransferOpCmd largeFileTransferOpCmd) {
        final int i2 = this.f3685c.f3699c;
        if (!isRun() || i2 <= 0 || this.f3685c.f3697a == null) {
            return;
        }
        LargeFileTransferOpParam largeFileTransferOpParam = (LargeFileTransferOpParam) largeFileTransferOpCmd.getParam();
        final int offset = largeFileTransferOpParam.getOffset();
        final short buffer = largeFileTransferOpParam.getBuffer();
        long a2 = a(this.f3685c.f3705i);
        CacheVar cacheVar = this.f3685c;
        if (cacheVar.f3706j == offset && a2 < cacheVar.k) {
            JL_Log.w(this.tag, RcspUtil.formatString("Received same packet.Skip! offset = %d, take time = %d, limit = %d", Integer.valueOf(offset), Long.valueOf(a2), Long.valueOf(this.f3685c.k)));
            return;
        }
        this.f3687e.removeMessages(TaskBase.MSG_WAITING_FOR_DATA_TIMEOUT);
        if (offset > 512) {
            int i3 = this.f3685c.f3702f;
            float f2 = i3 == 0 ? 0.0f : (offset * 100.0f) / i3;
            callbackProgress((int) (f2 <= 100.0f ? f2 : 100.0f));
        }
        try {
            this.executor.execute(new Runnable() { // from class: com.jieli.jl_rcsp.task.TransferTask$$ExternalSyntheticLambda4
                @Override // java.lang.Runnable
                public final void run() {
                    TransferTask.this.a(offset, buffer, i2, largeFileTransferOpCmd);
                }
            });
        } catch (Exception e2) {
            e2.printStackTrace();
            onError(16389, "Exception = " + e2.getMessage());
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(final int i2, int i3, int i4, LargeFileTransferOpCmd largeFileTransferOpCmd) {
        byte[] bArr;
        try {
            CacheVar cacheVar = this.f3685c;
            long j2 = i2;
            cacheVar.f3706j = j2;
            cacheVar.f3705i = b();
            this.f3685c.f3697a.seek(j2);
            final int min = Math.min(i3, this.f3685c.f3702f - i2);
            byte[] bArr2 = new byte[min];
            final int read = this.f3685c.f3697a.read(bArr2);
            if (read == -1) {
                this.f3687e.post(new Runnable() { // from class: com.jieli.jl_rcsp.task.TransferTask$$ExternalSyntheticLambda0
                    @Override // java.lang.Runnable
                    public final void run() {
                        TransferTask.this.a(i2, min, read);
                    }
                });
                return;
            }
            byte[] copyOfRange = Arrays.copyOfRange(bArr2, 0, read);
            this.f3685c.k = (long) Math.max((read * 10.0d) / i4, 10.0d);
            int i5 = 0;
            int i6 = 0;
            while (i5 < read) {
                int min2 = Math.min(i4, read - i5);
                int i7 = i5 + min2;
                byte[] copyOfRange2 = Arrays.copyOfRange(copyOfRange, i5, i7);
                Param param = this.f3686d;
                if (param.appHasCrc16 && param.f3707a) {
                    bArr = new byte[min2 + 3];
                    short CRC16 = CryptoUtil.CRC16(copyOfRange2, (short) 0);
                    bArr[1] = (byte) ((CRC16 >> 8) & 255);
                    bArr[2] = (byte) (CRC16 & 255);
                    System.arraycopy(copyOfRange2, 0, bArr, 3, min2);
                } else {
                    bArr = new byte[min2 + 1];
                    System.arraycopy(copyOfRange2, 0, bArr, 1, min2);
                }
                bArr[0] = CHexConver.intToByte(i6);
                this.f3685c.f3703g.add(new SendData(largeFileTransferOpCmd.getId(), bArr));
                i6++;
                i5 = i7;
            }
            if (this.f3685c.f3704h) {
                return;
            }
            g();
        } catch (IOException e2) {
            e2.printStackTrace();
            this.f3687e.post(new Runnable() { // from class: com.jieli.jl_rcsp.task.TransferTask$$ExternalSyntheticLambda1
                @Override // java.lang.Runnable
                public final void run() {
                    TransferTask.this.a(e2);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(int i2, int i3, int i4) {
        onError(16389, "Read data error.  offset = " + i2 + ", packetSize = " + i3 + ", read size = " + i4);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(IOException iOException) {
        onError(16389, "IO Exception = " + iOException.getMessage());
    }
}
