package com.jieli.jl_rcsp.task.logcat;

import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import com.jieli.jl_rcsp.constant.WatchError;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.IHandleResult;
import com.jieli.jl_rcsp.interfaces.OnOperationCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.base.CommandBase;
import com.jieli.jl_rcsp.model.command.ReadErrorMsgCmd;
import com.jieli.jl_rcsp.model.command.data.DataCmd;
import com.jieli.jl_rcsp.model.parameter.DataParam;
import com.jieli.jl_rcsp.task.TaskBase;
import com.jieli.jl_rcsp.tool.CustomRcspActionCallback;
import com.jieli.jl_rcsp.util.CommandBuilder;
import com.jieli.jl_rcsp.util.CryptoUtil;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

/* loaded from: classes3.dex */
public class ReadLogcatTask extends TaskBase {
    public static int WAIT_CMD_TIMEOUT = 12000;

    /* renamed from: g, reason: collision with root package name */
    private static final int f3749g = 4118;

    /* renamed from: b, reason: collision with root package name */
    private BluetoothDevice f3750b;

    /* renamed from: c, reason: collision with root package name */
    private final ByteArrayOutputStream f3751c;

    /* renamed from: d, reason: collision with root package name */
    private ReadErrorMsgCmd.ReadErrorMsgResponse f3752d;

    /* renamed from: e, reason: collision with root package name */
    private final Handler f3753e;

    /* renamed from: f, reason: collision with root package name */
    private final OnRcspCallback f3754f;

    public ReadLogcatTask(RcspOpImpl rcspOpImpl) throws RuntimeException {
        super(rcspOpImpl);
        this.f3751c = new ByteArrayOutputStream();
        this.f3753e = new Handler(Looper.getMainLooper(), new Handler.Callback() { // from class: com.jieli.jl_rcsp.task.logcat.ReadLogcatTask$$ExternalSyntheticLambda0
            @Override // android.os.Handler.Callback
            public final boolean handleMessage(Message message) {
                boolean a2;
                a2 = ReadLogcatTask.this.a(message);
                return a2;
            }
        });
        this.f3754f = new OnRcspCallback() { // from class: com.jieli.jl_rcsp.task.logcat.ReadLogcatTask.4
            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspCommand(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
                super.onRcspCommand(bluetoothDevice, commandBase);
                if (commandBase != null && commandBase.getId() == 41 && ReadLogcatTask.this.a(bluetoothDevice)) {
                    ReadErrorMsgCmd readErrorMsgCmd = (ReadErrorMsgCmd) commandBase;
                    if (((ReadErrorMsgCmd.ReadErrorMsgParam) readErrorMsgCmd.getParam()).getOp() == 1) {
                        ReadLogcatTask.this.a(readErrorMsgCmd);
                    }
                }
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspCallback
            public void onRcspDataCmd(BluetoothDevice bluetoothDevice, CommandBase commandBase) {
                DataParam dataParam;
                super.onRcspDataCmd(bluetoothDevice, commandBase);
                if (ReadLogcatTask.this.a(bluetoothDevice) && (dataParam = (DataParam) ((DataCmd) commandBase).getParam()) != null && dataParam.getXmOpCode() == 41) {
                    ReadLogcatTask.this.a(dataParam.getData());
                }
            }
        };
    }

    private void release() {
        this.f3750b = null;
        this.mRcspOp.unregisterOnRcspCallback(this.f3754f);
        this.f3753e.removeCallbacksAndMessages(null);
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void cancel(byte b2) {
    }

    public byte[] getResult() {
        return this.f3751c.toByteArray();
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void start() {
        if (isRun()) {
            JL_Log.w(this.tag, "Task is in progress.");
            return;
        }
        if (!this.mRcspOp.isRcspInit()) {
            a(8192);
        } else if (!this.mRcspOp.getDeviceInfo().isSupportReadErrorMSg()) {
            a(4353);
        } else {
            JL_Log.d(this.tag, "start... device support reading error message.");
            c();
        }
    }

    private void b() {
        this.f3750b = getConnectedDevice();
        this.f3751c.reset();
        this.mRcspOp.registerOnRcspCallback(this.f3754f);
        callbackBegin();
    }

    private void c() {
        b();
        this.mRcspOp.sendRcspCommand(this.f3750b, CommandBuilder.buildStartReadErrorMsgCmd(), new CustomRcspActionCallback("startReadLogcat", new OnOperationCallback<ReadErrorMsgCmd.ReadErrorMsgResponse>() { // from class: com.jieli.jl_rcsp.task.logcat.ReadLogcatTask.1
            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onFailed(BaseError baseError) {
                ReadLogcatTask.this.a(baseError.getSubCode(), baseError.getMessage());
            }

            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onSuccess(ReadErrorMsgCmd.ReadErrorMsgResponse readErrorMsgResponse) {
                if (readErrorMsgResponse == null) {
                    onFailed(new BaseError(12289, WatchError.getErrorDesc(12289)));
                    return;
                }
                ReadLogcatTask.this.a(readErrorMsgResponse);
                if (ReadLogcatTask.this.f3752d.getSize() > 0) {
                    ReadLogcatTask.this.f3753e.removeMessages(ReadLogcatTask.f3749g);
                    ReadLogcatTask.this.f3753e.sendEmptyMessageDelayed(ReadLogcatTask.f3749g, ReadLogcatTask.WAIT_CMD_TIMEOUT);
                    return;
                }
                JL_Log.w(ReadLogcatTask.this.tag, "startReadLogcat : Device has no abnormal information. file size = " + ReadLogcatTask.this.f3752d.getSize());
                ReadLogcatTask.this.a();
            }
        }, new IHandleResult<ReadErrorMsgCmd.ReadErrorMsgResponse, ReadErrorMsgCmd>() { // from class: com.jieli.jl_rcsp.task.logcat.ReadLogcatTask.2
            @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
            public int hasResult(BluetoothDevice bluetoothDevice, ReadErrorMsgCmd readErrorMsgCmd) {
                return 0;
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
            public ReadErrorMsgCmd.ReadErrorMsgResponse handleResult(BluetoothDevice bluetoothDevice, ReadErrorMsgCmd readErrorMsgCmd) {
                if (readErrorMsgCmd == null || readErrorMsgCmd.getStatus() != 0) {
                    return null;
                }
                return (ReadErrorMsgCmd.ReadErrorMsgResponse) readErrorMsgCmd.getResponse();
            }
        }));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ boolean a(Message message) {
        if (message.what != f3749g) {
            return true;
        }
        JL_Log.w(this.tag, "MSG_WAIT_COMMAND_TIMEOUT : >>>>>>>>>>");
        if (!isRun()) {
            return true;
        }
        a(12290, "Waiting for data timeout.");
        return true;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(ReadErrorMsgCmd.ReadErrorMsgResponse readErrorMsgResponse) {
        this.f3752d = readErrorMsgResponse;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(byte[] bArr) {
        if (bArr != null && bArr.length != 0) {
            try {
                if (isRun()) {
                    try {
                        if (this.f3753e.hasMessages(f3749g)) {
                            this.f3753e.removeMessages(f3749g);
                        }
                        this.f3751c.write(bArr);
                        int size = this.f3751c.size();
                        if (this.f3752d.getSize() > 0) {
                            int size2 = (size * 100) / this.f3752d.getSize();
                            if (size2 >= 100) {
                                size2 = 99;
                            }
                            callbackProgress(size2);
                        }
                        try {
                            this.f3751c.close();
                            return;
                        } catch (IOException e2) {
                            e2.printStackTrace();
                            return;
                        }
                    } catch (IOException e3) {
                        e3.printStackTrace();
                        callbackError(16389, "IO Exception = " + e3.getMessage());
                        try {
                            this.f3751c.close();
                            return;
                        } catch (IOException e4) {
                            e4.printStackTrace();
                            return;
                        }
                    }
                }
            } catch (Throwable th) {
                try {
                    this.f3751c.close();
                } catch (IOException e5) {
                    e5.printStackTrace();
                }
                throw th;
            }
        }
        JL_Log.w(this.tag, "handleLogcat: invalid param.");
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(ReadErrorMsgCmd readErrorMsgCmd) {
        if (readErrorMsgCmd != null && isRun()) {
            byte[] byteArray = this.f3751c.toByteArray();
            final short CRC16 = CryptoUtil.CRC16(byteArray, (short) 0);
            final short crc = this.f3752d.getCrc();
            final int i2 = crc == CRC16 ? 0 : 6;
            JL_Log.d(this.tag, RcspUtil.formatString("handleStopRead: sdk read logcat crc = %d, firmware crc = %d, status = %d", Short.valueOf(CRC16), Short.valueOf(crc), Integer.valueOf(i2)));
            readErrorMsgCmd.setStatus(i2);
            ReadErrorMsgCmd.ResponseReadResult responseReadResult = new ReadErrorMsgCmd.ResponseReadResult();
            responseReadResult.setSize(byteArray.length);
            responseReadResult.setCrc(CRC16);
            readErrorMsgCmd.setParam(responseReadResult);
            this.mRcspOp.sendCommandResponse(this.f3750b, readErrorMsgCmd, new RcspCommandCallback<ReadErrorMsgCmd>() { // from class: com.jieli.jl_rcsp.task.logcat.ReadLogcatTask.3
                @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
                public void onErrCode(BluetoothDevice bluetoothDevice, BaseError baseError) {
                    ReadLogcatTask.this.a(baseError.getSubCode(), baseError.getMessage());
                }

                @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
                public void onCommandResponse(BluetoothDevice bluetoothDevice, ReadErrorMsgCmd readErrorMsgCmd2) {
                    if (i2 == 0) {
                        ReadLogcatTask.this.a();
                        return;
                    }
                    ReadLogcatTask.this.a(12544, "Check data crc error. firmware crc = " + ((int) crc) + ", data crc = " + ((int) CRC16));
                }
            });
            return;
        }
        JL_Log.w(this.tag, "handleStopRead : Reading logcat did not start.");
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean a(BluetoothDevice bluetoothDevice) {
        return (bluetoothDevice == null || this.f3750b == null || !bluetoothDevice.getAddress().equals(this.f3750b.getAddress())) ? false : true;
    }

    private void a(int i2) {
        a(i2, (String) null);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(int i2, String str) {
        JL_Log.w(this.tag, "postError : " + i2 + ", " + str);
        if (str == null) {
            callbackError(i2);
        } else {
            callbackError(i2, str);
        }
        release();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a() {
        callbackProgress(100);
        callbackFinish();
        release();
    }
}
