package com.jieli.jl_rcsp.task.smallfile;

import android.bluetooth.BluetoothDevice;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.command.file_op.SmallFileTransferCmd;
import com.jieli.jl_rcsp.task.TaskBase;
import com.jieli.jl_rcsp.task.smallfile.QueryFileTask;
import com.jieli.jl_rcsp.tool.DeviceStatusManager;
import com.jieli.jl_rcsp.util.CryptoUtil;
import com.jieli.jl_rcsp.util.JL_Log;

/* loaded from: classes3.dex */
public class AddFileTask extends TaskBase {

    /* renamed from: b, reason: collision with root package name */
    private final Param f3770b;

    /* renamed from: c, reason: collision with root package name */
    public QueryFileTask.File f3771c;

    public static class Param {

        /* renamed from: a, reason: collision with root package name */
        private int f3776a = 0;

        /* renamed from: b, reason: collision with root package name */
        private int f3777b;

        /* renamed from: c, reason: collision with root package name */
        private byte[] f3778c;
        public int size;
        public byte type;

        public Param(byte b2, byte[] bArr) {
            this.type = b2;
            this.size = bArr.length;
            this.f3778c = bArr;
        }

        public byte[] getData() {
            return this.f3778c;
        }

        public int getOffset() {
            return this.f3776a;
        }

        public int getPacketSize() {
            return this.f3777b;
        }

        public int getSize() {
            return this.size;
        }

        public byte getType() {
            return this.type;
        }

        public void setData(byte[] bArr) {
            this.f3778c = bArr;
        }

        public void setOffset(int i2) {
            this.f3776a = i2;
        }

        public void setPacketSize(int i2) {
            this.f3777b = i2;
        }

        public void setSize(int i2) {
            this.size = i2;
        }

        public void setType(byte b2) {
            this.type = b2;
        }
    }

    public AddFileTask(RcspOpImpl rcspOpImpl, Param param) throws RuntimeException {
        super(rcspOpImpl);
        if (param == null) {
            throw new RuntimeException("AddFileTask.Param can not be null.");
        }
        this.f3770b = param;
        if (param.f3777b == 0) {
            param.f3777b = DeviceStatusManager.getInstance().getMaxCommunicationMtu(getConnectedDevice()) - 20;
        }
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void cancel(byte b2) {
        throw new RuntimeException("can not invoke cancel method");
    }

    public QueryFileTask.File getFile() {
        return this.f3771c;
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void start() {
        if (isRun()) {
            JL_Log.w(this.tag, "Task is in progress.");
        } else {
            callbackBegin();
            a(this.f3770b.f3776a, Math.min(this.f3770b.f3777b, this.f3770b.size), (short) 0);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(int i2, int i3, short s) {
        int min = Math.min(this.f3770b.size - i2, i3);
        byte[] bArr = new byte[min];
        System.arraycopy(this.f3770b.f3778c, i2, bArr, 0, min);
        final int i4 = min + i2;
        final short CRC16 = CryptoUtil.CRC16(bArr, s);
        final SmallFileTransferCmd.Param a2 = a((short) i2, (short) this.f3770b.size, bArr, CRC16);
        this.mRcspOp.sendRcspCommand(getConnectedDevice(), new SmallFileTransferCmd(a2), new RcspCommandCallback<SmallFileTransferCmd>() { // from class: com.jieli.jl_rcsp.task.smallfile.AddFileTask.1
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onErrCode(BluetoothDevice bluetoothDevice, BaseError baseError) {
                AddFileTask.this.callbackError(baseError.getSubCode(), baseError.getMessage());
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onCommandResponse(BluetoothDevice bluetoothDevice, SmallFileTransferCmd smallFileTransferCmd) {
                if (smallFileTransferCmd.getStatus() != 0) {
                    onErrCode(bluetoothDevice, AddFileTask.this.buildResponseBadState(smallFileTransferCmd.getId(), smallFileTransferCmd.getStatus()));
                    return;
                }
                SmallFileTransferCmd.ResultResponse resultResponse = (SmallFileTransferCmd.ResultResponse) smallFileTransferCmd.getResponse();
                byte b2 = resultResponse.ret;
                if (b2 != 0) {
                    onErrCode(bluetoothDevice, AddFileTask.this.buildResponseBadResult(smallFileTransferCmd.getId(), b2));
                    return;
                }
                AddFileTask.this.callbackProgress((int) ((i4 * 100.0d) / AddFileTask.this.f3770b.size));
                if (i4 < AddFileTask.this.f3770b.size) {
                    AddFileTask addFileTask = AddFileTask.this;
                    addFileTask.a(i4, addFileTask.f3770b.f3777b, CRC16);
                    return;
                }
                if (a2 instanceof SmallFileTransferCmd.AddFileParam) {
                    AddFileTask addFileTask2 = AddFileTask.this;
                    addFileTask2.f3771c = new QueryFileTask.File(addFileTask2.f3770b.type, ((SmallFileTransferCmd.AddFileResponse) resultResponse).id, AddFileTask.this.f3770b.size);
                    JL_Log.d(AddFileTask.this.tag, "add small file finished id = " + ((int) AddFileTask.this.f3771c.id));
                } else {
                    JL_Log.d(AddFileTask.this.tag, "update small file finished id = " + ((int) AddFileTask.this.f3771c.id));
                }
                AddFileTask.this.callbackFinish();
            }
        });
    }

    public SmallFileTransferCmd.Param a(short s, short s2, byte[] bArr, short s3) {
        return new SmallFileTransferCmd.AddFileParam(this.f3770b.type, s, s2, bArr, s3);
    }
}
