package com.jieli.jl_rcsp.task.smallfile;

import android.bluetooth.BluetoothDevice;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.command.file_op.SmallFileTransferCmd;
import com.jieli.jl_rcsp.task.TaskBase;
import com.jieli.jl_rcsp.tool.DeviceStatusManager;
import com.jieli.jl_rcsp.util.CryptoUtil;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;
import java.nio.ByteBuffer;

/* loaded from: classes3.dex */
public class ReadFileTask extends TaskBase {

    /* renamed from: b, reason: collision with root package name */
    private final Param f3787b;

    /* renamed from: c, reason: collision with root package name */
    private final ByteBuffer f3788c;

    public static class Param {

        /* renamed from: a, reason: collision with root package name */
        private final byte f3793a;

        /* renamed from: b, reason: collision with root package name */
        private final short f3794b;

        /* renamed from: c, reason: collision with root package name */
        private final int f3795c;

        /* renamed from: d, reason: collision with root package name */
        private final int f3796d;

        /* renamed from: e, reason: collision with root package name */
        private int f3797e;

        public Param(byte b2, short s, int i2, int i3) {
            this.f3793a = b2;
            this.f3794b = s;
            this.f3795c = i2;
            this.f3796d = i3;
        }

        public short getId() {
            return this.f3794b;
        }

        public int getOffset() {
            return this.f3796d;
        }

        public int getPacketSize() {
            return this.f3797e;
        }

        public int getSize() {
            return this.f3795c;
        }

        public byte getType() {
            return this.f3793a;
        }

        public void setPacketSize(int i2) {
            this.f3797e = i2;
        }
    }

    public ReadFileTask(RcspOpImpl rcspOpImpl, Param param) throws RuntimeException {
        super(rcspOpImpl);
        if (param == null) {
            throw new RuntimeException("ReadFileTask.Param can not be null.");
        }
        this.f3787b = param;
        if (param.f3797e == 0) {
            param.f3797e = DeviceStatusManager.getInstance().getMaxReceiveMtu(getConnectedDevice()) - 20;
        }
        this.f3788c = ByteBuffer.allocate(param.f3795c - param.f3796d);
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void cancel(byte b2) {
        throw new RuntimeException("can not invoke cancel method");
    }

    public byte[] getReadData() {
        return this.f3788c.array();
    }

    @Override // com.jieli.jl_rcsp.task.ITask
    public void start() {
        if (isRun()) {
            JL_Log.w(this.tag, "Task is in progress.");
        } else {
            callbackBegin();
            a(this.f3787b.f3796d, Math.min(this.f3787b.f3795c, this.f3787b.f3797e), (short) 0);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(final int i2, final int i3, final short s) {
        this.mRcspOp.sendRcspCommand(getConnectedDevice(), new SmallFileTransferCmd(new SmallFileTransferCmd.ReadFileParam(this.f3787b.f3793a, this.f3787b.f3794b, (short) i2, (short) i3, i2 == this.f3787b.f3796d ? (byte) 1 : (byte) 0)), new RcspCommandCallback<SmallFileTransferCmd>() { // from class: com.jieli.jl_rcsp.task.smallfile.ReadFileTask.1
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onErrCode(BluetoothDevice bluetoothDevice, BaseError baseError) {
                ReadFileTask.this.callbackError(baseError.getSubCode(), baseError.getMessage());
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onCommandResponse(BluetoothDevice bluetoothDevice, SmallFileTransferCmd smallFileTransferCmd) {
                if (smallFileTransferCmd.getStatus() != 0) {
                    onErrCode(bluetoothDevice, ReadFileTask.this.buildResponseBadState(smallFileTransferCmd.getId(), smallFileTransferCmd.getStatus()));
                    return;
                }
                SmallFileTransferCmd.ReadFileResponse readFileResponse = (SmallFileTransferCmd.ReadFileResponse) smallFileTransferCmd.getResponse();
                byte b2 = readFileResponse.ret;
                if (b2 != 0) {
                    onErrCode(bluetoothDevice, ReadFileTask.this.buildResponseBadResult(smallFileTransferCmd.getId(), b2));
                    return;
                }
                short CRC16 = CryptoUtil.CRC16(readFileResponse.fileData, s);
                if (CRC16 != readFileResponse.crc) {
                    onErrCode(bluetoothDevice, new BaseError(12544, RcspUtil.formatString("app last crc = %x, app crc = %x, device crc = %x.", Short.valueOf(s), Short.valueOf(CRC16), Short.valueOf(readFileResponse.crc))));
                    return;
                }
                ReadFileTask.this.f3788c.put(readFileResponse.fileData);
                int i4 = i2 + i3;
                ReadFileTask.this.callbackProgress((int) ((i4 * 100.0d) / ReadFileTask.this.f3787b.f3795c));
                if (i4 >= ReadFileTask.this.f3787b.f3795c) {
                    ReadFileTask.this.callbackFinish();
                } else {
                    ReadFileTask readFileTask = ReadFileTask.this;
                    readFileTask.a(i4, Math.min(i3, readFileTask.f3787b.f3795c - i4), CRC16);
                }
            }
        });
    }
}
