package com.jieli.jl_rcsp.tool;

import android.bluetooth.BluetoothDevice;
import android.graphics.Color;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.model.device.AttrBean;
import com.jieli.jl_rcsp.model.device.BatteryInfo;
import com.jieli.jl_rcsp.model.device.ChannelInfo;
import com.jieli.jl_rcsp.model.device.DevStorageInfo;
import com.jieli.jl_rcsp.model.device.DeviceInfo;
import com.jieli.jl_rcsp.model.device.DynamicLimiterParam;
import com.jieli.jl_rcsp.model.device.EqInfo;
import com.jieli.jl_rcsp.model.device.EqPresetInfo;
import com.jieli.jl_rcsp.model.device.ExpandFunction;
import com.jieli.jl_rcsp.model.device.FmStatusInfo;
import com.jieli.jl_rcsp.model.device.ID3MusicInfo;
import com.jieli.jl_rcsp.model.device.LightControlInfo;
import com.jieli.jl_rcsp.model.device.MusicNameInfo;
import com.jieli.jl_rcsp.model.device.MusicStatusInfo;
import com.jieli.jl_rcsp.model.device.PlayModeInfo;
import com.jieli.jl_rcsp.model.device.ReverberationParam;
import com.jieli.jl_rcsp.model.device.VoiceMode;
import com.jieli.jl_rcsp.model.device.VolumeInfo;
import com.jieli.jl_rcsp.model.device.health.AutomaticPressureDetection;
import com.jieli.jl_rcsp.model.device.health.BloodOxygenMeasurementAlert;
import com.jieli.jl_rcsp.model.device.health.DisconnectReminder;
import com.jieli.jl_rcsp.model.device.health.EmergencyContact;
import com.jieli.jl_rcsp.model.device.health.ExerciseHeartRateReminder;
import com.jieli.jl_rcsp.model.device.health.FallDetection;
import com.jieli.jl_rcsp.model.device.health.HealthSettingInfo;
import com.jieli.jl_rcsp.model.device.health.HeartRateMeasure;
import com.jieli.jl_rcsp.model.device.health.LiftWristDetection;
import com.jieli.jl_rcsp.model.device.health.SedentaryReminder;
import com.jieli.jl_rcsp.model.device.health.SensorInfo;
import com.jieli.jl_rcsp.model.device.health.SleepDetection;
import com.jieli.jl_rcsp.model.device.health.UserInfo;
import com.jieli.jl_rcsp.tool.callback.RcspEventListenerManager;
import com.jieli.jl_rcsp.util.CHexConver;
import com.jieli.jl_rcsp.util.JL_Log;
import java.io.UnsupportedEncodingException;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/* loaded from: classes3.dex */
public class RcspDataHandler {

    /* renamed from: c, reason: collision with root package name */
    private static final String f3827c = "rcsp_handler";

    /* renamed from: d, reason: collision with root package name */
    private static final int f3828d = 64;

    /* renamed from: a, reason: collision with root package name */
    private final RcspOpImpl f3829a;

    /* renamed from: b, reason: collision with root package name */
    private final RcspEventListenerManager f3830b;

    public RcspDataHandler(RcspOpImpl rcspOpImpl, RcspEventListenerManager rcspEventListenerManager) {
        this.f3829a = rcspOpImpl;
        this.f3830b = rcspEventListenerManager;
    }

    private void a(BluetoothDevice bluetoothDevice, List<AttrBean> list) {
        DeviceInfo deviceInfo;
        if (list == null || (deviceInfo = this.f3829a.getDeviceInfo(bluetoothDevice)) == null) {
            return;
        }
        for (AttrBean attrBean : list) {
            byte[] attrData = attrBean.getAttrData();
            if (attrData != null && attrData.length != 0 && attrBean.getType() == 0) {
                boolean z = CHexConver.byteToInt(attrData[0]) == 1;
                JL_Log.i(f3827c, "onAuxStatusChange >> " + z);
                deviceInfo.setAuxPlay(z);
                this.f3830b.onAuxStatusChange(bluetoothDevice, z);
            }
        }
    }

    private void b(BluetoothDevice bluetoothDevice, List<AttrBean> list) {
        DeviceInfo deviceInfo;
        String str;
        String str2;
        String str3;
        String str4;
        if (list == null || (deviceInfo = this.f3829a.getDeviceInfo(bluetoothDevice)) == null) {
            return;
        }
        ID3MusicInfo iD3MusicInfo = deviceInfo.getiD3MusicInfo();
        if (iD3MusicInfo == null) {
            iD3MusicInfo = new ID3MusicInfo();
        }
        ID3MusicInfo iD3MusicInfo2 = iD3MusicInfo;
        boolean z = false;
        for (AttrBean attrBean : list) {
            byte[] attrData = attrBean.getAttrData();
            if (attrData != null && attrData.length != 0) {
                switch (attrBean.getType()) {
                    case 0:
                        String byte2HexStr = CHexConver.byte2HexStr(attrData);
                        try {
                            str = new String(attrData, 0, attrData.length, StandardCharsets.UTF_8);
                        } catch (Exception e2) {
                            e2.printStackTrace();
                            str = null;
                        }
                        if (str != null && attrData.length == 64) {
                            str = str.substring(0, str.length() - 1) + "...";
                        }
                        iD3MusicInfo2.setTitle("00".equals(byte2HexStr) ? "" : str);
                        z = true;
                        break;
                    case 1:
                        String byte2HexStr2 = CHexConver.byte2HexStr(attrData);
                        try {
                            str2 = new String(attrData, 0, attrData.length, StandardCharsets.UTF_8);
                        } catch (Exception e3) {
                            e3.printStackTrace();
                            str2 = null;
                        }
                        if (str2 != null && attrData.length == 64) {
                            str2 = str2.substring(0, str2.length() - 1) + "...";
                        }
                        iD3MusicInfo2.setArtist("00".equals(byte2HexStr2) ? "" : str2);
                        z = true;
                        break;
                    case 2:
                        String byte2HexStr3 = CHexConver.byte2HexStr(attrData);
                        try {
                            str3 = new String(attrData, 0, attrData.length, StandardCharsets.UTF_8);
                        } catch (Exception e4) {
                            e4.printStackTrace();
                            str3 = null;
                        }
                        if (str3 != null && attrData.length == 64) {
                            str3 = str3.substring(0, str3.length() - 1) + "...";
                        }
                        iD3MusicInfo2.setAlbum("00".equals(byte2HexStr3) ? "" : str3);
                        z = true;
                        break;
                    case 3:
                        int byteToInt = CHexConver.byteToInt(attrData[0]);
                        JL_Log.d(f3827c, "-parseBtData- id3 number: " + byteToInt);
                        iD3MusicInfo2.setNumber(byteToInt);
                        z = true;
                        break;
                    case 4:
                        int bytesToInt = attrData.length >= 2 ? CHexConver.bytesToInt(attrData, 0, 2) : 0;
                        JL_Log.d(f3827c, "-parseBtData- id3 allNum: " + bytesToInt);
                        iD3MusicInfo2.setTotal(bytesToInt);
                        z = true;
                        break;
                    case 5:
                        try {
                            str4 = new String(attrData, 0, attrData.length, StandardCharsets.UTF_8);
                        } catch (Exception e5) {
                            e5.printStackTrace();
                            str4 = null;
                        }
                        JL_Log.d(f3827c, "-parseBtData- id3 genre: " + str4);
                        iD3MusicInfo2.setGenre(str4);
                        z = true;
                        break;
                    case 6:
                        int bytesToInt2 = attrData.length >= 2 ? CHexConver.bytesToInt(attrData, 0, 2) : 0;
                        JL_Log.i(f3827c, "-parseBtData- id3 allTime: " + bytesToInt2);
                        iD3MusicInfo2.setTotalTime(bytesToInt2);
                        z = true;
                        break;
                    case 7:
                        boolean z2 = (attrData[0] & 1) == 1;
                        JL_Log.d(f3827c, "-parseBtData- id3 isPlay: " + z2);
                        iD3MusicInfo2.setPlayStatus(z2);
                        z = true;
                        break;
                    case 8:
                        int bytesToInt3 = attrData.length >= 4 ? CHexConver.bytesToInt(attrData, 0, 4) / 1000 : 0;
                        JL_Log.d(f3827c, "-parseBtData- id3 currentTime: " + bytesToInt3);
                        iD3MusicInfo2.setCurrentTime(bytesToInt3);
                        z = true;
                        break;
                }
            }
        }
        if (z) {
            deviceInfo.setiD3MusicInfo(iD3MusicInfo2);
            this.f3830b.onID3MusicInfo(bluetoothDevice, iD3MusicInfo2);
        }
    }

    private void c(BluetoothDevice bluetoothDevice, List<AttrBean> list) {
        DeviceInfo deviceInfo;
        if (list == null || (deviceInfo = this.f3829a.getDeviceInfo(bluetoothDevice)) == null) {
            return;
        }
        for (AttrBean attrBean : list) {
            byte[] attrData = attrBean.getAttrData();
            if (attrData != null && attrData.length != 0) {
                byte type = attrBean.getType();
                int i2 = 1;
                if (type == 0) {
                    FmStatusInfo fmStatusInfo = new FmStatusInfo(CHexConver.byteToInt(attrData[0]) == 1, attrData.length > 1 ? CHexConver.byteToInt(attrData[1]) : 0, attrData.length > 3 ? CHexConver.bytesToInt(attrData[2], attrData[3]) / 10.0f : 0.0f, attrData.length > 4 ? CHexConver.byteToInt(attrData[4]) : 0);
                    deviceInfo.setFmStatusInfo(fmStatusInfo);
                    this.f3830b.onFmStatusChange(bluetoothDevice, fmStatusInfo);
                } else if (type == 1) {
                    ArrayList arrayList = new ArrayList();
                    int length = attrData.length;
                    while (length - i2 >= 3) {
                        int byteToInt = CHexConver.byteToInt(attrData[i2]);
                        float bytesToInt = CHexConver.bytesToInt(attrData[r6], attrData[r6 + 1]) / 10.0f;
                        i2 = i2 + 1 + 2;
                        arrayList.add(new ChannelInfo(byteToInt, bytesToInt));
                    }
                    deviceInfo.setChannelInfos(arrayList);
                    this.f3830b.onFmChannelsChange(bluetoothDevice, arrayList);
                }
            }
        }
    }

    private void d(BluetoothDevice bluetoothDevice, List<AttrBean> list) {
        DeviceInfo deviceInfo;
        String str;
        int i2;
        int i3;
        if (list == null || (deviceInfo = this.f3829a.getDeviceInfo(bluetoothDevice)) == null) {
            return;
        }
        for (AttrBean attrBean : list) {
            byte[] attrData = attrBean.getAttrData();
            if (attrData != null && attrData.length != 0) {
                byte type = attrBean.getType();
                if (type == 0) {
                    boolean z = (attrData[0] & 1) == 1;
                    if (attrData.length > 4) {
                        byte[] bArr = new byte[4];
                        System.arraycopy(attrData, 1, bArr, 0, 4);
                        int bytesToInt = CHexConver.bytesToInt(bArr) * 1000;
                        if (attrData.length > 8) {
                            System.arraycopy(attrData, 5, bArr, 0, 4);
                            i3 = CHexConver.bytesToInt(bArr) * 1000;
                            i2 = attrData.length > 9 ? CHexConver.byteToInt(attrData[9]) : 0;
                        } else {
                            i2 = 0;
                            i3 = 0;
                        }
                        r6 = bytesToInt;
                    } else {
                        i2 = 0;
                        i3 = 0;
                    }
                    MusicStatusInfo musicStatusInfo = new MusicStatusInfo(z, r6, i3, i2);
                    deviceInfo.setMusicStatusInfo(musicStatusInfo);
                    deviceInfo.setCurrentDevIndex(CHexConver.intToByte(musicStatusInfo.getCurrentDev()));
                    this.f3830b.onMusicStatusChange(bluetoothDevice, musicStatusInfo);
                } else if (type != 1) {
                    if (type == 2) {
                        int byteToInt = CHexConver.byteToInt(attrData[0]);
                        JL_Log.d(f3827c, "-parseMusicData- music play mode : " + byteToInt);
                        PlayModeInfo playModeInfo = new PlayModeInfo(byteToInt);
                        deviceInfo.setPlayModeInfo(playModeInfo);
                        this.f3830b.onPlayModeChange(bluetoothDevice, playModeInfo);
                    }
                } else if (attrData.length > 3) {
                    byte[] bArr2 = new byte[4];
                    System.arraycopy(attrData, 0, bArr2, 0, 4);
                    int bytesToInt2 = CHexConver.bytesToInt(bArr2);
                    if (attrData.length > 4) {
                        boolean z2 = (attrData[4] & 255) == 1;
                        if (attrData.length > 5) {
                            try {
                                str = new String(attrData, 5, attrData.length - 5, z2 ? "gbk" : "utf-16le");
                            } catch (UnsupportedEncodingException e2) {
                                e2.printStackTrace();
                            }
                            MusicNameInfo musicNameInfo = new MusicNameInfo(bytesToInt2, str);
                            deviceInfo.setMusicNameInfo(musicNameInfo);
                            deviceInfo.setCluster(musicNameInfo.getCluster());
                            this.f3830b.onMusicNameChange(bluetoothDevice, musicNameInfo);
                        }
                    }
                    str = null;
                    MusicNameInfo musicNameInfo2 = new MusicNameInfo(bytesToInt2, str);
                    deviceInfo.setMusicNameInfo(musicNameInfo2);
                    deviceInfo.setCluster(musicNameInfo2.getCluster());
                    this.f3830b.onMusicNameChange(bluetoothDevice, musicNameInfo2);
                }
            }
        }
    }

    private void e(BluetoothDevice bluetoothDevice, List<AttrBean> list) {
        String str;
        DeviceInfo deviceInfo = this.f3829a.getDeviceInfo(bluetoothDevice);
        if (deviceInfo == null) {
            return;
        }
        for (AttrBean attrBean : list) {
            byte[] attrData = attrBean.getAttrData();
            if (attrData != null) {
                if (attrData.length != 0) {
                    int i2 = 1;
                    int i3 = 0;
                    switch (attrBean.getType()) {
                        case 0:
                            this.f3830b.onBatteryChange(bluetoothDevice, new BatteryInfo(CHexConver.byteToInt(attrData[0])));
                            continue;
                        case 1:
                            int maxVol = deviceInfo.getMaxVol();
                            boolean isSupportVolumeSync = deviceInfo.isSupportVolumeSync();
                            int byteToInt = CHexConver.byteToInt(attrData[0]);
                            deviceInfo.setVolume(byteToInt);
                            this.f3830b.onVolumeChange(bluetoothDevice, new VolumeInfo(maxVol, byteToInt, isSupportVolumeSync));
                            continue;
                        case 2:
                            DevStorageInfo devStorageInfo = new DevStorageInfo();
                            devStorageInfo.parseData(attrData);
                            deviceInfo.setDevStorageInfo(devStorageInfo);
                            this.f3830b.onDevStorageInfoChange(bluetoothDevice, devStorageInfo);
                            continue;
                        case 4:
                            byte b2 = attrData[0];
                            boolean z = (b2 & 128) == 128;
                            int byteToInt2 = CHexConver.byteToInt(b2) & 127;
                            EqInfo eqInfo = new EqInfo();
                            eqInfo.setMode(byteToInt2);
                            eqInfo.setDynamic(z);
                            if (z) {
                                int i4 = attrData[1];
                                byte[] bArr = new byte[i4];
                                System.arraycopy(attrData, 2, bArr, 0, i4);
                                eqInfo.setValue(bArr);
                                EqPresetInfo a2 = a(list);
                                if (a2 == null) {
                                    a2 = deviceInfo.getEqPresetInfo();
                                }
                                if (a2 != null) {
                                    eqInfo.setFreqs(a2.getFreqs());
                                }
                                JL_Log.d(f3827c, "-parsePublicData- eq data freq-->" + a2);
                            } else {
                                byte[] bArr2 = new byte[0];
                                if (attrData.length > 10) {
                                    bArr2 = new byte[10];
                                    System.arraycopy(attrData, 1, bArr2, 0, 10);
                                }
                                eqInfo.setValue(bArr2);
                            }
                            deviceInfo.setEqInfo(eqInfo);
                            this.f3830b.onEqChange(bluetoothDevice, eqInfo);
                            continue;
                        case 5:
                            try {
                                str = new String(attrData);
                            } catch (Exception e2) {
                                e2.printStackTrace();
                                str = null;
                            }
                            deviceInfo.setPlayFileFormat(str);
                            this.f3830b.onFileFormatChange(bluetoothDevice, str);
                            continue;
                        case 6:
                            int byteToInt3 = CHexConver.byteToInt(attrData[0]);
                            deviceInfo.setCurFunction(attrData[0]);
                            JL_Log.i(f3827c, "-parsePublicData- onDeviceModeChange >> " + byteToInt3);
                            this.f3830b.onDeviceModeChange(bluetoothDevice, byteToInt3);
                            continue;
                        case 7:
                            JL_Log.i(f3827c, "-parsePublicData- SYS_INFO_ATTR_LIGHT");
                            int byteToInt4 = CHexConver.byteToInt(attrData[0]);
                            int byteToInt5 = CHexConver.byteToInt(attrData[1]);
                            int byteToInt6 = CHexConver.byteToInt(attrData[2]);
                            int byteToInt7 = CHexConver.byteToInt(attrData[3]);
                            int byteToInt8 = CHexConver.byteToInt(attrData[4]);
                            int byteToInt9 = CHexConver.byteToInt(attrData[5]);
                            int byteToInt10 = CHexConver.byteToInt(attrData[6]);
                            LightControlInfo luminance = new LightControlInfo().setSwitchState(byteToInt4 & 3).setLightMode((byteToInt4 & 12) >>> 2).setColor(Color.rgb(byteToInt5, byteToInt6, byteToInt7)).setTwinkleMode(byteToInt8).setTwinkleFreq(byteToInt9).setSceneMode(byteToInt10).setHue(CHexConver.bytesToInt(attrData[7], attrData[8])).setSaturation(CHexConver.byteToInt(attrData[9])).setLuminance(CHexConver.byteToInt(attrData[10]));
                            deviceInfo.setLightControlInfo(luminance);
                            this.f3830b.onLightControlInfo(bluetoothDevice, luminance);
                            continue;
                        case 8:
                            if (attrData.length >= 2 && attrData.length < 4) {
                                byte[] bArr3 = new byte[2];
                                System.arraycopy(attrData, 0, bArr3, 0, 2);
                                i3 = CHexConver.bytesToInt(bArr3[0], bArr3[1]);
                            } else if (attrData.length >= 4) {
                                byte[] bArr4 = new byte[4];
                                System.arraycopy(attrData, 0, bArr4, 0, 4);
                                i3 = CHexConver.bytesToInt(bArr4);
                            }
                            float f2 = i3 / 10.0f;
                            deviceInfo.setFrequency(f2);
                            this.f3830b.onFrequencyTx(bluetoothDevice, f2);
                            continue;
                        case 9:
                            this.f3830b.onPeripheralsModeChange(bluetoothDevice, CHexConver.byteToInt(attrData[0]));
                            continue;
                        case 10:
                            byte[] bArr5 = new byte[0];
                            boolean z2 = attrData[0] == 1;
                            if (z2 && attrData.length > 6) {
                                bArr5 = new byte[6];
                                System.arraycopy(attrData, 1, bArr5, 0, 6);
                            }
                            this.f3830b.onPeripheralsConnectStatusChange(bluetoothDevice, z2, CHexConver.hexDataCovetToAddress(bArr5));
                            continue;
                        case 11:
                            if (attrData.length >= 8) {
                                this.f3830b.onHighAndBassChange(bluetoothDevice, CHexConver.bytesToInt(attrData, 0, 4), CHexConver.bytesToInt(attrData, 4, 4));
                                break;
                            } else {
                                continue;
                            }
                        case 12:
                            JL_Log.d(f3827c, "-parsePublicData- eq preset data-->" + CHexConver.byte2HexStr(attrData, attrData.length));
                            EqPresetInfo a3 = a(attrBean);
                            deviceInfo.setEqPresetInfo(a3);
                            this.f3830b.onEqPresetChange(bluetoothDevice, a3);
                            continue;
                        case 13:
                            if (attrData.length >= 9) {
                                byte[] bArr6 = new byte[9];
                                System.arraycopy(attrData, 0, bArr6, 0, 9);
                                VoiceMode parse = VoiceMode.parse(bArr6);
                                deviceInfo.setCurrentVoiceMode(parse);
                                this.f3830b.onCurrentVoiceMode(bluetoothDevice, parse);
                                break;
                            } else {
                                continue;
                            }
                        case 14:
                            byte b3 = attrData[0];
                            if (b3 > 0) {
                                if (attrData.length >= (b3 * 9) + 1) {
                                    byte[] bArr7 = new byte[9];
                                    ArrayList arrayList = new ArrayList();
                                    for (int i5 = 0; i5 < b3; i5++) {
                                        System.arraycopy(attrData, i2, bArr7, 0, 9);
                                        i2 += 9;
                                        arrayList.add(VoiceMode.parse(bArr7));
                                    }
                                    deviceInfo.setVoiceModeList(arrayList);
                                    this.f3830b.onVoiceModeList(bluetoothDevice, arrayList);
                                    break;
                                } else {
                                    break;
                                }
                            } else {
                                continue;
                            }
                        case 15:
                            JL_Log.e(f3827c, "-parsePublicData- phone status change ：" + CHexConver.byte2HexStr(attrData));
                            int byteToInt11 = CHexConver.byteToInt(attrData[0]);
                            deviceInfo.setPhoneStatus(byteToInt11);
                            this.f3830b.onPhoneCallStatusChange(bluetoothDevice, byteToInt11);
                            continue;
                        case 16:
                            int length = attrData.length;
                            byte[] bArr8 = new byte[length];
                            System.arraycopy(attrData, 0, bArr8, 0, length);
                            a(bluetoothDevice, bArr8);
                            continue;
                        case 17:
                            EqInfo eqInfo2 = new EqInfo();
                            eqInfo2.setDynamic(true);
                            eqInfo2.setMode(0);
                            int i6 = attrData[0];
                            int[] iArr = new int[i6];
                            while (i3 < i6) {
                                iArr[i3] = CHexConver.bytesToInt(attrData, i2, 2);
                                i3++;
                                i2 += 2;
                            }
                            eqInfo2.setFreqs(iArr);
                            deviceInfo.setSoundCardEqInfo(eqInfo2);
                            continue;
                        case 18:
                            EqInfo soundCardEqInfo = deviceInfo.getSoundCardEqInfo();
                            if (soundCardEqInfo != null) {
                                int i7 = attrData[0];
                                byte[] bArr9 = new byte[i7];
                                System.arraycopy(attrData, 1, bArr9, 0, i7);
                                soundCardEqInfo.setValue(bArr9);
                                deviceInfo.setSoundCardEqInfo(soundCardEqInfo);
                                this.f3830b.onSoundCardEqChange(bluetoothDevice, soundCardEqInfo);
                                break;
                            } else {
                                continue;
                            }
                        case 19:
                            JL_Log.d(f3827c, "-parsePublicData- 声卡功能状态变化：" + CHexConver.byte2HexStr(attrData));
                            if (attrData.length >= 8) {
                                long bytesToLong = CHexConver.bytesToLong(attrData, 0, 8);
                                JL_Log.d(f3827c, "-parsePublicData- 声卡功能状态变化 ： mask  ->  " + CHexConver.byte2HexStr(attrData, 8));
                                byte[] bArr10 = new byte[0];
                                if (attrData.length > 8) {
                                    int length2 = attrData.length - 8;
                                    byte[] bArr11 = new byte[length2];
                                    System.arraycopy(attrData, 8, bArr11, 0, length2);
                                    JL_Log.d(f3827c, "-parsePublicData- 声卡功能状态变化 ： values  ->  " + CHexConver.byte2HexStr(bArr11));
                                    bArr10 = bArr11;
                                }
                                this.f3830b.onSoundCardStatusChange(bluetoothDevice, bytesToLong, bArr10);
                                break;
                            } else {
                                continue;
                            }
                    }
                }
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:75:0x01b8  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private void f(android.bluetooth.BluetoothDevice r23, java.util.List<com.jieli.jl_rcsp.model.device.AttrBean> r24) {
        /*
            Method dump skipped, instructions count: 632
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jieli.jl_rcsp.tool.RcspDataHandler.f(android.bluetooth.BluetoothDevice, java.util.List):void");
    }

    public void parseAttrMessage(BluetoothDevice bluetoothDevice, byte b2, List<AttrBean> list) {
        if (bluetoothDevice == null || list == null) {
            return;
        }
        if (b2 == -1) {
            e(bluetoothDevice, list);
            return;
        }
        if (b2 == 0) {
            b(bluetoothDevice, list);
            return;
        }
        if (b2 == 1) {
            d(bluetoothDevice, list);
            return;
        }
        if (b2 == 2) {
            f(bluetoothDevice, list);
        } else if (b2 == 3) {
            a(bluetoothDevice, list);
        } else {
            if (b2 != 4) {
                return;
            }
            c(bluetoothDevice, list);
        }
    }

    public void parseHealthSetting(BluetoothDevice bluetoothDevice, List<AttrBean> list) {
        DeviceInfo deviceInfo = this.f3829a.getDeviceInfo();
        if (deviceInfo == null) {
            return;
        }
        HealthSettingInfo healthSettingInfo = deviceInfo.getHealthSettingInfo();
        if (healthSettingInfo == null) {
            healthSettingInfo = new HealthSettingInfo();
            deviceInfo.setHealthSettingInfo(healthSettingInfo);
        }
        for (AttrBean attrBean : list) {
            byte[] attrData = attrBean.getAttrData();
            healthSettingInfo.setFuncFlag(attrBean.getType());
            switch (attrBean.getType()) {
                case 1:
                    healthSettingInfo.setSensorInfo(new SensorInfo(CHexConver.bytesToInt(attrData, 0, 2)));
                    break;
                case 2:
                    healthSettingInfo.setSedentaryReminder(new SedentaryReminder(attrData));
                    break;
                case 3:
                    healthSettingInfo.setHeartRateMeasure(new HeartRateMeasure(attrData));
                    break;
                case 4:
                    healthSettingInfo.setExerciseHeartRateReminder(new ExerciseHeartRateReminder(attrData));
                    break;
                case 5:
                    healthSettingInfo.setAutomaticPressureDetection(new AutomaticPressureDetection(attrData));
                    break;
                case 6:
                    healthSettingInfo.setSleepDetection(new SleepDetection(attrData));
                    break;
                case 7:
                    healthSettingInfo.setFallDetection(new FallDetection(attrData));
                    break;
                case 8:
                    healthSettingInfo.setLiftWristDetection(new LiftWristDetection(attrData));
                    break;
                case 9:
                    healthSettingInfo.setUserInfo(new UserInfo(attrData));
                    break;
                case 10:
                    healthSettingInfo.setDisconnectReminder(new DisconnectReminder(attrData));
                    break;
                case 11:
                    healthSettingInfo.setBloodOxygenMeasurementAlert(new BloodOxygenMeasurementAlert(attrData));
                    break;
                case 12:
                    healthSettingInfo.setEmergencyContact(new EmergencyContact(attrData));
                    break;
            }
            this.f3830b.onHealthSettingChange(bluetoothDevice, healthSettingInfo);
        }
    }

    private void a(BluetoothDevice bluetoothDevice, byte[] bArr) {
        JL_Log.d(f3827c, "parseFixedLenData-->" + CHexConver.byte2HexStr(bArr));
        DeviceInfo deviceInfo = this.f3829a.getDeviceInfo(bluetoothDevice);
        if (deviceInfo == null) {
            return;
        }
        ExpandFunction expandFunction = deviceInfo.getExpandFunction();
        int i2 = 4;
        if (bArr.length >= 4) {
            int bytesToInt = CHexConver.bytesToInt(bArr, 0, 4);
            if (expandFunction == null) {
                expandFunction = new ExpandFunction();
                expandFunction.setMask(bytesToInt);
            } else {
                expandFunction.setMask(expandFunction.getMask() | bytesToInt);
            }
            if ((bytesToInt & 1) == 1 && bArr.length >= 9) {
                byte[] bArr2 = new byte[5];
                System.arraycopy(bArr, 4, bArr2, 0, 5);
                expandFunction.putData(0, bArr2);
                this.f3830b.onExpandFunction(bluetoothDevice, 0, bArr2);
                ReverberationParam parseData = ReverberationParam.parseData(bArr2);
                if (parseData != null) {
                    this.f3830b.onReverberation(bluetoothDevice, parseData);
                }
                i2 = 9;
            }
            if ((bytesToInt & 2) == 2 && bArr.length >= i2 + 2) {
                byte[] bArr3 = new byte[2];
                System.arraycopy(bArr, i2, bArr3, 0, 2);
                expandFunction.putData(1, bArr3);
                this.f3830b.onExpandFunction(bluetoothDevice, 1, bArr3);
                DynamicLimiterParam parseData2 = DynamicLimiterParam.parseData(bArr3);
                if (parseData2 != null) {
                    this.f3830b.onDynamicLimiter(bluetoothDevice, parseData2);
                }
            }
            deviceInfo.setExpandFunction(expandFunction);
        }
    }

    private EqPresetInfo a(List<AttrBean> list) {
        AttrBean attrBean;
        Iterator<AttrBean> it2 = list.iterator();
        while (true) {
            if (!it2.hasNext()) {
                attrBean = null;
                break;
            }
            attrBean = it2.next();
            if (attrBean.getType() == 12) {
                break;
            }
        }
        if (attrBean == null) {
            return null;
        }
        return a(attrBean);
    }

    private EqPresetInfo a(AttrBean attrBean) {
        EqPresetInfo eqPresetInfo = new EqPresetInfo();
        byte[] attrData = attrBean.getAttrData();
        ArrayList arrayList = new ArrayList();
        int i2 = attrData[0];
        int[] iArr = new int[i2];
        int i3 = 1;
        for (int i4 = 0; i4 < i2; i4++) {
            iArr[i4] = ((attrData[i3] & 255) << 8) | (attrData[i3 + 1] & 255);
            i3 += 2;
        }
        for (int i5 = 0; i5 < 7; i5++) {
            byte[] bArr = new byte[i2];
            byte b2 = (byte) (attrData[i3] & Byte.MAX_VALUE);
            System.arraycopy(attrData, i3 + 1, bArr, 0, i2);
            EqInfo eqInfo = new EqInfo(b2, bArr, iArr);
            eqInfo.setDynamic((attrData[i3] & 128) == 128);
            arrayList.add(eqInfo);
            i3 += i2 + 1;
        }
        eqPresetInfo.setNumber(i2);
        eqPresetInfo.setFreqs(iArr);
        eqPresetInfo.setEqInfos(arrayList);
        JL_Log.d(f3827c, "-parseEqPresetInfo- eq--->" + eqPresetInfo);
        return eqPresetInfo;
    }

    private int b(List<AttrBean> list) {
        for (AttrBean attrBean : list) {
            if (attrBean.getType() == 4) {
                return attrBean.getAttrData()[0] & 7;
            }
        }
        return 0;
    }
}
