package com.jieli.jl_rcsp.tool;

import com.dd.plist.ASCIIPropertyListParser;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.OnOperationCallback;
import com.jieli.jl_rcsp.interfaces.listener.ThreadStateListener;
import com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback;
import com.jieli.jl_rcsp.model.NotificationMsg;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.command.watch.PushInfoDataToDeviceCmd;
import com.jieli.jl_rcsp.model.device.MessageInfo;
import com.jieli.jl_rcsp.task.SimpleTaskListener;
import com.jieli.jl_rcsp.task.smallfile.AddFileTask;
import com.jieli.jl_rcsp.task.smallfile.DeleteFileTask;
import com.jieli.jl_rcsp.util.CommandBuilder;
import com.jieli.jl_rcsp.util.JL_Log;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.LinkedBlockingQueue;

/* loaded from: classes3.dex */
public class SyncMessageTask extends Thread {

    /* renamed from: i, reason: collision with root package name */
    private static final String f3835i = "SyncMessageTask";

    /* renamed from: a, reason: collision with root package name */
    private final RcspOpImpl f3836a;

    /* renamed from: b, reason: collision with root package name */
    private final LinkedBlockingQueue<SyncTask> f3837b;

    /* renamed from: c, reason: collision with root package name */
    private final ThreadStateListener f3838c;

    /* renamed from: d, reason: collision with root package name */
    private volatile boolean f3839d;

    /* renamed from: e, reason: collision with root package name */
    private volatile boolean f3840e;

    /* renamed from: f, reason: collision with root package name */
    private boolean f3841f;

    /* renamed from: g, reason: collision with root package name */
    private boolean f3842g;

    /* renamed from: h, reason: collision with root package name */
    private final Map<String, Short> f3843h;

    public static class SyncTask {

        /* renamed from: a, reason: collision with root package name */
        private final int f3858a;

        /* renamed from: b, reason: collision with root package name */
        private final NotificationMsg f3859b;

        /* renamed from: c, reason: collision with root package name */
        private final OnWatchOpCallback<Boolean> f3860c;

        public SyncTask(int i2, NotificationMsg notificationMsg, OnWatchOpCallback<Boolean> onWatchOpCallback) {
            this.f3858a = i2;
            this.f3859b = notificationMsg;
            this.f3860c = onWatchOpCallback;
        }

        public OnWatchOpCallback<Boolean> getCallback() {
            return this.f3860c;
        }

        public NotificationMsg getMessage() {
            return this.f3859b;
        }

        public int getTaskOp() {
            return this.f3858a;
        }

        public String toString() {
            return "SyncTask{taskOp=" + this.f3858a + ", message=" + this.f3859b + ", callback=" + this.f3860c + ASCIIPropertyListParser.DICTIONARY_END_TOKEN;
        }
    }

    public SyncMessageTask(RcspOpImpl rcspOpImpl, ThreadStateListener threadStateListener) {
        super(f3835i);
        this.f3837b = new LinkedBlockingQueue<>();
        this.f3843h = new HashMap();
        if (rcspOpImpl == null) {
            throw new NullPointerException("RcspOpImpl can not be null.");
        }
        this.f3836a = rcspOpImpl;
        this.f3838c = threadStateListener;
    }

    private void b(final NotificationMsg notificationMsg, final OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (notificationMsg == null) {
            return;
        }
        if (this.f3836a.getDeviceInfo() == null) {
            this.f3837b.clear();
            return;
        }
        this.f3842g = true;
        final AddFileTask addFileTask = new AddFileTask(this.f3836a, new AddFileTask.Param((byte) 6, new MessageInfo(notificationMsg.getAppName(), notificationMsg.getFlag(), notificationMsg.getTitle(), notificationMsg.getContent(), notificationMsg.getTime()).beanToData()));
        addFileTask.setListener(new SimpleTaskListener() { // from class: com.jieli.jl_rcsp.tool.SyncMessageTask.4
            @Override // com.jieli.jl_rcsp.task.SimpleTaskListener, com.jieli.jl_rcsp.task.TaskListener
            public void onCancel(int i2) {
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onFailed(new BaseError(4098, "User cancel. reason : " + i2));
                }
            }

            @Override // com.jieli.jl_rcsp.task.SimpleTaskListener, com.jieli.jl_rcsp.task.TaskListener
            public void onError(int i2, String str) {
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onFailed(new BaseError(i2, str));
                }
            }

            @Override // com.jieli.jl_rcsp.task.SimpleTaskListener, com.jieli.jl_rcsp.task.TaskListener
            public void onFinish() {
                SyncMessageTask syncMessageTask = SyncMessageTask.this;
                syncMessageTask.a(syncMessageTask.a(notificationMsg.getAppName(), notificationMsg.getTime()), addFileTask.getFile().id);
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onSuccess(Boolean.TRUE);
                }
            }
        });
        addFileTask.start();
        if (this.f3842g) {
            b();
        }
    }

    private void c(NotificationMsg notificationMsg, final OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (this.f3836a.getDeviceInfo() == null) {
            this.f3837b.clear();
            return;
        }
        this.f3842g = true;
        RcspOpImpl rcspOpImpl = this.f3836a;
        rcspOpImpl.sendRcspCommand(rcspOpImpl.getTargetDevice(), CommandBuilder.buildRemoveMessageCmd(new PushInfoDataToDeviceCmd.RemoveMsg(notificationMsg.getAppName(), notificationMsg.getTime())), new BooleanRcspActionCallback("removeMessage", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.tool.SyncMessageTask.3
            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onFailed(BaseError baseError) {
                JL_Log.e(SyncMessageTask.f3835i, "---- removeMessage ---- error = " + baseError);
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onFailed(baseError);
                }
            }

            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onSuccess(Boolean bool) {
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onSuccess(Boolean.TRUE);
                }
            }
        }));
        if (this.f3842g) {
            b();
        }
    }

    private void d(NotificationMsg notificationMsg, final OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (notificationMsg == null) {
            return;
        }
        if (this.f3836a.getDeviceInfo() == null) {
            this.f3837b.clear();
            return;
        }
        final String a2 = a(notificationMsg.getAppName(), notificationMsg.getTime());
        Short a3 = a(a2);
        JL_Log.d(f3835i, "-removeMessageBySFT- key = " + a2 + ", id = " + a3);
        if (a3 == null) {
            return;
        }
        this.f3842g = true;
        DeleteFileTask deleteFileTask = new DeleteFileTask(this.f3836a, new DeleteFileTask.Param((byte) 6, a3.shortValue()));
        deleteFileTask.setListener(new SimpleTaskListener() { // from class: com.jieli.jl_rcsp.tool.SyncMessageTask.5
            @Override // com.jieli.jl_rcsp.task.SimpleTaskListener, com.jieli.jl_rcsp.task.TaskListener
            public void onCancel(int i2) {
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onFailed(new BaseError(4098, "Cancel operation. reason : " + i2));
                }
            }

            @Override // com.jieli.jl_rcsp.task.SimpleTaskListener, com.jieli.jl_rcsp.task.TaskListener
            public void onError(int i2, String str) {
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onFailed(new BaseError(i2, str));
                }
            }

            @Override // com.jieli.jl_rcsp.task.SimpleTaskListener, com.jieli.jl_rcsp.task.TaskListener
            public void onFinish() {
                SyncMessageTask.this.b(a2);
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onSuccess(Boolean.TRUE);
                }
            }
        });
        deleteFileTask.start();
        if (this.f3842g) {
            b();
        }
    }

    public void exit() {
        this.f3839d = false;
        c();
    }

    public boolean isRunning() {
        return this.f3839d;
    }

    public void putNotification(SyncTask syncTask) {
        boolean z;
        if (this.f3836a.isRcspInit()) {
            try {
                this.f3837b.put(syncTask);
                z = true;
            } catch (InterruptedException e2) {
                e2.printStackTrace();
                z = false;
            }
            if (z && this.f3840e) {
                this.f3840e = false;
                c();
            }
        }
    }

    @Override // java.lang.Thread, java.lang.Runnable
    public void run() {
        this.f3839d = true;
        ThreadStateListener threadStateListener = this.f3838c;
        if (threadStateListener != null) {
            threadStateListener.onStart(getId());
        }
        synchronized (this.f3837b) {
            while (this.f3839d) {
                this.f3840e = this.f3837b.isEmpty();
                if (this.f3840e) {
                    b();
                } else {
                    SyncTask poll = this.f3837b.poll();
                    if (!this.f3836a.isRcspInit()) {
                        this.f3837b.clear();
                        this.f3839d = false;
                        return;
                    } else if (poll != null) {
                        if (poll.getTaskOp() == 0) {
                            if (this.f3836a.getDeviceInfo().isContactsTransferBySmallFile()) {
                                b(poll.getMessage(), poll.getCallback());
                            } else {
                                a(poll.getMessage(), poll.getCallback());
                            }
                        } else if (this.f3836a.getDeviceInfo().isContactsTransferBySmallFile()) {
                            d(poll.getMessage(), poll.getCallback());
                        } else {
                            c(poll.getMessage(), poll.getCallback());
                        }
                    }
                }
            }
            this.f3837b.clear();
            this.f3843h.clear();
            this.f3839d = false;
            this.f3840e = false;
            this.f3842g = false;
            ThreadStateListener threadStateListener2 = this.f3838c;
            if (threadStateListener2 != null) {
                threadStateListener2.onFinish(getId());
            }
            JL_Log.w(f3835i, "---- thread end ----");
        }
    }

    @Override // java.lang.Thread
    public synchronized void start() {
        super.start();
    }

    private void a(NotificationMsg notificationMsg, final OnWatchOpCallback<Boolean> onWatchOpCallback) {
        if (notificationMsg == null) {
            return;
        }
        if (this.f3836a.getDeviceInfo() == null) {
            this.f3837b.clear();
            return;
        }
        JL_Log.i(f3835i, "---- pushMessageInfo ---- msg = " + notificationMsg);
        byte[] beanToData = new MessageInfo(notificationMsg.getAppName(), notificationMsg.getFlag(), notificationMsg.getTitle(), notificationMsg.getContent(), notificationMsg.getTime()).beanToData();
        if (beanToData.length > 240) {
            int length = beanToData.length / 240;
            if (beanToData.length % 240 != 0) {
                length++;
            }
            int i2 = 0;
            for (final int i3 = length - 1; i3 >= 0; i3--) {
                int length2 = beanToData.length - i2;
                if (length2 <= 0) {
                    return;
                }
                byte[] bArr = length2 > 240 ? new byte[240] : new byte[length2];
                System.arraycopy(beanToData, i2, bArr, 0, bArr.length);
                i2 += bArr.length;
                a(i3, bArr, new OnWatchOpCallback<Boolean>() { // from class: com.jieli.jl_rcsp.tool.SyncMessageTask.1
                    @Override // com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback
                    public void onFailed(BaseError baseError) {
                        OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                        if (onWatchOpCallback2 != null) {
                            onWatchOpCallback2.onFailed(baseError);
                        }
                    }

                    @Override // com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback
                    public void onSuccess(Boolean bool) {
                        OnWatchOpCallback onWatchOpCallback2;
                        if (i3 != 0 || (onWatchOpCallback2 = onWatchOpCallback) == null) {
                            return;
                        }
                        onWatchOpCallback2.onSuccess(Boolean.TRUE);
                    }
                });
            }
            return;
        }
        a(0, beanToData, onWatchOpCallback);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void c() {
        synchronized (this.f3837b) {
            if (this.f3841f) {
                this.f3837b.notifyAll();
            }
        }
    }

    private void b() {
        synchronized (this.f3837b) {
            try {
                if (!this.f3841f) {
                    this.f3841f = true;
                    this.f3837b.wait();
                }
            } catch (InterruptedException e2) {
                e2.printStackTrace();
            }
            this.f3841f = false;
        }
    }

    private void a(int i2, byte[] bArr, final OnWatchOpCallback<Boolean> onWatchOpCallback) {
        PushInfoDataToDeviceCmd.MessageData messageData = new PushInfoDataToDeviceCmd.MessageData(i2, bArr);
        this.f3842g = true;
        RcspOpImpl rcspOpImpl = this.f3836a;
        rcspOpImpl.sendRcspCommand(rcspOpImpl.getTargetDevice(), CommandBuilder.buildPushMessageInfoCmd(messageData), new BooleanRcspActionCallback("pushMessageInfo", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.tool.SyncMessageTask.2
            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onFailed(BaseError baseError) {
                JL_Log.e(SyncMessageTask.f3835i, "---- pushMessageInfo ---- error = " + baseError);
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onFailed(baseError);
                }
            }

            @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
            public void onSuccess(Boolean bool) {
                JL_Log.d(SyncMessageTask.f3835i, "---- pushMessageInfo ---- " + bool);
                SyncMessageTask.this.f3842g = false;
                SyncMessageTask.this.c();
                OnWatchOpCallback onWatchOpCallback2 = onWatchOpCallback;
                if (onWatchOpCallback2 != null) {
                    onWatchOpCallback2.onSuccess(Boolean.TRUE);
                }
            }
        }));
        if (this.f3842g) {
            b();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b(String str) {
        if (str != null) {
            this.f3843h.remove(str);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String a(String str, long j2) {
        return str + "_" + j2;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(String str, short s) {
        if (str != null) {
            this.f3843h.put(str, Short.valueOf(s));
        }
    }

    private Short a(String str) {
        if (str == null) {
            return null;
        }
        return this.f3843h.get(str);
    }
}
