package com.jieli.jl_rcsp.tool.filebrowse;

import android.bluetooth.BluetoothDevice;
import com.jieli.jl_bt_ota.constant.BluetoothConstant;
import com.jieli.jl_filebrowse.bean.PathData;
import com.jieli.jl_filebrowse.interfaces.FileBrowseOperator;
import com.jieli.jl_filebrowse.interfaces.OperatCallback;
import com.jieli.jl_rcsp.constant.RcspErrorCode;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.base.CommandBase;
import com.jieli.jl_rcsp.model.command.file_op.DelDevFileCmd;
import com.jieli.jl_rcsp.model.command.file_op.DeviceFormatCmd;
import com.jieli.jl_rcsp.model.parameter.DelDevFileParam;
import com.jieli.jl_rcsp.util.CommandBuilder;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;

/* loaded from: classes3.dex */
public class FileBrowseOperatorImpl implements FileBrowseOperator {

    /* renamed from: b, reason: collision with root package name */
    private static final String f3957b = "FileBrowseOperatorImpl";

    /* renamed from: a, reason: collision with root package name */
    private final RcspOpImpl f3958a;

    public static class CustomRcspCallback<C extends CommandBase> implements RcspCommandCallback<C> {

        /* renamed from: a, reason: collision with root package name */
        private final String f3968a;

        /* renamed from: b, reason: collision with root package name */
        private final OperatCallback f3969b;

        public CustomRcspCallback(String str, OperatCallback operatCallback) {
            this.f3968a = str;
            this.f3969b = operatCallback;
        }

        @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
        public void onCommandResponse(BluetoothDevice bluetoothDevice, C c2) {
            if (c2.getStatus() != 0) {
                onErrCode(bluetoothDevice, RcspErrorCode.buildJsonError(c2.getId(), 12292, c2.getStatus(), null));
                return;
            }
            OperatCallback operatCallback = this.f3969b;
            if (operatCallback != null) {
                operatCallback.onSuccess();
            }
        }

        @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
        public void onErrCode(BluetoothDevice bluetoothDevice, BaseError baseError) {
            JL_Log.e(FileBrowseOperatorImpl.f3957b, RcspUtil.formatString("-%s- device: %s, %s", this.f3968a, bluetoothDevice, baseError));
            OperatCallback operatCallback = this.f3969b;
            if (operatCallback != null) {
                operatCallback.onError(baseError.getSubCode());
            }
        }
    }

    public FileBrowseOperatorImpl(RcspOpImpl rcspOpImpl) {
        this.f3958a = rcspOpImpl;
    }

    @Override // com.jieli.jl_filebrowse.interfaces.FileBrowseOperator
    public boolean dataHasPacket() {
        return false;
    }

    @Override // com.jieli.jl_filebrowse.interfaces.FileBrowseOperator
    public void deleteFile(final int i2, final byte b2, final int i3, final boolean z, boolean z2, final OperatCallback operatCallback) {
        if (z2) {
            a((byte) 1, new OperatCallback() { // from class: com.jieli.jl_rcsp.tool.filebrowse.FileBrowseOperatorImpl.1
                @Override // com.jieli.jl_filebrowse.interfaces.OperatCallback
                public void onError(int i4) {
                    operatCallback.onError(i4);
                }

                @Override // com.jieli.jl_filebrowse.interfaces.OperatCallback
                public void onSuccess() {
                    FileBrowseOperatorImpl.this.a(i2, b2, i3, z, operatCallback);
                }
            });
        } else {
            a(i2, b2, i3, z, operatCallback);
        }
    }

    @Override // com.jieli.jl_filebrowse.interfaces.FileBrowseOperator
    public void formatDevice(final int i2, final OperatCallback operatCallback) {
        a((byte) 2, new OperatCallback() { // from class: com.jieli.jl_rcsp.tool.filebrowse.FileBrowseOperatorImpl.2
            @Override // com.jieli.jl_filebrowse.interfaces.OperatCallback
            public void onError(int i3) {
                OperatCallback operatCallback2 = operatCallback;
                if (operatCallback2 != null) {
                    operatCallback2.onError(i3);
                }
            }

            @Override // com.jieli.jl_filebrowse.interfaces.OperatCallback
            public void onSuccess() {
                JL_Log.i(FileBrowseOperatorImpl.f3957b, "开始格式化");
                FileBrowseOperatorImpl.this.f3958a.sendRcspCommand(FileBrowseOperatorImpl.this.f3958a.getTargetDevice(), new DeviceFormatCmd(new DeviceFormatCmd.Param(i2)), BluetoothConstant.PAIR_OR_UNPAIR_TIMEOUT, new CustomRcspCallback("formatDevice", operatCallback));
            }
        });
    }

    @Override // com.jieli.jl_filebrowse.interfaces.FileBrowseOperator
    public void sendPathDataCmd(PathData pathData, byte[] bArr, OperatCallback operatCallback) {
        RcspOpImpl rcspOpImpl = this.f3958a;
        rcspOpImpl.sendRcspCommand(rcspOpImpl.getTargetDevice(), CommandBuilder.buildSendPathDataCmd(pathData), new CustomRcspCallback("sendPathDataCmd", operatCallback));
    }

    private void a(byte b2, OperatCallback operatCallback) {
        RcspOpImpl rcspOpImpl = this.f3958a;
        rcspOpImpl.sendRcspCommand(rcspOpImpl.getTargetDevice(), CommandBuilder.buildNotifyPrepareEnvCmd(b2), new CustomRcspCallback("prepareDelEnv", operatCallback));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(int i2, byte b2, int i3, boolean z, OperatCallback operatCallback) {
        DelDevFileCmd delDevFileCmd = new DelDevFileCmd(new DelDevFileParam(i2, b2, i3, z));
        RcspOpImpl rcspOpImpl = this.f3958a;
        rcspOpImpl.sendRcspCommand(rcspOpImpl.getTargetDevice(), delDevFileCmd, 6000, new CustomRcspCallback("deleteFileActual", operatCallback));
    }
}
