package com.jieli.jl_rcsp.util;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.os.Build;
import android.text.TextUtils;
import com.autonavi.base.amap.mapcore.tools.GLMapStaticValue;
import com.facebook.internal.security.CertificateUtil;
import com.jieli.jl_rcsp.model.LtvBean;
import com.jieli.jl_rcsp.model.device.AttrBean;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;
import java.util.Locale;

/* loaded from: classes3.dex */
public class RcspUtil {
    public static byte[] addressCovertToByteArray(String str) {
        if (TextUtils.isEmpty(str) || !str.contains(CertificateUtil.DELIMITER)) {
            return null;
        }
        String replace = str.replace(CertificateUtil.DELIMITER, "");
        int length = replace.length() / 2;
        byte[] bArr = new byte[length];
        if (length != 6) {
            return null;
        }
        for (int i2 = 0; i2 < length; i2++) {
            int i3 = i2 * 2;
            int i4 = i3 + 2;
            if (i4 <= replace.length()) {
                try {
                    bArr[i2] = (byte) Integer.valueOf(replace.substring(i3, i4), 16).intValue();
                } catch (Exception e2) {
                    e2.printStackTrace();
                    return null;
                }
            }
        }
        return bArr;
    }

    public static byte[] attrs2Bytes(List<AttrBean> list) {
        ByteBuffer allocate = ByteBuffer.allocate(list.size() * 128);
        for (AttrBean attrBean : list) {
            allocate.put((byte) (attrBean.getAttrData().length + 1)).put(attrBean.getType()).put(attrBean.getAttrData());
        }
        byte[] bArr = new byte[allocate.position()];
        allocate.flip();
        allocate.get(bArr);
        return bArr;
    }

    public static int changeConnectStatus(int i2) {
        if (i2 != 1) {
            return i2 != 2 ? 0 : 1;
        }
        return 3;
    }

    public static boolean checkMaskHasBit(int i2, byte b2) {
        if (b2 > 32) {
            return false;
        }
        byte intToByte = CHexConver.intToByte((int) Math.pow(2.0d, CHexConver.byteToInt(b2)));
        return (i2 & intToByte) == intToByte;
    }

    public static boolean deviceEquals(BluetoothDevice bluetoothDevice, BluetoothDevice bluetoothDevice2) {
        return (bluetoothDevice == null || bluetoothDevice2 == null || !bluetoothDevice.getAddress().equals(bluetoothDevice2.getAddress())) ? false : true;
    }

    public static int formatBleMtu(int i2) {
        if (i2 < 20) {
            i2 = 20;
        }
        if (i2 > 509) {
            return 509;
        }
        return i2;
    }

    public static String formatString(String str, Object... objArr) {
        return String.format(Locale.ENGLISH, str, objArr);
    }

    public static byte[] getData(String str, int i2) {
        if (str == null || i2 <= 0) {
            return null;
        }
        return getData(str.getBytes(), i2);
    }

    public static BluetoothDevice getRemoteDevice(String str) {
        BluetoothAdapter defaultAdapter;
        if (!BluetoothAdapter.checkBluetoothAddress(str) || (defaultAdapter = BluetoothAdapter.getDefaultAdapter()) == null) {
            return null;
        }
        try {
            return defaultAdapter.getRemoteDevice(str);
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public static long intToTime(int i2) {
        int i3 = ((i2 >> 26) & 63) + GLMapStaticValue.MAP_PARAMETERNAME_TRAFFIC;
        Calendar calendar = Calendar.getInstance();
        calendar.set(1, i3);
        calendar.set(2, ((i2 >> 22) & 15) - 1);
        calendar.set(5, (i2 >> 17) & 31);
        calendar.set(11, (i2 >> 12) & 31);
        calendar.set(12, (i2 >> 6) & 63);
        calendar.set(13, i2 & 63);
        calendar.set(14, 0);
        return calendar.getTimeInMillis();
    }

    public static byte[] packLTVPacket(int i2, byte[] bArr) {
        if (bArr == null) {
            return null;
        }
        int length = bArr.length + 1;
        byte[] bArr2 = new byte[length + 1];
        bArr2[0] = CHexConver.intToByte(length);
        bArr2[1] = CHexConver.intToByte(i2);
        System.arraycopy(bArr, 0, bArr2, 2, bArr.length);
        return bArr2;
    }

    public static byte[] packLTVPacket2(int i2, byte[] bArr) {
        if (bArr == null) {
            return null;
        }
        int length = bArr.length + 1;
        byte[] bArr2 = new byte[length + 2];
        byte[] int2byte2 = CHexConver.int2byte2(length);
        System.arraycopy(int2byte2, 0, bArr2, 0, int2byte2.length);
        bArr2[2] = CHexConver.intToByte(i2);
        System.arraycopy(bArr, 0, bArr2, 3, bArr.length);
        return bArr2;
    }

    public static List<LtvBean> parseLTVData(byte[] bArr) {
        if (bArr == null || bArr.length <= 1) {
            return new ArrayList();
        }
        ArrayList arrayList = new ArrayList();
        int i2 = 0;
        while (i2 < bArr.length) {
            int i3 = bArr[i2];
            int i4 = i2 + 1;
            if (i4 + i3 > bArr.length) {
                break;
            }
            int byteToInt = CHexConver.byteToInt(bArr[i4]);
            int i5 = i4 + 1;
            int i6 = i3 - 1;
            byte[] bArr2 = new byte[i6];
            System.arraycopy(bArr, i5, bArr2, 0, i6);
            i2 = i5 + i6;
            arrayList.add(new LtvBean(i3, byteToInt, bArr2));
        }
        return arrayList;
    }

    public static String printBtDeviceInfo(BluetoothDevice bluetoothDevice) {
        return bluetoothDevice != null ? Build.VERSION.SDK_INT > 30 ? bluetoothDevice.toString() : formatString("device:{ name : %s,type : %d, address : %s }", bluetoothDevice.getName(), Integer.valueOf(bluetoothDevice.getType()), bluetoothDevice.getAddress()) : "null";
    }

    public static int time2Int(long j2) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTimeInMillis(j2);
        int i2 = calendar.get(1) - 2010;
        int i3 = calendar.get(2) + 1;
        return (calendar.get(5) << 17) | (i2 << 26) | (i3 << 22) | (calendar.get(11) << 12) | (calendar.get(12) << 6) | calendar.get(13);
    }

    public static byte[] getData(byte[] bArr, int i2) {
        if (bArr == null || i2 <= 0) {
            return null;
        }
        if (bArr.length <= i2) {
            return bArr;
        }
        byte[] bArr2 = new byte[i2];
        System.arraycopy(bArr, 0, bArr2, 0, i2);
        return bArr2;
    }
}
