package com.jieli.jl_rcsp.watch;

import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.Looper;
import com.jieli.jl_fatfs.interfaces.OnFatFileProgressListener;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.IHandleResult;
import com.jieli.jl_rcsp.interfaces.OnOperationCallback;
import com.jieli.jl_rcsp.interfaces.rcsp.OnRcspEventListener;
import com.jieli.jl_rcsp.interfaces.watch.IWatchManager;
import com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.command.external_flash.ExternalFlashIOCtrlCmd;
import com.jieli.jl_rcsp.model.device.DeviceInfo;
import com.jieli.jl_rcsp.model.response.ExternalFlashIOCtrlResponse;
import com.jieli.jl_rcsp.model.response.ExternalFlashMsgResponse;
import com.jieli.jl_rcsp.tool.CustomRcspActionCallback;
import com.jieli.jl_rcsp.util.CommandBuilder;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.watch.WatchProgressHandler;
import com.jieli.jl_rcsp.watch.fatfs.FatFsWatch;
import com.jieli.jl_rcsp.watch.rcsp.RcspWatch;

/* loaded from: classes3.dex */
public class WatchProgressHandler implements OnFatFileProgressListener {
    public static final int OP_CREATE_FILE = 1;
    public static final int OP_DELETE_FILE = 2;
    public static final int OP_REPLACE_FILE = 3;
    public static final int OP_RESTORE_SYS = 4;

    /* renamed from: i, reason: collision with root package name */
    private static final String f4012i = "WatchProgressHandler";

    /* renamed from: a, reason: collision with root package name */
    private final RcspOpImpl f4013a;

    /* renamed from: b, reason: collision with root package name */
    private final IWatchManager f4014b;

    /* renamed from: c, reason: collision with root package name */
    private final int f4015c;

    /* renamed from: d, reason: collision with root package name */
    private final OnFatFileProgressListener f4016d;

    /* renamed from: e, reason: collision with root package name */
    private final Handler f4017e = new Handler(Looper.getMainLooper());

    /* renamed from: f, reason: collision with root package name */
    private int f4018f = -1;

    /* renamed from: g, reason: collision with root package name */
    private final CustomRcspActionCallback<Boolean, ExternalFlashIOCtrlCmd> f4019g = new CustomRcspActionCallback<>("handleStopEvent", new OnOperationCallback<Boolean>() { // from class: com.jieli.jl_rcsp.watch.WatchProgressHandler.3
        @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
        public void onFailed(BaseError baseError) {
            WatchProgressHandler.this.a(baseError.getSubCode());
        }

        @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
        public void onSuccess(Boolean bool) {
            if (!(WatchProgressHandler.this.f4014b instanceof RcspWatch) || WatchProgressHandler.this.f4015c != 1) {
                WatchProgressHandler.this.f4014b.jumpToUpdateResource(true, WatchProgressHandler.this.f4020h);
            } else {
                WatchProgressHandler watchProgressHandler = WatchProgressHandler.this;
                watchProgressHandler.a(watchProgressHandler.f4018f);
            }
        }
    }, new IHandleResult<Boolean, ExternalFlashIOCtrlCmd>() { // from class: com.jieli.jl_rcsp.watch.WatchProgressHandler.4
        @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
        public Boolean handleResult(BluetoothDevice bluetoothDevice, ExternalFlashIOCtrlCmd externalFlashIOCtrlCmd) {
            return Boolean.TRUE;
        }

        /* JADX WARN: Multi-variable type inference failed */
        @Override // com.jieli.jl_rcsp.interfaces.IHandleResult
        public int hasResult(BluetoothDevice bluetoothDevice, ExternalFlashIOCtrlCmd externalFlashIOCtrlCmd) {
            ExternalFlashIOCtrlResponse externalFlashIOCtrlResponse;
            if (externalFlashIOCtrlCmd == null || (externalFlashIOCtrlResponse = (ExternalFlashIOCtrlResponse) externalFlashIOCtrlCmd.getResponse()) == null) {
                return -1;
            }
            return externalFlashIOCtrlResponse.getResult();
        }
    });

    /* renamed from: h, reason: collision with root package name */
    private final OnWatchOpCallback<Boolean> f4020h = new OnWatchOpCallback<Boolean>() { // from class: com.jieli.jl_rcsp.watch.WatchProgressHandler.5
        @Override // com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback
        public void onFailed(BaseError baseError) {
            WatchProgressHandler.this.a(baseError.getSubCode());
        }

        @Override // com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback
        public void onSuccess(Boolean bool) {
            WatchProgressHandler watchProgressHandler = WatchProgressHandler.this;
            watchProgressHandler.a(watchProgressHandler.f4018f);
        }
    };

    /* renamed from: com.jieli.jl_rcsp.watch.WatchProgressHandler$2, reason: invalid class name */
    public class AnonymousClass2 implements OnOperationCallback<ExternalFlashMsgResponse> {
        public AnonymousClass2() {
        }

        /* JADX INFO: Access modifiers changed from: private */
        public /* synthetic */ void a(ExternalFlashMsgResponse externalFlashMsgResponse) {
            WatchProgressHandler watchProgressHandler = WatchProgressHandler.this;
            watchProgressHandler.a(watchProgressHandler.f4018f);
            WatchProgressHandler.this.f4014b.getCallback().onWatchSystemException(WatchProgressHandler.this.f4013a.getTargetDevice(), externalFlashMsgResponse.getSysStatus());
        }

        @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
        public void onFailed(BaseError baseError) {
            JL_Log.w(WatchProgressHandler.f4012i, "handleWatchSysException : onErrCode = " + baseError);
            WatchProgressHandler watchProgressHandler = WatchProgressHandler.this;
            watchProgressHandler.a(watchProgressHandler.f4018f);
        }

        @Override // com.jieli.jl_rcsp.interfaces.OnOperationCallback
        public void onSuccess(final ExternalFlashMsgResponse externalFlashMsgResponse) {
            JL_Log.w(WatchProgressHandler.f4012i, "handleWatchSysException : SysStatus = " + externalFlashMsgResponse.getSysStatus());
            if (externalFlashMsgResponse.getSysStatus() == 0) {
                WatchProgressHandler.this.b();
                return;
            }
            if (WatchProgressHandler.this.f4014b instanceof FatFsWatch) {
                ((FatFsWatch) WatchProgressHandler.this.f4014b).destroyFatFileSystem();
            }
            WatchProgressHandler.this.f4017e.postDelayed(new Runnable() { // from class: com.jieli.jl_rcsp.watch.WatchProgressHandler$2$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    WatchProgressHandler.AnonymousClass2.this.a(externalFlashMsgResponse);
                }
            }, 1000L);
        }
    }

    public WatchProgressHandler(IWatchManager iWatchManager, int i2, OnFatFileProgressListener onFatFileProgressListener) {
        this.f4014b = iWatchManager;
        this.f4013a = (RcspOpImpl) iWatchManager.getRcspOp();
        this.f4015c = i2;
        this.f4016d = onFatFileProgressListener;
    }

    @Override // com.jieli.jl_fatfs.interfaces.OnFatFileProgressListener
    public void onProgress(float f2) {
        OnFatFileProgressListener onFatFileProgressListener = this.f4016d;
        if (onFatFileProgressListener != null) {
            onFatFileProgressListener.onProgress(f2);
        }
    }

    @Override // com.jieli.jl_fatfs.interfaces.OnFatFileProgressListener
    public void onStart(String str) {
        OnFatFileProgressListener onFatFileProgressListener = this.f4016d;
        if (onFatFileProgressListener != null) {
            onFatFileProgressListener.onStart(str);
        }
    }

    @Override // com.jieli.jl_fatfs.interfaces.OnFatFileProgressListener
    public void onStop(int i2) {
        this.f4018f = i2;
        if (i2 != 0 && this.f4014b.isSysException()) {
            a(i2, this.f4014b.isSysException());
        } else if (this.f4014b instanceof RcspWatch) {
            a(this.f4018f);
        } else {
            b();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b() {
        int i2 = this.f4015c;
        if (i2 == 1) {
            RcspOpImpl rcspOpImpl = this.f4013a;
            rcspOpImpl.sendRcspCommand(rcspOpImpl.getTargetDevice(), CommandBuilder.buildExternalFlashInsertNewFileEndCmd(), this.f4019g);
        } else if (i2 != 2) {
            this.f4014b.jumpToUpdateResource(true, this.f4020h);
        } else {
            RcspOpImpl rcspOpImpl2 = this.f4013a;
            rcspOpImpl2.sendRcspCommand(rcspOpImpl2.getTargetDevice(), CommandBuilder.buildExternalFlashDeleteFileEndCmd(), this.f4019g);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void c() {
        JL_Log.d(f4012i, "handleWatchSysException : query system status by device.");
        WatchBase.queryExtFlashMsgForDevice(this.f4013a, new AnonymousClass2());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(int i2) {
        OnFatFileProgressListener onFatFileProgressListener = this.f4016d;
        if (onFatFileProgressListener != null) {
            onFatFileProgressListener.onStop(i2);
        }
    }

    private void a(int i2, boolean z) {
        String str = f4012i;
        JL_Log.w(str, "handleStopEventBySysException : result = " + i2 + ", isSysException : " + z);
        DeviceInfo deviceInfo = this.f4013a.getDeviceInfo();
        if (this.f4015c != 4 && z && deviceInfo != null) {
            JL_Log.d(str, "handleStopEventBySysException : Obtain the current phone Status : " + deviceInfo.getPhoneStatus());
            if (deviceInfo.getPhoneStatus() == 1) {
                JL_Log.d(str, "handleStopEventBySysException : add OnRcspEventListener, waiting for phone status.");
                this.f4013a.registerOnRcspEventListener(new OnRcspEventListener() { // from class: com.jieli.jl_rcsp.watch.WatchProgressHandler.1
                    @Override // com.jieli.jl_rcsp.interfaces.rcsp.OnRcspEventListener
                    public void onPhoneCallStatusChange(BluetoothDevice bluetoothDevice, int i3) {
                        JL_Log.i(WatchProgressHandler.f4012i, "handleStopEventBySysException : onPhoneCallStatusChange : " + i3);
                        if (i3 == 0) {
                            WatchProgressHandler.this.f4013a.unregisterOnRcspEventListener(this);
                            WatchProgressHandler.this.c();
                        }
                    }
                });
                return;
            } else {
                c();
                return;
            }
        }
        a(i2);
    }
}
