package com.jieli.jl_rcsp.watch.fatfs;

import android.bluetooth.BluetoothDevice;
import com.jieli.jl_fatfs.FatFileSystem;
import com.jieli.jl_fatfs.interfaces.IBluetoothCtrl;
import com.jieli.jl_rcsp.constant.WatchConstant;
import com.jieli.jl_rcsp.impl.RcspOpImpl;
import com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback;
import com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback;
import com.jieli.jl_rcsp.model.base.BaseError;
import com.jieli.jl_rcsp.model.command.external_flash.ExtFlashIOCtrlNoResponseCmd;
import com.jieli.jl_rcsp.model.command.external_flash.ExternalFlashIOCtrlCmd;
import com.jieli.jl_rcsp.model.parameter.ExternalFlashIOCtrlParam;
import com.jieli.jl_rcsp.model.response.ExternalFlashIOCtrlResponse;
import com.jieli.jl_rcsp.model.response.ExternalFlashMsgResponse;
import com.jieli.jl_rcsp.tool.DeviceStatusManager;
import com.jieli.jl_rcsp.tool.WatchCacheManager;
import com.jieli.jl_rcsp.util.CHexConver;
import com.jieli.jl_rcsp.util.CommandBuilder;
import com.jieli.jl_rcsp.util.CryptoUtil;
import com.jieli.jl_rcsp.util.JL_Log;
import com.jieli.jl_rcsp.util.RcspUtil;

/* loaded from: classes3.dex */
public class FatFsBluetoothImp implements IBluetoothCtrl {

    /* renamed from: e, reason: collision with root package name */
    private static final String f4026e = "FatFsBluetoothImp";

    /* renamed from: a, reason: collision with root package name */
    private final RcspOpImpl f4027a;

    /* renamed from: b, reason: collision with root package name */
    private final FatFsWatch f4028b;

    /* renamed from: c, reason: collision with root package name */
    private final DeviceStatusManager f4029c = DeviceStatusManager.getInstance();

    /* renamed from: d, reason: collision with root package name */
    private final WatchCacheManager f4030d = new WatchCacheManager();

    public FatFsBluetoothImp(FatFsWatch fatFsWatch) {
        this.f4028b = fatFsWatch;
        this.f4027a = fatFsWatch.getRcspOp();
    }

    private int c(BluetoothDevice bluetoothDevice) {
        ExternalFlashMsgResponse extFlashMsg = this.f4029c.getExtFlashMsg(bluetoothDevice);
        if (extFlashMsg == null) {
            return 0;
        }
        return extFlashMsg.getCluster();
    }

    private int d(BluetoothDevice bluetoothDevice) {
        ExternalFlashMsgResponse extFlashMsg = this.f4029c.getExtFlashMsg(bluetoothDevice);
        if (extFlashMsg == null) {
            return 0;
        }
        return extFlashMsg.getReceiveMtu();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public FatFileSystem e(BluetoothDevice bluetoothDevice) {
        if (RcspUtil.deviceEquals(bluetoothDevice, this.f4027a.getTargetDevice())) {
            return this.f4028b.getWatchSystem();
        }
        return null;
    }

    @Override // com.jieli.jl_fatfs.interfaces.IBluetoothCtrl
    public BluetoothDevice getConnectedDevice() {
        return this.f4027a.getTargetDevice();
    }

    @Override // com.jieli.jl_fatfs.interfaces.IBluetoothCtrl
    public void readFatDataFromDevice(BluetoothDevice bluetoothDevice, int i2, int i3) {
        String str = f4026e;
        JL_Log.d(str, RcspUtil.formatString("readFatDataFromDevice :: device = %s, offset = %d, size = %d", RcspUtil.printBtDeviceInfo(bluetoothDevice), Integer.valueOf(i2), Integer.valueOf(i3)));
        FatFileSystem e2 = e(bluetoothDevice);
        if (e2 == null) {
            JL_Log.w(str, "readFatDataFromDevice :: fatFs is null");
            a(bluetoothDevice, false, new byte[0]);
        } else {
            e2.createReadBuffer(i3);
            a(bluetoothDevice, i2, i3);
        }
    }

    @Override // com.jieli.jl_fatfs.interfaces.IBluetoothCtrl
    public void release() {
        this.f4030d.destroy();
    }

    @Override // com.jieli.jl_fatfs.interfaces.IBluetoothCtrl
    public void sendWriteFlag(final BluetoothDevice bluetoothDevice, boolean z) {
        String str = f4026e;
        JL_Log.d(str, RcspUtil.formatString("sendWriteFlag :: device = %s, writeFlag = %s", RcspUtil.printBtDeviceInfo(bluetoothDevice), Boolean.valueOf(z)));
        if (e(bluetoothDevice) != null) {
            this.f4028b.sendWriteProtectFlag(z, new OnWatchOpCallback<Boolean>() { // from class: com.jieli.jl_rcsp.watch.fatfs.FatFsBluetoothImp.2
                @Override // com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback
                public void onFailed(BaseError baseError) {
                    FatFsBluetoothImp.this.a(bluetoothDevice, false);
                }

                @Override // com.jieli.jl_rcsp.interfaces.watch.OnWatchOpCallback
                public void onSuccess(Boolean bool) {
                    FatFsBluetoothImp.this.a(bluetoothDevice, true);
                }
            });
        } else {
            JL_Log.w(str, "sendWriteFlag :: fatFs is null");
            a(bluetoothDevice, false);
        }
    }

    @Override // com.jieli.jl_fatfs.interfaces.IBluetoothCtrl
    public void writeFatDataToDevice(BluetoothDevice bluetoothDevice, int i2, byte[] bArr) {
        String str = f4026e;
        JL_Log.d(str, RcspUtil.formatString(">>>>>> writeFatDataToDevice :: device = %s, offset = %d, \ndata = %s", RcspUtil.printBtDeviceInfo(bluetoothDevice), Integer.valueOf(i2), CHexConver.byte2HexStr(bArr)));
        FatFileSystem e2 = e(bluetoothDevice);
        if (e2 == null) {
            a(bluetoothDevice, "writeFatDataToDevice >> fatFs is null.");
            return;
        }
        e2.setWriteBuffer(bArr);
        if (a(i2)) {
            this.f4030d.putWatchCacheByDevice(bluetoothDevice, new WatchCacheManager.WatchCache().setWriteOffset(i2).setWriteLen(bArr.length).setCrc16(CryptoUtil.CRC16(bArr, (short) 0)));
        }
        if (d(bluetoothDevice) == 0) {
            a(bluetoothDevice, i2, bArr);
            return;
        }
        int leftDevSize = e2.getLeftDevSize();
        JL_Log.i(str, "-writeFatDataToDevice-  leftDevSize ==> " + leftDevSize);
        if (leftDevSize > 0) {
            e2.setNeedWriteData(leftDevSize);
            bArr = e2.getNeedSendLeftData();
        }
        b(bluetoothDevice, i2, bArr);
    }

    private int b(BluetoothDevice bluetoothDevice) {
        ExternalFlashMsgResponse extFlashMsg = this.f4029c.getExtFlashMsg(bluetoothDevice);
        if (extFlashMsg == null) {
            return 0;
        }
        return extFlashMsg.getBlockSize();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b(BluetoothDevice bluetoothDevice, boolean z) {
        if (RcspUtil.deviceEquals(bluetoothDevice, this.f4027a.getTargetDevice())) {
            JL_Log.w(f4026e, "updateWriteResult : " + z);
            if (this.f4028b.getWatchSystem() != null) {
                this.f4028b.getWatchSystem().updateWriteStatus(z);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, int i2, byte[] bArr) {
        int b2 = b(bluetoothDevice);
        if (b2 == 0) {
            a(bluetoothDevice, "handleWriteFatData :: mtu is 0 .");
            return;
        }
        FatFileSystem e2 = e(bluetoothDevice);
        if (e2 != null && !e2.writeBufferIsEmpty()) {
            int i3 = 0;
            if (bArr.length > b2) {
                byte[] bArr2 = new byte[b2];
                System.arraycopy(bArr, 0, bArr2, 0, b2);
                i3 = 1;
                bArr = bArr2;
            }
            a(bluetoothDevice, i3, i2, bArr);
            return;
        }
        a(bluetoothDevice, "handleWriteFatData :: fatFs is null or write buffer is empty.");
    }

    private void b(BluetoothDevice bluetoothDevice, int i2, int i3, byte[] bArr) {
        JL_Log.d(f4026e, "-writeDataToDeviceModify- :: device =" + RcspUtil.printBtDeviceInfo(bluetoothDevice) + ", offset = " + i3 + ", flag = " + i2);
        this.f4027a.sendRcspCommand(bluetoothDevice, CommandBuilder.buildExternalFlashWriteDataCmd(i2, i3, bArr), new RcspCommandCallback<ExtFlashIOCtrlNoResponseCmd>() { // from class: com.jieli.jl_rcsp.watch.fatfs.FatFsBluetoothImp.4
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onErrCode(BluetoothDevice bluetoothDevice2, BaseError baseError) {
                FatFsBluetoothImp.this.a(bluetoothDevice2, RcspUtil.formatString("writeDataToDeviceModify :: device = %s, error = %s", RcspUtil.printBtDeviceInfo(bluetoothDevice2), baseError));
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onCommandResponse(BluetoothDevice bluetoothDevice2, ExtFlashIOCtrlNoResponseCmd extFlashIOCtrlNoResponseCmd) {
                FatFileSystem e2 = FatFsBluetoothImp.this.e(bluetoothDevice2);
                if (e2 == null || e2.writeBufferIsEmpty()) {
                    FatFsBluetoothImp.this.a(bluetoothDevice2, "writeDataToDeviceModify :: fatFs is null or write buffer is empty.");
                    return;
                }
                ExternalFlashIOCtrlParam externalFlashIOCtrlParam = (ExternalFlashIOCtrlParam) extFlashIOCtrlNoResponseCmd.getParam();
                int length = externalFlashIOCtrlParam.getData().length;
                JL_Log.d(FatFsBluetoothImp.f4026e, RcspUtil.formatString("-writeDataToDeviceModify- :: device = %s, dataLen = %d, ctrlCmd = %s", RcspUtil.printBtDeviceInfo(bluetoothDevice2), Integer.valueOf(length), extFlashIOCtrlNoResponseCmd));
                e2.callbackProgress(length);
                int offset = externalFlashIOCtrlParam.getOffset();
                if (externalFlashIOCtrlParam.getFlag() == 1) {
                    FatFsBluetoothImp.this.b(bluetoothDevice2, offset + length, e2.getNeedSendLeftData());
                } else if (FatFsBluetoothImp.this.a(offset)) {
                    FatFsBluetoothImp.this.a(bluetoothDevice2);
                } else {
                    FatFsBluetoothImp.this.a(bluetoothDevice2, 1);
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void b(BluetoothDevice bluetoothDevice, final int i2, final byte[] bArr) {
        if (bArr != null && bArr.length != 0) {
            int b2 = b(bluetoothDevice);
            if (b2 == 0) {
                a(bluetoothDevice, "handleWriteFatDataModify :: mtu is 0 .");
                return;
            }
            final FatFileSystem e2 = e(bluetoothDevice);
            if (e2 != null && !e2.writeBufferIsEmpty()) {
                int leftDevSize = e2.getLeftDevSize();
                JL_Log.i(f4026e, "handleWriteFatDataModify :: lefDevSize = " + leftDevSize + ", mtu = " + b2 + ", leftData length = " + bArr.length);
                int i3 = 1;
                if (leftDevSize < b2) {
                    this.f4027a.sendRcspCommand(bluetoothDevice, CommandBuilder.buildExternalFlashQueryWriteResultCmd(1, CryptoUtil.CRC16(e2.getNeedWriteData(), (short) 0)), new RcspCommandCallback<ExternalFlashIOCtrlCmd>() { // from class: com.jieli.jl_rcsp.watch.fatfs.FatFsBluetoothImp.5
                        @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
                        public void onErrCode(BluetoothDevice bluetoothDevice2, BaseError baseError) {
                            FatFsBluetoothImp.this.a(bluetoothDevice2, "handleWriteFatDataModify :: onErrCode = " + baseError);
                        }

                        /* JADX WARN: Multi-variable type inference failed */
                        @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
                        public void onCommandResponse(BluetoothDevice bluetoothDevice2, ExternalFlashIOCtrlCmd externalFlashIOCtrlCmd) {
                            JL_Log.i(FatFsBluetoothImp.f4026e, "handleWriteFatDataModify :: onCommandResponse = " + externalFlashIOCtrlCmd);
                            ExternalFlashIOCtrlResponse externalFlashIOCtrlResponse = (ExternalFlashIOCtrlResponse) externalFlashIOCtrlCmd.getResponse();
                            if (externalFlashIOCtrlCmd.getStatus() == 0 && externalFlashIOCtrlResponse.getResult() == 0) {
                                int size = externalFlashIOCtrlResponse.getSize();
                                if (size > 0) {
                                    e2.setNeedWriteData(size);
                                    FatFsBluetoothImp.this.b(bluetoothDevice2, i2, bArr);
                                    return;
                                }
                                JL_Log.e(FatFsBluetoothImp.f4026e, "handleWriteFatDataModify :: left size is zero. error data");
                            } else {
                                JL_Log.e(FatFsBluetoothImp.f4026e, "handleWriteFatDataModify :: response an bad status");
                            }
                            FatFsBluetoothImp.this.b(bluetoothDevice2, false);
                        }
                    });
                    return;
                }
                if (bArr.length <= b2) {
                    i3 = 1 ^ (e2.judgeWriteFinish(bArr.length) ? 1 : 0);
                } else {
                    byte[] bArr2 = new byte[b2];
                    System.arraycopy(bArr, 0, bArr2, 0, b2);
                    bArr = bArr2;
                }
                b(bluetoothDevice, i3, i2, bArr);
                return;
            }
            a(bluetoothDevice, "handleWriteFatDataModify :: fatfs is null or write buffer is empty.");
            return;
        }
        a(bluetoothDevice, "handleWriteFatDataModify :: data is null.");
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, String str) {
        JL_Log.w(f4026e, "updateWriteFailed : " + str);
        b(bluetoothDevice, false);
    }

    private void a(BluetoothDevice bluetoothDevice, int i2, int i3, byte[] bArr) {
        JL_Log.d(f4026e, "-writeDataToDevice- :: device =" + RcspUtil.printBtDeviceInfo(bluetoothDevice) + ", offset = " + i3 + ", flag = " + i2);
        this.f4027a.sendRcspCommand(bluetoothDevice, CommandBuilder.buildExternalFlashWriteDataCmd(i2, i3, bArr), new RcspCommandCallback<ExtFlashIOCtrlNoResponseCmd>() { // from class: com.jieli.jl_rcsp.watch.fatfs.FatFsBluetoothImp.3
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onErrCode(BluetoothDevice bluetoothDevice2, BaseError baseError) {
                FatFsBluetoothImp.this.a(bluetoothDevice2, RcspUtil.formatString("writeDataToDevice :: device = %s, error = %s", RcspUtil.printBtDeviceInfo(bluetoothDevice2), baseError));
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onCommandResponse(BluetoothDevice bluetoothDevice2, ExtFlashIOCtrlNoResponseCmd extFlashIOCtrlNoResponseCmd) {
                FatFileSystem e2 = FatFsBluetoothImp.this.e(bluetoothDevice2);
                if (e2 == null || e2.writeBufferIsEmpty()) {
                    FatFsBluetoothImp.this.a(bluetoothDevice2, "writeDataToDevice : fatFs is null or write buffer is empty.");
                    return;
                }
                ExternalFlashIOCtrlParam externalFlashIOCtrlParam = (ExternalFlashIOCtrlParam) extFlashIOCtrlNoResponseCmd.getParam();
                int length = externalFlashIOCtrlParam.getData().length;
                JL_Log.d(FatFsBluetoothImp.f4026e, RcspUtil.formatString(">>>> writeDataToDevice :: device = %s, ctrlCmd = %s, dataLen = %d", RcspUtil.printBtDeviceInfo(bluetoothDevice2), extFlashIOCtrlNoResponseCmd, Integer.valueOf(length)));
                e2.callbackProgress(length);
                int offset = externalFlashIOCtrlParam.getOffset();
                if (externalFlashIOCtrlParam.isFinalData()) {
                    if (FatFsBluetoothImp.this.a(offset)) {
                        FatFsBluetoothImp.this.a(bluetoothDevice2);
                        return;
                    } else {
                        FatFsBluetoothImp.this.a(bluetoothDevice2, 0);
                        return;
                    }
                }
                int i4 = length + offset;
                byte[] writeLeftData = e2.getWriteLeftData();
                JL_Log.i(FatFsBluetoothImp.f4026e, RcspUtil.formatString("writeDataToDevice :: oldOffset = %d, offset = %d", Integer.valueOf(offset), Integer.valueOf(i4)));
                FatFsBluetoothImp.this.a(bluetoothDevice2, i4, writeLeftData);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, final int i2) {
        short crc16;
        final FatFileSystem e2 = e(bluetoothDevice);
        if (e2 == null) {
            a(bluetoothDevice, "queryWriteDataResult : fatFs is null.");
            return;
        }
        int i3 = 1;
        if (i2 == 1) {
            crc16 = CryptoUtil.CRC16(e2.getNeedWriteData(), (short) 0);
        } else {
            i3 = 0;
            crc16 = e2.getCrc16();
        }
        JL_Log.e(f4026e, "-queryWriteDataResult- version = " + i2 + ", crc16 = " + ((int) crc16) + ", hex str = " + CHexConver.byte2HexStr(CHexConver.shortToBigBytes(crc16)) + ", flag = " + i3);
        this.f4027a.sendRcspCommand(bluetoothDevice, CommandBuilder.buildExternalFlashQueryWriteResultCmd(i3, crc16), new RcspCommandCallback<ExternalFlashIOCtrlCmd>() { // from class: com.jieli.jl_rcsp.watch.fatfs.FatFsBluetoothImp.6
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onErrCode(BluetoothDevice bluetoothDevice2, BaseError baseError) {
                FatFsBluetoothImp.this.a(bluetoothDevice2, RcspUtil.formatString("queryWriteDataResult :: ExternalFlashQueryWriteResult >> device = %s, error = %s", RcspUtil.printBtDeviceInfo(bluetoothDevice2), baseError));
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onCommandResponse(BluetoothDevice bluetoothDevice2, ExternalFlashIOCtrlCmd externalFlashIOCtrlCmd) {
                ExternalFlashIOCtrlResponse externalFlashIOCtrlResponse = (ExternalFlashIOCtrlResponse) externalFlashIOCtrlCmd.getResponse();
                JL_Log.w(FatFsBluetoothImp.f4026e, "queryWriteDataResult :: FlashQueryWriteResultCmd  = " + externalFlashIOCtrlCmd);
                if (externalFlashIOCtrlCmd.getStatus() != 0 || externalFlashIOCtrlResponse.getResult() != 0) {
                    FatFsBluetoothImp.this.a(bluetoothDevice2, "queryWriteDataResult :: ExternalFlashQueryWriteResult response bad status. ");
                    return;
                }
                if (i2 == 1) {
                    e2.setNeedWriteData(externalFlashIOCtrlResponse.getSize());
                }
                FatFsBluetoothImp.this.b(bluetoothDevice2, true);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice) {
        FatFileSystem e2 = e(bluetoothDevice);
        if (e2 == null) {
            a(bluetoothDevice, "checkWriteDataResult :: fatFs is null");
            return;
        }
        WatchCacheManager.WatchCache watchCacheByDevice = this.f4030d.getWatchCacheByDevice(bluetoothDevice);
        if (watchCacheByDevice == null) {
            a(bluetoothDevice, "checkWriteDataResult :: cache is null");
            return;
        }
        watchCacheByDevice.setNeedCheckReadData(true);
        e2.createReadBuffer(watchCacheByDevice.getWriteLen());
        a(bluetoothDevice, watchCacheByDevice.getWriteOffset(), watchCacheByDevice.getWriteLen());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, int i2, int i3) {
        int d2 = d(bluetoothDevice);
        if (d2 == 0) {
            d2 = b(bluetoothDevice);
        }
        if (d2 == 0) {
            JL_Log.w(f4026e, "handleReadData :: mtu is 0");
            a(bluetoothDevice, false, new byte[0]);
            return;
        }
        JL_Log.d(f4026e, "handleReadData :: offset = " + i2 + ", size = " + i3);
        if (i3 <= d2) {
            a(bluetoothDevice, 0, i2, i3);
        } else {
            a(bluetoothDevice, 1, i2, d2);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, boolean z, byte[] bArr) {
        FatFileSystem e2 = e(bluetoothDevice);
        if (e2 == null) {
            return;
        }
        String str = f4026e;
        JL_Log.d(str, "updateReadResult :: device : " + RcspUtil.printBtDeviceInfo(bluetoothDevice) + ", isSuccess : " + z);
        if (WatchConstant.ENABLE_WRITE_DATA_CHECK && this.f4030d.isNeedCheckReadData(bluetoothDevice)) {
            WatchCacheManager.WatchCache removeWatchCacheByDevice = this.f4030d.removeWatchCacheByDevice(bluetoothDevice);
            if (z) {
                short CRC16 = CryptoUtil.CRC16(bArr, (short) 0);
                JL_Log.i(str, "updateReadResult :: readCrc16 : " + ((int) CRC16) + ", cacheCrc16 : " + ((int) removeWatchCacheByDevice.getCrc16()) + ", cache offset = " + removeWatchCacheByDevice.getWriteOffset());
                if (removeWatchCacheByDevice.getCrc16() == CRC16) {
                    a(bluetoothDevice, d(bluetoothDevice) != 0 ? 1 : 0);
                    return;
                }
            }
            JL_Log.w(str, "updateReadResult ::  " + z + ", crc is error. ");
            b(bluetoothDevice, false);
            return;
        }
        e2.updateReadStatus(z, bArr);
    }

    private void a(BluetoothDevice bluetoothDevice, int i2, int i3, int i4) {
        JL_Log.d(f4026e, RcspUtil.formatString("readDataFromDevice :: device = %s, flag = %d, offset=%d, size=%s", RcspUtil.printBtDeviceInfo(bluetoothDevice), Integer.valueOf(i2), Integer.valueOf(i3), Integer.valueOf(i4)));
        this.f4027a.sendRcspCommand(bluetoothDevice, CommandBuilder.buildExternalFlashReadDataCmd(i2, i3, i4), new RcspCommandCallback<ExternalFlashIOCtrlCmd>() { // from class: com.jieli.jl_rcsp.watch.fatfs.FatFsBluetoothImp.7
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onErrCode(BluetoothDevice bluetoothDevice2, BaseError baseError) {
                JL_Log.w(FatFsBluetoothImp.f4026e, RcspUtil.formatString("readDataFromDevice >> onErrCode :: device = %s, error = %s", RcspUtil.printBtDeviceInfo(bluetoothDevice2), baseError));
                FatFsBluetoothImp.this.a(bluetoothDevice2, false, new byte[0]);
            }

            /* JADX WARN: Multi-variable type inference failed */
            @Override // com.jieli.jl_rcsp.interfaces.rcsp.RcspCommandCallback
            public void onCommandResponse(BluetoothDevice bluetoothDevice2, ExternalFlashIOCtrlCmd externalFlashIOCtrlCmd) {
                FatFileSystem e2 = FatFsBluetoothImp.this.e(bluetoothDevice2);
                if (e2 == null || e2.readBufferIsEmpty()) {
                    String str = FatFsBluetoothImp.f4026e;
                    StringBuilder sb = new StringBuilder("readDataFromDevice :: fatfs = ");
                    sb.append(e2);
                    sb.append(", readBufferIsEmpty : ");
                    sb.append(e2 != null && e2.readBufferIsEmpty());
                    JL_Log.w(str, sb.toString());
                    FatFsBluetoothImp.this.a(bluetoothDevice2, false, new byte[0]);
                    return;
                }
                ExternalFlashIOCtrlResponse externalFlashIOCtrlResponse = (ExternalFlashIOCtrlResponse) externalFlashIOCtrlCmd.getResponse();
                JL_Log.d(FatFsBluetoothImp.f4026e, RcspUtil.formatString("readDataFromDevice :: device = %s, ctrlCmd = %s", RcspUtil.printBtDeviceInfo(bluetoothDevice2), externalFlashIOCtrlCmd));
                if (externalFlashIOCtrlCmd.getStatus() != 0 || externalFlashIOCtrlResponse.getResult() != 0) {
                    JL_Log.w(FatFsBluetoothImp.f4026e, "readDataFromDevice :: readDataFromExternalFlash response bad status. ctrlCmd : " + externalFlashIOCtrlCmd);
                    FatFsBluetoothImp.this.a(bluetoothDevice2, false, new byte[0]);
                    return;
                }
                ExternalFlashIOCtrlParam externalFlashIOCtrlParam = (ExternalFlashIOCtrlParam) externalFlashIOCtrlCmd.getParam();
                byte[] data = externalFlashIOCtrlResponse.getData();
                int offset = externalFlashIOCtrlParam.getOffset();
                if (data != null && data.length > 0) {
                    e2.putDataInReadBuff(data);
                    offset += data.length;
                }
                if (externalFlashIOCtrlParam.isFinalData()) {
                    FatFsBluetoothImp.this.a(bluetoothDevice2, true, e2.getReadBuffer());
                } else {
                    FatFsBluetoothImp.this.a(bluetoothDevice2, offset, e2.getReadLeftSize());
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void a(BluetoothDevice bluetoothDevice, boolean z) {
        FatFileSystem e2 = e(bluetoothDevice);
        if (e2 == null) {
            return;
        }
        e2.updateFlagStatus(z);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean a(int i2) {
        return WatchConstant.ENABLE_WRITE_DATA_CHECK && i2 >= 8192 && i2 <= 16384;
    }
}
