package com.orhanobut.logger;

import com.facebook.internal.security.CertificateUtil;
import com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.cli.HelpFormatter;

/* loaded from: classes3.dex */
public class PrettyFormatStrategy implements FormatStrategy {
    private static final String BOTTOM_BORDER = "└────────────────────────────────────────────────────────────────────────────────────────────────────────────────";
    private static final char BOTTOM_LEFT_CORNER = 9492;
    private static final int CHUNK_SIZE = 4000;
    private static final String DOUBLE_DIVIDER = "────────────────────────────────────────────────────────";
    private static final char HORIZONTAL_LINE = 9474;
    private static final String MIDDLE_BORDER = "├┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄";
    private static final char MIDDLE_CORNER = 9500;
    private static final int MIN_STACK_OFFSET = 5;
    private static final String SINGLE_DIVIDER = "┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄";
    private static final String TOP_BORDER = "┌────────────────────────────────────────────────────────────────────────────────────────────────────────────────";
    private static final char TOP_LEFT_CORNER = 9484;
    private final LogStrategy logStrategy;
    private final int methodCount;
    private final int methodOffset;
    private final boolean showThreadInfo;
    private final String tag;

    private PrettyFormatStrategy(Builder builder) {
        Utils.checkNotNull(builder);
        this.methodCount = builder.methodCount;
        this.methodOffset = builder.methodOffset;
        this.showThreadInfo = builder.showThreadInfo;
        this.logStrategy = builder.logStrategy;
        this.tag = builder.tag;
    }

    public static Builder newBuilder() {
        return new Builder();
    }

    @Override // com.orhanobut.logger.FormatStrategy
    public void log(int i2, String str, String str2) {
        Utils.checkNotNull(str2);
        String formatTag = formatTag(str);
        logTopBorder(i2, formatTag);
        logHeaderContent(i2, formatTag, this.methodCount);
        byte[] bytes = str2.getBytes();
        int length = bytes.length;
        if (length <= 4000) {
            if (this.methodCount > 0) {
                logDivider(i2, formatTag);
            }
            logContent(i2, formatTag, str2);
            logBottomBorder(i2, formatTag);
            return;
        }
        if (this.methodCount > 0) {
            logDivider(i2, formatTag);
        }
        for (int i3 = 0; i3 < length; i3 += 4000) {
            logContent(i2, formatTag, new String(bytes, i3, Math.min(length - i3, 4000)));
        }
        logBottomBorder(i2, formatTag);
    }

    private void logTopBorder(int i2, String str) {
        logChunk(i2, str, TOP_BORDER);
    }

    private void logHeaderContent(int i2, String str, int i3) {
        StackTraceElement[] stackTrace = Thread.currentThread().getStackTrace();
        if (this.showThreadInfo) {
            logChunk(i2, str, "│ Thread: " + Thread.currentThread().getName());
            logDivider(i2, str);
        }
        int stackOffset = getStackOffset(stackTrace) + this.methodOffset;
        if (i3 + stackOffset > stackTrace.length) {
            i3 = (stackTrace.length - stackOffset) - 1;
        }
        String str2 = "";
        while (i3 > 0) {
            int i4 = i3 + stackOffset;
            if (i4 < stackTrace.length) {
                str2 = str2 + "   ";
                logChunk(i2, str, "│ " + str2 + getSimpleClassName(stackTrace[i4].getClassName()) + "." + stackTrace[i4].getMethodName() + "  (" + stackTrace[i4].getFileName() + CertificateUtil.DELIMITER + stackTrace[i4].getLineNumber() + ")");
            }
            i3--;
        }
    }

    private void logBottomBorder(int i2, String str) {
        logChunk(i2, str, BOTTOM_BORDER);
    }

    private void logDivider(int i2, String str) {
        logChunk(i2, str, MIDDLE_BORDER);
    }

    private void logContent(int i2, String str, String str2) {
        Utils.checkNotNull(str2);
        for (String str3 : str2.split(System.getProperty("line.separator"))) {
            logChunk(i2, str, "│ " + str3);
        }
    }

    private void logChunk(int i2, String str, String str2) {
        Utils.checkNotNull(str2);
        this.logStrategy.log(i2, str, str2);
    }

    private String getSimpleClassName(String str) {
        Utils.checkNotNull(str);
        return str.substring(str.lastIndexOf(".") + 1);
    }

    private int getStackOffset(StackTraceElement[] stackTraceElementArr) {
        Utils.checkNotNull(stackTraceElementArr);
        for (int i2 = 5; i2 < stackTraceElementArr.length; i2++) {
            String className = stackTraceElementArr[i2].getClassName();
            if (!className.equals(LoggerPrinter.class.getName()) && !className.equals(Logger.class.getName())) {
                return i2 - 1;
            }
        }
        return -1;
    }

    private String formatTag(String str) {
        if (!Utils.isEmpty(str) && !Utils.equals(this.tag, str)) {
            return this.tag + HelpFormatter.DEFAULT_OPT_PREFIX + str;
        }
        return this.tag;
    }

    public static class Builder {
        LogStrategy logStrategy;
        int methodCount;
        int methodOffset;
        boolean showThreadInfo;
        String tag;

        private Builder() {
            this.methodCount = 2;
            this.methodOffset = 0;
            this.showThreadInfo = true;
            this.tag = "PRETTY_LOGGER";
        }

        public Builder methodCount(int i2) {
            this.methodCount = i2;
            return this;
        }

        public Builder methodOffset(int i2) {
            this.methodOffset = i2;
            return this;
        }

        public Builder showThreadInfo(boolean z) {
            this.showThreadInfo = z;
            return this;
        }

        public Builder logStrategy(LogStrategy logStrategy) {
            this.logStrategy = logStrategy;
            return this;
        }

        public Builder tag(String str) {
            this.tag = str;
            return this;
        }

        public PrettyFormatStrategy build() {
            if (this.logStrategy == null) {
                this.logStrategy = new LogcatLogStrategy();
            }
            return new PrettyFormatStrategy(this);
        }
    }
}
