package com.realsil.sdk.core.bluetooth.connection.le;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothGatt;
import android.bluetooth.BluetoothGattCallback;
import android.bluetooth.BluetoothGattCharacteristic;
import android.bluetooth.BluetoothGattDescriptor;
import android.bluetooth.BluetoothGattService;
import android.bluetooth.BluetoothManager;
import android.content.Context;
import android.os.Build;
import com.realsil.sdk.core.RtkCore;
import com.realsil.sdk.core.bluetooth.utils.BluetoothHelper;
import com.realsil.sdk.core.logger.ZLogger;
import com.realsil.sdk.core.utility.DataConverter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.UUID;
import java.util.concurrent.CopyOnWriteArrayList;

/* loaded from: classes3.dex */
public final class BluetoothGattManager {
    public static final String CLIENT_CHARACTERISTIC_CONFIG = "00002902-0000-1000-8000-00805f9b34fb";
    public static boolean CLOSE_GATT_ENABLED = true;
    public static boolean DUMP_SERVICE = false;
    public static final int STATE_CONNECTED = 2;
    public static final int STATE_CONNECTING = 1;
    public static final int STATE_DISCONNECTED = 0;
    public static BluetoothGattManager l;

    /* renamed from: a, reason: collision with root package name */
    public boolean f4198a;

    /* renamed from: b, reason: collision with root package name */
    public boolean f4199b;

    /* renamed from: c, reason: collision with root package name */
    public BluetoothManager f4200c;

    /* renamed from: d, reason: collision with root package name */
    public BluetoothAdapter f4201d;

    /* renamed from: i, reason: collision with root package name */
    public volatile boolean f4206i;
    public Context k;
    public static int SDK_INT = Build.VERSION.SDK_INT;
    public static final UUID CLIENT_CHARACTERISTIC_CONFIG_DESCRIPTOR_UUID = UUID.fromString("00002902-0000-1000-8000-00805f9b34fb");

    /* renamed from: j, reason: collision with root package name */
    public final Object f4207j = new Object();

    /* renamed from: f, reason: collision with root package name */
    public HashMap<String, BluetoothGatt> f4203f = new HashMap<>();

    /* renamed from: h, reason: collision with root package name */
    public HashMap<String, Integer> f4205h = new HashMap<>();

    /* renamed from: g, reason: collision with root package name */
    public HashMap<String, List<BluetoothGattCallback>> f4204g = new HashMap<>();

    /* renamed from: e, reason: collision with root package name */
    public List<String> f4202e = new CopyOnWriteArrayList();

    public class a extends BluetoothGattCallback {
        public a() {
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onCharacteristicChanged(BluetoothGatt bluetoothGatt, BluetoothGattCharacteristic bluetoothGattCharacteristic) {
            String address = bluetoothGatt.getDevice().getAddress();
            byte[] value = bluetoothGattCharacteristic.getValue();
            if (BluetoothGattManager.this.f4198a) {
                if (value != null) {
                    ZLogger.d(String.format(Locale.US, "<< %s\n(%d)%s", bluetoothGattCharacteristic.getUuid(), Integer.valueOf(value.length), DataConverter.bytes2Hex(value)));
                } else {
                    ZLogger.d(String.format(Locale.US, "<< %s", bluetoothGattCharacteristic.getUuid()));
                }
            }
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(address);
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onCharacteristicChanged(bluetoothGatt, bluetoothGattCharacteristic);
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onCharacteristicRead(BluetoothGatt bluetoothGatt, BluetoothGattCharacteristic bluetoothGattCharacteristic, int i2) {
            byte[] value = bluetoothGattCharacteristic.getValue();
            if (BluetoothGattManager.this.f4198a) {
                if (value != null) {
                    ZLogger.d(String.format(Locale.US, "%s << %s\n:\t(%d)%s", GattError.parse(i2), bluetoothGattCharacteristic.getUuid(), Integer.valueOf(value.length), DataConverter.bytes2Hex(value)));
                } else {
                    ZLogger.d(String.format(Locale.US, "%s << %s", GattError.parse(i2), bluetoothGattCharacteristic.getUuid()));
                }
            } else if (value != null) {
                ZLogger.d(String.format(Locale.US, "%s << (%d)", GattError.parse(i2), Integer.valueOf(value.length)));
            } else {
                ZLogger.d(String.format(Locale.US, "%s <<", GattError.parse(i2)));
            }
            synchronized (BluetoothGattManager.this.f4207j) {
                BluetoothGattManager.this.f4206i = true;
                BluetoothGattManager.this.f4207j.notifyAll();
            }
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(bluetoothGatt.getDevice().getAddress());
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onCharacteristicRead(bluetoothGatt, bluetoothGattCharacteristic, i2);
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onCharacteristicWrite(BluetoothGatt bluetoothGatt, BluetoothGattCharacteristic bluetoothGattCharacteristic, int i2) {
            String address = bluetoothGatt.getDevice().getAddress();
            byte[] value = bluetoothGattCharacteristic.getValue();
            if (BluetoothGattManager.this.f4198a) {
                if (value != null) {
                    ZLogger.d(String.format(Locale.US, "%s << %s\n(%d)%s", GattError.parse(i2), bluetoothGattCharacteristic.getUuid(), Integer.valueOf(value.length), DataConverter.bytes2Hex(value)));
                } else {
                    ZLogger.d(String.format(Locale.US, "%s << %s", GattError.parse(i2), bluetoothGattCharacteristic.getUuid()));
                }
            }
            synchronized (BluetoothGattManager.this.f4207j) {
                BluetoothGattManager.this.f4206i = true;
                BluetoothGattManager.this.f4207j.notifyAll();
            }
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(address);
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onCharacteristicWrite(bluetoothGatt, bluetoothGattCharacteristic, i2);
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onConnectionStateChange(BluetoothGatt bluetoothGatt, int i2, int i3) {
            BluetoothDevice device = bluetoothGatt.getDevice();
            if (device == null) {
                return;
            }
            String address = device.getAddress();
            ZLogger.v(String.format(Locale.US, "%s, status: %s , newState: %s", BluetoothHelper.formatAddress(address, true), GattError.parseConnectionError(i2), BluetoothHelper.parseProfileState(i3)));
            if (i2 != 0) {
                BluetoothGattManager.this.f4205h.put(address, 0);
            } else if (i3 == 2) {
                BluetoothGattManager.this.f4205h.put(address, 2);
                BluetoothGattManager.this.f4203f.put(address, bluetoothGatt);
            } else {
                BluetoothGattManager.this.f4205h.put(address, 0);
            }
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(address);
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onConnectionStateChange(bluetoothGatt, i2, i3);
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onDescriptorRead(BluetoothGatt bluetoothGatt, BluetoothGattDescriptor bluetoothGattDescriptor, int i2) {
            super.onDescriptorRead(bluetoothGatt, bluetoothGattDescriptor, i2);
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onDescriptorWrite(BluetoothGatt bluetoothGatt, BluetoothGattDescriptor bluetoothGattDescriptor, int i2) {
            String address = bluetoothGatt.getDevice().getAddress();
            UUID uuid = bluetoothGattDescriptor.getCharacteristic().getUuid();
            byte[] value = bluetoothGattDescriptor.getValue();
            if (BluetoothGattManager.this.f4198a) {
                if (value != null) {
                    ZLogger.d(String.format(Locale.US, "%s>> {\nCharacteristic:%s\nDescriptor:%s\nvalue:(%d)%s\n}", GattError.parse(i2), uuid, bluetoothGattDescriptor.getUuid(), Integer.valueOf(value.length), DataConverter.bytes2Hex(value)));
                } else {
                    ZLogger.d(String.format(Locale.US, "%s>> {\nCharacteristic:%s\nDescriptor:%s}", GattError.parse(i2), uuid, bluetoothGattDescriptor.getUuid()));
                }
            }
            synchronized (BluetoothGattManager.this.f4207j) {
                BluetoothGattManager.this.f4206i = true;
                BluetoothGattManager.this.f4207j.notifyAll();
            }
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(address);
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onDescriptorWrite(bluetoothGatt, bluetoothGattDescriptor, i2);
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onMtuChanged(BluetoothGatt bluetoothGatt, int i2, int i3) {
            String address = bluetoothGatt.getDevice().getAddress();
            ZLogger.d(String.format(Locale.US, "%s << mtu=%d, addr=%s", GattError.parse(i3), Integer.valueOf(i2), BluetoothHelper.formatAddress(address, true)));
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(address);
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onMtuChanged(bluetoothGatt, i2, i3);
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onPhyRead(BluetoothGatt bluetoothGatt, int i2, int i3, int i4) {
            super.onPhyRead(bluetoothGatt, i2, i3, i4);
            String address = bluetoothGatt.getDevice().getAddress();
            ZLogger.d(String.format(Locale.US, "%s << %s: txPhy=%d, rxPhy=%d", BluetoothHelper.formatAddress(address, true), GattError.parse(i4), Integer.valueOf(i2), Integer.valueOf(i3)));
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(address);
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onPhyRead(bluetoothGatt, i2, i3, i4);
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onPhyUpdate(BluetoothGatt bluetoothGatt, int i2, int i3, int i4) {
            super.onPhyUpdate(bluetoothGatt, i2, i3, i4);
            String address = bluetoothGatt.getDevice().getAddress();
            ZLogger.d(String.format(Locale.US, "%s << %s: txPhy=%d, rxPhy=%d", BluetoothHelper.formatAddress(address, true), GattError.parse(i4), Integer.valueOf(i2), Integer.valueOf(i3)));
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(address);
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onPhyUpdate(bluetoothGatt, i2, i3, i4);
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onReadRemoteRssi(BluetoothGatt bluetoothGatt, int i2, int i3) {
            super.onReadRemoteRssi(bluetoothGatt, i2, i3);
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onReliableWriteCompleted(BluetoothGatt bluetoothGatt, int i2) {
            super.onReliableWriteCompleted(bluetoothGatt, i2);
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onServicesDiscovered(BluetoothGatt bluetoothGatt, int i2) {
            String address = bluetoothGatt.getDevice().getAddress();
            ZLogger.d(String.format(Locale.US, "%s << addr=%s", GattError.parse(i2), BluetoothHelper.formatAddress(address, true)));
            if (BluetoothGattManager.DUMP_SERVICE) {
                for (BluetoothGattService bluetoothGattService : bluetoothGatt.getServices()) {
                    ZLogger.d(String.format(Locale.US, "service: type=%d, %d/%s", Integer.valueOf(bluetoothGattService.getType()), Integer.valueOf(bluetoothGattService.getInstanceId()), bluetoothGattService.getUuid().toString()));
                    for (BluetoothGattCharacteristic bluetoothGattCharacteristic : bluetoothGattService.getCharacteristics()) {
                        ZLogger.v(String.format(Locale.US, "\tcharacteristic: %d/%s", Integer.valueOf(bluetoothGattCharacteristic.getInstanceId()), bluetoothGattCharacteristic.getUuid().toString()));
                    }
                }
            }
            List<BluetoothGattCallback> list = BluetoothGattManager.this.f4204g.get(address);
            if (list == null || list.size() <= 0) {
                return;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onServicesDiscovered(bluetoothGatt, i2);
            }
        }
    }

    public BluetoothGattManager(Context context) {
        this.f4198a = false;
        this.f4199b = false;
        this.k = context;
        this.f4198a = RtkCore.DEBUG;
        this.f4199b = RtkCore.VDBG;
        a();
    }

    public static BluetoothGattManager getInstance() {
        return l;
    }

    public static synchronized void initial(Context context) {
        synchronized (BluetoothGattManager.class) {
            if (l == null) {
                synchronized (BluetoothGattManager.class) {
                    if (l == null) {
                        l = new BluetoothGattManager(context.getApplicationContext());
                    }
                }
            }
        }
    }

    public void close(String str) {
        if (str == null) {
            return;
        }
        BluetoothGatt bluetoothGatt = this.f4203f.get(str);
        if (bluetoothGatt != null) {
            if (isConnected(str)) {
                if (this.f4198a) {
                    ZLogger.v("disconnect : " + str);
                }
                bluetoothGatt.disconnect();
                try {
                    Thread.sleep(500L);
                } catch (InterruptedException e2) {
                    e2.printStackTrace();
                }
            }
            if (CLOSE_GATT_ENABLED) {
                if (this.f4199b) {
                    ZLogger.v("closeGatt, addr:=" + str);
                }
                bluetoothGatt.close();
            }
            this.f4203f.remove(str);
        }
        HashMap<String, List<BluetoothGattCallback>> hashMap = this.f4204g;
        if (hashMap != null) {
            hashMap.remove(str);
        }
        List<String> list = this.f4202e;
        if (list == null || !list.contains(str)) {
            return;
        }
        this.f4202e.remove(str);
    }

    public void closeAll() {
        List<String> list = this.f4202e;
        if (list == null || list.size() <= 0) {
            return;
        }
        Iterator<String> it2 = this.f4202e.iterator();
        while (it2.hasNext()) {
            close(it2.next());
        }
    }

    public synchronized void closeGatt(String str) {
        closeGatt(str, CLOSE_GATT_ENABLED);
    }

    public boolean disconnectGatt(String str) {
        BluetoothGatt bluetoothGatt = this.f4203f.get(str);
        List<BluetoothGattCallback> list = this.f4204g.get(str);
        if (bluetoothGatt == null) {
            return false;
        }
        if (!isConnected(str)) {
            if (list == null || list.size() <= 0) {
                return true;
            }
            Iterator<BluetoothGattCallback> it2 = list.iterator();
            while (it2.hasNext()) {
                it2.next().onConnectionStateChange(bluetoothGatt, 0, 0);
            }
            return true;
        }
        if (this.f4198a) {
            ZLogger.v("disconnect : " + str);
        }
        bluetoothGatt.disconnect();
        try {
            Thread.sleep(500L);
            return true;
        } catch (InterruptedException e2) {
            e2.printStackTrace();
            return true;
        }
    }

    public BluetoothAdapter getBluetoothAdapter() {
        return this.f4201d;
    }

    public List<String> getBluetoothDeviceAddresss() {
        return this.f4202e;
    }

    public BluetoothGatt getBluetoothGatt(String str) {
        return this.f4203f.get(str);
    }

    public List<BluetoothGattCallback> getCallback(String str) {
        HashMap<String, List<BluetoothGattCallback>> hashMap = this.f4204g;
        if (hashMap != null) {
            return hashMap.get(str);
        }
        return null;
    }

    public ArrayList<BluetoothDevice> getConnectDevices() {
        ArrayList<BluetoothDevice> arrayList = new ArrayList<>();
        for (String str : this.f4202e) {
            if (isConnected(str)) {
                arrayList.add(getBluetoothGatt(str).getDevice());
            }
        }
        return arrayList;
    }

    public BluetoothDevice getConnectedDevice() {
        for (String str : this.f4202e) {
            if (isConnected(str)) {
                return getBluetoothGatt(str).getDevice();
            }
        }
        return null;
    }

    public ArrayList<BluetoothDevice> getConnectedDevices() {
        ArrayList<BluetoothDevice> arrayList = new ArrayList<>();
        for (String str : this.f4202e) {
            if (isConnected(str)) {
                arrayList.add(getBluetoothGatt(str).getDevice());
            }
        }
        return arrayList;
    }

    public String getDeviceName(String str) {
        BluetoothGatt bluetoothGatt = this.f4203f.get(str);
        if (bluetoothGatt != null) {
            return bluetoothGatt.getDevice().getName();
        }
        if (!this.f4198a) {
            return null;
        }
        ZLogger.w("no bluetoothGatt exist, addr=" + str);
        return null;
    }

    public List<BluetoothGattService> getSupportedGattServices(String str) {
        if (this.f4203f.get(str) == null) {
            return null;
        }
        return this.f4203f.get(str).getServices();
    }

    public boolean isBluetoothSupported() {
        return this.f4201d != null || a();
    }

    public boolean isCallbackRegisted(String str, BluetoothGattCallback bluetoothGattCallback) {
        List<BluetoothGattCallback> callback = getCallback(str);
        return callback != null && callback.contains(bluetoothGattCallback);
    }

    public boolean isConnected(String str) {
        Integer num = this.f4205h.get(str);
        return num != null && num.intValue() == 2;
    }

    public boolean isHostConnected(String str) {
        BluetoothManager bluetoothManager = this.f4200c;
        if (bluetoothManager == null) {
            if (this.f4198a) {
                ZLogger.w("mBluetoothManager == null");
            }
            return false;
        }
        List<BluetoothDevice> connectedDevices = bluetoothManager.getConnectedDevices(7);
        if (connectedDevices != null) {
            Iterator<BluetoothDevice> it2 = connectedDevices.iterator();
            while (it2.hasNext()) {
                if (it2.next().getAddress().equals(str)) {
                    if (!this.f4199b) {
                        return true;
                    }
                    ZLogger.d("addr: " + str + ", Connected.");
                    return true;
                }
            }
        }
        if (this.f4199b) {
            ZLogger.v("addr: " + str + ", Disconnected.");
        }
        return false;
    }

    public boolean readCharacteristic(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic) {
        if (this.f4201d == null) {
            ZLogger.w("BluetoothAdapter not initialized");
            return false;
        }
        BluetoothGatt bluetoothGatt = this.f4203f.get(str);
        if (bluetoothGatt == null) {
            ZLogger.w("unspecified address.");
            return false;
        }
        if (this.f4198a) {
            ZLogger.d("raddr: " + BluetoothHelper.formatAddress(str, true));
        }
        return bluetoothGatt.readCharacteristic(bluetoothGattCharacteristic);
    }

    public boolean readCharacteristicSync(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic) {
        this.f4206i = false;
        if (!readCharacteristic(str, bluetoothGattCharacteristic)) {
            return false;
        }
        synchronized (this.f4207j) {
            try {
                if (!this.f4206i) {
                    if (this.f4198a) {
                        ZLogger.v("wait for 3000ms");
                    }
                    this.f4207j.wait(3000L);
                    if (this.f4198a) {
                        ZLogger.v("wait time reached");
                    }
                }
            } catch (InterruptedException e2) {
                ZLogger.e(e2.toString());
            }
        }
        return true;
    }

    public synchronized void registerCallback(String str, BluetoothGattCallback bluetoothGattCallback) {
        List<BluetoothGattCallback> callback = getCallback(str);
        if (callback == null) {
            CopyOnWriteArrayList copyOnWriteArrayList = new CopyOnWriteArrayList();
            copyOnWriteArrayList.add(bluetoothGattCallback);
            this.f4204g.put(str, copyOnWriteArrayList);
        } else {
            if (!callback.contains(bluetoothGattCallback)) {
                callback.add(bluetoothGattCallback);
                this.f4204g.put(str, callback);
            }
        }
    }

    public boolean setCharacteristicIndication(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic, boolean z) {
        return setCharacteristicIndication(str, bluetoothGattCharacteristic, CLIENT_CHARACTERISTIC_CONFIG_DESCRIPTOR_UUID, z);
    }

    public boolean setCharacteristicNotification(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic, boolean z) {
        return setCharacteristicNotification(str, bluetoothGattCharacteristic, CLIENT_CHARACTERISTIC_CONFIG_DESCRIPTOR_UUID, z);
    }

    public boolean setCharacteristicNotificationSync(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic, UUID uuid, boolean z) {
        this.f4206i = false;
        if (!setCharacteristicNotification(str, bluetoothGattCharacteristic, uuid, z)) {
            return false;
        }
        synchronized (this.f4207j) {
            try {
                if (!this.f4206i) {
                    if (this.f4198a) {
                        ZLogger.v("wait for 3000ms");
                    }
                    this.f4207j.wait(3000L);
                    if (this.f4198a) {
                        ZLogger.v("wait time reached");
                    }
                }
            } catch (InterruptedException e2) {
                ZLogger.e(e2.toString());
            }
        }
        return true;
    }

    public void unRegisterAllCallback(String str) {
        if (this.f4204g.get(str) == null) {
            if (this.f4198a) {
                ZLogger.d("mCallbacks.get(addr) == null");
            }
        } else {
            if (this.f4198a) {
                ZLogger.v("addr: " + str);
            }
            this.f4204g.remove(str);
        }
    }

    public synchronized void unRegisterCallback(String str, BluetoothGattCallback bluetoothGattCallback) {
        List<BluetoothGattCallback> callback = getCallback(str);
        if (callback != null) {
            if (callback.contains(bluetoothGattCallback)) {
                callback.remove(bluetoothGattCallback);
                this.f4204g.put(str, callback);
            }
        } else {
            if (this.f4198a) {
                ZLogger.v("callback not registered, addr= " + str);
            }
        }
    }

    public boolean writeCharacteristic(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic) {
        if (this.f4201d == null) {
            ZLogger.w("BluetoothAdapter not initialized");
            return false;
        }
        BluetoothGatt bluetoothGatt = this.f4203f.get(str);
        if (bluetoothGatt != null) {
            return bluetoothGatt.writeCharacteristic(bluetoothGattCharacteristic);
        }
        ZLogger.w("unspecified address.");
        return false;
    }

    public synchronized boolean writeCharacteristicSync(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic) {
        this.f4206i = false;
        if (!writeCharacteristic(str, bluetoothGattCharacteristic)) {
            return false;
        }
        synchronized (this.f4207j) {
            try {
                if (!this.f4206i) {
                    if (this.f4198a) {
                        ZLogger.v("wait for 3000ms");
                    }
                    this.f4207j.wait(3000L);
                    if (this.f4198a) {
                        ZLogger.v("wait time reached");
                    }
                }
            } catch (InterruptedException e2) {
                ZLogger.e(e2.toString());
            }
        }
        return true;
    }

    public final boolean a() {
        if (this.f4200c == null) {
            BluetoothManager bluetoothManager = (BluetoothManager) this.k.getSystemService("bluetooth");
            this.f4200c = bluetoothManager;
            if (bluetoothManager == null) {
                ZLogger.w("BLUETOOTH_SERVICE not supported.");
                return false;
            }
        }
        if (this.f4201d == null) {
            BluetoothAdapter adapter = this.f4200c.getAdapter();
            this.f4201d = adapter;
            if (adapter == null) {
                ZLogger.w("BluetoothAdapter is not supported");
                return false;
            }
        }
        ZLogger.d("initialize success");
        return true;
    }

    public synchronized void closeGatt(String str, boolean z) {
        BluetoothGatt bluetoothGatt;
        if (str == null) {
            ZLogger.d(this.f4198a, "Invalid address");
            return;
        }
        HashMap<String, BluetoothGatt> hashMap = this.f4203f;
        if (hashMap != null) {
            if (z && (bluetoothGatt = hashMap.get(str)) != null) {
                if (this.f4199b) {
                    ZLogger.v("closeGatt, addr:=" + str);
                }
                bluetoothGatt.close();
            }
            this.f4203f.remove(str);
        }
        HashMap<String, List<BluetoothGattCallback>> hashMap2 = this.f4204g;
        if (hashMap2 != null) {
            hashMap2.remove(str);
        }
        List<String> list = this.f4202e;
        if (list != null) {
            list.remove(str);
        }
    }

    public boolean connect(String str, BluetoothGattCallback bluetoothGattCallback) {
        return connect(str, 2, bluetoothGattCallback);
    }

    public boolean setCharacteristicIndication(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic, UUID uuid, boolean z) {
        if (this.f4201d == null) {
            ZLogger.w("BluetoothAdapter not initialized");
            return false;
        }
        BluetoothGatt bluetoothGatt = this.f4203f.get(str);
        if (bluetoothGatt == null) {
            ZLogger.w("BluetoothGatt can not be null, addr=" + str);
            return false;
        }
        if (bluetoothGattCharacteristic == null) {
            ZLogger.w("characteristic is null");
            return false;
        }
        if (this.f4198a) {
            ZLogger.d("addr:=" + str + ", enabled=" + z);
        }
        bluetoothGatt.setCharacteristicNotification(bluetoothGattCharacteristic, z);
        BluetoothGattDescriptor descriptor = bluetoothGattCharacteristic.getDescriptor(uuid);
        if (descriptor == null) {
            ZLogger.w("descriptor not found, uuid=" + uuid.toString());
            return false;
        }
        if (z) {
            descriptor.setValue(BluetoothGattDescriptor.ENABLE_INDICATION_VALUE);
        } else {
            descriptor.setValue(BluetoothGattDescriptor.DISABLE_NOTIFICATION_VALUE);
        }
        bluetoothGatt.writeDescriptor(descriptor);
        return true;
    }

    public boolean setCharacteristicNotification(String str, BluetoothGattCharacteristic bluetoothGattCharacteristic, UUID uuid, boolean z) {
        if (this.f4201d == null) {
            ZLogger.w("BluetoothAdapter not initialized");
            return false;
        }
        BluetoothGatt bluetoothGatt = this.f4203f.get(str);
        if (bluetoothGatt == null) {
            ZLogger.w("BluetoothGatt can not be null, addr=" + str);
            return false;
        }
        if (this.f4198a) {
            ZLogger.d("addr:=" + str + ", enabled=" + z);
        }
        bluetoothGatt.setCharacteristicNotification(bluetoothGattCharacteristic, z);
        BluetoothGattDescriptor descriptor = bluetoothGattCharacteristic.getDescriptor(uuid);
        if (descriptor == null) {
            ZLogger.w("descriptor not found, uuid=" + uuid.toString());
            return false;
        }
        if (z) {
            descriptor.setValue(BluetoothGattDescriptor.ENABLE_NOTIFICATION_VALUE);
        } else {
            descriptor.setValue(BluetoothGattDescriptor.DISABLE_NOTIFICATION_VALUE);
        }
        bluetoothGatt.writeDescriptor(descriptor);
        return true;
    }

    public boolean connect(String str, int i2, BluetoothGattCallback bluetoothGattCallback) {
        if (Build.VERSION.SDK_INT >= 26) {
            return connect(str, false, i2, 1, bluetoothGattCallback);
        }
        return connect(str, false, i2, 1, bluetoothGattCallback);
    }

    public boolean connect(String str, int i2, int i3, BluetoothGattCallback bluetoothGattCallback) {
        return connect(str, false, i2, i3, bluetoothGattCallback);
    }

    public boolean connect(String str, boolean z, int i2, int i3, BluetoothGattCallback bluetoothGattCallback) {
        BluetoothGatt connectGatt;
        BluetoothGatt bluetoothGatt;
        BluetoothAdapter bluetoothAdapter = this.f4201d;
        if (bluetoothAdapter == null) {
            ZLogger.w("BluetoothAdapter not initialized");
            return false;
        }
        if (str == null) {
            ZLogger.w("unspecified address.");
            return false;
        }
        BluetoothDevice remoteDevice = bluetoothAdapter.getRemoteDevice(str);
        if (remoteDevice == null) {
            ZLogger.w("Device not found.  Unable to connect.");
            return false;
        }
        if (this.f4202e.contains(str) && (bluetoothGatt = this.f4203f.get(str)) != null) {
            if (isConnected(str)) {
                if (this.f4198a) {
                    ZLogger.v("already connected, addr=" + BluetoothHelper.formatAddress(str, true));
                }
                registerCallback(str, bluetoothGattCallback);
                if (bluetoothGattCallback != null) {
                    bluetoothGattCallback.onConnectionStateChange(bluetoothGatt, 0, 2);
                }
                return true;
            }
            if (z) {
                registerCallback(str, bluetoothGattCallback);
                if (this.f4198a) {
                    ZLogger.v("re-connect previous device: " + str);
                }
                if (bluetoothGatt.connect()) {
                    this.f4205h.put(str, 1);
                    return true;
                }
                ZLogger.d("reconnect failed.");
                closeGatt(str);
                return false;
            }
            closeGatt(str);
        }
        if (this.f4198a) {
            ZLogger.v("create connection to " + BluetoothHelper.formatAddress(str, true));
        }
        registerCallback(str, bluetoothGattCallback);
        this.f4205h.put(str, 1);
        if (Build.VERSION.SDK_INT >= 26) {
            connectGatt = remoteDevice.connectGatt(this.k, z, new a(), i2, i3);
        } else {
            connectGatt = remoteDevice.connectGatt(this.k, z, new a(), i2);
        }
        if (connectGatt == null) {
            ZLogger.d("BluetoothGatt not exist.  Unable to connect.");
            this.f4205h.put(str, 0);
            closeGatt(str);
            return false;
        }
        this.f4203f.put(str, connectGatt);
        if (!this.f4202e.contains(str)) {
            this.f4202e.add(str);
        }
        return true;
    }
}
