package com.realsil.sdk.core.bluetooth.connection.legacy;

import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;
import com.realsil.sdk.core.logger.ZLogger;
import java.util.Iterator;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.CopyOnWriteArrayList;

/* loaded from: classes3.dex */
public final class BluetoothSppManager {
    public static UUID UUID_SECURE = UUID.fromString("00001101-0000-1000-8000-00805F9B34FB");

    /* renamed from: f, reason: collision with root package name */
    public static volatile BluetoothSppManager f4230f;

    /* renamed from: b, reason: collision with root package name */
    public BluetoothSpp f4232b;

    /* renamed from: c, reason: collision with root package name */
    public volatile boolean f4233c;

    /* renamed from: d, reason: collision with root package name */
    public final Object f4234d = new Object();

    /* renamed from: e, reason: collision with root package name */
    public BluetoothSppCallback f4235e = new a();

    /* renamed from: a, reason: collision with root package name */
    public List<BluetoothSppCallback> f4231a = new CopyOnWriteArrayList();

    public class a extends BluetoothSppCallback {
        public a() {
        }

        @Override // com.realsil.sdk.core.bluetooth.connection.legacy.BluetoothSppCallback
        public void onConnectionStateChanged(BluetoothDevice bluetoothDevice, boolean z, int i2) {
            super.onConnectionStateChanged(bluetoothDevice, z, i2);
            synchronized (BluetoothSppManager.this.f4231a) {
                List<BluetoothSppCallback> list = BluetoothSppManager.this.f4231a;
                if (list != null && list.size() > 0) {
                    Iterator<BluetoothSppCallback> it2 = BluetoothSppManager.this.f4231a.iterator();
                    while (it2.hasNext()) {
                        it2.next().onConnectionStateChanged(bluetoothDevice, z, i2);
                    }
                }
            }
        }

        @Override // com.realsil.sdk.core.bluetooth.connection.legacy.BluetoothSppCallback
        public void onDataReceive(byte[] bArr) {
            super.onDataReceive(bArr);
            synchronized (BluetoothSppManager.this.f4231a) {
                List<BluetoothSppCallback> list = BluetoothSppManager.this.f4231a;
                if (list != null && list.size() > 0) {
                    Iterator<BluetoothSppCallback> it2 = BluetoothSppManager.this.f4231a.iterator();
                    while (it2.hasNext()) {
                        it2.next().onDataReceive(bArr);
                    }
                }
            }
        }
    }

    public static BluetoothSppManager getInstance() {
        return f4230f;
    }

    public static synchronized void initialize() {
        synchronized (BluetoothSppManager.class) {
            if (f4230f == null) {
                synchronized (BluetoothSppManager.class) {
                    if (f4230f == null) {
                        f4230f = new BluetoothSppManager();
                    }
                }
            }
        }
    }

    public final BluetoothSpp a() {
        if (this.f4232b == null) {
            this.f4232b = new BluetoothSpp(UUID_SECURE, this.f4235e);
        }
        return this.f4232b;
    }

    public synchronized boolean connect(BluetoothDevice bluetoothDevice, BluetoothSocket bluetoothSocket, BluetoothSppCallback bluetoothSppCallback) {
        register(bluetoothSppCallback);
        if (getConnectionState() == 512) {
            BluetoothDevice device = a().getDevice();
            if (device != null && device.equals(bluetoothDevice)) {
                bluetoothSppCallback.onConnectionStateChanged(bluetoothDevice, true, 512);
                return true;
            }
            ZLogger.d("current connected device is conflict with the connecting device");
        }
        boolean connect = a().connect(bluetoothDevice, bluetoothSocket);
        if (!connect) {
            unregister(bluetoothSppCallback);
        }
        return connect;
    }

    public void destroy() {
        synchronized (this.f4231a) {
            List<BluetoothSppCallback> list = this.f4231a;
            if (list != null) {
                list.clear();
            }
        }
        disconnect();
    }

    public void disconnect() {
        a().stop();
    }

    public int getConnectionState() {
        return a().getConnectionState();
    }

    public void notifyAck() {
        synchronized (this.f4234d) {
            this.f4233c = true;
            this.f4234d.notifyAll();
        }
    }

    public void register(BluetoothSppCallback bluetoothSppCallback) {
        synchronized (this.f4231a) {
            if (this.f4231a == null) {
                this.f4231a = new CopyOnWriteArrayList();
            }
            if (!this.f4231a.contains(bluetoothSppCallback)) {
                this.f4231a.add(bluetoothSppCallback);
            }
            ZLogger.v("callback's size=" + this.f4231a.size());
        }
    }

    public synchronized boolean sendPacket(byte[] bArr, boolean z) {
        if (bArr == null) {
            return false;
        }
        if (!z) {
            this.f4233c = false;
        }
        if (!a().write(bArr)) {
            ZLogger.w("send spp data failed");
            return false;
        }
        if (z) {
            return true;
        }
        synchronized (this.f4234d) {
            if (this.f4233c) {
                return true;
            }
            try {
                this.f4234d.wait(5000L);
            } catch (InterruptedException e2) {
                e2.printStackTrace();
            }
            return this.f4233c;
        }
    }

    public void unregister(BluetoothSppCallback bluetoothSppCallback) {
        synchronized (this.f4231a) {
            List<BluetoothSppCallback> list = this.f4231a;
            if (list != null) {
                list.remove(bluetoothSppCallback);
            }
        }
    }

    public boolean write(byte[] bArr) {
        return a().write(bArr);
    }

    public synchronized boolean connect(BluetoothDevice bluetoothDevice, BluetoothSppCallback bluetoothSppCallback) {
        register(bluetoothSppCallback);
        if (getConnectionState() == 512) {
            BluetoothDevice device = a().getDevice();
            if (device != null && device.equals(bluetoothDevice)) {
                ZLogger.d("connection already connected");
                bluetoothSppCallback.onConnectionStateChanged(bluetoothDevice, true, 512);
                return true;
            }
            ZLogger.d("current connected device is conflict with the connecting device");
        }
        boolean connect = a().connect(bluetoothDevice);
        if (!connect) {
            unregister(bluetoothSppCallback);
        }
        return connect;
    }
}
