package com.realsil.sdk.core.bluetooth.profile;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothProfile;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import com.realsil.sdk.core.bluetooth.impl.BluetoothClassImpl;
import com.realsil.sdk.core.bluetooth.impl.BluetoothInputDeviceImpl;
import com.realsil.sdk.core.logger.ZLogger;
import java.lang.reflect.Method;
import org.eclipse.paho.android.service.MqttServiceConstants;

/* loaded from: classes3.dex */
public final class BluetoothInputDeviceManager extends HideProfileManager {
    public static BluetoothInputDeviceManager m;

    /* renamed from: h, reason: collision with root package name */
    public BluetoothDevice f4245h;

    /* renamed from: i, reason: collision with root package name */
    public boolean f4246i;

    /* renamed from: j, reason: collision with root package name */
    public RCUReconnectReceiver f4247j;
    public HidConnectionCallback k;
    public BluetoothProfile.ServiceListener l;

    public static abstract class HidConnectionCallback {
        public void onConnectionStateChange(boolean z) {
        }
    }

    public class RCUReconnectReceiver extends BroadcastReceiver {
        public RCUReconnectReceiver() {
        }

        @Override // android.content.BroadcastReceiver
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            ZLogger.i("RCUReconnectReceiver " + action);
            if ("android.bluetooth.input.profile.action.CONNECTION_STATE_CHANGED".equals(action)) {
                int intExtra = intent.getIntExtra("android.bluetooth.profile.extra.STATE", -1);
                if (intExtra == 0) {
                    ZLogger.i(" Braodcast: RCU Disconnected!");
                    HidConnectionCallback hidConnectionCallback = BluetoothInputDeviceManager.this.k;
                    if (hidConnectionCallback != null) {
                        hidConnectionCallback.onConnectionStateChange(false);
                    }
                    BluetoothInputDeviceManager bluetoothInputDeviceManager = BluetoothInputDeviceManager.this;
                    bluetoothInputDeviceManager.k = null;
                    bluetoothInputDeviceManager.f4245h = null;
                    return;
                }
                if (intExtra == 1) {
                    ZLogger.i(" Braodcast: RCU Connecting!");
                    return;
                }
                if (intExtra != 2) {
                    if (intExtra != 3) {
                        return;
                    }
                    ZLogger.i(" Braodcast: RCU Disconnecting!");
                    return;
                }
                ZLogger.i(" Braodcast: RCU Connected!");
                HidConnectionCallback hidConnectionCallback2 = BluetoothInputDeviceManager.this.k;
                if (hidConnectionCallback2 != null) {
                    hidConnectionCallback2.onConnectionStateChange(true);
                }
                BluetoothInputDeviceManager bluetoothInputDeviceManager2 = BluetoothInputDeviceManager.this;
                bluetoothInputDeviceManager2.k = null;
                bluetoothInputDeviceManager2.f4245h = null;
                return;
            }
            if ("android.bluetooth.device.action.BOND_STATE_CHANGED" == action) {
                switch (intent.getIntExtra("android.bluetooth.device.extra.BOND_STATE", Integer.MIN_VALUE)) {
                    case 10:
                        ZLogger.i(" Braodcast: RCU unpaired!");
                        BluetoothInputDeviceManager bluetoothInputDeviceManager3 = BluetoothInputDeviceManager.this;
                        if (!bluetoothInputDeviceManager3.f4246i) {
                            HidConnectionCallback hidConnectionCallback3 = bluetoothInputDeviceManager3.k;
                            if (hidConnectionCallback3 != null) {
                                hidConnectionCallback3.onConnectionStateChange(false);
                            }
                            BluetoothInputDeviceManager bluetoothInputDeviceManager4 = BluetoothInputDeviceManager.this;
                            bluetoothInputDeviceManager4.k = null;
                            bluetoothInputDeviceManager4.f4245h = null;
                            break;
                        } else {
                            bluetoothInputDeviceManager3.f4246i = false;
                            BluetoothInputDeviceManager.this.f4245h.createBond();
                            break;
                        }
                    case 11:
                        ZLogger.i(" Braodcast: RCU BONDING!");
                        break;
                    case 12:
                        ZLogger.i(" Braodcast: RCU BONDED!");
                        BluetoothInputDeviceManager bluetoothInputDeviceManager5 = BluetoothInputDeviceManager.this;
                        BluetoothDevice bluetoothDevice = bluetoothInputDeviceManager5.f4245h;
                        if (bluetoothDevice != null) {
                            bluetoothInputDeviceManager5.a(bluetoothDevice);
                            break;
                        }
                        break;
                }
            }
        }
    }

    public BluetoothInputDeviceManager(Context context) {
        super(context);
        BluetoothProfile.ServiceListener serviceListener = new BluetoothProfile.ServiceListener() { // from class: com.realsil.sdk.core.bluetooth.profile.BluetoothInputDeviceManager.1
            @Override // android.bluetooth.BluetoothProfile.ServiceListener
            public void onServiceConnected(int i2, BluetoothProfile bluetoothProfile) {
                if (4 == i2) {
                    try {
                        BluetoothInputDeviceManager.this.f4255f = bluetoothProfile.getClass().asSubclass(Class.forName(BluetoothInputDeviceImpl.CLASS_NAME));
                    } catch (ClassNotFoundException e2) {
                        e2.printStackTrace();
                    }
                    BluetoothInputDeviceManager.this.f4256g = bluetoothProfile;
                    ZLogger.i("get Bluetooth input device proxy");
                }
            }

            @Override // android.bluetooth.BluetoothProfile.ServiceListener
            public void onServiceDisconnected(int i2) {
                if (4 == i2) {
                    BluetoothInputDeviceManager bluetoothInputDeviceManager = BluetoothInputDeviceManager.this;
                    bluetoothInputDeviceManager.f4255f = null;
                    bluetoothInputDeviceManager.f4256g = null;
                    ZLogger.i("close Bluetooth input device proxy");
                }
            }
        };
        this.l = serviceListener;
        BluetoothAdapter bluetoothAdapter = this.f4251b;
        if (bluetoothAdapter != null) {
            bluetoothAdapter.getProfileProxy(context, serviceListener, 4);
        }
        this.f4247j = new RCUReconnectReceiver();
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.bluetooth.input.profile.action.CONNECTION_STATE_CHANGED");
        intentFilter.addAction("android.bluetooth.device.action.BOND_STATE_CHANGED");
        this.f4252c.registerReceiver(this.f4247j, intentFilter);
    }

    public static BluetoothInputDeviceManager getInstance() {
        return m;
    }

    public static void initial(Context context) {
        ZLogger.v("initial");
        m = new BluetoothInputDeviceManager(context);
    }

    public boolean checkProfileConnect() {
        if (this.f4255f != null) {
            return true;
        }
        ZLogger.d("checkProfileConnect(): profile not connect");
        return false;
    }

    public void close() {
        if (this.f4255f != null) {
            this.f4251b.closeProfileProxy(4, this.f4256g);
        }
        if (this.f4252c != null && this.f4247j != null) {
            try {
                ZLogger.d("unregisterReceiver");
                this.f4252c.unregisterReceiver(this.f4247j);
            } catch (Exception e2) {
                ZLogger.e(e2.toString());
            }
        }
        this.k = null;
    }

    public boolean connect(String str, HidConnectionCallback hidConnectionCallback) {
        return a(this.f4251b.getRemoteDevice(str), hidConnectionCallback);
    }

    public int getConnectionState(String str) {
        return getConnectionState(this.f4251b.getRemoteDevice(str));
    }

    public boolean isHidDevice(String str) {
        return isHidDevice(this.f4251b.getRemoteDevice(str));
    }

    public boolean isHogpConnect(String str) {
        return getConnectionState(str) == 2;
    }

    public static boolean isHidDevice(BluetoothDevice bluetoothDevice) {
        return BluetoothClassImpl.isHidDevice(bluetoothDevice.getBluetoothClass());
    }

    public final boolean a(BluetoothDevice bluetoothDevice, HidConnectionCallback hidConnectionCallback) {
        ZLogger.d("connect()");
        this.k = hidConnectionCallback;
        this.f4245h = bluetoothDevice;
        this.f4246i = false;
        if (!checkProfileConnect()) {
            return false;
        }
        if (bluetoothDevice.getBondState() != 12) {
            ZLogger.i("connect with not bond device, bond first, current state: " + bluetoothDevice.getBondState());
            bluetoothDevice.createBond();
            return false;
        }
        try {
            ZLogger.d("connect with bonded device, remove bond first.");
            Method method = bluetoothDevice.getClass().getMethod("removeBond", new Class[0]);
            if (method != null) {
                boolean booleanValue = ((Boolean) method.invoke(bluetoothDevice, new Object[0])).booleanValue();
                if (!booleanValue) {
                    return a(bluetoothDevice);
                }
                this.f4246i = booleanValue;
                ZLogger.d("removeBond(): result: " + booleanValue);
                return booleanValue;
            }
        } catch (Exception e2) {
            ZLogger.e("removeBond(): An exception occured, e = " + e2);
        }
        return a(bluetoothDevice);
    }

    public boolean isHogpConnect(BluetoothDevice bluetoothDevice) {
        return getConnectionState(bluetoothDevice) == 2;
    }

    public final boolean a(BluetoothDevice bluetoothDevice) {
        try {
            Method method = this.f4255f.getMethod(MqttServiceConstants.CONNECT_ACTION, BluetoothDevice.class);
            if (method != null) {
                boolean booleanValue = ((Boolean) method.invoke(this.f4256g, bluetoothDevice)).booleanValue();
                ZLogger.d("connect(): connect result: " + booleanValue);
                return booleanValue;
            }
        } catch (Exception e2) {
            ZLogger.e("connect(): An exception occured while connect device, e = " + e2);
        }
        return false;
    }
}
