package com.realsil.sdk.core.bluetooth.profile;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothManager;
import android.bluetooth.BluetoothProfile;
import android.content.Context;
import com.realsil.sdk.core.logger.ZLogger;
import java.lang.String;
import java.lang.reflect.Method;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

/* loaded from: classes3.dex */
public abstract class HideProfileManager<CN extends String> {

    /* renamed from: a, reason: collision with root package name */
    public BluetoothManager f4250a;

    /* renamed from: b, reason: collision with root package name */
    public BluetoothAdapter f4251b;

    /* renamed from: c, reason: collision with root package name */
    public Context f4252c;

    /* renamed from: d, reason: collision with root package name */
    public List<ProfileManagerCallback> f4253d;

    /* renamed from: e, reason: collision with root package name */
    public CN f4254e;

    /* renamed from: f, reason: collision with root package name */
    public Class f4255f;

    /* renamed from: g, reason: collision with root package name */
    public BluetoothProfile f4256g;

    public HideProfileManager(Context context) {
        this.f4252c = context.getApplicationContext();
        initialize();
    }

    public void addProfileManagerCallback(ProfileManagerCallback profileManagerCallback) {
        if (this.f4253d == null) {
            this.f4253d = new CopyOnWriteArrayList();
        }
        if (this.f4253d.contains(profileManagerCallback)) {
            return;
        }
        this.f4253d.add(profileManagerCallback);
    }

    public CN getClassName() {
        return this.f4254e;
    }

    public int getConnectionState(BluetoothDevice bluetoothDevice) {
        BluetoothAdapter bluetoothAdapter = this.f4251b;
        if (bluetoothAdapter == null || !bluetoothAdapter.isEnabled()) {
            ZLogger.w("BT not enabled");
            return -1;
        }
        Class cls = this.f4255f;
        if (cls == null) {
            ZLogger.w("not supported > " + this.f4255f.getName());
            return -1;
        }
        try {
            Method method = cls.getMethod("getConnectionState", BluetoothDevice.class);
            if (method != null) {
                Integer num = (Integer) method.invoke(this.f4256g, bluetoothDevice);
                ZLogger.d("result: " + num);
                return num.intValue();
            }
        } catch (Exception e2) {
            ZLogger.e("An exception occured,  " + e2.toString());
        }
        return -1;
    }

    public boolean initialize() {
        if (this.f4250a == null) {
            BluetoothManager bluetoothManager = (BluetoothManager) this.f4252c.getSystemService("bluetooth");
            this.f4250a = bluetoothManager;
            if (bluetoothManager == null) {
                ZLogger.w("Unable to initialize BluetoothManager.");
                return false;
            }
        }
        if (this.f4251b != null) {
            return true;
        }
        BluetoothAdapter adapter = this.f4250a.getAdapter();
        this.f4251b = adapter;
        if (adapter != null) {
            return true;
        }
        ZLogger.w("Unable to obtain a BluetoothAdapter.");
        return false;
    }

    public boolean isProfileSupported() {
        return this.f4255f != null;
    }

    public void removeProfileManagerCallback(ProfileManagerCallback profileManagerCallback) {
        List<ProfileManagerCallback> list = this.f4253d;
        if (list != null) {
            list.remove(profileManagerCallback);
        }
    }

    public void setClassName(CN cn2) {
        this.f4254e = cn2;
    }
}
