package com.realsil.sdk.core.bluetooth.profile;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothManager;
import android.bluetooth.BluetoothProfile;
import android.content.Context;
import com.realsil.sdk.core.logger.ZLogger;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

/* loaded from: classes3.dex */
public abstract class PublicProfileManager<BP extends BluetoothProfile> {

    /* renamed from: a, reason: collision with root package name */
    public BluetoothManager f4257a;

    /* renamed from: b, reason: collision with root package name */
    public BluetoothAdapter f4258b;

    /* renamed from: c, reason: collision with root package name */
    public Context f4259c;

    /* renamed from: d, reason: collision with root package name */
    public List<ProfileManagerCallback> f4260d;

    /* renamed from: e, reason: collision with root package name */
    public BP f4261e;

    public PublicProfileManager(Context context) {
        this.f4259c = context.getApplicationContext();
        initialize();
    }

    public void addProfileManagerCallback(ProfileManagerCallback profileManagerCallback) {
        if (this.f4260d == null) {
            this.f4260d = new CopyOnWriteArrayList();
        }
        if (this.f4260d.contains(profileManagerCallback)) {
            return;
        }
        this.f4260d.add(profileManagerCallback);
    }

    public BP getBluetoothProfile() {
        return this.f4261e;
    }

    public int getConnectionState(BluetoothDevice bluetoothDevice) {
        BluetoothAdapter bluetoothAdapter = this.f4258b;
        if (bluetoothAdapter == null || !bluetoothAdapter.isEnabled()) {
            ZLogger.w("BT not enabled");
            return -1;
        }
        if (getBluetoothProfile() != null) {
            return this.f4261e.getConnectionState(bluetoothDevice);
        }
        ZLogger.w("not supported > " + this.f4261e.getClass().getName());
        return -1;
    }

    public boolean initialize() {
        if (this.f4257a == null) {
            BluetoothManager bluetoothManager = (BluetoothManager) this.f4259c.getSystemService("bluetooth");
            this.f4257a = bluetoothManager;
            if (bluetoothManager == null) {
                ZLogger.w("Unable to initialize BluetoothManager.");
                return false;
            }
        }
        if (this.f4258b != null) {
            return true;
        }
        BluetoothAdapter adapter = this.f4257a.getAdapter();
        this.f4258b = adapter;
        if (adapter != null) {
            return true;
        }
        ZLogger.w("Unable to obtain a BluetoothAdapter.");
        return false;
    }

    public boolean isProfileSupported() {
        return getBluetoothProfile() != null;
    }

    public void removeProfileManagerCallback(ProfileManagerCallback profileManagerCallback) {
        List<ProfileManagerCallback> list = this.f4260d;
        if (list != null) {
            list.remove(profileManagerCallback);
        }
    }

    public void setBluetoothProfile(BP bp) {
        this.f4261e = bp;
    }
}
