package com.realsil.sdk.core.bluetooth.utils;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.Context;
import android.provider.Settings;
import com.facebook.internal.AnalyticsEvents;
import com.facebook.internal.security.CertificateUtil;
import com.realsil.sdk.core.bluetooth.impl.BluetoothDeviceImpl;
import com.realsil.sdk.core.bluetooth.impl.BluetoothGattImpl;
import com.realsil.sdk.core.logger.ZLogger;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;

/* loaded from: classes3.dex */
public final class BluetoothHelper {
    public static final int BD_ADDR_LEN = 6;
    public static final int BD_UUID_LEN = 16;

    public static String convertMac(byte[] bArr) {
        String str;
        String str2;
        String str3;
        String str4;
        String str5;
        if (bArr == null || bArr.length < 6) {
            return null;
        }
        if ((bArr[5] & 255) <= 15) {
            str = "0" + Integer.toHexString(bArr[5] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        } else {
            str = Integer.toHexString(bArr[5] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        }
        if ((bArr[4] & 255) <= 15) {
            str2 = str + "0" + Integer.toHexString(bArr[4] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        } else {
            str2 = str + Integer.toHexString(bArr[4] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        }
        if ((bArr[3] & 255) <= 15) {
            str3 = str2 + "0" + Integer.toHexString(bArr[3] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        } else {
            str3 = str2 + Integer.toHexString(bArr[3] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        }
        if ((bArr[2] & 255) <= 15) {
            str4 = str3 + "0" + Integer.toHexString(bArr[2] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        } else {
            str4 = str3 + Integer.toHexString(bArr[2] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        }
        if ((bArr[1] & 255) <= 15) {
            str5 = str4 + "0" + Integer.toHexString(bArr[1] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        } else {
            str5 = str4 + Integer.toHexString(bArr[1] & 255).toUpperCase() + CertificateUtil.DELIMITER;
        }
        if ((bArr[0] & 255) > 15) {
            return str5 + Integer.toHexString(bArr[0] & 255).toUpperCase();
        }
        return str5 + "0" + Integer.toHexString(bArr[0] & 255).toUpperCase();
    }

    public static void enableBle() {
        BluetoothAdapter defaultAdapter = BluetoothAdapter.getDefaultAdapter();
        if (defaultAdapter != null) {
            defaultAdapter.enable();
        }
    }

    public static String formatAddress(String str, boolean z) {
        if (!z) {
            return str;
        }
        if (str == null || str.length() != 17) {
            return "";
        }
        byte[] convertAddress = convertAddress(str);
        return convertAddress.length < 6 ? "" : String.format("**:**:**:%02X:%02X:%02X", Byte.valueOf(convertAddress[2]), Byte.valueOf(convertAddress[1]), Byte.valueOf(convertAddress[0]));
    }

    public static String formatAddressNegatitive(byte[] bArr) {
        if (bArr == null || bArr.length < 6) {
            return null;
        }
        return String.format("%02X:%02X:%02X:%02X:%02X:%02X", Byte.valueOf(bArr[5]), Byte.valueOf(bArr[4]), Byte.valueOf(bArr[3]), Byte.valueOf(bArr[2]), Byte.valueOf(bArr[1]), Byte.valueOf(bArr[0]));
    }

    public static String formatAddressPositive(byte[] bArr) {
        if (bArr == null || bArr.length < 6) {
            return null;
        }
        return String.format("%02X:%02X:%02X:%02X:%02X:%02X", Byte.valueOf(bArr[0]), Byte.valueOf(bArr[1]), Byte.valueOf(bArr[2]), Byte.valueOf(bArr[3]), Byte.valueOf(bArr[4]), Byte.valueOf(bArr[5]));
    }

    public static String getBluetoothAddress(Context context, BluetoothAdapter bluetoothAdapter) {
        if (bluetoothAdapter != null) {
            Class<?> cls = bluetoothAdapter.getClass();
            try {
                Class<?> cls2 = Class.forName("android.bluetooth.IBluetooth");
                Field declaredField = cls.getDeclaredField("mService");
                declaredField.setAccessible(true);
                Method method = cls2.getMethod("getAddress", new Class[0]);
                method.setAccessible(true);
                return (String) method.invoke(declaredField.get(bluetoothAdapter), new Object[0]);
            } catch (Exception e2) {
                ZLogger.e(e2.toString());
            }
        } else if (context != null) {
            return Settings.Secure.getString(context.getContentResolver(), "bluetooth_address");
        }
        return null;
    }

    public static List<BluetoothDevice> getBondedBluetoothDevices() {
        ArrayList arrayList = new ArrayList();
        try {
            for (BluetoothDevice bluetoothDevice : BluetoothAdapter.getDefaultAdapter().getBondedDevices()) {
                if (BluetoothDeviceImpl.isConnected(bluetoothDevice)) {
                    ZLogger.v("connected: " + formatAddress(bluetoothDevice.getAddress(), true));
                    arrayList.add(bluetoothDevice);
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        return arrayList;
    }

    public static String getCharPermission(int i2) {
        return BluetoothGattImpl.getCharPermission(i2);
    }

    public static String getCharPropertie(int i2) {
        return BluetoothGattImpl.getCharPropertie(i2);
    }

    public static List<BluetoothDevice> getConnectedBluetoothDevices() {
        ArrayList arrayList = new ArrayList();
        BluetoothAdapter defaultAdapter = BluetoothAdapter.getDefaultAdapter();
        try {
            Method declaredMethod = BluetoothAdapter.class.getDeclaredMethod("getConnectionState", null);
            declaredMethod.setAccessible(true);
            if (((Integer) declaredMethod.invoke(defaultAdapter, null)).intValue() == 2) {
                for (BluetoothDevice bluetoothDevice : defaultAdapter.getBondedDevices()) {
                    if (BluetoothDeviceImpl.isConnected(bluetoothDevice)) {
                        ZLogger.v("connected: " + formatAddress(bluetoothDevice.getAddress(), true));
                        arrayList.add(bluetoothDevice);
                    }
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        return arrayList;
    }

    public static String getDescPermission(int i2) {
        return BluetoothGattImpl.getDescPermission(i2);
    }

    public static boolean isBleEnabled() {
        BluetoothAdapter defaultAdapter = BluetoothAdapter.getDefaultAdapter();
        return defaultAdapter != null && defaultAdapter.isEnabled();
    }

    public static boolean isBleSupported(Context context) {
        return context.getPackageManager().hasSystemFeature("android.hardware.bluetooth_le");
    }

    public static String parseDeviceType(int i2) {
        return BluetoothDeviceImpl.parseDeviceType(i2);
    }

    public static String parseProfile(int i2) {
        if (i2 == 16) {
            return "HEADSET_CLIENT";
        }
        if (i2 == 17) {
            return "PBAP_CLIENT";
        }
        switch (i2) {
            case 1:
                return "HEADSET";
            case 2:
                return "A2DP";
            case 3:
                return "HEALTH";
            case 4:
                return "HID_HOST";
            case 5:
                return "PAN";
            case 6:
                return "PBAP";
            case 7:
                return "GATT";
            case 8:
                return "GATT_SERVER";
            case 9:
                return "MAP";
            case 10:
                return "SAP";
            case 11:
                return "A2DP_SINK";
            case 12:
                return "AVRCP_CONTROLLER";
            default:
                return AnalyticsEvents.PARAMETER_DIALOG_OUTCOME_VALUE_UNKNOWN;
        }
    }

    public static String parseProfileState(int i2) {
        if (i2 == 0) {
            return "0-BluetoothProfile.STATE_DISCONNECTED";
        }
        if (i2 == 1) {
            return "1-BluetoothProfile.STATE_CONNECTING";
        }
        if (i2 == 2) {
            return "2-BluetoothProfile.STATE_CONNECTED";
        }
        if (i2 == 3) {
            return "3-BluetoothProfile.STATE_DISCONNECTING";
        }
        return "UNKNOWN (" + i2 + ")";
    }

    public static List<String> parseProperty(int i2) {
        return BluetoothGattImpl.parseProperty(i2);
    }

    public static String parseProperty2(int i2) {
        return BluetoothGattImpl.parseProperty2(i2);
    }

    public static byte[] convertAddress(String str) {
        byte[] bArr = new byte[6];
        if (str != null) {
            bArr[0] = (byte) ((Character.digit(str.charAt(15), 16) * 16) + Character.digit(str.charAt(16), 16));
            bArr[1] = (byte) ((Character.digit(str.charAt(12), 16) * 16) + Character.digit(str.charAt(13), 16));
            bArr[2] = (byte) ((Character.digit(str.charAt(9), 16) * 16) + Character.digit(str.charAt(10), 16));
            bArr[3] = (byte) ((Character.digit(str.charAt(6), 16) * 16) + Character.digit(str.charAt(7), 16));
            bArr[4] = (byte) ((Character.digit(str.charAt(3), 16) * 16) + Character.digit(str.charAt(4), 16));
            bArr[5] = (byte) ((Character.digit(str.charAt(0), 16) * 16) + Character.digit(str.charAt(1), 16));
        } else {
            bArr[0] = 0;
            bArr[1] = 0;
            bArr[2] = 0;
            bArr[3] = 0;
            bArr[4] = 0;
            bArr[5] = 0;
        }
        return bArr;
    }

    public static String formatAddress(byte[] bArr, boolean z) {
        return (bArr == null || bArr.length < 6) ? "" : z ? String.format("**:**:**:%02X:%02X:%02X", Byte.valueOf(bArr[3]), Byte.valueOf(bArr[4]), Byte.valueOf(bArr[5])) : String.format("%02X:%02X:%02X:%02X:%02X:%02X", Byte.valueOf(bArr[0]), Byte.valueOf(bArr[1]), Byte.valueOf(bArr[2]), Byte.valueOf(bArr[3]), Byte.valueOf(bArr[4]), Byte.valueOf(bArr[5]));
    }

    public static List<BluetoothDevice> getConnectedBluetoothDevices(int i2) {
        ArrayList arrayList = new ArrayList();
        BluetoothAdapter defaultAdapter = BluetoothAdapter.getDefaultAdapter();
        try {
            if (defaultAdapter.getProfileConnectionState(i2) == 2) {
                for (BluetoothDevice bluetoothDevice : defaultAdapter.getBondedDevices()) {
                    if (BluetoothDeviceImpl.isConnected(bluetoothDevice)) {
                        ZLogger.v("connected: " + formatAddress(bluetoothDevice.getAddress(), true));
                        arrayList.add(bluetoothDevice);
                    }
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        return arrayList;
    }
}
