package com.realsil.sdk.dfu.image.pack;

import android.content.Context;
import androidx.core.view.MotionEventCompat;
import androidx.core.view.ViewCompat;
import com.google.firebase.crashlytics.buildtools.reloc.com.google.common.base.Ascii;
import com.realsil.sdk.core.logger.ZLogger;
import com.realsil.sdk.dfu.i.a;
import com.realsil.sdk.dfu.image.stream.BaseBinInputStream;
import java.io.IOException;
import java.nio.BufferUnderflowException;
import java.util.Locale;

/* loaded from: classes3.dex */
public class SubFileInfo {
    public static final int HEADER_SIZE = 12;
    public int bankBlockSize;
    public int binId;
    public int bitNumber;
    public int downloadAddr;
    public int fileLocation;
    public String filePath;
    public int icType;
    public int imageId;
    public int reserved;
    public byte[] sha256;
    public int size;
    public long startAddr;
    public int version = -1;

    public SubFileInfo(int i2, int i3, String str, int i4, int i5, long j2, int i6, int i7, int i8) {
        this.icType = i2;
        this.fileLocation = i3;
        this.filePath = str;
        this.bitNumber = i4;
        this.bankBlockSize = i5;
        this.startAddr = j2;
        this.downloadAddr = i6;
        this.size = i7;
        this.reserved = i8;
    }

    public static SubFileInfo builder(int i2, String str, int i3, int i4, long j2, byte[] bArr) {
        SubFileInfo subFileInfo = new SubFileInfo(i2, 0, str, i3, i4, j2, ((bArr[3] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[2] << 16) & 16711680) | ((bArr[1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | (bArr[0] & 255), ((bArr[7] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[6] << 16) & 16711680) | ((bArr[5] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | (bArr[4] & 255), 0);
        subFileInfo.a();
        return subFileInfo;
    }

    public static SubFileInfo builderFromAssets(Context context, int i2, String str, int i3, int i4, long j2, byte[] bArr) {
        SubFileInfo subFileInfo = new SubFileInfo(i2, 1, str, i3, i4, j2, ((bArr[3] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[2] << 16) & 16711680) | ((bArr[1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | (bArr[0] & 255), ((bArr[7] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[6] << 16) & 16711680) | ((bArr[5] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | (bArr[4] & 255), 0);
        subFileInfo.a(context);
        ZLogger.v(subFileInfo.toString());
        return subFileInfo;
    }

    public final void a() {
        BaseBinInputStream binInputStream = getBinInputStream(this.icType);
        if (binInputStream != null) {
            binInputStream.parseImageHeaderEx();
            this.version = binInputStream.getImageVersion();
            this.binId = binInputStream.getBinId();
            this.imageId = binInputStream.getImageId();
            this.sha256 = binInputStream.getSha256();
            try {
                binInputStream.close();
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
    }

    public BaseBinInputStream getAssetsBinInputStream(Context context, int i2) {
        try {
            BaseBinInputStream openAssetsInputStream = a.openAssetsInputStream(context, i2, this.filePath, this.startAddr);
            if (openAssetsInputStream != null) {
                openAssetsInputStream.setSha256(this.sha256);
            }
            return openAssetsInputStream;
        } catch (Exception e2) {
            ZLogger.e(e2.toString());
            return null;
        }
    }

    public BaseBinInputStream getBinInputStream(Context context, int i2) {
        try {
            BaseBinInputStream openAssetsInputStream = this.fileLocation == 1 ? a.openAssetsInputStream(context, i2, this.filePath, this.startAddr) : a.openFileInputStream(i2, this.filePath, this.startAddr);
            if (openAssetsInputStream != null) {
                openAssetsInputStream.setSha256(this.sha256);
            }
            return openAssetsInputStream;
        } catch (Exception e2) {
            ZLogger.e(e2.toString());
            return null;
        }
    }

    public String toString() {
        return String.format(Locale.US, "icType=0x%02X, bitNumber=%d(%d）, binId=0x%04X, imageId=0x%04X, startAddr=%d, downloadAddr=0x%08x, size(include mp header+data)=0x%08x(%d), reserved=%d", Integer.valueOf(this.icType), Integer.valueOf(this.bitNumber), Integer.valueOf(this.bankBlockSize), Integer.valueOf(this.binId), Integer.valueOf(this.imageId), Long.valueOf(this.startAddr), Integer.valueOf(this.downloadAddr), Integer.valueOf(this.size), Integer.valueOf(this.size), Integer.valueOf(this.reserved));
    }

    public int wrapperBitNumber() {
        int i2 = this.bankBlockSize;
        return i2 == 0 ? this.bitNumber : this.bitNumber % i2;
    }

    public BaseBinInputStream getBinInputStream(int i2) {
        try {
            BaseBinInputStream openFileInputStream = a.openFileInputStream(i2, this.filePath, this.startAddr);
            if (openFileInputStream != null) {
                openFileInputStream.setSha256(this.sha256);
            }
            return openFileInputStream;
        } catch (Exception e2) {
            ZLogger.e(e2.toString());
            return null;
        }
    }

    public final void a(Context context) {
        try {
            BaseBinInputStream assetsBinInputStream = getAssetsBinInputStream(context, this.icType);
            if (assetsBinInputStream != null) {
                assetsBinInputStream.parseImageHeaderEx();
                this.version = assetsBinInputStream.getImageVersion();
                this.binId = assetsBinInputStream.getBinId();
                this.imageId = assetsBinInputStream.getImageId();
                this.sha256 = assetsBinInputStream.getSha256();
                assetsBinInputStream.close();
            }
        } catch (IOException | BufferUnderflowException e2) {
            e2.printStackTrace();
            ZLogger.e(e2.toString());
        }
    }
}
