package com.realsil.sdk.dfu.internal.base;

import android.content.Context;
import android.text.TextUtils;
import com.realsil.sdk.core.logger.ZLogger;
import com.realsil.sdk.core.utility.FileUtils;
import com.realsil.sdk.dfu.DfuConstants;
import com.realsil.sdk.dfu.RtkDfu;
import com.realsil.sdk.dfu.h.a;
import com.realsil.sdk.dfu.image.stream.BaseBinInputStream;
import com.realsil.sdk.dfu.model.BinInfo;
import com.realsil.sdk.dfu.model.DfuConfig;
import com.realsil.sdk.dfu.model.DfuProgressInfo;
import com.realsil.sdk.dfu.model.OtaDeviceInfo;
import com.realsil.sdk.dfu.utils.AesJni;
import com.realsil.sdk.dfu.utils.DfuUtils;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Locale;

/* loaded from: classes3.dex */
public abstract class BaseDfuTask extends Thread {

    /* renamed from: f, reason: collision with root package name */
    public DfuConfig f4434f;

    /* renamed from: h, reason: collision with root package name */
    public byte[] f4436h;

    /* renamed from: i, reason: collision with root package name */
    public AesJni f4437i;
    public boolean imageFileLoaded;
    public boolean initialized;

    /* renamed from: j, reason: collision with root package name */
    public String f4438j;
    public volatile boolean lastPacketTransferred;
    public boolean mAborted;
    public BinInfo mBinIno;
    public int mBytesSentBuffer;
    public Context mContext;
    public BaseBinInputStream mCurBinInputStream;
    public String mDeviceAddress;
    public volatile int mErrorState;
    public BaseBinInputStream mNextBinInputStream;
    public String mOtaDeviceAddress;
    public OtaDeviceInfo mOtaDeviceInfo;
    public String mOtaDeviceName;
    public volatile boolean mReadRequestCompleted;
    public DfuThreadCallback mThreadCallback;
    public volatile boolean mWriteRequestCompleted;
    public volatile int mWriteRequestStatus;
    public volatile boolean mWriteRetransFlag;
    public DfuProgressInfo n;
    public boolean otaEnvironmentPrepared;
    public boolean otaModeEnabled;
    public a u;
    public boolean DBG = false;
    public boolean VDBG = false;

    /* renamed from: e, reason: collision with root package name */
    public int f4433e = 0;
    public volatile boolean isConnectedCallbackCome = false;
    public final Object mConnectionLock = new Object();
    public int mConnectionState = 0;
    public final Object mReadLock = new Object();
    public volatile byte[] mReadRxData = null;

    /* renamed from: g, reason: collision with root package name */
    public final Object f4435g = new Object();
    public volatile int mProcessState = 257;
    public List<BaseBinInputStream> pendingImageInputStreams = new ArrayList();
    public int k = -1;
    public int mOtaWorkMode = 0;
    public boolean l = false;
    public int MAX_PACKET_SIZE = 20;
    public final Object m = new Object();
    public int o = 0;
    public int mImageUpdateOffset = 0;
    public int p = 256;
    public int q = 16;
    public boolean r = false;
    public final Object s = new Object();
    public final Object t = new Object();

    public BaseDfuTask(Context context, DfuConfig dfuConfig, DfuThreadCallback dfuThreadCallback) {
        this.mContext = context;
        this.f4434f = dfuConfig;
        this.mThreadCallback = dfuThreadCallback;
    }

    public void a(long j2) {
        try {
            ZLogger.v("wait device auto reconnect for " + j2);
            synchronized (this.t) {
                this.t.wait(j2);
            }
        } catch (InterruptedException e2) {
            e2.printStackTrace();
        }
    }

    public boolean abort() {
        if (isIdle()) {
            ZLogger.d("already in idle state");
        } else {
            this.mAborted = true;
            notifyStateChanged(525, true);
            abortInner();
        }
        e();
        synchronized (this.mReadLock) {
            this.mReadLock.notifyAll();
        }
        synchronized (this.mConnectionLock) {
            this.mConnectionLock.notifyAll();
        }
        f();
        return true;
    }

    public void abortInner() {
    }

    public boolean activeImage(boolean z) {
        if (this.mProcessState == 523) {
            return true;
        }
        ZLogger.w(String.format("activeImage failed, state conflict: 0x%04X", Integer.valueOf(this.mProcessState)));
        return false;
    }

    public void alignmentSendBytes(int i2, boolean z) {
        int i3 = 0;
        if (i2 != 0) {
            try {
                int max = Math.max(i2 - 12, 0);
                byte[] bArr = new byte[getDfuProgressInfo().getImageSizeInBytes()];
                i3 = z ? this.mCurBinInputStream.read(bArr, max) : this.mCurBinInputStream.read(bArr, 0, max);
            } catch (IOException e2) {
                ZLogger.e(e2.toString());
                return;
            }
        }
        getDfuProgressInfo().setBytesSent(i3);
    }

    public boolean b() {
        if (this.f4437i == null) {
            this.f4437i = new AesJni();
        }
        if (this.f4437i.aesInit(3, this.f4436h)) {
            return true;
        }
        if (!this.DBG) {
            ZLogger.w("encrpt initial error, encrypted key invalid!");
            return false;
        }
        ZLogger.w("encrpt initial error, encrypted key: " + Arrays.toString(this.f4436h));
        return false;
    }

    public void blockSpeedControl() {
        a aVar = this.u;
        if (aVar != null) {
            aVar.a();
        }
    }

    public void c() {
        this.u = new a(getDfuConfig().isFlowControlEnabled(), getDfuConfig().getFlowControlInterval());
    }

    public void closeInputStream(InputStream inputStream) {
        if (inputStream != null) {
            try {
                if (this.DBG) {
                    ZLogger.v("closeInputStream...");
                }
                inputStream.close();
            } catch (IOException e2) {
                ZLogger.e("closeInputStream fail: " + e2.toString());
            }
        }
    }

    public boolean d() {
        return (this.mConnectionState & 512) == 512;
    }

    public void e() {
        synchronized (this.m) {
            this.m.notifyAll();
        }
    }

    public void executeOtaProcedure() {
    }

    public void f() {
        try {
            synchronized (this.t) {
                this.t.notifyAll();
            }
        } catch (Exception e2) {
            ZLogger.e(e2.toString());
        }
    }

    public void g() {
        synchronized (this.f4435g) {
            this.mWriteRequestCompleted = true;
            this.f4435g.notifyAll();
        }
    }

    public DfuConfig getDfuConfig() {
        if (this.f4434f == null) {
            this.f4434f = new DfuConfig();
        }
        return this.f4434f;
    }

    public DfuProgressInfo getDfuProgressInfo() {
        if (this.n == null) {
            this.n = new DfuProgressInfo();
        }
        return this.n;
    }

    public OtaDeviceInfo getOtaDeviceInfo() {
        if (this.mOtaDeviceInfo == null) {
            this.mOtaDeviceInfo = new OtaDeviceInfo(this.f4433e, 2);
        }
        return this.mOtaDeviceInfo;
    }

    public int getProcessState() {
        return this.mProcessState;
    }

    public void h() {
        a(5000L);
    }

    public void initialize() {
        notifyStateChanged(513, true);
        this.initialized = false;
        this.mAborted = false;
        this.r = false;
        this.f4437i = new AesJni();
        this.otaEnvironmentPrepared = false;
        this.imageFileLoaded = false;
        this.pendingImageInputStreams = new ArrayList();
        this.mBytesSentBuffer = 0;
        this.n = new DfuProgressInfo();
        this.mErrorState = 0;
        if (getDfuConfig().getLogLevel() != 0) {
            this.DBG = true;
        } else {
            this.DBG = RtkDfu.DEBUG_ENABLE;
        }
        if (this.DBG) {
            ZLogger.d(getDfuConfig().toString());
        }
        this.f4433e = getDfuConfig().getProtocolType();
        this.mDeviceAddress = getDfuConfig().getAddress();
        this.mOtaWorkMode = getDfuConfig().getOtaWorkMode();
        this.f4438j = getDfuConfig().getFilePath();
        this.k = getDfuConfig().getFileIndicator();
        this.f4436h = getDfuConfig().getSecretKey();
        this.l = getDfuConfig().isAutomaticActiveEnabled();
        this.MAX_PACKET_SIZE = getDfuConfig().getPrimaryMtuSize();
    }

    public int innerCheck() {
        if (!this.initialized) {
            ZLogger.w("DfuThread not initialized");
            return 4114;
        }
        if (TextUtils.isEmpty(this.f4438j)) {
            ZLogger.w("the file path string is null");
            return 4098;
        }
        String suffix = FileUtils.getSuffix(this.f4438j);
        if (suffix == null || !suffix.equalsIgnoreCase(getDfuConfig().getFileSuffix())) {
            ZLogger.w("the file suffix is not right, suffix=" + suffix);
            return 4099;
        }
        if (getDfuConfig().getFileLocation() == 1) {
            if (DfuUtils.isAssetsFileExist(this.mContext, this.f4438j)) {
                return 0;
            }
            ZLogger.w("the bin file not exist, path: " + this.f4438j);
            return 4100;
        }
        if (FileUtils.exists(this.f4438j)) {
            return 0;
        }
        ZLogger.w("the bin file not exist, path: " + this.f4438j);
        return 4100;
    }

    public boolean isIdle() {
        return (this.mProcessState & 256) == 256;
    }

    public void notifyConnectionLock() {
        try {
            synchronized (this.mConnectionLock) {
                this.isConnectedCallbackCome = true;
                if (this.VDBG) {
                    ZLogger.v(String.format("isConnectedCallbackCome=%b", Boolean.valueOf(this.isConnectedCallbackCome)));
                }
                this.mConnectionLock.notifyAll();
            }
        } catch (Exception e2) {
            ZLogger.e(e2.toString());
        }
    }

    public void notifyProcessChanged() {
        this.lastPacketTransferred = getDfuProgressInfo().isFileSendOver();
        DfuThreadCallback dfuThreadCallback = this.mThreadCallback;
        if (dfuThreadCallback != null) {
            dfuThreadCallback.onProgressChanged(getDfuProgressInfo());
        } else {
            ZLogger.v(this.VDBG, "no ThreadCallback registed ");
        }
    }

    public void notifyReadLock() {
        synchronized (this.mReadLock) {
            this.mReadRequestCompleted = true;
            this.mReadLock.notifyAll();
        }
    }

    public void notifyStateChanged(int i2) {
        notifyStateChanged(i2, true);
    }

    public void onDestroy() {
    }

    @Override // java.lang.Thread, java.lang.Runnable
    public void run() {
        super.run();
        setName("DFU");
        executeOtaProcedure();
        onDestroy();
    }

    public void setConnectionState(int i2) {
        ZLogger.d(String.format("Conn: 0x%04X >> 0x%04X(%s)", Integer.valueOf(this.mConnectionState), Integer.valueOf(i2), DfuConstants.parseConnectionState(i2)));
        this.mConnectionState = i2;
    }

    public void startSpeedControl() {
        if (this.u == null) {
            c();
        }
        this.u.b();
    }

    public void waitUntilDisconnected() {
        try {
        } catch (InterruptedException e2) {
            ZLogger.e("waitUntilDisconnected interrupted: " + e2.toString());
        }
        synchronized (this.mConnectionLock) {
            int i2 = this.mConnectionState;
            if (i2 == 0 || i2 == 1280) {
                if (this.DBG) {
                    ZLogger.d("connection already disconnected");
                }
                return;
            }
            if (this.DBG) {
                ZLogger.v("wait for disconnect, wait for 32000ms");
            }
            this.mConnectionLock.wait(32000L);
            int i3 = this.mConnectionState;
            if (i3 != 0 && i3 != 1280) {
                ZLogger.d("waitUntilDisconnected timeout");
            } else if (this.DBG) {
                ZLogger.d("connection disconnected");
            }
        }
    }

    public void notifyStateChanged(int i2, boolean z) {
        ZLogger.d(String.format("DFU: 0x%04X >> 0x%04X(%s)", Integer.valueOf(this.mProcessState), Integer.valueOf(i2), DfuConstants.parseOtaState(i2)));
        this.mProcessState = i2;
        if (!z) {
            ZLogger.d("no need to notify state change");
            return;
        }
        DfuThreadCallback dfuThreadCallback = this.mThreadCallback;
        if (dfuThreadCallback != null) {
            dfuThreadCallback.onStateChanged(this.mProcessState, null);
        } else {
            ZLogger.d("no callback registed");
        }
    }

    public static byte[] convertAddress(String str) {
        byte[] bArr = new byte[6];
        if (str != null) {
            bArr[5] = (byte) ((Character.digit(str.charAt(15), 16) * 16) + Character.digit(str.charAt(16), 16));
            bArr[4] = (byte) ((Character.digit(str.charAt(12), 16) * 16) + Character.digit(str.charAt(13), 16));
            bArr[3] = (byte) ((Character.digit(str.charAt(9), 16) * 16) + Character.digit(str.charAt(10), 16));
            bArr[2] = (byte) ((Character.digit(str.charAt(6), 16) * 16) + Character.digit(str.charAt(7), 16));
            bArr[1] = (byte) ((Character.digit(str.charAt(3), 16) * 16) + Character.digit(str.charAt(4), 16));
            bArr[0] = (byte) ((Character.digit(str.charAt(0), 16) * 16) + Character.digit(str.charAt(1), 16));
        } else {
            bArr[0] = 0;
            bArr[1] = 0;
            bArr[2] = 0;
            bArr[3] = 0;
            bArr[4] = 0;
            bArr[5] = 0;
        }
        return bArr;
    }

    public boolean a() {
        return !this.mAborted;
    }

    public void a(int i2) {
        int max = Math.max(16, i2);
        this.p = max;
        ZLogger.v(this.DBG, String.format(Locale.US, "mCurrentMaxBufferSize= %d", Integer.valueOf(max)));
    }

    public void a(BaseBinInputStream baseBinInputStream) {
        if (getDfuProgressInfo().getImageSizeInBytes() <= 102400 || getDfuProgressInfo().getBytesSent() != 104000) {
            return;
        }
        try {
            getDfuProgressInfo().setBytesSent(143348);
            baseBinInputStream.skip(39348);
            ZLogger.d("big image reach the special size, skip some packet");
        } catch (IOException e2) {
            e2.printStackTrace();
        }
    }

    public short a(byte[] bArr, int i2) {
        short s = 0;
        for (int i3 = 0; i3 < i2; i3 += 2) {
            s = (short) (s ^ ((short) ((bArr[i3 + 1] << 8) | (bArr[i3] & 255))));
        }
        return (short) (((s & 255) << 8) | ((65280 & s) >> 8));
    }
}
