package com.realsil.sdk.dfu.m;

import android.content.Context;
import com.realsil.sdk.core.bluetooth.scanner.ScannerParams;
import com.realsil.sdk.core.bluetooth.scanner.compat.CompatScanFilter;
import com.realsil.sdk.core.logger.ZLogger;
import com.realsil.sdk.dfu.DfuConstants;
import com.realsil.sdk.dfu.DfuException;
import com.realsil.sdk.dfu.exception.OtaException;
import com.realsil.sdk.dfu.image.stream.BaseBinInputStream;
import com.realsil.sdk.dfu.internal.base.DfuThreadCallback;
import com.realsil.sdk.dfu.model.DfuConfig;
import com.realsil.sdk.dfu.model.OtaDeviceInfo;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.Locale;
import kotlin.UShort;

/* loaded from: classes3.dex */
public class e extends c {
    public e(Context context, DfuConfig dfuConfig, DfuThreadCallback dfuThreadCallback) {
        super(context, dfuConfig, dfuThreadCallback);
    }

    public final boolean A() {
        while (a()) {
            try {
                if (!z() || !D()) {
                    return false;
                }
                this.mBytesSentBuffer += getDfuProgressInfo().getBytesSent();
                if (getDfuProgressInfo().isLastImageFile()) {
                    ZLogger.d("no pendding image file to upload.");
                    if (getOtaDeviceInfo().specVersion >= 2) {
                        a(getDfuProgressInfo().getCurImageId(), (byte) 1);
                    } else {
                        g(getDfuProgressInfo().getCurImageId());
                    }
                    getDfuProgressInfo().setActiveImageSize(this.mBytesSentBuffer);
                    return true;
                }
                ZLogger.d("has pendding image file to upload");
                if (getOtaDeviceInfo().getUpdateMechanism() == 1) {
                    if (getOtaDeviceInfo().specVersion >= 2) {
                        a(getDfuProgressInfo().getCurImageId(), (byte) 1);
                    } else {
                        g(getDfuProgressInfo().getCurImageId());
                    }
                    this.mOtaDeviceAddress = this.mDeviceAddress;
                    this.otaModeEnabled = true;
                    this.mBytesSentBuffer = 0;
                    q();
                    h();
                } else if (getOtaDeviceInfo().getUpdateMechanism() == 3) {
                    BaseBinInputStream baseBinInputStream = this.mNextBinInputStream;
                    if (baseBinInputStream != null) {
                        ZLogger.v(String.format(Locale.US, "nextBinSize=%d, mBytesSentBuffer=%d, otaTempBufferSize=%d", Integer.valueOf(baseBinInputStream.remainSizeInBytes()), Integer.valueOf(this.mBytesSentBuffer), Integer.valueOf(getOtaDeviceInfo().otaTempBufferSize * 4096)));
                        if (this.mNextBinInputStream.remainSizeInBytes() + this.mBytesSentBuffer > getOtaDeviceInfo().otaTempBufferSize * 4096) {
                            if (getOtaDeviceInfo().specVersion >= 2) {
                                a(getDfuProgressInfo().getCurImageId(), (byte) 1);
                            } else {
                                g(getDfuProgressInfo().getCurImageId());
                            }
                            ZLogger.i("make device to enter the ota advertiser mode, and let the app continue update image");
                            this.otaModeEnabled = true;
                            this.mBytesSentBuffer = 0;
                            a((byte) 1);
                            h();
                        } else if (getOtaDeviceInfo().specVersion >= 2) {
                            a(getDfuProgressInfo().getCurImageId(), (byte) 0);
                        } else {
                            g(getDfuProgressInfo().getCurImageId());
                        }
                    } else if (getOtaDeviceInfo().specVersion >= 2) {
                        a(getDfuProgressInfo().getCurImageId(), (byte) 1);
                    } else {
                        g(getDfuProgressInfo().getCurImageId());
                    }
                } else if (getOtaDeviceInfo().specVersion >= 2) {
                    a(getDfuProgressInfo().getCurImageId(), (byte) 0);
                } else {
                    g(getDfuProgressInfo().getCurImageId());
                }
                try {
                    Thread.sleep(1000L);
                } catch (InterruptedException e2) {
                    e2.printStackTrace();
                }
            } catch (DfuException e3) {
                ZLogger.e(DfuConstants.parseOtaState(this.mProcessState) + ", " + e3.toString());
                int errCode = e3.getErrCode();
                if (errCode == 4128) {
                    a(errCode, true);
                } else if (errCode == 4097 || errCode == 265) {
                    a(errCode, false);
                } else {
                    x();
                    a(errCode, false);
                }
                return false;
            }
        }
        a(DfuException.ERROR_DFU_ABORTED, true);
        return false;
    }

    public final void B() throws DfuException {
        this.otaEnvironmentPrepared = false;
        notifyStateChanged(517);
        try {
            Thread.sleep(1500L);
        } catch (InterruptedException e2) {
            e2.printStackTrace();
        }
        this.mOtaDeviceInfo = new OtaDeviceInfo(16, 2);
        u();
        if (getOtaDeviceInfo().isRwsEnabled() && getOtaDeviceInfo().getRwsUpdateFlag() != 0) {
            throw new OtaException("rws state not ready", 282);
        }
        v();
        s();
        w();
        if (this.DBG) {
            ZLogger.d(getOtaDeviceInfo().toString());
        }
        k();
        this.otaEnvironmentPrepared = true;
        ZLogger.d("Ota Environment prepared.");
    }

    public final int C() throws DfuException {
        if (this.W == null) {
            ZLogger.w("no mControlPointCharacteristic found");
            return 0;
        }
        if (this.mAborted) {
            throw new OtaException("user aborted", DfuException.ERROR_DFU_ABORTED);
        }
        ZLogger.d("<< OPCODE_DFU_ENABLE_BUFFER_CHECK_MODE(0x09)");
        a(this.W, new byte[]{9}, false);
        try {
            ZLogger.d(this.DBG, "... Reading OPCODE_DFU_ENABLE_BUFFER_CHECK_MODE notification");
            byte[] f2 = f(1600);
            if (f2[2] == 1) {
                ByteBuffer wrap = ByteBuffer.wrap(f2);
                wrap.order(ByteOrder.LITTLE_ENDIAN);
                int i2 = (((short) (wrap.get(4) & 255)) << 8) | ((short) (wrap.get(3) & 255));
                int i3 = ((short) (wrap.get(5) & 255)) | (((short) (wrap.get(6) & 255)) << 8);
                ZLogger.v(this.DBG, "maxBufferSize=" + i2 + ", bufferCheckMtuSize=" + i3);
                a(i2);
                b(i3);
                return 1;
            }
        } catch (DfuException unused) {
            ZLogger.w("Read DFU_REPORT_OTA_FUNCTION_VERSION failed, just think remote is normal function.");
            this.mErrorState = 0;
        }
        return 0;
    }

    public final boolean D() throws DfuException {
        if (!a()) {
            a(DfuException.ERROR_DFU_ABORTED, true);
            return false;
        }
        if (getOtaDeviceInfo().isAesEncryptEnabled() && !b()) {
            e(4113);
            return false;
        }
        notifyStateChanged(521);
        ZLogger.d(String.format("mOtaWorkMode=%s, ICType=%s", DfuConstants.parseOtaMode(this.mOtaWorkMode), DfuConstants.parseIcType(getOtaDeviceInfo().icType)));
        if (this.DBG) {
            ZLogger.v(getDfuProgressInfo().toString());
        }
        a(this.E, this.W, true);
        a(this.E, 256);
        ZLogger.d("isBufferCheckEnabled=" + getOtaDeviceInfo().isBufferCheckEnabled());
        if (getOtaDeviceInfo().isBufferCheckEnabled()) {
            this.o = C();
        } else {
            this.o = 0;
        }
        ZLogger.v(this.DBG, "mRemoteOtaFunctionInfo=" + this.o);
        getDfuProgressInfo().start();
        h(getDfuProgressInfo().getCurImageId());
        if (!getDfuConfig().isBreakpointResumeEnabled()) {
            this.mImageUpdateOffset = 0;
            ZLogger.d(String.format(Locale.US, "BreakpointResume disable: mImageUpdateOffset=0x%08X(%d)", 0, Integer.valueOf(this.mImageUpdateOffset)));
        }
        if (this.mImageUpdateOffset == 0) {
            y();
        }
        if (this.mImageUpdateOffset - 12 >= getDfuProgressInfo().getImageSizeInBytes()) {
            ZLogger.d("Last send reach the bottom");
        } else {
            i(getDfuProgressInfo().getCurImageId());
            if (this.o == 1) {
                b(this.E, this.X, this.mCurBinInputStream);
            } else {
                a(this.E, this.X, this.mCurBinInputStream);
            }
        }
        getDfuProgressInfo().sendOver();
        return true;
    }

    /* JADX WARN: Code restructure failed: missing block: B:30:0x00c5, code lost:
    
        if (r1.equals(r6.mDeviceAddress) != false) goto L40;
     */
    /* JADX WARN: Code restructure failed: missing block: B:31:0x0109, code lost:
    
        r1 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:52:0x0107, code lost:
    
        if (r1.equals(r0.getAddress()) != false) goto L40;
     */
    @Override // com.realsil.sdk.dfu.j.b
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public void a(com.realsil.sdk.core.bluetooth.scanner.ExtendedBluetoothDevice r7) {
        /*
            Method dump skipped, instructions count: 455
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.realsil.sdk.dfu.m.e.a(com.realsil.sdk.core.bluetooth.scanner.ExtendedBluetoothDevice):void");
    }

    @Override // com.realsil.sdk.dfu.internal.base.BaseDfuTask
    public boolean activeImage(boolean z) {
        if (!super.activeImage(z)) {
            return false;
        }
        if (this.mConnectionState != 515) {
            ZLogger.d(this.DBG, "start to re-connect the RCU which going to active image, current state is: " + this.mConnectionState);
            int a2 = a(this.mOtaDeviceAddress, getDfuConfig().getRetransConnectTimes());
            if (a2 != 0) {
                ZLogger.e(String.format("Something error in OTA process, errorCode: 0x%04X, mProcessState=0x%04X", Integer.valueOf(a2), Integer.valueOf(this.mProcessState)));
                a(a2, true);
                return false;
            }
        }
        if (z) {
            try {
                q();
                notifyStateChanged(258);
            } catch (DfuException e2) {
                e2.printStackTrace();
                e(e2.getErrCode());
            }
        } else {
            x();
            a(274, false);
        }
        return true;
    }

    public void d(ScannerParams scannerParams) throws DfuException {
        if (this.mAborted) {
            throw new OtaException("user aborted", DfuException.ERROR_DFU_ABORTED);
        }
        notifyStateChanged(527);
        this.mErrorState = 0;
        this.y = false;
        b(scannerParams);
        try {
            synchronized (this.x) {
                if (this.mErrorState == 0 && !this.y) {
                    this.x.wait(31000L);
                }
            }
        } catch (InterruptedException e2) {
            ZLogger.e("findRemoteDevice interrupted, e = " + e2.toString());
            this.mErrorState = 259;
        }
        if (this.mErrorState == 0 && !this.y) {
            ZLogger.w("didn't find the secondary bud device");
            this.mErrorState = 265;
        }
        if (this.mErrorState != 0) {
            throw new OtaException("Error while scan remote device", this.mErrorState);
        }
    }

    @Override // com.realsil.sdk.dfu.internal.base.BaseDfuTask
    public void executeOtaProcedure() {
        int innerCheck;
        super.executeOtaProcedure();
        try {
            setName("ProcessorXG0010S");
            ZLogger.d("ProcessorXG0010S running.");
            innerCheck = innerCheck();
        } catch (Exception e2) {
            e2.printStackTrace();
            ZLogger.e(e2.toString());
            e(0);
        }
        if (innerCheck != 0) {
            e(innerCheck);
            return;
        }
        notifyStateChanged(514);
        this.mOtaDeviceAddress = this.mDeviceAddress;
        this.otaModeEnabled = true;
        if (A()) {
            if (getOtaDeviceInfo().isRwsEnabled()) {
                q();
                notifyStateChanged(522);
                ZLogger.d("wait master to handover ...");
                ArrayList arrayList = new ArrayList();
                arrayList.add(new CompatScanFilter.Builder().setManufacturerData(getDfuConfig().getManufacturerId(), getOtaDeviceInfo().getRwsBdAddr()).build());
                ScannerParams m = m();
                m.setScanFilters(arrayList);
                d(m);
                ZLogger.d("start to upload secondary bud ...");
                this.otaModeEnabled = true;
                this.otaEnvironmentPrepared = false;
                this.mBytesSentBuffer = 0;
                if (A()) {
                    if (this.l) {
                        q();
                        notifyStateChanged(258);
                    } else {
                        notifyStateChanged(523);
                    }
                }
            } else if (this.l) {
                q();
                notifyStateChanged(258);
            } else {
                notifyStateChanged(523);
            }
        }
        closeInputStream(this.mCurBinInputStream);
        ZLogger.d(this.DBG, "ProcessorXG0010S stopped");
        onDestroy();
        if (this.mProcessState == 525) {
            notifyStateChanged(259);
        }
    }

    public final void h(int i2) throws DfuException {
        int i3;
        if (this.mAborted) {
            throw new OtaException("user aborted", DfuException.ERROR_DFU_ABORTED);
        }
        ZLogger.d(this.DBG, "<< OPCODE_DFU_REPORT_TARGET_IMAGE_INFO(0x06)");
        a(this.W, new byte[]{6, (byte) (i2 & 255), (byte) ((i2 >> 8) & 255)}, false);
        ZLogger.d(this.DBG, "... Reading OPCODE_DFU_REPORT_TARGET_IMAGE_INFO(0x06) notification");
        byte[] t = t();
        int length = t != null ? t.length : 0;
        if ((length > 2 ? t[2] : (byte) -2) != 1) {
            ZLogger.e(String.format("0x%04X, Get target image info failed", Integer.valueOf(DfuException.ERROR_OPCODE_RESPONSE_NOT_SUPPORTED)));
            throw new OtaException("Get target image info failed", DfuException.ERROR_OPCODE_RESPONSE_NOT_SUPPORTED);
        }
        ByteBuffer wrap = ByteBuffer.wrap(t);
        wrap.order(ByteOrder.LITTLE_ENDIAN);
        if (length >= 11) {
            i3 = wrap.getShort(3) & UShort.MAX_VALUE;
            this.mImageUpdateOffset = wrap.getInt(7);
        } else if (length >= 9) {
            i3 = wrap.getShort(3) & UShort.MAX_VALUE;
            this.mImageUpdateOffset = wrap.getInt(5);
        } else {
            this.mImageUpdateOffset = 0;
            i3 = 0;
        }
        ZLogger.d(String.format(Locale.US, "mOriginalFwVersion=%d, mImageUpdateOffset=0x%08X(%d)", Integer.valueOf(i3), Integer.valueOf(this.mImageUpdateOffset), Integer.valueOf(this.mImageUpdateOffset)));
    }

    public final void i(int i2) throws DfuException {
        int i3 = this.mImageUpdateOffset;
        if (i3 == 0) {
            if (getOtaDeviceInfo().specVersion < 2) {
                this.mImageUpdateOffset = 12;
            }
            ZLogger.d(this.DBG, String.format(Locale.US, "First Packet, mImageUpdateOffset=0x%08X(%d)", Integer.valueOf(this.mImageUpdateOffset), Integer.valueOf(this.mImageUpdateOffset)));
        } else {
            ZLogger.d(this.DBG, String.format(Locale.US, "mImageUpdateOffset=0x%08X(%d)", Integer.valueOf(i3), Integer.valueOf(this.mImageUpdateOffset)));
        }
        a(i2, this.mImageUpdateOffset);
        int bytesSent = getDfuProgressInfo().getBytesSent();
        int i4 = this.mImageUpdateOffset;
        if (bytesSent == i4 || i4 == -1) {
            return;
        }
        ZLogger.d("mBytesSent != mImageUpdateOffset, reload image bin file");
        this.imageFileLoaded = false;
        k();
        alignmentSendBytes(this.mImageUpdateOffset, false);
    }

    public final boolean z() throws DfuException {
        d(this.mOtaDeviceAddress);
        int r = r();
        if (r != 0) {
            throw new OtaException("load dfu service failed", r);
        }
        if (this.otaEnvironmentPrepared) {
            j();
        } else {
            B();
        }
        if (this.mCurBinInputStream != null) {
            return true;
        }
        e(4097);
        return false;
    }

    public final void d(String str) throws DfuException {
        if (!this.mAborted) {
            notifyStateChanged(516);
            int a2 = a(str, getDfuConfig().getRetransConnectTimes());
            if (a2 == 0) {
                return;
            }
            if (a2 != 4128) {
                a(m());
                if (!this.mAborted) {
                    int a3 = a(str, getDfuConfig().getRetransConnectTimes());
                    if (a3 == 0) {
                        return;
                    }
                    if (a3 == 4128) {
                        throw new OtaException("aborted, connectRemoteDevice failed", a3);
                    }
                    throw new OtaException("connectRemoteDevice failed", a3);
                }
                throw new OtaException("user aborted", DfuException.ERROR_DFU_ABORTED);
            }
            throw new OtaException("aborted, connectRemoteDevice failed", a2);
        }
        throw new OtaException("user aborted", DfuException.ERROR_DFU_ABORTED);
    }
}
