package com.realsil.sdk.dfu.model;

import androidx.core.view.MotionEventCompat;
import androidx.core.view.ViewCompat;
import com.google.firebase.crashlytics.buildtools.reloc.com.google.common.base.Ascii;
import com.realsil.sdk.core.bluetooth.utils.BluetoothHelper;
import com.realsil.sdk.core.logger.ZLogger;
import com.realsil.sdk.core.utility.DataConverter;
import com.realsil.sdk.dfu.image.wrapper.SocImageWrapper;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import kotlin.UShort;
import org.apache.commons.text.StringSubstitutor;

/* loaded from: classes3.dex */
public class DeviceInfo {
    public static final int AES_MODE_16_FIRST = 0;
    public static final int AES_MODE_16_N = 1;
    public static final int BANK_INDICATOR_0 = 0;
    public static final int BANK_INDICATOR_1 = 1;
    public static final int BANK_INDICATOR_F = 15;
    public static final int BUD_ROLE_PRIMARY = 1;
    public static final int BUD_ROLE_SECONDARY = 2;
    public static final int BUD_ROLE_SINGLE = 0;
    public static final int MECHANISM_ALL_IN_ONE = 2;
    public static final int MECHANISM_ALL_IN_ONE_WITH_BUFFER = 3;
    public static final int MECHANISM_DEFAULT = 1;
    public static final int MECHANISM_ONE_BY_ONE = 1;
    public static final int RWS_FLAG_HANDOVER_PROCESSING = 1;
    public static final int RWS_FLAG_PREPARED = 0;
    public static final int RWS_MODE_ENGAGEED = 2;
    public static final int RWS_MODE_ENGAGE_IDLE = 1;
    public static final int RWS_MODE_SINGLE = 0;
    public static final int UPDATE_INDICATOR_BANK_0 = 1;
    public static final int UPDATE_INDICATOR_BANK_1 = 2;
    public static final int UPDATE_INDICATOR_STANDALONE = 0;
    public static final int UPDATE_MULTI_AT_A_TIME = 1;
    public static final int UPDATE_ONE_BY_ONE = 0;
    public List<CharacteristicInfo> A;
    public int B;
    public byte C;
    public byte D;
    public byte[] E;

    /* renamed from: a, reason: collision with root package name */
    public boolean f4489a;
    public int appData0;
    public int appData1;
    public int appData2;
    public int appData3;

    /* renamed from: b, reason: collision with root package name */
    public int f4490b;

    /* renamed from: c, reason: collision with root package name */
    public int f4491c;

    /* renamed from: d, reason: collision with root package name */
    public int f4492d;

    /* renamed from: e, reason: collision with root package name */
    public int f4493e;

    /* renamed from: f, reason: collision with root package name */
    public boolean f4494f;

    /* renamed from: g, reason: collision with root package name */
    public int f4495g;

    /* renamed from: h, reason: collision with root package name */
    public int f4496h;

    /* renamed from: i, reason: collision with root package name */
    public boolean f4497i;
    public byte[] imageSectionSizeValues;
    public byte[] imageVersionValues;
    public byte[] inactiveImageVersionValues;

    /* renamed from: j, reason: collision with root package name */
    public boolean f4498j;
    public boolean l;
    public int mtu;
    public boolean n;
    public int protocolType;
    public byte[] r;
    public byte[] s;
    public int secureVersion;
    public int t;
    public int u;
    public int v;
    public boolean x;
    public List<ImageVersionInfo> y;
    public List<ImageVersionInfo> z;
    public int icType = 3;
    public int specVersion = 0;
    public int appFreeBank = 0;
    public int patchFreeBank = 0;
    public int mode = 2;
    public int k = 1;
    public int m = 0;
    public int o = 0;
    public int p = 0;
    public int q = 0;
    public int maxBufferchecksize = 256;
    public int otaTempBufferSize = 0;
    public int imageVersionIndicator = 0;
    public int w = 1;
    public int updateBankIndicator = 0;

    public final int a(int i2, int i3) {
        return ((i3 >> (i2 * 2)) & 3) == 2 ? i2 + 16 : i2;
    }

    public final void a() {
        if (this.x) {
            this.w = 2;
            return;
        }
        if (this.m != 1) {
            this.w = 1;
        } else if (this.otaTempBufferSize != 0) {
            this.w = 3;
        } else {
            this.w = 2;
        }
    }

    public void appendActiveImageVersionBytes(byte[] bArr) {
        appendActiveImageVersionBytes(bArr, 0);
    }

    public void appendDebugCharacteristicInfo(int i2, byte[] bArr) {
        if (this.A == null) {
            this.A = new ArrayList();
        }
        this.A.add(new CharacteristicInfo(i2, bArr));
    }

    public void appendImageSectionSizeBytes(byte[] bArr) {
        byte[] bArr2 = this.imageSectionSizeValues;
        if (bArr2 == null || bArr2.length <= 0) {
            this.imageSectionSizeValues = bArr;
        } else {
            byte[] bArr3 = new byte[bArr2.length + bArr.length];
            System.arraycopy(bArr2, 0, bArr3, 0, bArr2.length);
            System.arraycopy(bArr, 0, bArr3, this.imageSectionSizeValues.length, bArr.length);
            this.imageSectionSizeValues = bArr3;
        }
        ZLogger.v(String.format("appendImageSectionSizeBytes: imageVersionIndicator = 0x%08x, \nimageSectionSizeValues=%s", Integer.valueOf(this.imageVersionIndicator), DataConverter.bytes2Hex(this.imageSectionSizeValues)));
        if (this.protocolType != 17 || this.specVersion < 6) {
            b();
        } else {
            c();
        }
    }

    public void appendImageVersionBytes(byte[] bArr) {
        if (this.protocolType != 17 || this.specVersion < 6) {
            appendActiveImageVersionBytes(bArr);
        } else if (bArr[0] == 0) {
            appendActiveImageVersionBytes(bArr, 1);
        } else {
            appendInactiveImageVersionBytes(bArr, 1);
        }
    }

    public void appendInactiveImageVersionBytes(byte[] bArr) {
        appendInactiveImageVersionBytes(bArr, 0);
    }

    public final void b() {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        byte b2;
        this.updateBankIndicator = 0;
        ArrayList arrayList = new ArrayList();
        int i7 = 0;
        int i8 = 0;
        for (int i9 = 0; i9 < 16; i9++) {
            int i10 = (this.imageVersionIndicator >> (i9 * 2)) & 3;
            if (i10 == 0) {
                arrayList.add(new ImageVersionInfo(i9, i10, 0, 0));
            } else {
                if (i10 == 1) {
                    if (this.updateBankIndicator == 0) {
                        this.updateBankIndicator = 2;
                    }
                } else if (i10 == 2) {
                    this.updateBankIndicator = 1;
                }
                byte[] bArr = this.imageVersionValues;
                if (bArr == null || (i5 = i7 + 3) >= bArr.length) {
                    i2 = 0;
                } else {
                    if (this.protocolType != 17) {
                        i6 = ((bArr[i5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[i7 + 2] << 16) & 16711680) | ((bArr[i7 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                        b2 = bArr[i7];
                    } else if (this.specVersion < 5) {
                        i6 = ((bArr[i5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[i7 + 2] << 16) & 16711680) | ((bArr[i7 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                        b2 = bArr[i7];
                    } else if (i9 == 2) {
                        i6 = ((bArr[i7 + 0] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[i7 + 1] << 16) & 16711680) | ((bArr[i7 + 2] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                        b2 = bArr[i5];
                    } else {
                        i6 = ((bArr[i5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[i7 + 2] << 16) & 16711680) | ((bArr[i7 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                        b2 = bArr[i7];
                    }
                    i2 = (b2 & 255) | i6;
                    i7 += 4;
                }
                byte[] bArr2 = this.imageSectionSizeValues;
                if (bArr2 == null || (i4 = i8 + 3) >= bArr2.length) {
                    i3 = 0;
                } else {
                    i3 = ((bArr2[i8 + 2] << 16) & 16711680) | ((-16777216) & (bArr2[i4] << Ascii.CAN)) | (65280 & (bArr2[i8 + 1] << 8)) | (bArr2[i8] & 255);
                    i8 += 4;
                }
                arrayList.add(new ImageVersionInfo(i9, i10, i2, i3));
            }
        }
        this.y = arrayList;
        this.x = this.updateBankIndicator != 0;
        a();
    }

    public final void c() {
        int i2;
        int i3;
        byte b2;
        ZLogger.v(String.format("imageVersionIndicator = 0x%08x, \nimageVersionValues = %s", Integer.valueOf(this.imageVersionIndicator), DataConverter.bytes2Hex(this.imageVersionValues)));
        byte[] bArr = this.imageVersionValues;
        if (bArr == null || bArr.length <= 0) {
            this.y = new ArrayList();
            return;
        }
        int i4 = bArr[0] & 255;
        ArrayList arrayList = new ArrayList();
        HashMap hashMap = new HashMap();
        HashMap hashMap2 = new HashMap();
        int i5 = 1;
        for (int i6 = 0; i6 < i4; i6++) {
            byte[] bArr2 = this.imageVersionValues;
            if (bArr2 != null && (i2 = i5 + 3) < bArr2.length) {
                int i7 = (bArr2[i5] & 255) | ((bArr2[i5 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                if (i7 == 10128) {
                    i3 = ((bArr2[i5 + 2] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr2[i2] << 16) & 16711680) | ((bArr2[i5 + 4] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                    b2 = bArr2[i5 + 5];
                } else {
                    i3 = ((bArr2[i5 + 5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr2[i5 + 4] << 16) & 16711680) | ((bArr2[i2] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                    b2 = bArr2[i5 + 2];
                }
                hashMap.put(Integer.valueOf(i7), Integer.valueOf(i3 | (b2 & 255)));
            }
            byte[] bArr3 = this.imageSectionSizeValues;
            if (bArr3 != null && (i5 * 4) + 3 < bArr3.length) {
                hashMap2.put(Integer.valueOf(((bArr3[i5 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | (bArr3[i5] & 255)), Integer.valueOf((bArr3[i5 + 2] & 255) | ((bArr3[i5 + 5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr3[i5 + 4] << 16) & 16711680) | ((bArr3[i5 + 3] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK)));
            }
            i5 += 6;
        }
        Iterator it2 = hashMap.keySet().iterator();
        while (it2.hasNext()) {
            int intValue = ((Integer) it2.next()).intValue();
            int i8 = this.updateBankIndicator;
            ImageVersionInfo imageVersionInfo = new ImageVersionInfo(255, i8 == 1 ? 2 : i8 == 2 ? 1 : 3, (!hashMap.containsKey(Integer.valueOf(intValue)) || hashMap.get(Integer.valueOf(intValue)) == null) ? 0 : ((Integer) hashMap.get(Integer.valueOf(intValue))).intValue(), (!hashMap2.containsKey(Integer.valueOf(intValue)) || hashMap2.get(Integer.valueOf(intValue)) == null) ? 0 : ((Integer) hashMap2.get(Integer.valueOf(intValue))).intValue(), intValue);
            ZLogger.v(imageVersionInfo.toString());
            arrayList.add(imageVersionInfo);
        }
        this.y = arrayList;
        a();
    }

    public final void d() {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        byte b2;
        ArrayList arrayList = new ArrayList();
        int i7 = 0;
        int i8 = 0;
        for (int i9 = 0; i9 < 16; i9++) {
            int i10 = (this.imageVersionIndicator >> (i9 * 2)) & 3;
            if (i10 == 0) {
                ImageVersionInfo imageVersionInfo = new ImageVersionInfo(i9, i10, 0, 0);
                ZLogger.v(imageVersionInfo.toString());
                arrayList.add(imageVersionInfo);
            } else {
                byte[] bArr = this.inactiveImageVersionValues;
                if (bArr == null || (i5 = i7 + 3) >= bArr.length) {
                    ZLogger.v(true, "imageVersion loss, offset=" + i7);
                    i2 = 0;
                } else {
                    if (this.protocolType != 17) {
                        i6 = ((bArr[i5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[i7 + 2] << 16) & 16711680) | ((bArr[i7 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                        b2 = bArr[i7];
                    } else if (this.specVersion < 5) {
                        i6 = ((bArr[i5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[i7 + 2] << 16) & 16711680) | ((bArr[i7 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                        b2 = bArr[i7];
                    } else if (i9 == 2) {
                        i2 = (bArr[i5] & 255) | ((bArr[i7 + 0] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[i7 + 1] << 16) & 16711680) | ((bArr[i7 + 2] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                        i7 += 4;
                    } else {
                        i6 = ((bArr[i5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr[i7 + 2] << 16) & 16711680) | ((bArr[i7 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                        b2 = bArr[i7];
                    }
                    i2 = (b2 & 255) | i6;
                    i7 += 4;
                }
                byte[] bArr2 = this.imageSectionSizeValues;
                if (bArr2 == null || (i4 = i8 + 3) >= bArr2.length) {
                    ZLogger.v(true, "sectionsize loss, offset=" + i8);
                    i3 = 0;
                } else {
                    i3 = ((bArr2[i8 + 2] << 16) & 16711680) | ((-16777216) & (bArr2[i4] << Ascii.CAN)) | (65280 & (bArr2[i8 + 1] << 8)) | (bArr2[i8] & 255);
                    i8 += 4;
                }
                ImageVersionInfo imageVersionInfo2 = new ImageVersionInfo(i9, i10, i2, i3);
                ZLogger.v(imageVersionInfo2.toString());
                arrayList.add(imageVersionInfo2);
            }
        }
        this.z = arrayList;
    }

    public final void e() {
        int i2;
        int i3;
        byte b2;
        byte[] bArr = this.inactiveImageVersionValues;
        if (bArr == null || bArr.length <= 0) {
            this.z = new ArrayList();
            return;
        }
        int i4 = bArr[0] & 255;
        ArrayList arrayList = new ArrayList();
        HashMap hashMap = new HashMap();
        HashMap hashMap2 = new HashMap();
        int i5 = 1;
        for (int i6 = 0; i6 < i4; i6++) {
            byte[] bArr2 = this.inactiveImageVersionValues;
            if (bArr2 != null && (i2 = i5 + 3) < bArr2.length) {
                int i7 = (bArr2[i5] & 255) | ((bArr2[i5 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                if (i7 == 10128) {
                    i3 = ((bArr2[i2] << 16) & 16711680) | ((bArr2[i5 + 2] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr2[i5 + 4] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK);
                    b2 = bArr2[i5 + 5];
                } else {
                    i3 = ((bArr2[i2] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | ((bArr2[i5 + 5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | ((bArr2[i5 + 4] << 16) & 16711680);
                    b2 = bArr2[i5 + 2];
                }
                hashMap.put(Integer.valueOf(i7), Integer.valueOf((b2 & 255) | i3));
            }
            byte[] bArr3 = this.imageSectionSizeValues;
            if (bArr3 != null && (i5 * 4) + 3 < bArr3.length) {
                hashMap2.put(Integer.valueOf(((bArr3[i5 + 1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | (bArr3[i5] & 255)), Integer.valueOf((bArr3[i5 + 2] & 255) | ((bArr3[i5 + 5] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | (16711680 & (bArr3[i5 + 4] << 16)) | ((bArr3[i5 + 3] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK)));
            }
            i5 += 6;
        }
        Iterator it2 = hashMap.keySet().iterator();
        while (it2.hasNext()) {
            int intValue = ((Integer) it2.next()).intValue();
            int i8 = this.updateBankIndicator;
            arrayList.add(new ImageVersionInfo(255, i8 == 1 ? 2 : i8 == 2 ? 1 : 3, (!hashMap.containsKey(Integer.valueOf(intValue)) || hashMap.get(Integer.valueOf(intValue)) == null) ? 0 : ((Integer) hashMap.get(Integer.valueOf(intValue))).intValue(), (!hashMap2.containsKey(Integer.valueOf(intValue)) || hashMap2.get(Integer.valueOf(intValue)) == null) ? 0 : ((Integer) hashMap2.get(Integer.valueOf(intValue))).intValue(), intValue));
        }
        this.z = arrayList;
    }

    public final void f() {
        int i2 = this.specVersion;
        if (i2 == 0) {
            if (this.m == 1) {
                this.w = 2;
                return;
            } else {
                this.w = 1;
                return;
            }
        }
        if (i2 == 1) {
            if (this.m != 1) {
                this.w = 1;
                return;
            } else if (this.otaTempBufferSize != 0) {
                this.w = 3;
                return;
            } else {
                this.w = 2;
                return;
            }
        }
        if (i2 == 2) {
            this.w = 1;
            return;
        }
        if (this.m != 1) {
            this.w = 1;
        } else if (this.otaTempBufferSize != 0) {
            this.w = 3;
        } else {
            this.w = 2;
        }
    }

    public int getActiveBank() {
        int i2 = this.updateBankIndicator;
        if (i2 == 1) {
            return 1;
        }
        return i2 == 2 ? 0 : 15;
    }

    public ImageVersionInfo getActiveImageVersionInfo(int i2) {
        List<ImageVersionInfo> list = this.y;
        if (list != null && list.size() > 0) {
            for (ImageVersionInfo imageVersionInfo : this.y) {
                if (imageVersionInfo.getBitNumber() == i2) {
                    return imageVersionInfo;
                }
            }
        }
        return null;
    }

    public ImageVersionInfo getActiveImageVersionInfoByImageId(int i2) {
        List<ImageVersionInfo> list = this.y;
        if (list != null && list.size() > 0) {
            for (ImageVersionInfo imageVersionInfo : this.y) {
                if (imageVersionInfo.getImageId() == i2) {
                    return imageVersionInfo;
                }
            }
        }
        return null;
    }

    public int getAesEncryptMode() {
        return this.k;
    }

    public byte[] getAppConfigReleaseVer() {
        return this.E;
    }

    public SocImageWrapper getAppUiParameterVersion() {
        ImageVersionInfo activeImageVersionInfo;
        SocImageWrapper.Builder builder = new SocImageWrapper.Builder();
        builder.setProtocolType(this.protocolType);
        builder.setSpecVersion(this.specVersion);
        builder.setIcType(this.icType);
        builder.setImageId(10134);
        builder.setBankIndicator(getActiveBank());
        int i2 = this.protocolType;
        if (i2 == 16) {
            int a2 = a(9, this.imageVersionIndicator);
            activeImageVersionInfo = getActiveImageVersionInfo(a2);
            builder.setBitNumber(a2);
        } else if (i2 != 17) {
            int i3 = this.specVersion;
            activeImageVersionInfo = (i3 != 0 && i3 == 1) ? getActiveImageVersionInfo(a(9, this.imageVersionIndicator)) : null;
        } else if (this.specVersion >= 6) {
            activeImageVersionInfo = getActiveImageVersionInfoByImageId(10134);
        } else {
            int a3 = a(9, this.imageVersionIndicator);
            activeImageVersionInfo = getActiveImageVersionInfo(a3);
            builder.setBitNumber(a3);
        }
        if (activeImageVersionInfo != null) {
            builder.setImageVersion(activeImageVersionInfo.getVersion());
        }
        return builder.build();
    }

    public int getAppVersion() {
        ImageVersionInfo activeImageVersionInfo;
        int i2 = this.protocolType;
        if (i2 == 16) {
            int i3 = this.icType;
            if (i3 > 3) {
                if (i3 == 5 || i3 == 9 || i3 == 12) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(5, this.imageVersionIndicator));
                } else if (i3 == 4 || i3 == 6 || i3 == 7 || i3 == 8 || i3 == 10) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(5, this.imageVersionIndicator));
                }
            }
            activeImageVersionInfo = null;
        } else if (i2 == 17) {
            int i4 = this.icType;
            if (i4 > 3) {
                if (i4 == 5 || i4 == 9 || i4 == 12) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(5, this.imageVersionIndicator));
                } else if (i4 == 4 || i4 == 6 || i4 == 7 || i4 == 8 || i4 == 10) {
                    activeImageVersionInfo = this.specVersion >= 6 ? getActiveImageVersionInfoByImageId(10131) : getActiveImageVersionInfo(a(5, this.imageVersionIndicator));
                }
            }
            activeImageVersionInfo = null;
        } else {
            int i5 = this.specVersion;
            if (i5 == 0) {
                return this.u;
            }
            if (i5 >= 1) {
                int i6 = this.icType;
                if (i6 <= 3) {
                    activeImageVersionInfo = this.updateBankIndicator == 2 ? getActiveImageVersionInfo(2) : getActiveImageVersionInfo(1);
                } else if (i6 == 5 || i6 == 9 || i6 == 12) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(5, this.imageVersionIndicator));
                } else if (i6 == 4 || i6 == 6 || i6 == 7 || i6 == 8 || i6 == 10) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(5, this.imageVersionIndicator));
                }
            }
            activeImageVersionInfo = null;
        }
        if (activeImageVersionInfo != null) {
            return activeImageVersionInfo.getVersion();
        }
        return 0;
    }

    public int getBatteryLevel() {
        return this.f4495g;
    }

    public int getBudRole() {
        return this.o;
    }

    public List<CharacteristicInfo> getDebugCharacteristicInfos() {
        return this.A;
    }

    public byte[] getDeviceMac() {
        return this.s;
    }

    public SocImageWrapper getDspUiParameterVersion() {
        ImageVersionInfo activeImageVersionInfo;
        SocImageWrapper.Builder builder = new SocImageWrapper.Builder();
        builder.setProtocolType(this.protocolType);
        builder.setSpecVersion(this.specVersion);
        builder.setIcType(this.icType);
        builder.setImageId(10135);
        builder.setBankIndicator(getActiveBank());
        int i2 = this.protocolType;
        if (i2 == 16) {
            int a2 = a(8, this.imageVersionIndicator);
            activeImageVersionInfo = getActiveImageVersionInfo(a2);
            builder.setBitNumber(a2);
        } else if (i2 != 17) {
            int i3 = this.specVersion;
            activeImageVersionInfo = (i3 != 0 && i3 == 1) ? getActiveImageVersionInfo(a(8, this.imageVersionIndicator)) : null;
        } else if (this.specVersion >= 6) {
            activeImageVersionInfo = getActiveImageVersionInfoByImageId(10135);
        } else {
            int a3 = a(8, this.imageVersionIndicator);
            activeImageVersionInfo = getActiveImageVersionInfo(a3);
            builder.setBitNumber(a3);
        }
        if (activeImageVersionInfo != null) {
            builder.setImageVersion(activeImageVersionInfo.getVersion());
        }
        return builder.build();
    }

    public List<ImageVersionInfo> getExistImageVersionInfos() {
        ArrayList arrayList = new ArrayList();
        List<ImageVersionInfo> list = this.y;
        if (list != null && list.size() > 0) {
            for (ImageVersionInfo imageVersionInfo : this.y) {
                if (imageVersionInfo.getIndication() != 0) {
                    arrayList.add(imageVersionInfo);
                }
            }
        }
        return arrayList;
    }

    public List<ImageVersionInfo> getExistInactiveImageVersionInfos() {
        ArrayList arrayList = new ArrayList();
        List<ImageVersionInfo> list = this.z;
        if (list != null && list.size() > 0) {
            for (ImageVersionInfo imageVersionInfo : this.z) {
                if (imageVersionInfo.getIndication() != 0) {
                    arrayList.add(imageVersionInfo);
                }
            }
        }
        return arrayList;
    }

    public byte getIcId() {
        return this.C;
    }

    public List<ImageVersionInfo> getImageVersionInfos() {
        return this.y;
    }

    public ImageVersionInfo getInActiveImageVersionInfo(int i2) {
        List<ImageVersionInfo> list = this.z;
        if (list != null && list.size() > 0) {
            for (ImageVersionInfo imageVersionInfo : this.z) {
                if (imageVersionInfo.getBitNumber() == i2) {
                    return imageVersionInfo;
                }
            }
        }
        return null;
    }

    public ImageVersionInfo getInActiveImageVersionInfoByImageId(int i2) {
        List<ImageVersionInfo> list = this.z;
        if (list != null && list.size() > 0) {
            for (ImageVersionInfo imageVersionInfo : this.z) {
                if (imageVersionInfo.getImageId() == i2) {
                    return imageVersionInfo;
                }
            }
        }
        return null;
    }

    public int getInactiveBank() {
        int i2 = this.updateBankIndicator;
        if (i2 == 1) {
            return 0;
        }
        return i2 == 2 ? 1 : 15;
    }

    public List<ImageVersionInfo> getInactiveImageVersionInfos() {
        return this.z;
    }

    public String getIpv() {
        return String.format("I%02XP%04XV%02X", Integer.valueOf(this.icType), Integer.valueOf(this.protocolType), Integer.valueOf(this.specVersion));
    }

    public int getNoTempImageId() {
        return this.B;
    }

    /* JADX WARN: Removed duplicated region for block: B:14:0x00ae  */
    /* JADX WARN: Removed duplicated region for block: B:17:0x00b3 A[RETURN] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public int getOtaHeaderImageVersion() {
        /*
            r12 = this;
            int r0 = r12.protocolType
            r1 = 16
            r2 = 12
            r3 = 9
            r4 = 5
            r5 = 10
            r6 = 8
            r7 = 7
            r8 = 0
            r9 = 4
            r10 = 6
            r11 = 2
            if (r0 != r1) goto L3f
            int r0 = r12.icType
            if (r0 == r9) goto L33
            if (r0 == r10) goto L33
            if (r0 == r7) goto L33
            if (r0 == r6) goto L33
            if (r0 != r5) goto L21
            goto L33
        L21:
            if (r0 == r4) goto L27
            if (r0 == r3) goto L27
            if (r0 != r2) goto Lab
        L27:
            int r0 = r12.imageVersionIndicator
            int r0 = r12.a(r11, r0)
            com.realsil.sdk.dfu.model.ImageVersionInfo r0 = r12.getActiveImageVersionInfo(r0)
            goto Lac
        L33:
            int r0 = r12.imageVersionIndicator
            int r0 = r12.a(r11, r0)
            com.realsil.sdk.dfu.model.ImageVersionInfo r0 = r12.getActiveImageVersionInfo(r0)
            goto Lac
        L3f:
            r1 = 17
            if (r0 != r1) goto L77
            int r0 = r12.icType
            if (r0 == r9) goto L61
            if (r0 == r10) goto L61
            if (r0 == r7) goto L61
            if (r0 == r6) goto L61
            if (r0 != r5) goto L50
            goto L61
        L50:
            if (r0 == r4) goto L56
            if (r0 == r3) goto L56
            if (r0 != r2) goto Lab
        L56:
            int r0 = r12.imageVersionIndicator
            int r0 = r12.a(r11, r0)
            com.realsil.sdk.dfu.model.ImageVersionInfo r0 = r12.getActiveImageVersionInfo(r0)
            goto Lac
        L61:
            int r0 = r12.specVersion
            if (r0 < r10) goto L6c
            r0 = 10128(0x2790, float:1.4192E-41)
            com.realsil.sdk.dfu.model.ImageVersionInfo r0 = r12.getActiveImageVersionInfoByImageId(r0)
            goto Lac
        L6c:
            int r0 = r12.imageVersionIndicator
            int r0 = r12.a(r11, r0)
            com.realsil.sdk.dfu.model.ImageVersionInfo r0 = r12.getActiveImageVersionInfo(r0)
            goto Lac
        L77:
            int r0 = r12.specVersion
            if (r0 != 0) goto L7c
            return r8
        L7c:
            r1 = 1
            if (r0 != r1) goto La8
            int r0 = r12.icType
            if (r0 == r9) goto L9d
            if (r0 == r10) goto L9d
            if (r0 == r7) goto L9d
            if (r0 == r6) goto L9d
            if (r0 != r5) goto L8c
            goto L9d
        L8c:
            if (r0 == r4) goto L92
            if (r0 == r3) goto L92
            if (r0 != r2) goto Lab
        L92:
            int r0 = r12.imageVersionIndicator
            int r0 = r12.a(r11, r0)
            com.realsil.sdk.dfu.model.ImageVersionInfo r0 = r12.getActiveImageVersionInfo(r0)
            goto Lac
        L9d:
            int r0 = r12.imageVersionIndicator
            int r0 = r12.a(r11, r0)
            com.realsil.sdk.dfu.model.ImageVersionInfo r0 = r12.getActiveImageVersionInfo(r0)
            goto Lac
        La8:
            if (r0 != r11) goto Lab
            return r8
        Lab:
            r0 = 0
        Lac:
            if (r0 == 0) goto Lb3
            int r0 = r0.getVersion()
            return r0
        Lb3:
            return r8
        */
        throw new UnsupportedOperationException("Method not decompiled: com.realsil.sdk.dfu.model.DeviceInfo.getOtaHeaderImageVersion():int");
    }

    public byte getPackageId() {
        return this.D;
    }

    public int getPatchExtensionVersion() {
        return this.v;
    }

    public int getPatchVersion() {
        ImageVersionInfo activeImageVersionInfo;
        int i2 = this.protocolType;
        if (i2 == 16) {
            int i3 = this.icType;
            if (i3 <= 3) {
                activeImageVersionInfo = getActiveImageVersionInfo(a(0, this.imageVersionIndicator));
            } else if (i3 == 5 || i3 == 9 || i3 == 12) {
                activeImageVersionInfo = getActiveImageVersionInfo(a(4, this.imageVersionIndicator));
            } else {
                if (i3 == 4 || i3 == 6 || i3 == 7 || i3 == 8 || i3 == 10) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(4, this.imageVersionIndicator));
                }
                activeImageVersionInfo = null;
            }
        } else if (i2 == 17) {
            int i4 = this.icType;
            if (i4 <= 3) {
                activeImageVersionInfo = getActiveImageVersionInfo(a(0, this.imageVersionIndicator));
            } else if (i4 == 5 || i4 == 9 || i4 == 12) {
                activeImageVersionInfo = getActiveImageVersionInfo(a(4, this.imageVersionIndicator));
            } else {
                if (i4 == 4 || i4 == 6 || i4 == 7 || i4 == 8 || i4 == 10) {
                    activeImageVersionInfo = this.specVersion >= 6 ? getActiveImageVersionInfoByImageId(10130) : getActiveImageVersionInfo(a(4, this.imageVersionIndicator));
                }
                activeImageVersionInfo = null;
            }
        } else {
            int i5 = this.specVersion;
            if (i5 == 0) {
                return this.t;
            }
            if (i5 == 1) {
                int i6 = this.icType;
                if (i6 <= 3) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(0, this.imageVersionIndicator));
                } else if (i6 == 5 || i6 == 9 || i6 == 12) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(4, this.imageVersionIndicator));
                } else if (i6 == 4 || i6 == 6 || i6 == 7 || i6 == 8 || i6 == 10) {
                    activeImageVersionInfo = getActiveImageVersionInfo(a(4, this.imageVersionIndicator));
                }
            } else if (i5 == 2) {
                return this.t;
            }
            activeImageVersionInfo = null;
        }
        if (activeImageVersionInfo != null) {
            return activeImageVersionInfo.getVersion();
        }
        return 0;
    }

    public int getPrimaryBat() {
        return this.f4495g;
    }

    public int getProductId() {
        return this.f4492d;
    }

    public int getProductVersion() {
        return this.f4493e;
    }

    public int getProtocolType() {
        return this.protocolType;
    }

    public byte[] getRwsBdAddr() {
        return this.r;
    }

    public int getRwsMode() {
        return this.q;
    }

    public int getRwsUpdateFlag() {
        return this.p;
    }

    public int getSecondaryBat() {
        return this.f4496h;
    }

    public int getUpdateBank() {
        int i2 = this.updateBankIndicator;
        if (i2 == 1) {
            return 0;
        }
        return i2 == 2 ? 1 : 15;
    }

    public int getUpdateImageFlag() {
        return this.m;
    }

    public int getUpdateMechanism() {
        return this.w;
    }

    public int getVendorId() {
        return this.f4491c;
    }

    public int getVendorIdSource() {
        return this.f4490b;
    }

    public boolean isAesEncryptEnabled() {
        return this.f4498j;
    }

    public boolean isBankEnabled() {
        return this.x;
    }

    public boolean isBasSupported() {
        return this.f4494f;
    }

    public boolean isBufferCheckEnabled() {
        return this.f4497i;
    }

    public boolean isCopyImageEnabled() {
        return this.l;
    }

    public boolean isDisSupported() {
        return this.f4489a;
    }

    public boolean isRwsEnabled() {
        return this.n;
    }

    public void parseX0000(byte[] bArr) {
        parseX0000(bArr, 0);
    }

    public void parseX0010(byte[] bArr) {
        parseX0010(bArr, 0);
    }

    public void parseX0011(byte[] bArr) {
        parseX0011(bArr, 0);
    }

    public void setActiveImageVersionValues(byte[] bArr) {
        this.imageVersionValues = bArr;
        if (this.protocolType != 17 || this.specVersion < 6) {
            b();
        } else {
            c();
        }
    }

    public void setAppConfigReleaseVer(byte[] bArr) {
        this.E = bArr;
    }

    public void setAppVersion(int i2) {
        this.u = i2;
    }

    public void setBatteryLevel(int i2) {
        setBatteryLevel(i2, 0);
    }

    public void setDeviceMac(byte[] bArr) {
        this.s = bArr;
    }

    public void setIcId(byte b2) {
        this.C = b2;
    }

    public void setImageSectionSizeValues(byte[] bArr) {
        this.imageSectionSizeValues = bArr;
        ZLogger.v(String.format("imageVersionIndicator = 0x%08x, \nimageSectionSizeValues=%s", Integer.valueOf(this.imageVersionIndicator), DataConverter.bytes2Hex(this.imageSectionSizeValues)));
        if (this.protocolType != 17 || this.specVersion < 6) {
            b();
        } else {
            c();
        }
    }

    public void setImageVersionValues(byte[] bArr) {
        if (this.protocolType != 17 || this.specVersion < 6) {
            setActiveImageVersionValues(bArr);
            return;
        }
        byte b2 = bArr[0];
        int length = bArr.length - 1;
        byte[] bArr2 = new byte[length];
        System.arraycopy(bArr, 1, bArr2, 0, length);
        if (b2 == 0) {
            setActiveImageVersionValues(bArr2);
        } else {
            setInactiveImageVersionValues(bArr2);
        }
    }

    public void setInactiveImageVersionValues(byte[] bArr) {
        this.inactiveImageVersionValues = bArr;
        if (this.protocolType != 17 || this.specVersion < 6) {
            d();
        } else {
            e();
        }
    }

    public void setMode(int i2) {
        this.mode = i2;
        this.f4497i = (i2 & 1) != 0;
        this.f4498j = ((i2 & 2) >> 1) != 0;
        this.k = (i2 & 4) >> 2;
        this.l = ((i2 & 8) >> 3) != 0;
        this.m = (i2 & 16) >> 4;
        this.n = ((i2 & 32) >> 5) != 0;
        f();
    }

    public void setNoTempImageId(int i2) {
        this.B = i2;
    }

    public void setPackageId(byte b2) {
        this.D = b2;
    }

    public void setPatchExtensionVersion(int i2) {
        this.v = i2;
    }

    public void setPatchVersion(int i2) {
        this.t = i2;
    }

    public void setPnpId(byte[] bArr) {
        if (bArr == null || bArr.length < 7) {
            this.f4489a = false;
            this.f4490b = 0;
            this.f4491c = 0;
            this.f4492d = 0;
            this.f4493e = 0;
            return;
        }
        this.f4489a = true;
        this.f4490b = bArr[0];
        this.f4491c = (bArr[2] << 8) | bArr[1];
        this.f4492d = (bArr[4] << 8) | bArr[3];
        this.f4493e = bArr[5] | (bArr[6] << 8);
    }

    public void setPrimaryBat(int i2) {
        this.f4495g = i2;
    }

    public void setProductId(int i2) {
        this.f4492d = i2;
    }

    public void setProductVersion(int i2) {
        this.f4493e = i2;
    }

    public void setProtocolType(int i2) {
        this.protocolType = i2;
    }

    public void setRwsBdAddr(byte[] bArr) {
        this.r = bArr;
    }

    public void setRwsMode(int i2) {
        this.q = i2;
    }

    public void setRwsUpdateFlag(int i2) {
        this.p = i2;
    }

    public void setSecondaryBat(int i2) {
        this.f4496h = i2;
    }

    public void setVendorId(int i2) {
        this.f4491c = i2;
    }

    public void setVendorIdSource(int i2) {
        this.f4490b = i2;
    }

    public String toString() {
        StringBuilder sb = new StringBuilder("DeviceInfo{\n");
        sb.append(String.format("IPV=%s\n", getIpv()));
        boolean z = this.f4489a;
        if (z) {
            sb.append("PnP_ID:\n");
            Locale locale = Locale.US;
            sb.append(String.format(locale, "\tvendorIdSource=0x%04X(%d)\n", Integer.valueOf(this.f4490b), Integer.valueOf(this.f4491c)));
            sb.append(String.format(locale, "\tvendorId=0x%04X(%d)\n", Integer.valueOf(this.f4491c), Integer.valueOf(this.f4491c)));
            sb.append(String.format(locale, "\tproductId=0x%04X(%d)\n", Integer.valueOf(this.f4492d), Integer.valueOf(this.f4492d)));
            sb.append(String.format(locale, "\tproductVersion=0x%04X(%d)\n", Integer.valueOf(this.f4493e), Integer.valueOf(this.f4493e)));
        } else {
            sb.append(String.format("DIS=%b\n", Boolean.valueOf(z)));
        }
        boolean z2 = this.f4494f;
        if (z2) {
            sb.append(String.format(Locale.US, "primaryBat=0x%02X(%d), secondaryBat=0x%02X(%d)\n", Integer.valueOf(this.f4495g), Integer.valueOf(this.f4495g), Integer.valueOf(this.f4496h), Integer.valueOf(this.f4496h)));
        } else {
            sb.append(String.format("BAS=%b\n", Boolean.valueOf(z2)));
        }
        sb.append(String.format("deviceMac: %s\n", BluetoothHelper.formatAddressPositive(this.s)));
        sb.append(String.format("mode=0x%02X\n", Integer.valueOf(this.mode)));
        sb.append(String.format("\tbufferCheckEnabled=%b\n", Boolean.valueOf(this.f4497i)));
        if (this.f4497i) {
            sb.append(String.format(Locale.US, "\t\tmaxBuffercheckSize=0x%04X(%d)\n", Integer.valueOf(this.maxBufferchecksize), Integer.valueOf(this.maxBufferchecksize)));
        }
        sb.append(String.format("\taesEncryptEnabled=%b\n", Boolean.valueOf(this.f4498j)));
        if (this.f4498j) {
            sb.append(String.format("\t\taesEncryptMode=0x%02X\n", Integer.valueOf(this.k)));
        }
        sb.append(String.format("\tcopyImageEnabled=%b\n", Boolean.valueOf(this.l)));
        sb.append(String.format("\tupdateImageFlag=0x%02X\n", Integer.valueOf(this.m)));
        sb.append(String.format("\trwsEnabled=%b, rwsMode=0x%02X, budRole: 0x%02X\n", Boolean.valueOf(this.n), Integer.valueOf(this.q), Integer.valueOf(this.o)));
        if (this.n) {
            sb.append(String.format("\t\trwsUpdateFlag:0x%02X, rwsBdAddr: %s\n", Integer.valueOf(this.p), BluetoothHelper.formatAddressPositive(this.r)));
        }
        Locale locale2 = Locale.US;
        sb.append(String.format(locale2, "otaTempBufferSize=0x%02X(%d)\n", Integer.valueOf(this.otaTempBufferSize), Integer.valueOf(this.otaTempBufferSize)));
        sb.append(String.format("mUpdateMechanism=0x%02X\n", Integer.valueOf(this.w)));
        int i2 = this.protocolType;
        if (i2 == 0) {
            int i3 = this.specVersion;
            if (i3 == 0) {
                sb.append(String.format(locale2, "\tpatchVersion=0x%04X\n", Integer.valueOf(this.t)));
                sb.append(String.format(locale2, "\tpatchFreeBank=0x%02X\n", Integer.valueOf(this.patchFreeBank)));
                sb.append(String.format(locale2, "\tappVersion=0x%04X\n", Integer.valueOf(this.u)));
                sb.append(String.format("\tappFreeBank=0x%02X\n", Integer.valueOf(this.appFreeBank)));
                sb.append(String.format(locale2, "\tpatchExtensionVersion=%d\n", Integer.valueOf(this.v)));
                if (this.icType > 3) {
                    sb.append(String.format(locale2, "\tappData0=%d\n", Integer.valueOf(this.appData0)));
                    sb.append(String.format(locale2, "\tappData1=%d\n", Integer.valueOf(this.appData1)));
                    sb.append(String.format(locale2, "\tappData2=%d\n", Integer.valueOf(this.appData2)));
                    sb.append(String.format(locale2, "\tappData3=%d\n", Integer.valueOf(this.appData3)));
                }
            } else if (i3 == 1) {
                sb.append(String.format(locale2, "\tsecureVersion=0x%04X(%d)\n", Integer.valueOf(this.secureVersion), Integer.valueOf(this.secureVersion)));
                sb.append(String.format(locale2, "\timageVersionIndicator=0x%08X\n", Integer.valueOf(this.imageVersionIndicator)));
                sb.append(String.format(locale2, "\tupdateBankIndicator=0x%02X\n", Integer.valueOf(this.updateBankIndicator)));
            } else if (i3 == 2) {
                sb.append(String.format(locale2, "\tnoTempImageId=0x%04X\n", Integer.valueOf(this.B)));
                sb.append(String.format(locale2, "\tpatchVersion=0x%04X\n", Integer.valueOf(this.t)));
            }
        } else if (i2 == 17) {
            sb.append(String.format(locale2, "\tsecureVersion=0x%04X(%d)\n", Integer.valueOf(this.secureVersion), Integer.valueOf(this.secureVersion)));
            sb.append(String.format(locale2, "\timageVersionIndicator=0x%08X\n", Integer.valueOf(this.imageVersionIndicator)));
            sb.append(String.format(locale2, "\tupdateBankIndicator=0x%02X(%d)\n", Integer.valueOf(this.updateBankIndicator), Integer.valueOf(this.updateBankIndicator)));
            if (this.specVersion >= 6) {
                sb.append(String.format(locale2, "\tmtu=0x%04X\n", Integer.valueOf(this.mtu)));
            }
        } else {
            sb.append(String.format(locale2, "\tsecureVersion=0x%04X(%d)\n", Integer.valueOf(this.secureVersion), Integer.valueOf(this.secureVersion)));
            sb.append(String.format(locale2, "\timageVersionIndicator=0x%08X\n", Integer.valueOf(this.imageVersionIndicator)));
            sb.append(String.format(locale2, "\tupdateBankIndicator=0x%02X(%d)\n", Integer.valueOf(this.updateBankIndicator), Integer.valueOf(this.updateBankIndicator)));
        }
        sb.append(String.format("bankEnabled=%b\n", Boolean.valueOf(this.x)));
        sb.append(String.format("\ticId=0x%02X, packageId=0x%02X\n", Byte.valueOf(this.C), Byte.valueOf(this.D)));
        sb.append(StringSubstitutor.DEFAULT_VAR_END);
        return sb.toString();
    }

    public void appendActiveImageVersionBytes(byte[] bArr, int i2) {
        int length = bArr.length - i2;
        byte[] bArr2 = this.imageVersionValues;
        if (bArr2 == null || bArr2.length <= 0) {
            byte[] bArr3 = new byte[length];
            this.imageVersionValues = bArr3;
            System.arraycopy(bArr, i2, bArr3, 0, length);
        } else {
            byte[] bArr4 = new byte[bArr2.length + length];
            System.arraycopy(bArr2, 0, bArr4, 0, bArr2.length);
            System.arraycopy(bArr, i2, bArr4, this.imageVersionValues.length, length);
            this.imageVersionValues = bArr4;
        }
        if (this.protocolType != 17 || this.specVersion < 6) {
            b();
        } else {
            c();
        }
    }

    public void appendInactiveImageVersionBytes(byte[] bArr, int i2) {
        int length = bArr.length - i2;
        byte[] bArr2 = this.inactiveImageVersionValues;
        if (bArr2 == null || bArr2.length <= 0) {
            byte[] bArr3 = new byte[length];
            this.inactiveImageVersionValues = bArr3;
            System.arraycopy(bArr, i2, bArr3, 0, length);
        } else {
            byte[] bArr4 = new byte[bArr2.length + bArr.length];
            System.arraycopy(bArr2, 0, bArr4, 0, bArr2.length);
            System.arraycopy(bArr, i2, bArr4, this.inactiveImageVersionValues.length, bArr.length - i2);
            this.inactiveImageVersionValues = bArr4;
        }
        if (this.protocolType != 17 || this.specVersion < 6) {
            d();
        } else {
            e();
        }
    }

    public void parseX0000(byte[] bArr, int i2) {
        if (bArr == null) {
            return;
        }
        ByteBuffer wrap = ByteBuffer.wrap(bArr);
        wrap.order(ByteOrder.LITTLE_ENDIAN);
        int remaining = wrap.remaining();
        if (remaining <= i2) {
            return;
        }
        int i3 = remaining - i2;
        try {
            if (i3 <= 1) {
                this.icType = 3;
                this.specVersion = 0;
                this.appFreeBank = (byte) (wrap.get(i2) & 15);
                byte b2 = (byte) ((wrap.get(i2) & 240) >> 4);
                this.patchFreeBank = b2;
                int i4 = this.appFreeBank;
                if (i4 == 15 && b2 == 15) {
                    this.x = false;
                    this.updateBankIndicator = 0;
                } else {
                    this.x = true;
                    if (i4 != 1 && b2 != 1) {
                        this.updateBankIndicator = 1;
                    }
                    this.updateBankIndicator = 2;
                }
                setMode(2);
                return;
            }
            this.icType = wrap.get(i2) & 255;
            byte b3 = (byte) (wrap.get(i2 + 1) & 15);
            this.specVersion = b3;
            if (b3 == 0) {
                if (i3 >= 3) {
                    int i5 = i2 + 2;
                    this.appFreeBank = (byte) (wrap.get(i5) & 15);
                    this.patchFreeBank = (byte) ((wrap.get(i5) & 240) >> 4);
                }
                this.otaTempBufferSize = 0;
                if (i3 >= 4) {
                    setMode(wrap.get(i2 + 3));
                }
                if (i3 >= 6) {
                    this.maxBufferchecksize = (wrap.get(i2 + 5) << 8) | wrap.get(4);
                }
                if (i3 >= 14) {
                    this.appData0 = (wrap.get(i2 + 7) << 8) | wrap.get(i2 + 6);
                    this.appData1 = (wrap.get(i2 + 9) << 8) | wrap.get(i2 + 8);
                    this.appData2 = (wrap.get(i2 + 11) << 8) | wrap.get(i2 + 10);
                    this.appData3 = wrap.get(i2 + 12) | (wrap.get(i2 + 13) << 8);
                }
                f();
                int i6 = this.appFreeBank;
                if (i6 == 15 && this.patchFreeBank == 15) {
                    this.x = false;
                    this.updateBankIndicator = 0;
                    return;
                }
                this.x = true;
                if (i6 != 1 && this.patchFreeBank != 1) {
                    this.updateBankIndicator = 1;
                    return;
                }
                this.updateBankIndicator = 2;
                return;
            }
            if (b3 == 1) {
                if (i3 >= 3) {
                    this.secureVersion = wrap.get(i2 + 2) & 255;
                }
                if (i3 >= 4) {
                    setMode(wrap.get(i2 + 3));
                }
                if (i3 >= 5) {
                    this.maxBufferchecksize = wrap.getShort(i2 + 4) & UShort.MAX_VALUE;
                }
                if (i3 >= 7) {
                    this.otaTempBufferSize = wrap.get(i2 + 6) & 255;
                }
                if (i3 >= 12) {
                    this.imageVersionIndicator = wrap.getInt(i2 + 8);
                }
                f();
                if (this.imageVersionIndicator == 0) {
                    this.x = false;
                    return;
                } else {
                    this.x = true;
                    return;
                }
            }
            if (b3 == 2) {
                if (i3 >= 3) {
                    this.secureVersion = wrap.get(i2 + 2) & 255;
                }
                if (i3 >= 4) {
                    setMode(wrap.get(i2 + 3));
                }
                if (i3 >= 5) {
                    this.maxBufferchecksize = wrap.getShort(i2 + 4) & UShort.MAX_VALUE;
                }
                if (i3 >= 7) {
                    this.B = wrap.getShort(i2 + 6);
                }
                if (i3 >= 8) {
                    this.t = wrap.getShort(i2 + 7) & UShort.MAX_VALUE;
                }
                f();
                if (this.imageVersionIndicator == 0) {
                    this.x = false;
                } else {
                    this.x = true;
                }
            }
        } catch (Exception e2) {
            ZLogger.e(e2.toString());
        }
    }

    public void parseX0010(byte[] bArr, int i2) {
        if (bArr == null) {
            return;
        }
        ByteBuffer wrap = ByteBuffer.wrap(bArr);
        wrap.order(ByteOrder.LITTLE_ENDIAN);
        int remaining = wrap.remaining();
        if (remaining <= i2) {
            return;
        }
        int i3 = remaining - i2;
        try {
            this.icType = wrap.get(i2) & 255;
            this.specVersion = (byte) (wrap.get(i2 + 1) & 15);
            if (i3 >= 3) {
                this.secureVersion = wrap.get(i2 + 2) & 255;
            }
            if (i3 >= 4) {
                int i4 = wrap.get(i2 + 3) & 255;
                this.mode = i4;
                this.f4497i = (i4 & 1) != 0;
                this.f4498j = ((i4 & 2) >> 1) != 0;
                this.k = (i4 & 4) >> 2;
                this.l = ((i4 & 8) >> 3) != 0;
                this.m = (i4 & 16) >> 4;
                this.n = ((i4 & 32) >> 5) != 0;
                this.o = (i4 & 64) >> 6;
                this.p = (i4 & 128) >> 7;
            }
            if (i3 >= 5) {
                this.q = wrap.get(i2 + 4) & 255 & 1;
            }
            if (i3 >= 7) {
                this.otaTempBufferSize = wrap.get(i2 + 6) & 255;
            }
            if (i3 >= 12) {
                this.imageVersionIndicator = wrap.getInt(i2 + 8);
            }
        } catch (Exception e2) {
            ZLogger.e(e2.toString());
        }
        if (this.imageVersionIndicator == 0) {
            this.x = false;
        } else {
            this.x = true;
        }
        a();
    }

    public void parseX0011(byte[] bArr, int i2) {
        if (bArr == null) {
            return;
        }
        ByteBuffer wrap = ByteBuffer.wrap(bArr);
        wrap.order(ByteOrder.LITTLE_ENDIAN);
        int remaining = wrap.remaining();
        if (remaining <= i2) {
            ZLogger.v(String.format(Locale.US, "invalid offset:%d, len is %d", Integer.valueOf(i2), Integer.valueOf(remaining)));
            return;
        }
        int i3 = remaining - i2;
        if (i3 >= 1) {
            this.icType = wrap.get(i2) & 255;
        }
        if (i3 >= 2) {
            this.specVersion = (byte) (wrap.get(i2 + 1) & 15);
        }
        if (this.specVersion <= 5) {
            if (i3 >= 3) {
                this.secureVersion = wrap.get(i2 + 2);
            }
            if (i3 >= 4) {
                int i4 = wrap.get(i2 + 3) & 255;
                this.mode = i4;
                this.f4497i = (i4 & 1) != 0;
                this.f4498j = ((i4 & 2) >> 1) != 0;
                this.k = (i4 & 4) >> 2;
                this.l = ((i4 & 8) >> 3) != 0;
                this.m = (i4 & 16) >> 4;
                this.n = ((i4 & 32) >> 5) != 0;
                this.o = (i4 & 64) >> 6;
            }
            if (i3 >= 5) {
                this.q = wrap.get(i2 + 4) & 255 & 1;
            }
            if (i3 >= 7) {
                this.otaTempBufferSize = wrap.get(i2 + 6) & 255;
            }
            if (i3 >= 12) {
                this.imageVersionIndicator = wrap.getInt(i2 + 8);
            }
            if (this.imageVersionIndicator == 0) {
                this.x = false;
            } else {
                this.x = true;
            }
        } else {
            if (i3 >= 3) {
                int i5 = wrap.get(i2 + 2) & 255;
                this.mode = i5;
                this.f4497i = (i5 & 1) != 0;
                this.f4498j = ((i5 & 2) >> 1) != 0;
                this.k = (i5 & 4) >> 2;
                this.m = (i5 & 8) >> 3;
            }
            if (i3 >= 4) {
                int i6 = wrap.get(i2 + 3) & 255;
                int i7 = i6 & 3;
                this.q = i7;
                this.o = (i6 & 12) >> 2;
                this.n = i7 == 2;
            }
            if (i3 >= 5) {
                this.otaTempBufferSize = wrap.get(i2 + 4) & 255;
            }
            if (i3 >= 6) {
                int i8 = wrap.get(i2 + 5) & 255;
                if (i8 == 0) {
                    this.x = false;
                    this.updateBankIndicator = 0;
                    this.imageVersionIndicator = 3;
                } else if (i8 == 1) {
                    this.x = true;
                    this.updateBankIndicator = 2;
                    this.imageVersionIndicator = 1;
                } else if (i8 == 2) {
                    this.x = true;
                    this.updateBankIndicator = 1;
                    this.imageVersionIndicator = 2;
                }
            }
            if (i3 >= 7) {
                this.mtu = wrap.getShort(i2 + 6) & UShort.MAX_VALUE;
            }
        }
        a();
    }

    public void setBatteryLevel(int i2, int i3) {
        this.f4494f = true;
        this.f4495g = i2;
        this.f4496h = i3;
    }
}
