package com.realsil.sdk.dfu.utils;

import android.content.Context;
import android.os.Handler;
import android.os.Message;
import com.realsil.sdk.core.logger.ZLogger;
import com.realsil.sdk.dfu.RtkDfu;
import com.realsil.sdk.dfu.image.BinIndicator;
import com.realsil.sdk.dfu.image.pack.SubFileInfo;
import com.realsil.sdk.dfu.model.BinInfo;
import com.realsil.sdk.dfu.model.DfuConfig;
import com.realsil.sdk.dfu.model.DfuProgressInfo;
import com.realsil.sdk.dfu.model.FileTypeInfo;
import com.realsil.sdk.dfu.model.OtaDeviceInfo;
import com.realsil.sdk.dfu.model.OtaModeInfo;
import com.realsil.sdk.dfu.model.Throughput;
import com.realsil.sdk.dfu.params.QcConfig;
import com.realsil.sdk.dfu.r.a;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.List;

/* loaded from: classes3.dex */
public abstract class DfuAdapter {
    public static final int MODE_QC = 1;
    public static final int MODE_RELEASE = 0;
    public static final int SECONDARY_STATE_IDLE = 0;
    public static final int STAGE_BACK_CONNECT = 2048;
    public static final int STAGE_IDLE = 0;
    public static final int STAGE_INIT = 256;
    public static final int STAGE_OTA = 1024;
    public static final int STAGE_PREPARE = 512;
    public static final int STATE_ABORTED = 8193;
    public static final int STATE_BACKCONNECT_COMPLETED = 2063;
    public static final int STATE_BACKCONNECT_CONNECTING = 2069;
    public static final int STATE_BACKCONNECT_FAILED = 2062;
    public static final int STATE_BACKCONNECT_SYNC_DATA = 2072;
    public static final int STATE_BACKCONNECT_VALIDATE = 2077;
    public static final int STATE_BACKCONNECT_VALIDATE_FAILED = 2061;
    public static final int STATE_BACKCONNECT_WAIT_PROFILE_CONNECTED = 2065;
    public static final int STATE_CONNECT_FAILED = 4098;
    public static final int STATE_DISCONNECTED = 4097;
    public static final int STATE_DISCONNECTING = 4096;
    public static final int STATE_DISCOVERY_SERVICE = 535;
    public static final int STATE_INIT_BINDING_SERVICE = 257;
    public static final int STATE_INIT_OK = 258;
    public static final int STATE_MASK_BUSY = 16;
    public static final int STATE_MASK_IDLE = 0;
    public static final int STATE_OTA_PROCESSING = 1025;
    public static final int STATE_OTA_START_FAILED = 1026;
    public static final int STATE_PENDDING_DISCOVERY_SERVICE = 534;
    public static final int STATE_PENDING_ABORT = 8192;
    public static final int STATE_PREPARED = 527;
    public static final int STATE_PREPARE_CONNECTING = 533;
    public static final int STATE_PREPARE_PAIRING_REQUEST = 532;
    public static final int STATE_READ_BATTERY_INFO = 540;
    public static final int STATE_READ_DEVICE_INFO = 537;
    public static final int STATE_READ_IMAGE_INFO = 539;
    public static final int STATE_READ_PROTOCOL_TYPE = 538;

    /* renamed from: i, reason: collision with root package name */
    public ConnectParams f4584i;
    public DfuHelperCallback k;
    public Context mContext;
    public OtaDeviceInfo q;
    public DfuConfig r;

    /* renamed from: e, reason: collision with root package name */
    public boolean f4580e = true;

    /* renamed from: f, reason: collision with root package name */
    public boolean f4581f = RtkDfu.DEBUG_ENABLE;

    /* renamed from: g, reason: collision with root package name */
    public boolean f4582g = RtkDfu.VDBG;

    /* renamed from: h, reason: collision with root package name */
    public a f4583h = null;

    /* renamed from: j, reason: collision with root package name */
    public int f4585j = 2;
    public Object l = new Object();
    public int m = 0;
    public int n = 0;
    public int o = 0;
    public boolean p = false;
    public Handler s = new Handler();
    public Runnable t = new Runnable() { // from class: com.realsil.sdk.dfu.utils.DfuAdapter.1
        @Override // java.lang.Runnable
        public void run() {
            DfuAdapter.this.b();
        }
    };

    public static final class BackConnectState extends ConnectState {
        public static final int CHECK_OTA_RESULT = 29;
        public static final int CHECK_OTA_RESULT_FAILED = 13;
    }

    public static class ConnectState {
        public static final int COMPLETED = 15;
        public static final int CONNECTING = 21;
        public static final int CONNECT_PROILE = 17;
        public static final int DISCOVERY_SERVICE = 23;
        public static final int ERROR = 14;
        public static final int PAIRING_REQUEST = 20;
        public static final int PENDING_CREATE_BOND = 18;
        public static final int PENDING_DISCOVERY_SERVICE = 22;
        public static final int PENDING_REMOVE_BOND = 19;
        public static final int READ_BATTERY_INFO = 28;
        public static final int READ_DEVICE_INFO = 25;
        public static final int READ_IMAGE_INFO = 27;
        public static final int READ_PROTOCOL_TYPE = 26;
        public static final int SYNC_DATA = 24;
    }

    public static abstract class DfuHelperCallback {
        public void onError(int i2, int i3) {
        }

        public void onProcessStateChanged(int i2, Throughput throughput) {
        }

        public void onProgressChanged(DfuProgressInfo dfuProgressInfo) {
        }

        public void onStateChanged(int i2) {
        }

        public void onTargetInfoChanged(OtaDeviceInfo otaDeviceInfo) {
        }
    }

    public interface IInnerHandler {
        void handleMessage(Message message);
    }

    public static class InnerHandler extends Handler {

        /* renamed from: a, reason: collision with root package name */
        public IInnerHandler f4587a;

        public InnerHandler(IInnerHandler iInnerHandler) {
            this.f4587a = iInnerHandler;
        }

        @Override // android.os.Handler
        public void handleMessage(Message message) {
            super.handleMessage(message);
            IInnerHandler iInnerHandler = this.f4587a;
            if (iInnerHandler != null) {
                iInnerHandler.handleMessage(message);
            } else {
                ZLogger.d("mIInnerHandler is null");
            }
        }
    }

    public static class InnerHandler2 extends Handler {

        /* renamed from: a, reason: collision with root package name */
        public WeakReference<IInnerHandler> f4588a;

        public InnerHandler2(IInnerHandler iInnerHandler) {
            this.f4588a = new WeakReference<>(iInnerHandler);
        }

        @Override // android.os.Handler
        public void handleMessage(Message message) {
            super.handleMessage(message);
            IInnerHandler iInnerHandler = this.f4588a.get();
            if (iInnerHandler != null) {
                iInnerHandler.handleMessage(message);
            } else {
                ZLogger.d("mWeakReference is null");
            }
        }
    }

    public static List<FileTypeInfo> getSupportedFileContents(BinInfo binInfo) {
        ArrayList arrayList = new ArrayList();
        List<SubFileInfo> list = binInfo != null ? binInfo.supportSubFileInfos : null;
        if (list != null && list.size() > 0) {
            for (SubFileInfo subFileInfo : list) {
                int i2 = binInfo.icType;
                if (i2 <= 3) {
                    arrayList.add(new FileTypeInfo(subFileInfo.bitNumber, BinIndicator.parseBitNumber(i2, subFileInfo.wrapperBitNumber())));
                } else {
                    arrayList.add(new FileTypeInfo(subFileInfo.bitNumber, BinIndicator.parseSubBinId(i2, subFileInfo.binId)));
                }
            }
        }
        return arrayList;
    }

    public boolean a() {
        DfuConfig dfuConfig = this.r;
        return dfuConfig != null && dfuConfig.isCheckOtaResultEnabled();
    }

    public boolean abort() {
        return true;
    }

    public void addDfuHelperCallback(DfuHelperCallback dfuHelperCallback) {
        this.k = dfuHelperCallback;
    }

    public boolean b() {
        if (this.f4583h == null) {
            ZLogger.d(this.f4580e, "dfu has not been initialized");
            initialize();
        }
        if (this.f4584i == null) {
            ZLogger.d("mConnectParams == null");
            notifyStateChanged(4098);
            return false;
        }
        ZLogger.v("retry to reconnect device, reconnectTimes =" + this.f4585j);
        return true;
    }

    public boolean checkResult(OtaDeviceInfo otaDeviceInfo, BinInfo binInfo, com.realsil.sdk.dfu.s.a aVar) {
        return false;
    }

    public boolean checkStage(int i2) {
        return (this.n & i2) == i2;
    }

    public boolean checkState(int i2, int i3) {
        return this.n == (i2 | i3);
    }

    public boolean connectBack() {
        if (!this.p) {
            return true;
        }
        ZLogger.d("ota is processing, please wait");
        return false;
    }

    public boolean connectDevice(ConnectParams connectParams) {
        if (this.f4583h == null) {
            ZLogger.w(this.f4580e, "dfu has not been initialized");
            initialize();
            return false;
        }
        if (connectParams == null) {
            ZLogger.w("ConnectParams can not be null");
            return false;
        }
        this.f4584i = connectParams;
        this.f4585j = connectParams.getReconnectTimes();
        ZLogger.v("mConnectParams:" + this.f4584i.toString());
        return true;
    }

    public void destroy() {
        ZLogger.v(this.f4580e, "destroy");
        this.m = 0;
        this.n = 0;
        this.f4584i = null;
        this.f4585j = 0;
        Handler handler = this.s;
        if (handler != null) {
            handler.removeCallbacks(null);
        }
        this.k = null;
        a aVar = this.f4583h;
        if (aVar != null) {
            aVar.b();
        }
    }

    public void disconnect() {
        this.f4585j = 0;
        Handler handler = this.s;
        if (handler != null) {
            handler.removeCallbacks(null);
        }
    }

    public boolean equals(Object obj, Object obj2) {
        return obj == obj2 || (obj != null && obj.equals(obj2));
    }

    public Context getContext() {
        return this.mContext;
    }

    public DfuHelperCallback getDfuAdapterCallback() {
        return this.k;
    }

    public OtaModeInfo getPriorityWorkMode(int i2) {
        List<OtaModeInfo> supportedModes = getSupportedModes();
        if (supportedModes == null || supportedModes.size() <= 0) {
            return new OtaModeInfo(0);
        }
        for (OtaModeInfo otaModeInfo : supportedModes) {
            if (otaModeInfo.getWorkmode() == i2) {
                return otaModeInfo;
            }
        }
        return supportedModes.get(0);
    }

    public int getState() {
        return this.n;
    }

    public List<OtaModeInfo> getSupportedModes() {
        return new ArrayList();
    }

    public boolean initialize() {
        return true;
    }

    public boolean isBackConnecting() {
        return (this.n & 2048) == 2048;
    }

    public boolean isBusy() {
        return (this.n & 16) == 16;
    }

    public boolean isInitalized() {
        return this.n >= 258;
    }

    public boolean isPreparing() {
        return (this.n & 512) == 512;
    }

    public boolean isStageBusy(int i2) {
        int i3 = this.n;
        return (i3 & i2) == i2 && (i3 & 16) == 16;
    }

    public void notifyError(int i2) {
        notifyError(65536, i2);
    }

    public void notifyLock() {
        try {
            synchronized (this.l) {
                this.l.notifyAll();
            }
        } catch (Exception e2) {
            e2.printStackTrace();
            ZLogger.e(e2.toString());
        }
    }

    public void notifyProgressChanged(DfuProgressInfo dfuProgressInfo) {
        DfuHelperCallback dfuHelperCallback = this.k;
        if (dfuHelperCallback != null) {
            dfuHelperCallback.onProgressChanged(dfuProgressInfo);
        } else {
            ZLogger.v(this.f4582g, "no callback registed");
        }
    }

    public void notifyStateChanged(int i2) {
        ZLogger.v(String.format("DFU 0x%04X >> 0x%04X", Integer.valueOf(this.n), Integer.valueOf(i2)));
        this.n = i2;
        DfuHelperCallback dfuHelperCallback = this.k;
        if (dfuHelperCallback != null) {
            dfuHelperCallback.onStateChanged(i2);
        } else {
            ZLogger.v(this.f4582g, "no callback registed");
        }
    }

    public void removeDfuHelperCallback(DfuHelperCallback dfuHelperCallback) {
        this.k = null;
    }

    public void setDfuAdapterCallback(DfuHelperCallback dfuHelperCallback) {
        this.k = dfuHelperCallback;
    }

    public void setMode(int i2) {
        this.o = i2;
    }

    public boolean setTestParams(OtaDeviceInfo otaDeviceInfo, QcConfig qcConfig) {
        if (otaDeviceInfo != null && qcConfig != null) {
            return false;
        }
        ZLogger.d("IllegalArgumentException: deviceInfo and params can not be null");
        return false;
    }

    public boolean validate(OtaDeviceInfo otaDeviceInfo) {
        if (this.q != null) {
            return true;
        }
        ZLogger.d("cacheDeviceInfo has already been clean");
        return false;
    }

    public void a(long j2) {
        synchronized (this.l) {
            try {
                if (this.f4582g) {
                    ZLogger.v("waitSyncLock");
                }
                this.l.wait(j2);
            } catch (InterruptedException e2) {
                ZLogger.d("wait sync data interrupted: " + e2.toString());
            }
        }
    }

    public void notifyError(int i2, int i3) {
        ZLogger.v(String.format("onError: 0x%04X", Integer.valueOf(i3)));
        DfuHelperCallback dfuHelperCallback = this.k;
        if (dfuHelperCallback != null) {
            dfuHelperCallback.onError(i2, i3);
        } else {
            ZLogger.v(this.f4582g, "no callback registed");
        }
    }

    public void notifyStateChanged(int i2, int i3) {
        int i4 = i3 | i2;
        ZLogger.v(String.format("notifyStateChanged 0x%04X >> 0x%04X", Integer.valueOf(this.n), Integer.valueOf(i4)));
        this.m = i2;
        this.n = i4;
        DfuHelperCallback dfuHelperCallback = this.k;
        if (dfuHelperCallback != null) {
            dfuHelperCallback.onStateChanged(i4);
        } else {
            ZLogger.v(this.f4582g, "no callback registed");
        }
    }

    public OtaModeInfo getPriorityWorkMode() {
        return getPriorityWorkMode(16);
    }
}
