package com.realsil.sdk.dfu.utils;

import android.content.Context;
import android.content.res.AssetManager;
import android.text.TextUtils;
import androidx.core.app.FrameMetricsAggregator;
import com.dd.plist.ASCIIPropertyListParser;
import com.facebook.internal.security.CertificateUtil;
import com.google.android.gms.common.ConnectionResult;
import com.realsil.sdk.core.logger.ZLogger;
import com.realsil.sdk.dfu.image.wrapper.BinImageWrapper;
import java.io.IOException;
import java.util.Locale;

/* loaded from: classes3.dex */
public class DfuUtils {
    public static int IMAGE_VERSION_FORMAT;
    public static final int IMAGE_VERSION_FORMAT_AUTO = 0;

    public static int binarySearch(int[] iArr, int i2) {
        if (iArr == null || iArr.length <= 0) {
            return -1;
        }
        int length = iArr.length - 1;
        int i3 = 0;
        while (i3 <= length) {
            int i4 = (i3 + length) >>> 1;
            int i5 = iArr[i4];
            if (i5 < i2) {
                i3 = i4 + 1;
            } else {
                if (i5 <= i2) {
                    return i4;
                }
                length = i4 - 1;
            }
        }
        return ~i3;
    }

    public static String convertVersion2Str(int i2, int i3) {
        return convertVersion2Str(0, i2, i3);
    }

    public static String formatBatteryLevel(int i2) {
        return String.format(Locale.US, "%d%%", Integer.valueOf(i2));
    }

    public static String formatImageVersionWithBinId(int i2, int i3, int i4, int i5) {
        return new BinImageWrapper.Builder().setOtaVersion(i4).setImageVersion(i5).setFormatWithBinId(i2, i3).build().getFormatedVersion();
    }

    public static String formatImageVersionWithBitNumber(int i2, int i3, int i4, int i5) {
        return new BinImageWrapper.Builder().setOtaVersion(i4).setImageVersion(i5).setFormatWithBitNumber(i2, i3).build().getFormatedVersion();
    }

    public static String formatLinkKey(byte[] bArr) {
        if (bArr == null || bArr.length <= 0) {
            return null;
        }
        StringBuilder sb = new StringBuilder();
        int length = bArr.length;
        for (int i2 = 0; i2 < length; i2++) {
            byte b2 = bArr[i2];
            if ((b2 & 255) <= 15) {
                sb.append("0" + Integer.toHexString(bArr[i2] & 255).toUpperCase());
            } else {
                sb.append(Integer.toHexString(b2 & 255).toUpperCase());
            }
            if (i2 < length - 1) {
                sb.append(CertificateUtil.DELIMITER);
            }
        }
        return sb.toString();
    }

    public static String formatManufacturerAddr(String str) {
        char[] charArray = str.toCharArray();
        char[] cArr = new char[17];
        int i2 = 0;
        int i3 = 0;
        while (i2 < 17) {
            int i4 = i2 + 1;
            if (i4 % 3 == 0) {
                cArr[i2] = ASCIIPropertyListParser.DATE_TIME_FIELD_DELIMITER;
            } else {
                cArr[i2] = charArray[i3];
                i3++;
            }
            i2 = i4;
        }
        return String.valueOf(cArr);
    }

    public static String getAssetsFileName(String str) {
        int lastIndexOf = str.lastIndexOf("/");
        if (lastIndexOf == -1) {
            return str;
        }
        if (lastIndexOf != 0) {
            str.substring(0, lastIndexOf + 1);
        }
        return str.substring(lastIndexOf + 1);
    }

    public static int getBatteryLevel(int i2) {
        if (i2 >= 80) {
            return 5;
        }
        if (i2 >= 60) {
            return 4;
        }
        if (i2 >= 40) {
            return 3;
        }
        if (i2 >= 20) {
            return 2;
        }
        return i2 >= 1 ? 1 : 0;
    }

    public static int getControlSpeed(int i2) {
        switch (i2) {
            case 1:
                return 3000;
            case 2:
                return 2500;
            case 3:
                return 2000;
            case 4:
                return ConnectionResult.DRIVE_EXTERNAL_STORAGE_REQUIRED;
            case 5:
                return 1000;
            case 6:
                return 500;
            default:
                return -1;
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:34:0x0040, code lost:
    
        if (r8 == 2048) goto L34;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static int getImageVersionFormatWithBinId(int r7, int r8) {
        /*
            r0 = 2
            r1 = 1
            r2 = 3
            if (r7 > r2) goto L7
            r3 = 7
            goto L46
        L7:
            r3 = 768(0x300, float:1.076E-42)
            r4 = 512(0x200, float:7.17E-43)
            r5 = 5
            if (r7 == r5) goto L36
            r6 = 9
            if (r7 == r6) goto L36
            r6 = 12
            if (r7 != r6) goto L17
            goto L36
        L17:
            if (r8 == r4) goto L45
            if (r8 == r3) goto L34
            r3 = 1024(0x400, float:1.435E-42)
            if (r8 == r3) goto L32
            r3 = 1040(0x410, float:1.457E-42)
            if (r8 == r3) goto L2f
            r3 = 1280(0x500, float:1.794E-42)
            if (r8 == r3) goto L2c
            r3 = 1538(0x602, float:2.155E-42)
            if (r8 == r3) goto L2c
            goto L43
        L2c:
            r3 = 515(0x203, float:7.22E-43)
            goto L46
        L2f:
            r3 = 514(0x202, float:7.2E-43)
            goto L46
        L32:
            r3 = r0
            goto L46
        L34:
            r3 = r5
            goto L46
        L36:
            if (r8 == r4) goto L45
            if (r8 == r3) goto L45
            r3 = 1792(0x700, float:2.511E-42)
            if (r8 == r3) goto L45
            r3 = 2048(0x800, float:2.87E-42)
            if (r8 == r3) goto L43
            goto L45
        L43:
            r3 = r1
            goto L46
        L45:
            r3 = r2
        L46:
            java.util.Locale r4 = java.util.Locale.US
            java.lang.Object[] r2 = new java.lang.Object[r2]
            java.lang.Integer r7 = java.lang.Integer.valueOf(r7)
            r5 = 0
            r2[r5] = r7
            java.lang.Integer r7 = java.lang.Integer.valueOf(r8)
            r2[r1] = r7
            java.lang.Integer r7 = java.lang.Integer.valueOf(r3)
            r2[r0] = r7
            java.lang.String r7 = "icType=0x%02X, binId=0x%04X, format=%d"
            java.lang.String r7 = java.lang.String.format(r4, r7, r2)
            com.realsil.sdk.core.logger.ZLogger.v(r7)
            return r3
        */
        throw new UnsupportedOperationException("Method not decompiled: com.realsil.sdk.dfu.utils.DfuUtils.getImageVersionFormatWithBinId(int, int):int");
    }

    /* JADX WARN: Removed duplicated region for block: B:14:0x0019 A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:15:0x001c A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:16:0x001f  */
    /* JADX WARN: Removed duplicated region for block: B:18:0x0021 A[RETURN, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static int getImageVersionFormatWithBitNumber(int r4, int r5) {
        /*
            r0 = 3
            if (r4 > r0) goto L5
            r0 = 7
            goto L32
        L5:
            r1 = 2
            r2 = 5
            if (r4 == r2) goto L23
            r3 = 9
            if (r4 == r3) goto L23
            r3 = 12
            if (r4 != r3) goto L12
            goto L23
        L12:
            switch(r5) {
                case 0: goto L31;
                case 1: goto L31;
                case 2: goto L21;
                case 3: goto L32;
                case 4: goto L32;
                case 5: goto L1f;
                case 6: goto L1c;
                case 7: goto L1c;
                case 8: goto L19;
                case 9: goto L31;
                default: goto L15;
            }
        L15:
            switch(r5) {
                case 19: goto L32;
                case 20: goto L32;
                case 21: goto L1f;
                case 22: goto L1c;
                case 23: goto L1c;
                case 24: goto L19;
                case 25: goto L31;
                default: goto L18;
            }
        L18:
            goto L21
        L19:
            r0 = 514(0x202, float:7.2E-43)
            goto L32
        L1c:
            r0 = 515(0x203, float:7.22E-43)
            goto L32
        L1f:
            r0 = r2
            goto L32
        L21:
            r0 = 1
            goto L32
        L23:
            if (r5 == r1) goto L31
            if (r5 == r0) goto L32
            r4 = 4
            if (r5 == r4) goto L32
            if (r5 == r2) goto L32
            r4 = 18
            if (r5 == r4) goto L31
            goto L32
        L31:
            r0 = r1
        L32:
            return r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.realsil.sdk.dfu.utils.DfuUtils.getImageVersionFormatWithBitNumber(int, int):int");
    }

    /* JADX WARN: Removed duplicated region for block: B:14:0x0019 A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:15:0x001c A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:16:0x001f  */
    /* JADX WARN: Removed duplicated region for block: B:18:0x0021 A[RETURN, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static int getSocImageVersionFormatWithBitNumber(int r2, boolean r3, int r4, int r5) {
        /*
            r2 = 3
            if (r4 > r2) goto L5
            r2 = 7
            goto L32
        L5:
            r3 = 2
            r0 = 5
            if (r4 == r0) goto L23
            r1 = 9
            if (r4 == r1) goto L23
            r1 = 12
            if (r4 != r1) goto L12
            goto L23
        L12:
            switch(r5) {
                case 0: goto L31;
                case 1: goto L31;
                case 2: goto L21;
                case 3: goto L32;
                case 4: goto L32;
                case 5: goto L1f;
                case 6: goto L1c;
                case 7: goto L1c;
                case 8: goto L19;
                case 9: goto L31;
                default: goto L15;
            }
        L15:
            switch(r5) {
                case 19: goto L32;
                case 20: goto L32;
                case 21: goto L1f;
                case 22: goto L1c;
                case 23: goto L1c;
                case 24: goto L19;
                case 25: goto L31;
                default: goto L18;
            }
        L18:
            goto L21
        L19:
            r2 = 514(0x202, float:7.2E-43)
            goto L32
        L1c:
            r2 = 515(0x203, float:7.22E-43)
            goto L32
        L1f:
            r2 = r0
            goto L32
        L21:
            r2 = 1
            goto L32
        L23:
            if (r5 == r3) goto L31
            if (r5 == r2) goto L32
            r4 = 4
            if (r5 == r4) goto L32
            if (r5 == r0) goto L32
            r4 = 18
            if (r5 == r4) goto L31
            goto L32
        L31:
            r2 = r3
        L32:
            return r2
        */
        throw new UnsupportedOperationException("Method not decompiled: com.realsil.sdk.dfu.utils.DfuUtils.getSocImageVersionFormatWithBitNumber(int, boolean, int, int):int");
    }

    public static boolean isAssetsFileExist(Context context, String str) {
        String str2;
        String[] list;
        AssetManager assets = context.getResources().getAssets();
        if (assets == null || TextUtils.isEmpty(str)) {
            return false;
        }
        int lastIndexOf = str.lastIndexOf("/");
        str2 = "";
        if (lastIndexOf != -1) {
            str2 = lastIndexOf != 0 ? str.substring(0, lastIndexOf) : "";
            str = str.substring(lastIndexOf + 1);
        }
        try {
            list = assets.list(str2);
        } catch (IOException e2) {
            e2.printStackTrace();
        }
        if (list != null && list.length > 0) {
            for (String str3 : list) {
                if (str.equals(str3)) {
                    ZLogger.v("\t =" + str3);
                    return true;
                }
                ZLogger.v("\t =" + str3);
            }
            ZLogger.v(String.format("not find asset file: <%s>/<%s>", str2, str));
            return false;
        }
        ZLogger.d(String.format("no asset file found: <%s>/<%s>", str2, str));
        return false;
    }

    public static String convertVersion2Str(int i2, int i3, int i4) {
        return i4 == 1 ? i2 <= 0 ? String.valueOf(i3) : String.format(Locale.US, "%d.%d.%d.%d", Integer.valueOf(i3 & 255), Integer.valueOf((i3 >> 8) & 255), Integer.valueOf((i3 >> 16) & 255), Integer.valueOf((i3 >> 24) & 255)) : i4 == 2 ? i2 <= 0 ? String.valueOf(i3) : String.format(Locale.US, "%d.%d.%d.%d", Integer.valueOf((i3 >> 24) & 255), Integer.valueOf((i3 >> 16) & 255), Integer.valueOf((i3 >> 8) & 255), Integer.valueOf(i3 & 255)) : i4 == 3 ? i2 <= 0 ? String.valueOf(i3) : String.format(Locale.US, "%d.%d.%d.%d", Integer.valueOf(i3 & 15), Integer.valueOf((i3 >> 4) & 255), Integer.valueOf((i3 >> 12) & 32767), Integer.valueOf((i3 >> 27) & 31)) : i4 == 5 ? i2 <= 0 ? String.valueOf(i3) : String.format(Locale.US, "%d.%d.%d.%d", Integer.valueOf(i3 & 15), Integer.valueOf((i3 >> 4) & 255), Integer.valueOf((i3 >> 12) & FrameMetricsAggregator.EVERY_DURATION), Integer.valueOf((i3 >> 21) & 2047)) : i4 == 515 ? i2 <= 0 ? String.valueOf(i3) : String.format(Locale.US, "%d.%d.%d.%d", 0, 0, Integer.valueOf((i3 >> 8) & 255), Integer.valueOf(i3 & 255)) : i4 == 4 ? String.valueOf(i3) : i4 == 7 ? String.valueOf(i3) : i4 == 514 ? i2 <= 0 ? String.valueOf(i3) : String.format(Locale.US, "%d.%d.%d.%d", Integer.valueOf((i3 >> 8) & 255), Integer.valueOf(i3 & 255), Integer.valueOf((i3 >> 24) & 255), Integer.valueOf((i3 >> 16) & 255)) : String.valueOf(i3);
    }
}
