package com.realsil.sdk.dfu.utils;

import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothGatt;
import android.bluetooth.BluetoothGattCallback;
import android.bluetooth.BluetoothGattCharacteristic;
import android.bluetooth.BluetoothGattService;
import android.content.Context;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import com.realsil.sdk.core.bluetooth.BluetoothProfileCallback;
import com.realsil.sdk.core.bluetooth.BluetoothProfileManager;
import com.realsil.sdk.core.bluetooth.GlobalGatt;
import com.realsil.sdk.core.bluetooth.impl.BluetoothGattImpl;
import com.realsil.sdk.core.logger.ZLogger;
import com.realsil.sdk.dfu.exception.ConnectionException;
import com.realsil.sdk.dfu.exception.LoadFileException;
import com.realsil.sdk.dfu.image.FirmwareLoaderX;
import com.realsil.sdk.dfu.image.LoadParams;
import com.realsil.sdk.dfu.image.pack.SubFileInfo;
import com.realsil.sdk.dfu.j.a;
import com.realsil.sdk.dfu.model.BinInfo;
import com.realsil.sdk.dfu.model.DfuConfig;
import com.realsil.sdk.dfu.model.OtaDeviceInfo;
import com.realsil.sdk.dfu.model.OtaModeInfo;
import com.realsil.sdk.dfu.params.QcConfig;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.List;
import java.util.Locale;
import java.util.Objects;
import java.util.UUID;

/* loaded from: classes3.dex */
public class HidDfuAdapter extends BluetoothDfuAdapter implements com.realsil.sdk.dfu.j.c {
    public static volatile HidDfuAdapter O;
    public GlobalGatt D;
    public BluetoothGatt E;
    public BluetoothGattService F;
    public BluetoothGattService G;
    public BluetoothGattCharacteristic H;
    public com.realsil.sdk.dfu.j.a I;
    public a.c J = new a();
    public Runnable K = new b();
    public Runnable L = new c();
    public Handler M = new Handler(Looper.getMainLooper());
    public BluetoothGattCallback N = new d();

    public class a implements a.c {
        public a() {
        }

        @Override // com.realsil.sdk.dfu.j.a.c
        public void a(int i2) {
            if (i2 == 1) {
                if (HidDfuAdapter.this.isPreparing()) {
                    HidDfuAdapter.this.notifyStateChanged(527);
                } else if (!HidDfuAdapter.this.isBackConnecting()) {
                    HidDfuAdapter hidDfuAdapter = HidDfuAdapter.this;
                    ZLogger.v(hidDfuAdapter.f4582g, String.format("ignore, is not in preparing or backconnect state: 0x%04X", Integer.valueOf(hidDfuAdapter.n)));
                } else if (HidDfuAdapter.this.a()) {
                    HidDfuAdapter.this.notifyStateChanged(DfuAdapter.STATE_BACKCONNECT_VALIDATE);
                    HidDfuAdapter hidDfuAdapter2 = HidDfuAdapter.this;
                    if (hidDfuAdapter2.validate(hidDfuAdapter2.getOtaDeviceInfo())) {
                        HidDfuAdapter.this.notifyStateChanged(DfuAdapter.STATE_BACKCONNECT_COMPLETED);
                    } else {
                        HidDfuAdapter.this.notifyStateChanged(DfuAdapter.STATE_BACKCONNECT_VALIDATE_FAILED);
                    }
                } else {
                    HidDfuAdapter.this.notifyStateChanged(DfuAdapter.STATE_BACKCONNECT_COMPLETED);
                }
            }
            if (i2 == 2) {
                if (HidDfuAdapter.this.isPreparing() || HidDfuAdapter.this.isBackConnecting()) {
                    HidDfuAdapter.this.a(new ConnectionException(5));
                } else {
                    ZLogger.d(String.format("ignore, is not in preparing state: 0x%04X", Integer.valueOf(HidDfuAdapter.this.n)));
                }
            }
        }
    }

    public class b implements Runnable {
        public b() {
        }

        @Override // java.lang.Runnable
        public void run() {
            HidDfuAdapter hidDfuAdapter = HidDfuAdapter.this;
            hidDfuAdapter.y = hidDfuAdapter.getBondState(hidDfuAdapter.z);
            ZLogger.v(">> mBondState: " + HidDfuAdapter.this.y);
            HidDfuAdapter hidDfuAdapter2 = HidDfuAdapter.this;
            if (hidDfuAdapter2.y == 11) {
                hidDfuAdapter2.a(15000L);
                try {
                    Thread.sleep(800L);
                } catch (InterruptedException e2) {
                    e2.printStackTrace();
                }
            }
            HidDfuAdapter.this.e();
        }
    }

    public class c implements Runnable {
        public c() {
        }

        @Override // java.lang.Runnable
        public void run() {
            if (HidDfuAdapter.this.checkState(512, 22) || HidDfuAdapter.this.checkState(2048, 22)) {
                new Thread(HidDfuAdapter.this.K).start();
                return;
            }
            if (HidDfuAdapter.this.n == 532) {
                ZLogger.d("STATE_PROCESS_PAIRING_REQUEST: wait to discover service");
                new Thread(HidDfuAdapter.this.K).start();
            } else {
                ZLogger.d("ignore state:" + HidDfuAdapter.this.n);
            }
        }
    }

    public class d extends BluetoothGattCallback {
        public d() {
        }

        public final void a() {
            if (!HidDfuAdapter.this.isPreparing()) {
                HidDfuAdapter.this.notifyStateChanged(4097);
            } else {
                HidDfuAdapter.this.notifyLock();
                HidDfuAdapter.this.a(new ConnectionException(0));
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onCharacteristicRead(BluetoothGatt bluetoothGatt, BluetoothGattCharacteristic bluetoothGattCharacteristic, int i2) {
            super.onCharacteristicRead(bluetoothGatt, bluetoothGattCharacteristic, i2);
            UUID uuid = bluetoothGattCharacteristic.getUuid();
            bluetoothGattCharacteristic.getValue();
            if (i2 != 0) {
                ZLogger.d(HidDfuAdapter.this.f4580e, "Characteristic read error: " + i2);
                if (!com.realsil.sdk.dfu.j.c.f4451c.equals(uuid)) {
                    ZLogger.v("ignore exctption when read other info");
                    return;
                } else {
                    if (HidDfuAdapter.this.isPreparing()) {
                        HidDfuAdapter.this.a(new ConnectionException(5));
                        return;
                    }
                    return;
                }
            }
            byte[] value = bluetoothGattCharacteristic.getValue();
            if (com.realsil.sdk.dfu.j.c.f4451c.equals(uuid)) {
                ByteBuffer wrap = ByteBuffer.wrap(value);
                wrap.order(ByteOrder.LITTLE_ENDIAN);
                HidDfuAdapter.this.b(wrap.getShort(0));
                if (HidDfuAdapter.this.I != null) {
                    com.realsil.sdk.dfu.j.a aVar = HidDfuAdapter.this.I;
                    HidDfuAdapter hidDfuAdapter = HidDfuAdapter.this;
                    String str = hidDfuAdapter.z;
                    BluetoothGatt bluetoothGatt2 = hidDfuAdapter.E;
                    HidDfuAdapter hidDfuAdapter2 = HidDfuAdapter.this;
                    aVar.a(str, bluetoothGatt2, hidDfuAdapter2.F, hidDfuAdapter2.G);
                }
            }
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onConnectionStateChange(BluetoothGatt bluetoothGatt, int i2, int i3) {
            if (i2 != 0) {
                a();
                return;
            }
            if (i3 != 2) {
                if (i3 == 0) {
                    HidDfuAdapter.this.disconnect();
                    a();
                    return;
                }
                return;
            }
            HidDfuAdapter hidDfuAdapter = HidDfuAdapter.this;
            hidDfuAdapter.E = hidDfuAdapter.D.getBluetoothGatt(HidDfuAdapter.this.z);
            ConnectParams connectParams = HidDfuAdapter.this.f4584i;
            if (connectParams != null && connectParams.isRefreshCache()) {
                BluetoothGattImpl.refresh(bluetoothGatt);
            }
            if (bluetoothGatt == null) {
                a();
                return;
            }
            if (HidDfuAdapter.this.isPreparing()) {
                HidDfuAdapter hidDfuAdapter2 = HidDfuAdapter.this;
                if (hidDfuAdapter2.n != 534) {
                    hidDfuAdapter2.notifyStateChanged(534);
                    if (HidDfuAdapter.this.M == null) {
                        ZLogger.v(HidDfuAdapter.this.f4582g, "mHandler == null");
                        return;
                    }
                    ZLogger.v("delay to discover service for : 1600");
                    HidDfuAdapter.this.M.removeCallbacks(HidDfuAdapter.this.L);
                    boolean postDelayed = HidDfuAdapter.this.M.postDelayed(HidDfuAdapter.this.L, 1600L);
                    if (postDelayed) {
                        return;
                    }
                    ZLogger.v(HidDfuAdapter.this.f4580e, "postDelayed:" + postDelayed);
                    return;
                }
                return;
            }
            if (!HidDfuAdapter.this.isBackConnecting() || HidDfuAdapter.this.checkState(2048, 22)) {
                return;
            }
            HidDfuAdapter.this.notifyStateChanged(2048, 22);
            if (HidDfuAdapter.this.M == null) {
                ZLogger.v(HidDfuAdapter.this.f4582g, "mHandler == null");
                return;
            }
            ZLogger.v("delay to discover service for : 1600");
            HidDfuAdapter.this.M.removeCallbacks(HidDfuAdapter.this.L);
            boolean postDelayed2 = HidDfuAdapter.this.M.postDelayed(HidDfuAdapter.this.L, 1600L);
            if (postDelayed2) {
                return;
            }
            ZLogger.v(HidDfuAdapter.this.f4580e, "postDelayed:" + postDelayed2);
        }

        @Override // android.bluetooth.BluetoothGattCallback
        public void onServicesDiscovered(BluetoothGatt bluetoothGatt, int i2) {
            HidDfuAdapter hidDfuAdapter = HidDfuAdapter.this;
            if (hidDfuAdapter.n == 1025) {
                ZLogger.d("ignore, when it is ota processing");
                return;
            }
            if (i2 != 0) {
                ZLogger.w("service discovery failed !!!");
                if (HidDfuAdapter.this.isPreparing()) {
                    HidDfuAdapter.this.a(new ConnectionException(1));
                    return;
                }
                return;
            }
            if (hidDfuAdapter.checkState(512, 23) || HidDfuAdapter.this.checkState(2048, 23)) {
                HidDfuAdapter hidDfuAdapter2 = HidDfuAdapter.this;
                hidDfuAdapter2.notifyStateChanged(hidDfuAdapter2.m, 25);
                HidDfuAdapter.this.notifyLock();
            }
        }
    }

    public class e extends BluetoothProfileCallback {
        public e() {
        }

        @Override // com.realsil.sdk.core.bluetooth.BluetoothProfileCallback
        public void onHidStateChanged(BluetoothDevice bluetoothDevice, int i2) {
            super.onHidStateChanged(bluetoothDevice, i2);
            HidDfuAdapter hidDfuAdapter = HidDfuAdapter.this;
            int i3 = hidDfuAdapter.n;
            if (i3 == 2065) {
                BluetoothDevice bluetoothDevice2 = hidDfuAdapter.x;
                if (bluetoothDevice2 == null) {
                    ZLogger.v("device has already been clean");
                    HidDfuAdapter.this.notifyStateChanged(DfuAdapter.STATE_BACKCONNECT_FAILED);
                    return;
                }
                if (!bluetoothDevice2.equals(bluetoothDevice)) {
                    ZLogger.v(String.format("target device is %s, ignore device:%s", HidDfuAdapter.this.x.toString(), bluetoothDevice.toString()));
                    return;
                }
                if (i2 == 2) {
                    ZLogger.v("pending to back connect with previous device");
                    HidDfuAdapter hidDfuAdapter2 = HidDfuAdapter.this;
                    hidDfuAdapter2.connectDevice(hidDfuAdapter2.f4584i);
                    return;
                } else {
                    if (i2 == 0) {
                        ZLogger.v("proile disconnected");
                        HidDfuAdapter.this.notifyStateChanged(DfuAdapter.STATE_BACKCONNECT_FAILED);
                        return;
                    }
                    return;
                }
            }
            if (i3 != 529) {
                ZLogger.v(hidDfuAdapter.f4582g, String.format("isgnore hid state change, when state is 0x%04X", Integer.valueOf(hidDfuAdapter.m)));
                return;
            }
            BluetoothDevice bluetoothDevice3 = hidDfuAdapter.x;
            if (bluetoothDevice3 == null) {
                ZLogger.v("device has already been clean");
                HidDfuAdapter.this.notifyStateChanged(4098);
                return;
            }
            if (!bluetoothDevice3.equals(bluetoothDevice)) {
                ZLogger.v(String.format("target device is %s, ignore device:%s", HidDfuAdapter.this.x.toString(), bluetoothDevice.toString()));
                return;
            }
            if (i2 == 0) {
                ZLogger.v(HidDfuAdapter.this.f4580e, "RCU Disconnected!");
                HidDfuAdapter.this.a(new ConnectionException(0));
                return;
            }
            if (i2 == 1) {
                ZLogger.v(HidDfuAdapter.this.f4582g, "RCU Connecting!");
                return;
            }
            if (i2 != 2) {
                if (i2 != 3) {
                    return;
                }
                ZLogger.v(HidDfuAdapter.this.f4582g, " RCU Disconnecting!");
            } else {
                ZLogger.v(HidDfuAdapter.this.f4580e, "RCU Connected!");
                HidDfuAdapter hidDfuAdapter3 = HidDfuAdapter.this;
                hidDfuAdapter3.a(hidDfuAdapter3.z);
            }
        }
    }

    public HidDfuAdapter(Context context) {
        this.mContext = context;
        c();
    }

    public static HidDfuAdapter getInstance(Context context) {
        if (O == null) {
            synchronized (HidDfuAdapter.class) {
                if (O == null) {
                    O = new HidDfuAdapter(context.getApplicationContext());
                }
            }
        }
        return O;
    }

    public int checkBatteryLevel(int i2, int i3) {
        int primaryBat = getOtaDeviceInfo().getPrimaryBat();
        if (getOtaDeviceInfo().icType <= 3 && i3 == 1) {
            primaryBat = (((primaryBat * 2) - 210) * 100) / 90;
        }
        if (primaryBat <= i2) {
            return 269;
        }
        return (primaryBat <= 110 || primaryBat > 140) ? 0 : 269;
    }

    @Override // com.realsil.sdk.dfu.utils.DfuAdapter
    public boolean connectBack() {
        if (!super.connectBack()) {
            ZLogger.v("connect back failed");
            return false;
        }
        BluetoothDevice bluetoothDevice = this.x;
        if (bluetoothDevice == null) {
            ZLogger.d("device has already been clean, no need to connect back");
            return false;
        }
        int bondState = bluetoothDevice.getBondState();
        this.y = bondState;
        if (bondState != 12) {
            ZLogger.d(this.f4580e, "device is not bonded, maybe has something wrong");
            return false;
        }
        if (this.v.getConnectionState(4, this.x) != 2) {
            ZLogger.v("wait hid profile auto connected");
            notifyStateChanged(2048, 17);
            return true;
        }
        this.m = 2048;
        ZLogger.d(this.f4580e, "profile has already connected, pending to connect");
        return connectDevice(this.f4584i);
    }

    @Override // com.realsil.sdk.dfu.utils.BluetoothDfuAdapter, com.realsil.sdk.dfu.utils.DfuAdapter
    public boolean connectDevice(ConnectParams connectParams) {
        if (!super.connectDevice(connectParams)) {
            return false;
        }
        String str = this.z;
        if (str != null && !Objects.equals(str, this.f4584i.getAddress())) {
            this.D.unRegisterCallback(this.z, this.N);
            this.D.close(this.z);
        }
        this.x = getRemoteDevice(this.f4584i.getAddress());
        this.z = this.f4584i.getAddress();
        if (this.m != 512) {
            this.m = 512;
        }
        boolean d2 = d();
        if (!d2) {
            notifyStateChanged(4098);
        }
        return d2;
    }

    @Override // com.realsil.sdk.dfu.utils.BluetoothDfuAdapter, com.realsil.sdk.dfu.utils.DfuAdapter
    public void destroy() {
        super.destroy();
        GlobalGatt globalGatt = this.D;
        if (globalGatt != null) {
            globalGatt.unRegisterCallback(this.z, this.N);
        }
        com.realsil.sdk.dfu.j.a aVar = this.I;
        if (aVar != null) {
            aVar.a();
        }
        O = null;
    }

    @Override // com.realsil.sdk.dfu.utils.DfuAdapter
    public void disconnect() {
        super.disconnect();
        String str = this.z;
        if (str == null) {
            ZLogger.d("no device registed");
            notifyStateChanged(4097);
        } else {
            GlobalGatt globalGatt = this.D;
            if (globalGatt == null) {
                ZLogger.d("mGlobalGatt == null");
                notifyStateChanged(4097);
            } else if (!globalGatt.isConnected(str)) {
                ZLogger.v("already disconnected");
                notifyStateChanged(4097);
            } else if (this.D.isCallbackRegisted(this.z, this.N)) {
                notifyStateChanged(4096);
                this.D.close(this.z);
            } else {
                ZLogger.v("no gatt callback registed");
                notifyStateChanged(4097);
            }
        }
        this.E = null;
    }

    @Override // com.realsil.sdk.dfu.utils.BluetoothDfuAdapter
    public BluetoothProfileCallback getBluetoothProfileCallback() {
        return new e();
    }

    @Override // com.realsil.sdk.dfu.utils.BluetoothDfuAdapter
    public OtaDeviceInfo getOtaDeviceInfo() {
        com.realsil.sdk.dfu.j.a aVar = this.I;
        return aVar != null ? aVar.b() : super.getOtaDeviceInfo();
    }

    @Override // com.realsil.sdk.dfu.utils.DfuAdapter
    public OtaModeInfo getPriorityWorkMode(int i2) {
        com.realsil.sdk.dfu.j.a aVar = this.I;
        return aVar != null ? aVar.a(i2) : super.getPriorityWorkMode(i2);
    }

    @Override // com.realsil.sdk.dfu.utils.DfuAdapter
    public List<OtaModeInfo> getSupportedModes() {
        com.realsil.sdk.dfu.j.a aVar = this.I;
        return aVar != null ? aVar.c() : super.getSupportedModes();
    }

    public boolean isHogpConnect(BluetoothDevice bluetoothDevice) {
        return bluetoothDevice != null && BluetoothProfileManager.getInstance().getConnectionState(4, bluetoothDevice) == 2;
    }

    @Override // com.realsil.sdk.dfu.utils.BluetoothDfuAdapter
    public void processBluetoothStateChanged(int i2) {
        super.processBluetoothStateChanged(i2);
        if (i2 != 10 || Build.VERSION.SDK_INT < 29) {
            return;
        }
        if (!isPreparing()) {
            notifyStateChanged(4097);
            return;
        }
        ZLogger.v("auto disconnect when bt off");
        disconnect();
        notifyLock();
        a(new ConnectionException(0));
    }

    @Override // com.realsil.sdk.dfu.utils.BluetoothDfuAdapter
    public void processBondStateChanged(int i2) {
        switch (i2) {
            case 10:
                ZLogger.v(this.f4580e, "BOND_NONE");
                if (checkState(512, 19)) {
                    if (this.x != null) {
                        notifyStateChanged(512, 18);
                        ZLogger.v(this.f4582g, "createBond");
                        this.x.createBond();
                        break;
                    } else {
                        ZLogger.v("device has already been clean");
                        notifyStateChanged(4098);
                        break;
                    }
                }
                break;
            case 11:
                ZLogger.v(this.f4580e, "BOND_BONDING");
                break;
            case 12:
                ZLogger.v(this.f4580e, "BOND_BONDED");
                if (!checkState(512, 18)) {
                    notifyLock();
                    break;
                } else {
                    BluetoothDevice bluetoothDevice = this.x;
                    if (bluetoothDevice != null) {
                        if (!isHogpConnect(bluetoothDevice)) {
                            ZLogger.v("hid not connect");
                            a(this.x);
                            break;
                        } else {
                            ZLogger.v("hid already connected");
                            a(this.z);
                            break;
                        }
                    } else {
                        ZLogger.v("device has already been clean");
                        notifyStateChanged(4098);
                        break;
                    }
                }
        }
    }

    public void readDeviceInfo() {
        BluetoothGattService service;
        BluetoothGattService service2;
        BluetoothGatt bluetoothGatt = this.E;
        if (bluetoothGatt == null) {
            return;
        }
        ConnectParams connectParams = this.f4584i;
        if (connectParams != null) {
            service = bluetoothGatt.getService(connectParams.getOtaServiceUuid());
            service2 = this.E.getService(this.f4584i.getDfuServiceUuid());
        } else {
            service = bluetoothGatt.getService(com.realsil.sdk.dfu.j.c.f4450b);
            service2 = this.E.getService(com.realsil.sdk.dfu.j.c.f4452d);
        }
        this.F = service;
        this.G = service2;
        notifyStateChanged(this.m, 26);
        if (service == null) {
            ZLogger.d(this.f4580e, "not find OTA_SERVICE = " + com.realsil.sdk.dfu.j.c.f4450b);
            this.H = null;
        } else {
            ZLogger.v(this.f4580e, "find OTA_SERVICE = " + com.realsil.sdk.dfu.j.c.f4450b);
            this.H = service.getCharacteristic(com.realsil.sdk.dfu.j.c.f4451c);
        }
        if (this.H != null) {
            ZLogger.v(this.f4580e, "find CHARACTERISTIC_PROTOCOL_TYPE = " + com.realsil.sdk.dfu.j.c.f4451c);
            a(this.H);
            return;
        }
        b(0);
        com.realsil.sdk.dfu.j.a aVar = this.I;
        if (aVar != null) {
            aVar.a(this.z, this.E, this.F, this.G);
        }
    }

    @Override // com.realsil.sdk.dfu.utils.BluetoothDfuAdapter
    public boolean startOtaProcedure(OtaDeviceInfo otaDeviceInfo, DfuConfig dfuConfig, QcConfig qcConfig, boolean z) {
        if (!super.startOtaProcedure(otaDeviceInfo, dfuConfig, qcConfig, z)) {
            return false;
        }
        notifyStateChanged(1025);
        GlobalGatt globalGatt = this.D;
        if (globalGatt != null) {
            globalGatt.unRegisterCallback(this.z, this.N);
        }
        com.realsil.sdk.dfu.j.a aVar = this.I;
        if (aVar != null) {
            aVar.a();
        }
        boolean a2 = this.f4583h.a(dfuConfig);
        if (!a2) {
            notifyStateChanged(1026);
        }
        return a2;
    }

    @Override // com.realsil.sdk.dfu.utils.DfuAdapter
    public boolean validate(OtaDeviceInfo otaDeviceInfo) {
        List<SubFileInfo> list;
        if (!super.validate(otaDeviceInfo)) {
            return false;
        }
        if (this.q.isBankEnabled()) {
            if (!otaDeviceInfo.isBankEnabled()) {
                ZLogger.d("conflict: not support bank");
                return false;
            }
            if (this.q.getActiveBank() == otaDeviceInfo.getActiveBank()) {
                ZLogger.d("conflict: active bank not changed");
                return false;
            }
        } else if (this.r != null) {
            try {
                BinInfo loadImageBinInfo = FirmwareLoaderX.loadImageBinInfo(new LoadParams.Builder().with(this.mContext).fileLocation(this.r.getFileLocation()).setFilePath(this.r.getFilePath()).setSectionSizeCheckEnabled(this.r.isSectionSizeCheckEnabled()).setIcCheckEnabled(this.r.isIcCheckEnabled()).setFileSuffix(this.r.getFileSuffix()).setVersionCheckEnabled(true).setOtaDeviceInfo(otaDeviceInfo).build());
                if (loadImageBinInfo != null && loadImageBinInfo.status == 0 && (list = loadImageBinInfo.supportSubFileInfos) != null && list.size() > 0) {
                    ZLogger.d("conflict: version not apply");
                    return false;
                }
            } catch (LoadFileException e2) {
                e2.printStackTrace();
            }
        }
        return true;
    }

    @Override // com.realsil.sdk.dfu.utils.DfuAdapter
    public boolean b() {
        if (!super.b()) {
            notifyStateChanged(4098);
            return false;
        }
        boolean d2 = d();
        if (!d2) {
            notifyStateChanged(4098);
        }
        return d2;
    }

    @Override // com.realsil.sdk.dfu.utils.BluetoothDfuAdapter
    public void c() {
        super.c();
        GlobalGatt globalGatt = GlobalGatt.getInstance();
        this.D = globalGatt;
        if (globalGatt == null) {
            GlobalGatt.initial(this.mContext);
            this.D = GlobalGatt.getInstance();
        }
    }

    public final boolean d() {
        boolean a2;
        int bondState = getBondState(this.z);
        this.y = bondState;
        ZLogger.v(this.f4580e, String.format(Locale.US, ">> mBondState: %d", Integer.valueOf(bondState)));
        if (!this.f4584i.isHid()) {
            return a(this.z);
        }
        if (this.y != 12) {
            ZLogger.d(this.f4580e, "connect with not bond device, bond first, current state: " + this.y);
            notifyStateChanged(512, 18);
            a2 = this.x.createBond();
        } else if (isHogpConnect(this.x)) {
            ZLogger.d("hogp already connected");
            a2 = a(this.z);
        } else {
            a2 = a(this.x);
        }
        return !a2 ? a(this.z) : a2;
    }

    public final boolean e() {
        if (this.n == 535) {
            ZLogger.w("discoverServices already started");
            return false;
        }
        if (this.E == null) {
            ZLogger.w("mBtGatt is null");
            return false;
        }
        notifyStateChanged(this.m | 23);
        ZLogger.v(this.f4582g, "discoverServices...");
        if (!this.E.discoverServices()) {
            ZLogger.d("discoverServices failed");
            if (isPreparing()) {
                a(new ConnectionException(1));
            }
            return false;
        }
        synchronized (this.l) {
            try {
                ZLogger.v(this.f4582g, "wait discover service complete");
                this.l.wait(30000L);
            } catch (InterruptedException e2) {
                e2.printStackTrace();
                ZLogger.e(e2.toString());
            }
        }
        if (this.n != 535) {
            readDeviceInfo();
            return true;
        }
        ZLogger.d("discoverServices timeout");
        disconnect();
        return false;
    }

    public final boolean a(String str) {
        notifyStateChanged(this.m | 21);
        ZLogger.v(this.f4582g, "connect gatt: " + this.z);
        return this.D.connect(str, this.N);
    }

    public final boolean a(BluetoothDevice bluetoothDevice) {
        if (bluetoothDevice == null) {
            return false;
        }
        notifyStateChanged(this.m | 17);
        return BluetoothProfileManager.getInstance().connectHid(bluetoothDevice);
    }

    public final void b(int i2) {
        ZLogger.v(String.format("protocolType=0x%04X", Integer.valueOf(i2)));
        com.realsil.sdk.dfu.j.a aVar = this.I;
        if (aVar != null) {
            aVar.a();
        }
        if (i2 == 16) {
            this.I = new com.realsil.sdk.dfu.m.a();
        } else if (i2 == 18) {
            ConnectParams connectParams = this.f4584i;
            this.I = new com.realsil.sdk.dfu.k.a(i2, connectParams != null && "BeeTgt02".equals(connectParams.getLocalName()));
        } else {
            ConnectParams connectParams2 = this.f4584i;
            this.I = new com.realsil.sdk.dfu.l.a(0, connectParams2 != null && "BeeTgt02".equals(connectParams2.getLocalName()));
        }
        this.I.a(this.z, this.E, this.F, this.G, this.J);
    }

    public final boolean a(BluetoothGattCharacteristic bluetoothGattCharacteristic) {
        if (this.E != null && bluetoothGattCharacteristic != null) {
            if (this.f4580e) {
                ZLogger.v(String.format(Locale.US, "readCharacteristic:(%d) %s", Integer.valueOf(bluetoothGattCharacteristic.getInstanceId()), bluetoothGattCharacteristic.getUuid().toString()));
            }
            return this.E.readCharacteristic(bluetoothGattCharacteristic);
        }
        ZLogger.w("mBtGatt is null maybe disconnected just now");
        return false;
    }
}
