package com.wevey.selector.dialog;

import android.app.Dialog;
import android.content.Context;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.TextView;
import androidx.core.content.ContextCompat;
import com.weavey.utils.ScreenSizeUtils;
import com.wevey.selector.dialog.DialogInterface;

/* loaded from: classes3.dex */
public class MDAlertDialog {
    private Builder mBuilder;
    private TextView mContent;
    private Dialog mDialog;
    private View mDialogView;
    private TextView mLeftBtn;
    private TextView mRightBtn;
    private TextView mTitle;

    public MDAlertDialog(Builder builder) {
        this.mBuilder = builder;
        this.mDialog = new Dialog(this.mBuilder.getContext(), R.style.MyDialogStyle);
        View inflate = View.inflate(this.mBuilder.getContext(), R.layout.widget_md_dialog, null);
        this.mDialogView = inflate;
        this.mTitle = (TextView) inflate.findViewById(R.id.md_dialog_title);
        this.mContent = (TextView) this.mDialogView.findViewById(R.id.md_dialog_content);
        this.mLeftBtn = (TextView) this.mDialogView.findViewById(R.id.md_dialog_leftbtn);
        this.mRightBtn = (TextView) this.mDialogView.findViewById(R.id.md_dialog_rightbtn);
        this.mDialogView.setMinimumHeight((int) (ScreenSizeUtils.getInstance(this.mBuilder.getContext()).getScreenHeight() * builder.getHeight()));
        this.mDialog.setContentView(this.mDialogView);
        Window window = this.mDialog.getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        attributes.width = (int) (ScreenSizeUtils.getInstance(this.mBuilder.getContext()).getScreenWidth() * builder.getWidth());
        attributes.height = -2;
        attributes.gravity = 17;
        window.setAttributes(attributes);
        initDialog();
    }

    private void initDialog() {
        this.mDialog.setCanceledOnTouchOutside(this.mBuilder.isTouchOutside());
        if (this.mBuilder.getTitleVisible()) {
            this.mTitle.setVisibility(0);
        } else {
            this.mTitle.setVisibility(8);
        }
        this.mTitle.setText(this.mBuilder.getTitleText());
        this.mTitle.setTextColor(this.mBuilder.getTitleTextColor());
        this.mTitle.setTextSize(this.mBuilder.getTitleTextSize());
        this.mContent.setText(this.mBuilder.getContentText());
        this.mContent.setTextColor(this.mBuilder.getContentTextColor());
        this.mContent.setTextSize(this.mBuilder.getContentTextSize());
        this.mLeftBtn.setText(this.mBuilder.getLeftButtonText());
        this.mLeftBtn.setTextColor(this.mBuilder.getLeftButtonTextColor());
        this.mLeftBtn.setTextSize(this.mBuilder.getButtonTextSize());
        this.mRightBtn.setText(this.mBuilder.getRightButtonText());
        this.mRightBtn.setTextColor(this.mBuilder.getRightButtonTextColor());
        this.mRightBtn.setTextSize(this.mBuilder.getButtonTextSize());
        this.mLeftBtn.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.MDAlertDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (MDAlertDialog.this.mBuilder.getListener() != null) {
                    DialogInterface.OnLeftAndRightClickListener<MDAlertDialog> listener = MDAlertDialog.this.mBuilder.getListener();
                    MDAlertDialog mDAlertDialog = MDAlertDialog.this;
                    listener.clickLeftButton(mDAlertDialog, mDAlertDialog.mLeftBtn);
                }
            }
        });
        this.mRightBtn.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.MDAlertDialog.2
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (MDAlertDialog.this.mBuilder.getListener() != null) {
                    DialogInterface.OnLeftAndRightClickListener<MDAlertDialog> listener = MDAlertDialog.this.mBuilder.getListener();
                    MDAlertDialog mDAlertDialog = MDAlertDialog.this;
                    listener.clickRightButton(mDAlertDialog, mDAlertDialog.mRightBtn);
                }
            }
        });
    }

    public void show() {
        this.mDialog.show();
    }

    public void dismiss() {
        this.mDialog.dismiss();
    }

    public Dialog getDialog() {
        return this.mDialog;
    }

    public static class Builder {
        private int contentTextColor;
        private int leftButtonTextColor;
        private Context mContext;
        private int rightButtonTextColor;
        private int titleTextColor;
        private String titleText = "提示";
        private String contentText = "";
        private String leftButtonText = "取消";
        private String rightButtonText = "确定";
        private DialogInterface.OnLeftAndRightClickListener<MDAlertDialog> listener = null;
        private boolean isTitleVisible = true;
        private boolean isTouchOutside = true;
        private float height = 0.21f;
        private float width = 0.73f;
        private int titleTextSize = 16;
        private int contentTextSize = 14;
        private int buttonTextSize = 14;

        public Builder(Context context) {
            this.mContext = context;
            this.titleTextColor = ContextCompat.getColor(context, R.color.black_light);
            this.contentTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.leftButtonTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.rightButtonTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
        }

        public Context getContext() {
            return this.mContext;
        }

        public String getTitleText() {
            return this.titleText;
        }

        public Builder setTitleText(String str) {
            this.titleText = str;
            return this;
        }

        public int getTitleTextColor() {
            return this.titleTextColor;
        }

        public Builder setTitleTextColor(int i2) {
            this.titleTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getContentText() {
            return this.contentText;
        }

        public Builder setContentText(String str) {
            this.contentText = str;
            return this;
        }

        public int getContentTextColor() {
            return this.contentTextColor;
        }

        public Builder setContentTextColor(int i2) {
            this.contentTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getLeftButtonText() {
            return this.leftButtonText;
        }

        public Builder setLeftButtonText(String str) {
            this.leftButtonText = str;
            return this;
        }

        public int getLeftButtonTextColor() {
            return this.leftButtonTextColor;
        }

        public Builder setLeftButtonTextColor(int i2) {
            this.leftButtonTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getRightButtonText() {
            return this.rightButtonText;
        }

        public Builder setRightButtonText(String str) {
            this.rightButtonText = str;
            return this;
        }

        public int getRightButtonTextColor() {
            return this.rightButtonTextColor;
        }

        public Builder setRightButtonTextColor(int i2) {
            this.rightButtonTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public boolean getTitleVisible() {
            return this.isTitleVisible;
        }

        public Builder setTitleVisible(boolean z) {
            this.isTitleVisible = z;
            return this;
        }

        public boolean isTouchOutside() {
            return this.isTouchOutside;
        }

        public Builder setCanceledOnTouchOutside(boolean z) {
            this.isTouchOutside = z;
            return this;
        }

        public float getHeight() {
            return this.height;
        }

        public Builder setHeight(float f2) {
            this.height = f2;
            return this;
        }

        public float getWidth() {
            return this.width;
        }

        public Builder setWidth(float f2) {
            this.width = f2;
            return this;
        }

        public int getContentTextSize() {
            return this.contentTextSize;
        }

        public Builder setContentTextSize(int i2) {
            this.contentTextSize = i2;
            return this;
        }

        public int getTitleTextSize() {
            return this.titleTextSize;
        }

        public Builder setTitleTextSize(int i2) {
            this.titleTextSize = i2;
            return this;
        }

        public int getButtonTextSize() {
            return this.buttonTextSize;
        }

        public Builder setButtonTextSize(int i2) {
            this.buttonTextSize = i2;
            return this;
        }

        public DialogInterface.OnLeftAndRightClickListener<MDAlertDialog> getListener() {
            return this.listener;
        }

        public Builder setOnclickListener(DialogInterface.OnLeftAndRightClickListener<MDAlertDialog> onLeftAndRightClickListener) {
            this.listener = onLeftAndRightClickListener;
            return this;
        }

        public MDAlertDialog build() {
            return new MDAlertDialog(this);
        }
    }
}
