package com.wevey.selector.dialog;

import android.app.Dialog;
import android.content.Context;
import android.text.InputFilter;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.EditText;
import android.widget.TextView;
import androidx.core.content.ContextCompat;
import com.weavey.utils.ScreenSizeUtils;
import com.wevey.selector.dialog.DialogInterface;

/* loaded from: classes3.dex */
public class MDEditDialog {
    private View lineView;
    private Builder mBuilder;
    private Dialog mDialog;
    private View mDialogView;
    private EditText mEdit;
    private TextView mLeftBtn;
    private TextView mRightBtn;
    private TextView mTitle;

    public MDEditDialog(Builder builder) {
        this.mBuilder = builder;
        this.mDialog = new Dialog(this.mBuilder.getContext(), R.style.MyDialogStyle);
        View inflate = View.inflate(this.mBuilder.getContext(), R.layout.widget_edit_dialog, null);
        this.mDialogView = inflate;
        this.mTitle = (TextView) inflate.findViewById(R.id.edit_dialog_title);
        this.mEdit = (EditText) this.mDialogView.findViewById(R.id.edit_dialog_exittext);
        this.mLeftBtn = (TextView) this.mDialogView.findViewById(R.id.edit_dialog_leftbtn);
        this.mRightBtn = (TextView) this.mDialogView.findViewById(R.id.edit_dialog_rightbtn);
        this.lineView = this.mDialogView.findViewById(R.id.edit_dialog_line);
        this.mDialogView.setMinimumHeight((int) (ScreenSizeUtils.getInstance(this.mBuilder.getContext()).getScreenHeight() * builder.getMinHeight()));
        this.mDialog.setContentView(this.mDialogView);
        Window window = this.mDialog.getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        attributes.width = (int) (ScreenSizeUtils.getInstance(this.mBuilder.getContext()).getScreenWidth() * builder.getWidth());
        attributes.height = -2;
        attributes.gravity = 17;
        window.setAttributes(attributes);
        initDialog();
    }

    private void initDialog() {
        this.mDialog.setCanceledOnTouchOutside(this.mBuilder.isTouchOutside());
        if (this.mBuilder.getTitleVisible()) {
            this.mTitle.setVisibility(0);
        } else {
            this.mTitle.setVisibility(8);
        }
        this.mTitle.setText(this.mBuilder.getTitleText());
        this.mTitle.setTextColor(this.mBuilder.getTitleTextColor());
        this.mTitle.setTextSize(this.mBuilder.getTitleTextSize());
        this.mEdit.setText(this.mBuilder.getContentText());
        this.mEdit.setTextColor(this.mBuilder.getContentTextColor());
        this.mEdit.setTextSize(this.mBuilder.getContentTextSize());
        this.mEdit.setInputType(this.mBuilder.getInputTpye());
        this.mLeftBtn.setText(this.mBuilder.getLeftButtonText());
        this.mLeftBtn.setTextColor(this.mBuilder.getLeftButtonTextColor());
        this.mLeftBtn.setTextSize(this.mBuilder.getButtonTextSize());
        this.mRightBtn.setText(this.mBuilder.getRightButtonText());
        this.mRightBtn.setTextColor(this.mBuilder.getRightButtonTextColor());
        this.mRightBtn.setTextSize(this.mBuilder.getButtonTextSize());
        this.lineView.setBackgroundColor(this.mBuilder.getLineColor());
        this.mLeftBtn.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.MDEditDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (MDEditDialog.this.mBuilder.getListener() != null) {
                    DialogInterface.OnLeftAndRightClickListener<MDEditDialog> listener = MDEditDialog.this.mBuilder.getListener();
                    MDEditDialog mDEditDialog = MDEditDialog.this;
                    listener.clickLeftButton(mDEditDialog, mDEditDialog.mLeftBtn);
                }
            }
        });
        this.mRightBtn.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.MDEditDialog.2
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (MDEditDialog.this.mBuilder.getListener() != null) {
                    DialogInterface.OnLeftAndRightClickListener<MDEditDialog> listener = MDEditDialog.this.mBuilder.getListener();
                    MDEditDialog mDEditDialog = MDEditDialog.this;
                    listener.clickRightButton(mDEditDialog, mDEditDialog.mRightBtn);
                }
            }
        });
        this.mEdit.setHint(this.mBuilder.getHintText());
        this.mEdit.setHintTextColor(this.mBuilder.getHintTextColor());
        if (this.mBuilder.getLines() != -1) {
            this.mEdit.setLines(this.mBuilder.getLines());
        }
        if (this.mBuilder.getMaxLines() != -1) {
            this.mEdit.setMaxLines(this.mBuilder.getMaxLines());
        }
        if (this.mBuilder.getMaxLength() != -1) {
            this.mEdit.setFilters(new InputFilter[]{new InputFilter.LengthFilter(this.mBuilder.getMaxLength())});
        }
    }

    public String getEditTextContent() {
        return this.mEdit.getText().toString();
    }

    public void show() {
        this.mDialog.show();
        EditText editText = this.mEdit;
        editText.setSelection(editText.getText().toString().length());
    }

    public void dismiss() {
        this.mDialog.dismiss();
    }

    public Dialog getDialog() {
        return this.mDialog;
    }

    public static class Builder {
        private int contentTextColor;
        private int hintTextColor;
        private int leftButtonTextColor;
        private int lineColor;
        private Context mContext;
        private int rightButtonTextColor;
        private int titleTextColor;
        private String titleText = "提示";
        private String contentText = "";
        private String leftButtonText = "取消";
        private String rightButtonText = "确定";
        private DialogInterface.OnLeftAndRightClickListener<MDEditDialog> listener = null;
        private boolean isTitleVisible = true;
        private boolean isTouchOutside = true;
        private String hintText = "";
        private int lines = -1;
        private int maxLines = -1;
        private int maxLength = -1;
        private float height = 0.28f;
        private float width = 0.8f;
        private int titleTextSize = 20;
        private int contentTextSize = 18;
        private int buttonTextSize = 16;
        private int inputTpye = 0;

        public Builder(Context context) {
            this.mContext = context;
            this.titleTextColor = ContextCompat.getColor(context, R.color.black_light);
            this.contentTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.leftButtonTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.rightButtonTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.lineColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.hintTextColor = ContextCompat.getColor(this.mContext, R.color.gray);
        }

        public Context getContext() {
            return this.mContext;
        }

        public String getTitleText() {
            return this.titleText;
        }

        public Builder setTitleText(String str) {
            this.titleText = str;
            return this;
        }

        public int getTitleTextColor() {
            return this.titleTextColor;
        }

        public Builder setTitleTextColor(int i2) {
            this.titleTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getContentText() {
            return this.contentText;
        }

        public Builder setContentText(String str) {
            this.contentText = str;
            return this;
        }

        public int getContentTextColor() {
            return this.contentTextColor;
        }

        public Builder setContentTextColor(int i2) {
            this.contentTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getLeftButtonText() {
            return this.leftButtonText;
        }

        public Builder setLeftButtonText(String str) {
            this.leftButtonText = str;
            return this;
        }

        public int getLeftButtonTextColor() {
            return this.leftButtonTextColor;
        }

        public Builder setLeftButtonTextColor(int i2) {
            this.leftButtonTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getRightButtonText() {
            return this.rightButtonText;
        }

        public Builder setRightButtonText(String str) {
            this.rightButtonText = str;
            return this;
        }

        public int getRightButtonTextColor() {
            return this.rightButtonTextColor;
        }

        public Builder setRightButtonTextColor(int i2) {
            this.rightButtonTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public boolean getTitleVisible() {
            return this.isTitleVisible;
        }

        public Builder setTitleVisible(boolean z) {
            this.isTitleVisible = z;
            return this;
        }

        public boolean isTouchOutside() {
            return this.isTouchOutside;
        }

        public Builder setCanceledOnTouchOutside(boolean z) {
            this.isTouchOutside = z;
            return this;
        }

        public float getMinHeight() {
            return this.height;
        }

        public Builder setMinHeight(float f2) {
            this.height = f2;
            return this;
        }

        public float getWidth() {
            return this.width;
        }

        public Builder setWidth(float f2) {
            this.width = f2;
            return this;
        }

        public int getContentTextSize() {
            return this.contentTextSize;
        }

        public Builder setContentTextSize(int i2) {
            this.contentTextSize = i2;
            return this;
        }

        public int getLineColor() {
            return this.lineColor;
        }

        public Builder setLineColor(int i2) {
            this.lineColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public int getLines() {
            return this.lines;
        }

        public Builder setLines(int i2) {
            this.lines = i2;
            return this;
        }

        public int getMaxLines() {
            return this.maxLines;
        }

        public Builder setMaxLines(int i2) {
            this.maxLines = i2;
            return this;
        }

        public int getMaxLength() {
            return this.maxLength;
        }

        public Builder setMaxLength(int i2) {
            this.maxLength = i2;
            return this;
        }

        public int getTitleTextSize() {
            return this.titleTextSize;
        }

        public Builder setTitleTextSize(int i2) {
            this.titleTextSize = i2;
            return this;
        }

        public int getButtonTextSize() {
            return this.buttonTextSize;
        }

        public Builder setButtonTextSize(int i2) {
            this.buttonTextSize = i2;
            return this;
        }

        public String getHintText() {
            return this.hintText;
        }

        public Builder setHintText(String str) {
            this.hintText = str;
            return this;
        }

        public int getHintTextColor() {
            return this.hintTextColor;
        }

        public Builder setHintTextColor(int i2) {
            this.hintTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public int getInputTpye() {
            return this.inputTpye;
        }

        public Builder setInputTpye(int i2) {
            this.inputTpye = i2;
            return this;
        }

        public DialogInterface.OnLeftAndRightClickListener<MDEditDialog> getListener() {
            return this.listener;
        }

        public Builder setOnclickListener(DialogInterface.OnLeftAndRightClickListener<MDEditDialog> onLeftAndRightClickListener) {
            this.listener = onLeftAndRightClickListener;
            return this;
        }

        public MDEditDialog build() {
            return new MDEditDialog(this);
        }
    }
}
