package com.wevey.selector.dialog;

import android.app.Dialog;
import android.content.Context;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.LinearLayout;
import androidx.core.content.ContextCompat;
import com.weavey.utils.ScreenSizeUtils;
import com.weavey.utils.UiUtils;
import com.wevey.selector.dialog.DialogInterface;
import java.util.ArrayList;
import java.util.List;

/* loaded from: classes3.dex */
public class MDSelectionDialog {
    private int clickPosition;
    private List<String> datas;
    private View dialogView;
    private LinearLayout linearLayout;
    private Builder mBuilder;
    private Dialog mDialog;

    public MDSelectionDialog(Builder builder) {
        this.mBuilder = builder;
        this.mDialog = new Dialog(this.mBuilder.getContext(), R.style.MyDialogStyle);
        View inflate = View.inflate(this.mBuilder.getContext(), R.layout.widget_md_mid_dialog, null);
        this.dialogView = inflate;
        this.linearLayout = (LinearLayout) inflate.findViewById(R.id.md_mid_dialog_linear);
        this.mDialog.setContentView(this.dialogView);
        Window window = this.mDialog.getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        attributes.width = (int) (ScreenSizeUtils.getInstance(this.mBuilder.getContext()).getScreenWidth() * builder.itemWidth);
        attributes.gravity = 17;
        attributes.height = -2;
        window.setAttributes(attributes);
        this.mDialog.setCanceledOnTouchOutside(builder.isTouchOutside());
    }

    private void loadItem() {
        if (this.datas.size() == 1) {
            Button button = getButton(this.datas.get(0), 0);
            button.setBackgroundResource(R.drawable.selector_widget_md_single);
            this.linearLayout.addView(button);
        } else if (this.datas.size() > 1) {
            for (int i2 = 0; i2 < this.datas.size(); i2++) {
                Button button2 = getButton(this.datas.get(i2), i2);
                if (i2 == 0) {
                    button2.setBackgroundResource(R.drawable.selector_widget_md_top);
                } else if (i2 > 0 && i2 != this.datas.size() - 1) {
                    button2.setBackgroundResource(R.drawable.selector_widget_md_middle);
                } else {
                    button2.setBackgroundResource(R.drawable.selector_widget_md_bottom);
                }
                this.linearLayout.addView(button2);
            }
        }
    }

    private Button getButton(String str, int i2) {
        final Button button = new Button(this.mBuilder.getContext());
        button.setText(str);
        button.setTag(Integer.valueOf(i2));
        button.setTextColor(this.mBuilder.getItemTextColor());
        button.setTextSize(this.mBuilder.getItemTextSize());
        button.setLayoutParams(new LinearLayout.LayoutParams(-1, this.mBuilder.getItemHeight()));
        button.setGravity(19);
        button.setPadding(UiUtils.dp2px(this.mBuilder.getContext(), 10), 0, UiUtils.dp2px(this.mBuilder.getContext(), 10), 0);
        button.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.MDSelectionDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (MDSelectionDialog.this.mBuilder.getOnItemListener() != null) {
                    MDSelectionDialog.this.clickPosition = Integer.parseInt(button.getTag().toString());
                    DialogInterface.OnItemClickListener<MDSelectionDialog> onItemListener = MDSelectionDialog.this.mBuilder.getOnItemListener();
                    MDSelectionDialog mDSelectionDialog = MDSelectionDialog.this;
                    onItemListener.onItemClick(mDSelectionDialog, button, mDSelectionDialog.clickPosition);
                }
            }
        });
        return button;
    }

    public MDSelectionDialog setDatas(List<String> list) {
        this.linearLayout.removeAllViews();
        if (list == null) {
            list = new ArrayList<>();
        }
        this.datas = list;
        loadItem();
        return this;
    }

    public List<String> getDatas() {
        List<String> list = this.datas;
        return list == null ? new ArrayList() : list;
    }

    public int getFinalClickPosition() {
        return this.clickPosition;
    }

    public void show() {
        this.mDialog.show();
    }

    public void dismiss() {
        this.mDialog.dismiss();
    }

    public Dialog getDialog() {
        return this.mDialog;
    }

    public static class Builder {
        private int itemHeight;
        private int itemTextColor;
        private Context mContext;
        private DialogInterface.OnItemClickListener<MDSelectionDialog> onItemListener = null;
        private float itemWidth = 0.75f;
        private float itemTextSize = 14.0f;
        private boolean isTouchOutside = true;

        public Builder(Context context) {
            this.mContext = context;
            this.itemHeight = UiUtils.dp2px(context, 45);
            this.itemTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
        }

        public Context getContext() {
            return this.mContext;
        }

        public DialogInterface.OnItemClickListener<MDSelectionDialog> getOnItemListener() {
            return this.onItemListener;
        }

        public Builder setOnItemListener(DialogInterface.OnItemClickListener<MDSelectionDialog> onItemClickListener) {
            this.onItemListener = onItemClickListener;
            return this;
        }

        public int getItemHeight() {
            return this.itemHeight;
        }

        public Builder setItemHeight(int i2) {
            this.itemHeight = UiUtils.dp2px(this.mContext, i2);
            return this;
        }

        public float getItemWidth() {
            return this.itemWidth;
        }

        public Builder setItemWidth(float f2) {
            this.itemWidth = f2;
            return this;
        }

        public int getItemTextColor() {
            return this.itemTextColor;
        }

        public Builder setItemTextColor(int i2) {
            this.itemTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public float getItemTextSize() {
            return this.itemTextSize;
        }

        public Builder setItemTextSize(int i2) {
            this.itemTextSize = i2;
            return this;
        }

        public boolean isTouchOutside() {
            return this.isTouchOutside;
        }

        public Builder setCanceledOnTouchOutside(boolean z) {
            this.isTouchOutside = z;
            return this;
        }

        public MDSelectionDialog build() {
            return new MDSelectionDialog(this);
        }
    }
}
