package com.wevey.selector.dialog;

import android.app.Dialog;
import android.content.Context;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.TextView;
import androidx.core.content.ContextCompat;
import com.weavey.utils.ScreenSizeUtils;
import com.wevey.selector.dialog.DialogInterface;

/* loaded from: classes3.dex */
public class NormalAlertDialog {
    private Builder mBuilder;
    private TextView mContent;
    private Dialog mDialog;
    private View mDialogView;
    private Button mLeftBtn;
    private TextView mLine;
    private Button mRightBtn;
    private Button mSingleBtn;
    private TextView mTitle;

    public NormalAlertDialog(Builder builder) {
        this.mBuilder = builder;
        this.mDialog = new Dialog(this.mBuilder.getContext(), R.style.NormalDialogStyle);
        View inflate = View.inflate(this.mBuilder.getContext(), R.layout.widget_dialog_normal, null);
        this.mDialogView = inflate;
        this.mTitle = (TextView) inflate.findViewById(R.id.dialog_normal_title);
        this.mContent = (TextView) this.mDialogView.findViewById(R.id.dialog_normal_content);
        this.mLeftBtn = (Button) this.mDialogView.findViewById(R.id.dialog_normal_leftbtn);
        this.mRightBtn = (Button) this.mDialogView.findViewById(R.id.dialog_normal_rightbtn);
        this.mSingleBtn = (Button) this.mDialogView.findViewById(R.id.dialog_normal_midbtn);
        this.mLine = (TextView) this.mDialogView.findViewById(R.id.dialog_normal_line);
        this.mDialogView.setMinimumHeight((int) (ScreenSizeUtils.getInstance(this.mBuilder.getContext()).getScreenHeight() * builder.getHeight()));
        this.mDialog.setContentView(this.mDialogView);
        Window window = this.mDialog.getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        attributes.width = (int) (ScreenSizeUtils.getInstance(this.mBuilder.getContext()).getScreenWidth() * builder.getWidth());
        attributes.height = -2;
        attributes.gravity = 17;
        window.setAttributes(attributes);
        initDialog(builder);
    }

    private void initDialog(Builder builder) {
        this.mDialog.setCanceledOnTouchOutside(builder.isTouchOutside());
        if (builder.getTitleVisible()) {
            this.mTitle.setVisibility(0);
        } else {
            this.mTitle.setVisibility(8);
        }
        if (builder.isSingleMode()) {
            this.mSingleBtn.setVisibility(0);
            this.mLine.setVisibility(8);
            this.mLeftBtn.setVisibility(8);
            this.mRightBtn.setVisibility(8);
        }
        this.mTitle.setText(builder.getTitleText());
        this.mTitle.setTextColor(builder.getTitleTextColor());
        this.mTitle.setTextSize(builder.getTitleTextSize());
        this.mContent.setText(builder.getContentText());
        this.mContent.setTextColor(builder.getContentTextColor());
        this.mContent.setTextSize(builder.getContentTextSize());
        this.mLeftBtn.setText(builder.getLeftButtonText());
        this.mLeftBtn.setTextColor(builder.getLeftButtonTextColor());
        this.mLeftBtn.setTextSize(builder.getButtonTextSize());
        this.mRightBtn.setText(builder.getRightButtonText());
        this.mRightBtn.setTextColor(builder.getRightButtonTextColor());
        this.mRightBtn.setTextSize(builder.getButtonTextSize());
        this.mSingleBtn.setText(builder.getSingleButtonText());
        this.mSingleBtn.setTextColor(builder.getSingleButtonTextColor());
        this.mSingleBtn.setTextSize(builder.getButtonTextSize());
        this.mLeftBtn.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.NormalAlertDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (NormalAlertDialog.this.mBuilder.getOnclickListener() != null) {
                    DialogInterface.OnLeftAndRightClickListener<NormalAlertDialog> onclickListener = NormalAlertDialog.this.mBuilder.getOnclickListener();
                    NormalAlertDialog normalAlertDialog = NormalAlertDialog.this;
                    onclickListener.clickLeftButton(normalAlertDialog, normalAlertDialog.mLeftBtn);
                }
            }
        });
        this.mRightBtn.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.NormalAlertDialog.2
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (NormalAlertDialog.this.mBuilder.getOnclickListener() != null) {
                    DialogInterface.OnLeftAndRightClickListener<NormalAlertDialog> onclickListener = NormalAlertDialog.this.mBuilder.getOnclickListener();
                    NormalAlertDialog normalAlertDialog = NormalAlertDialog.this;
                    onclickListener.clickRightButton(normalAlertDialog, normalAlertDialog.mRightBtn);
                }
            }
        });
        this.mSingleBtn.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.NormalAlertDialog.3
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (NormalAlertDialog.this.mBuilder.getSingleListener() != null) {
                    DialogInterface.OnSingleClickListener<NormalAlertDialog> singleListener = NormalAlertDialog.this.mBuilder.getSingleListener();
                    NormalAlertDialog normalAlertDialog = NormalAlertDialog.this;
                    singleListener.clickSingleButton(normalAlertDialog, normalAlertDialog.mSingleBtn);
                }
            }
        });
    }

    public void show() {
        this.mDialog.show();
    }

    public void dismiss() {
        this.mDialog.dismiss();
    }

    public Dialog getDialog() {
        return this.mDialog;
    }

    public static class Builder {
        private int contentTextColor;
        private int leftButtonTextColor;
        private Context mContext;
        private int rightButtonTextColor;
        private int singleButtonTextColor;
        private int titleTextColor;
        private String titleText = "温馨提示";
        private String contentText = "";
        private boolean isSingleMode = false;
        private String singleButtonText = "确定";
        private String leftButtonText = "取消";
        private String rightButtonText = "确定";
        private DialogInterface.OnLeftAndRightClickListener<NormalAlertDialog> onclickListener = null;
        private DialogInterface.OnSingleClickListener<NormalAlertDialog> singleListener = null;
        private boolean isTitleVisible = false;
        private boolean isTouchOutside = true;
        private float height = 0.23f;
        private float width = 0.65f;
        private int titleTextSize = 16;
        private int contentTextSize = 14;
        private int buttonTextSize = 14;

        public Builder(Context context) {
            this.mContext = context;
            this.titleTextColor = ContextCompat.getColor(context, R.color.black_light);
            this.contentTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.singleButtonTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.leftButtonTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
            this.rightButtonTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
        }

        public Context getContext() {
            return this.mContext;
        }

        public String getTitleText() {
            return this.titleText;
        }

        public Builder setTitleText(String str) {
            this.titleText = str;
            return this;
        }

        public int getTitleTextColor() {
            return this.titleTextColor;
        }

        public Builder setTitleTextColor(int i2) {
            this.titleTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getContentText() {
            return this.contentText;
        }

        public Builder setContentText(String str) {
            this.contentText = str;
            return this;
        }

        public int getContentTextColor() {
            return this.contentTextColor;
        }

        public Builder setContentTextColor(int i2) {
            this.contentTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public boolean isSingleMode() {
            return this.isSingleMode;
        }

        public Builder setSingleMode(boolean z) {
            this.isSingleMode = z;
            return this;
        }

        public String getSingleButtonText() {
            return this.singleButtonText;
        }

        public Builder setSingleButtonText(String str) {
            this.singleButtonText = str;
            return this;
        }

        public int getSingleButtonTextColor() {
            return this.singleButtonTextColor;
        }

        public Builder setSingleButtonTextColor(int i2) {
            this.singleButtonTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getLeftButtonText() {
            return this.leftButtonText;
        }

        public Builder setLeftButtonText(String str) {
            this.leftButtonText = str;
            return this;
        }

        public int getLeftButtonTextColor() {
            return this.leftButtonTextColor;
        }

        public Builder setLeftButtonTextColor(int i2) {
            this.leftButtonTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public String getRightButtonText() {
            return this.rightButtonText;
        }

        public Builder setRightButtonText(String str) {
            this.rightButtonText = str;
            return this;
        }

        public int getRightButtonTextColor() {
            return this.rightButtonTextColor;
        }

        public Builder setRightButtonTextColor(int i2) {
            this.rightButtonTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public DialogInterface.OnLeftAndRightClickListener<NormalAlertDialog> getOnclickListener() {
            return this.onclickListener;
        }

        public Builder setOnclickListener(DialogInterface.OnLeftAndRightClickListener<NormalAlertDialog> onLeftAndRightClickListener) {
            this.onclickListener = onLeftAndRightClickListener;
            return this;
        }

        public DialogInterface.OnSingleClickListener<NormalAlertDialog> getSingleListener() {
            return this.singleListener;
        }

        public Builder setSingleListener(DialogInterface.OnSingleClickListener<NormalAlertDialog> onSingleClickListener) {
            this.singleListener = onSingleClickListener;
            return this;
        }

        public boolean getTitleVisible() {
            return this.isTitleVisible;
        }

        public Builder setTitleVisible(boolean z) {
            this.isTitleVisible = z;
            return this;
        }

        public boolean isTouchOutside() {
            return this.isTouchOutside;
        }

        public Builder setCanceledOnTouchOutside(boolean z) {
            this.isTouchOutside = z;
            return this;
        }

        public int getContentTextSize() {
            return this.contentTextSize;
        }

        public Builder setContentTextSize(int i2) {
            this.contentTextSize = i2;
            return this;
        }

        public int getTitleTextSize() {
            return this.titleTextSize;
        }

        public Builder setTitleTextSize(int i2) {
            this.titleTextSize = i2;
            return this;
        }

        public int getButtonTextSize() {
            return this.buttonTextSize;
        }

        public Builder setButtonTextSize(int i2) {
            this.buttonTextSize = i2;
            return this;
        }

        public float getHeight() {
            return this.height;
        }

        public Builder setHeight(float f2) {
            this.height = f2;
            return this;
        }

        public float getWidth() {
            return this.width;
        }

        public Builder setWidth(float f2) {
            this.width = f2;
            return this;
        }

        public NormalAlertDialog build() {
            return new NormalAlertDialog(this);
        }
    }
}
