package com.wevey.selector.dialog;

import android.app.Dialog;
import android.content.Context;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import androidx.core.content.ContextCompat;
import com.weavey.utils.ScreenSizeUtils;
import com.weavey.utils.UiUtils;
import com.wevey.selector.dialog.DialogInterface;
import java.util.ArrayList;
import java.util.List;

/* loaded from: classes3.dex */
public class NormalSelectionDialog {
    private Button bottomBtn;
    private int clickPosition;
    private List<String> datas;
    private View dialogView;
    private LinearLayout linearLayout;
    private Builder mBuilder;
    private Dialog mDialog;
    private TextView title;

    public NormalSelectionDialog(Builder builder) {
        this.mBuilder = builder;
        this.mDialog = new Dialog(this.mBuilder.getContext(), R.style.bottomDialogStyle);
        View inflate = View.inflate(this.mBuilder.getContext(), R.layout.widget_bottom_dialog, null);
        this.dialogView = inflate;
        this.mDialog.setContentView(inflate);
        Window window = this.mDialog.getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        attributes.width = (int) (ScreenSizeUtils.getInstance(this.mBuilder.getContext()).getScreenWidth() * builder.getItemWidth());
        attributes.gravity = 80;
        attributes.height = -2;
        window.setAttributes(attributes);
        this.title = (TextView) this.dialogView.findViewById(R.id.action_dialog_title);
        this.linearLayout = (LinearLayout) this.dialogView.findViewById(R.id.action_dialog_linearlayout);
        Button button = (Button) this.dialogView.findViewById(R.id.action_dialog_botbtn);
        this.bottomBtn = button;
        button.setText(builder.getCancleButtonText());
        this.bottomBtn.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.NormalSelectionDialog.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                NormalSelectionDialog.this.mDialog.dismiss();
            }
        });
        this.mDialog.setCanceledOnTouchOutside(builder.isTouchOutside());
    }

    private void loadItem() {
        if (this.mBuilder.getTitleVisible()) {
            this.title.setVisibility(0);
            this.title.setText(this.mBuilder.getTitleText());
            this.title.setTextColor(this.mBuilder.getTitleTextColor());
            this.title.setTextSize(this.mBuilder.getTitleTextSize());
            LinearLayout.LayoutParams layoutParams = (LinearLayout.LayoutParams) this.title.getLayoutParams();
            layoutParams.height = UiUtils.dp2px(this.mBuilder.getContext(), this.mBuilder.getTitleHeight());
            this.title.setLayoutParams(layoutParams);
            if (this.datas.size() != 0) {
                this.title.setBackgroundResource(R.drawable.selector_widget_actiondialog_top);
            } else {
                this.title.setBackgroundResource(R.drawable.selector_widget_actiondialog_single);
            }
        } else {
            this.title.setVisibility(8);
        }
        this.bottomBtn.setTextColor(this.mBuilder.getItemTextColor());
        this.bottomBtn.setTextSize(this.mBuilder.getItemTextSize());
        LinearLayout.LayoutParams layoutParams2 = new LinearLayout.LayoutParams(-1, this.mBuilder.getItemHeight());
        layoutParams2.topMargin = 10;
        this.bottomBtn.setLayoutParams(layoutParams2);
        if (this.datas.size() == 1) {
            Button button = getButton(this.datas.get(0), 0);
            if (this.mBuilder.getTitleVisible()) {
                button.setBackgroundResource(R.drawable.selector_widget_actiondialog_bottom);
            } else {
                button.setBackgroundResource(R.drawable.selector_widget_actiondialog_single);
            }
            this.linearLayout.addView(button);
            return;
        }
        if (this.datas.size() > 1) {
            for (int i2 = 0; i2 < this.datas.size(); i2++) {
                Button button2 = getButton(this.datas.get(i2), i2);
                if (!this.mBuilder.getTitleVisible() && i2 == 0) {
                    button2.setBackgroundResource(R.drawable.selector_widget_actiondialog_top);
                } else if (i2 != this.datas.size() - 1) {
                    button2.setBackgroundResource(R.drawable.selector_widget_actiondialog_middle);
                } else {
                    button2.setBackgroundResource(R.drawable.selector_widget_actiondialog_bottom);
                }
                this.linearLayout.addView(button2);
            }
        }
    }

    private Button getButton(String str, int i2) {
        final Button button = new Button(this.mBuilder.getContext());
        button.setText(str);
        button.setTag(Integer.valueOf(i2));
        button.setTextColor(this.mBuilder.getItemTextColor());
        button.setTextSize(this.mBuilder.getItemTextSize());
        button.setLayoutParams(new LinearLayout.LayoutParams(-1, this.mBuilder.getItemHeight()));
        button.setOnClickListener(new View.OnClickListener() { // from class: com.wevey.selector.dialog.NormalSelectionDialog.2
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (NormalSelectionDialog.this.mBuilder.getOnItemListener() != null) {
                    NormalSelectionDialog.this.clickPosition = Integer.parseInt(button.getTag().toString());
                    DialogInterface.OnItemClickListener<NormalSelectionDialog> onItemListener = NormalSelectionDialog.this.mBuilder.getOnItemListener();
                    NormalSelectionDialog normalSelectionDialog = NormalSelectionDialog.this;
                    onItemListener.onItemClick(normalSelectionDialog, button, normalSelectionDialog.clickPosition);
                }
            }
        });
        return button;
    }

    public NormalSelectionDialog setDatas(List<String> list) {
        int childCount = this.linearLayout.getChildCount();
        if (childCount > 1) {
            this.linearLayout.removeViewsInLayout(1, childCount - 1);
        }
        if (list == null) {
            list = new ArrayList<>();
        }
        this.datas = list;
        loadItem();
        return this;
    }

    public List<String> getDatas() {
        List<String> list = this.datas;
        return list == null ? new ArrayList() : list;
    }

    public int getFinalClickPosition() {
        return this.clickPosition;
    }

    public void show() {
        this.mDialog.show();
    }

    public void dismiss() {
        this.mDialog.dismiss();
    }

    public Dialog getDialog() {
        return this.mDialog;
    }

    public static class Builder {
        private int itemHeight;
        private int itemTextColor;
        private Context mContext;
        private int titleTextColor;
        private boolean boolTitle = false;
        private int titleHeight = 65;
        private String titleText = "请选择";
        private float titleTextSize = 13.0f;
        private DialogInterface.OnItemClickListener<NormalSelectionDialog> onItemListener = null;
        private float itemWidth = 0.92f;
        private float itemTextSize = 14.0f;
        private String cancleButtonText = "取消";
        private boolean isTouchOutside = true;

        public Builder(Context context) {
            this.mContext = context;
            this.titleTextColor = ContextCompat.getColor(context, R.color.black_light);
            this.itemHeight = UiUtils.dp2px(context, 45);
            this.itemTextColor = ContextCompat.getColor(this.mContext, R.color.black_light);
        }

        public Context getContext() {
            return this.mContext;
        }

        public boolean getTitleVisible() {
            return this.boolTitle;
        }

        public Builder setlTitleVisible(boolean z) {
            this.boolTitle = z;
            return this;
        }

        public int getTitleHeight() {
            return this.titleHeight;
        }

        public Builder setTitleHeight(int i2) {
            this.titleHeight = i2;
            return this;
        }

        public String getTitleText() {
            return this.titleText;
        }

        public Builder setTitleText(String str) {
            this.titleText = str;
            return this;
        }

        public int getTitleTextColor() {
            return this.titleTextColor;
        }

        public Builder setTitleTextColor(int i2) {
            this.titleTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public float getTitleTextSize() {
            return this.titleTextSize;
        }

        public Builder setTitleTextSize(int i2) {
            this.titleTextSize = i2;
            return this;
        }

        public DialogInterface.OnItemClickListener<NormalSelectionDialog> getOnItemListener() {
            return this.onItemListener;
        }

        public Builder setOnItemListener(DialogInterface.OnItemClickListener<NormalSelectionDialog> onItemClickListener) {
            this.onItemListener = onItemClickListener;
            return this;
        }

        public int getItemHeight() {
            return this.itemHeight;
        }

        public Builder setItemHeight(int i2) {
            this.itemHeight = UiUtils.dp2px(this.mContext, i2);
            return this;
        }

        public float getItemWidth() {
            return this.itemWidth;
        }

        public Builder setItemWidth(float f2) {
            this.itemWidth = f2;
            return this;
        }

        public int getItemTextColor() {
            return this.itemTextColor;
        }

        public Builder setItemTextColor(int i2) {
            this.itemTextColor = ContextCompat.getColor(this.mContext, i2);
            return this;
        }

        public float getItemTextSize() {
            return this.itemTextSize;
        }

        public Builder setItemTextSize(int i2) {
            this.itemTextSize = i2;
            return this;
        }

        public String getCancleButtonText() {
            return this.cancleButtonText;
        }

        public Builder setCancleButtonText(String str) {
            this.cancleButtonText = str;
            return this;
        }

        public boolean isTouchOutside() {
            return this.isTouchOutside;
        }

        public Builder setCanceledOnTouchOutside(boolean z) {
            this.isTouchOutside = z;
            return this;
        }

        public NormalSelectionDialog build() {
            return new NormalSelectionDialog(this);
        }
    }
}
