package com.yanzhenjie.permission.checker;

import android.content.Context;
import com.yanzhenjie.permission.Permission;
import java.util.Iterator;
import java.util.List;

/* loaded from: classes3.dex */
public final class StrictChecker implements PermissionChecker {
    @Override // com.yanzhenjie.permission.checker.PermissionChecker
    public boolean hasPermission(Context context, String... strArr) {
        for (String str : strArr) {
            if (!hasPermission(context, str)) {
                return false;
            }
        }
        return true;
    }

    @Override // com.yanzhenjie.permission.checker.PermissionChecker
    public boolean hasPermission(Context context, List<String> list) {
        Iterator<String> it2 = list.iterator();
        while (it2.hasNext()) {
            if (!hasPermission(context, it2.next())) {
                return false;
            }
        }
        return true;
    }

    private boolean hasPermission(Context context, String str) {
        char c2;
        try {
            switch (str.hashCode()) {
                case -2062386608:
                    if (str.equals(Permission.READ_SMS)) {
                        c2 = 19;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1928411001:
                    if (str.equals(Permission.READ_CALENDAR)) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1921431796:
                    if (str.equals(Permission.READ_CALL_LOG)) {
                        c2 = 11;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1888586689:
                    if (str.equals(Permission.ACCESS_FINE_LOCATION)) {
                        c2 = 7;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1479758289:
                    if (str.equals(Permission.RECEIVE_WAP_PUSH)) {
                        c2 = 20;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1238066820:
                    if (str.equals(Permission.BODY_SENSORS)) {
                        c2 = 16;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -895679497:
                    if (str.equals(Permission.RECEIVE_MMS)) {
                        c2 = 18;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -895673731:
                    if (str.equals(Permission.RECEIVE_SMS)) {
                        c2 = 21;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -406040016:
                    if (str.equals(Permission.READ_EXTERNAL_STORAGE)) {
                        c2 = 22;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -63024214:
                    if (str.equals(Permission.ACCESS_COARSE_LOCATION)) {
                        c2 = 6;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -5573545:
                    if (str.equals(Permission.READ_PHONE_STATE)) {
                        c2 = '\t';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 52602690:
                    if (str.equals(Permission.SEND_SMS)) {
                        c2 = 17;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 112197485:
                    if (str.equals(Permission.CALL_PHONE)) {
                        c2 = '\n';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 214526995:
                    if (str.equals(Permission.WRITE_CONTACTS)) {
                        c2 = 4;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 463403621:
                    if (str.equals(Permission.CAMERA)) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 603653886:
                    if (str.equals(Permission.WRITE_CALENDAR)) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 610633091:
                    if (str.equals(Permission.WRITE_CALL_LOG)) {
                        c2 = '\f';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 784519842:
                    if (str.equals(Permission.USE_SIP)) {
                        c2 = 14;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 952819282:
                    if (str.equals(Permission.PROCESS_OUTGOING_CALLS)) {
                        c2 = 15;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1271781903:
                    if (str.equals(Permission.GET_ACCOUNTS)) {
                        c2 = 5;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1365911975:
                    if (str.equals(Permission.WRITE_EXTERNAL_STORAGE)) {
                        c2 = 23;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1831139720:
                    if (str.equals(Permission.RECORD_AUDIO)) {
                        c2 = '\b';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1977429404:
                    if (str.equals(Permission.READ_CONTACTS)) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133799037:
                    if (str.equals(Permission.ADD_VOICEMAIL)) {
                        c2 = '\r';
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                    return checkReadCalendar(context);
                case 1:
                    return checkWriteCalendar(context);
                case 2:
                    return checkCamera(context);
                case 3:
                    return checkReadContacts(context);
                case 4:
                    return checkWriteContacts(context);
                case 5:
                case '\n':
                case 15:
                case 17:
                case 18:
                case 20:
                case 21:
                default:
                    return true;
                case 6:
                    return checkCoarseLocation(context);
                case 7:
                    return checkFineLocation(context);
                case '\b':
                    return checkRecordAudio(context);
                case '\t':
                    return checkReadPhoneState(context);
                case 11:
                    return checkReadCallLog(context);
                case '\f':
                    return checkWriteCallLog(context);
                case '\r':
                    return checkAddVoicemail(context);
                case 14:
                    return checkSip(context);
                case 16:
                    return checkSensors(context);
                case 19:
                    return checkReadSms(context);
                case 22:
                    return checkReadStorage();
                case 23:
                    return checkWriteStorage();
            }
        } catch (Throwable unused) {
            return false;
        }
    }

    private static boolean checkReadCalendar(Context context) throws Throwable {
        return new CalendarReadTest(context).test();
    }

    private static boolean checkWriteCalendar(Context context) throws Throwable {
        return new CalendarWriteTest(context).test();
    }

    private static boolean checkCamera(Context context) throws Throwable {
        return new CameraTest(context).test();
    }

    private static boolean checkReadContacts(Context context) throws Throwable {
        return new ContactsReadTest(context).test();
    }

    private static boolean checkWriteContacts(Context context) throws Throwable {
        return new ContactsWriteTest(context.getContentResolver()).test();
    }

    private static boolean checkCoarseLocation(Context context) throws Throwable {
        return new LocationCoarseTest(context).test();
    }

    private static boolean checkFineLocation(Context context) throws Throwable {
        return new LocationFineTest(context).test();
    }

    private static boolean checkRecordAudio(Context context) throws Throwable {
        return new RecordAudioTest(context).test();
    }

    private static boolean checkReadPhoneState(Context context) throws Throwable {
        return new PhoneStateReadTest(context).test();
    }

    private static boolean checkReadCallLog(Context context) throws Throwable {
        return new CallLogReadTest(context).test();
    }

    private static boolean checkWriteCallLog(Context context) throws Throwable {
        return new CallLogWriteTest(context).test();
    }

    private static boolean checkAddVoicemail(Context context) throws Throwable {
        return new AddVoicemailTest(context).test();
    }

    private static boolean checkSip(Context context) throws Throwable {
        return new SipTest(context).test();
    }

    private static boolean checkSensors(Context context) throws Throwable {
        return new SensorsTest(context).test();
    }

    private static boolean checkReadSms(Context context) throws Throwable {
        return new SmsReadTest(context).test();
    }

    private static boolean checkReadStorage() throws Throwable {
        return new StorageReadTest().test();
    }

    private static boolean checkWriteStorage() throws Throwable {
        return new StorageWriteTest().test();
    }
}
