package com.yanzhenjie.recyclerview;

import android.util.SparseBooleanArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.yanzhenjie.recyclerview.ExpandableAdapter.ViewHolder;
import java.util.ArrayList;
import java.util.List;

/* loaded from: classes3.dex */
public abstract class ExpandableAdapter<VH extends ViewHolder> extends RecyclerView.Adapter<VH> {
    private static final int TYPE_CHILD = 20000000;
    private static final int TYPE_PARENT = 10000000;
    private final SparseBooleanArray mExpandItemArray = new SparseBooleanArray();
    private final List<Integer> mParentViewType = new ArrayList();

    public abstract void bindChildHolder(VH vh, int i2, int i3);

    public abstract void bindParentHolder(VH vh, int i2);

    public abstract int childItemCount(int i2);

    public int childItemViewType(int i2, int i3) {
        return TYPE_CHILD;
    }

    public abstract VH createChildHolder(ViewGroup viewGroup, int i2);

    public abstract VH createParentHolder(ViewGroup viewGroup, int i2);

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    @Deprecated
    public final void onBindViewHolder(VH vh, int i2) {
    }

    public abstract int parentItemCount();

    public int parentItemViewType(int i2) {
        return TYPE_PARENT;
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public /* bridge */ /* synthetic */ void onBindViewHolder(RecyclerView.ViewHolder viewHolder, int i2, List list) {
        onBindViewHolder((ExpandableAdapter<VH>) viewHolder, i2, (List<Object>) list);
    }

    public final boolean isExpanded(int i2) {
        return this.mExpandItemArray.get(i2, false);
    }

    public final void expandParent(int i2) {
        if (isExpanded(i2)) {
            return;
        }
        this.mExpandItemArray.append(i2, true);
        notifyItemRangeInserted(positionFromParentPosition(i2) + 1, childItemCount(i2));
    }

    public final void collapseParent(int i2) {
        if (isExpanded(i2)) {
            this.mExpandItemArray.append(i2, false);
            notifyItemRangeRemoved(positionFromParentPosition(i2) + 1, childItemCount(i2));
        }
    }

    public final void notifyParentChanged(int i2) {
        notifyItemChanged(positionFromParentPosition(i2));
    }

    public final void notifyParentInserted(int i2) {
        notifyItemInserted(positionFromParentPosition(i2));
    }

    public final void notifyParentRemoved(int i2) {
        notifyItemRemoved(positionFromParentPosition(i2));
    }

    public final void notifyChildChanged(int i2, int i3) {
        notifyItemChanged(positionFromChildPosition(i2, i3));
    }

    public final void notifyChildInserted(int i2, int i3) {
        notifyItemInserted(positionFromChildPosition(i2, i3));
    }

    public final void notifyChildRemoved(int i2, int i3) {
        notifyItemRemoved(positionFromChildPosition(i2, i3));
    }

    private int positionFromParentPosition(int i2) {
        int parentItemCount = parentItemCount();
        int i3 = 0;
        for (int i4 = 0; i4 < parentItemCount; i4++) {
            i3++;
            if (i2 == i4) {
                return i3 - 1;
            }
            if (isExpanded(i4)) {
                i3 += childItemCount(i4);
            }
        }
        throw new IllegalStateException("The parent position is invalid: " + i2);
    }

    private int positionFromChildPosition(int i2, int i3) {
        int parentItemCount = parentItemCount();
        int i4 = 0;
        for (int i5 = 0; i5 < parentItemCount; i5++) {
            i4++;
            if (i2 == i5) {
                if (i3 < childItemCount(i2)) {
                    return (i4 + (i3 + 1)) - 1;
                }
                throw new IllegalStateException("The child position is invalid: " + i3);
            }
            if (isExpanded(i5)) {
                i4 += childItemCount(i5);
            }
        }
        throw new IllegalStateException("The parent position is invalid: " + i2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public final int getItemCount() {
        int parentItemCount = parentItemCount();
        for (int i2 = 0; i2 < parentItemCount; i2++) {
            if (isExpanded(i2)) {
                parentItemCount += childItemCount(i2);
            }
        }
        return parentItemCount;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public final int getItemViewType(int i2) {
        int parentItemPosition = parentItemPosition(i2);
        if (isParentItem(i2)) {
            int parentItemViewType = parentItemViewType(parentItemPosition);
            if (!this.mParentViewType.contains(Integer.valueOf(parentItemViewType))) {
                this.mParentViewType.add(Integer.valueOf(parentItemViewType));
            }
            return parentItemViewType;
        }
        return childItemViewType(parentItemPosition, childItemPosition(i2));
    }

    public final boolean isParentItem(int i2) {
        int parentItemCount = parentItemCount();
        int i3 = 0;
        for (int i4 = 0; i4 < parentItemCount; i4++) {
            if (i3 == i2) {
                return true;
            }
            i3++;
            if (isExpanded(i4)) {
                i3 += childItemCount(i4);
            }
        }
        return false;
    }

    public final int parentItemPosition(int i2) {
        int i3 = 0;
        for (int i4 = 0; i4 < parentItemCount(); i4++) {
            i3++;
            if (isExpanded(i4)) {
                i3 += childItemCount(i4);
            }
            if (i2 < i3) {
                return i4;
            }
        }
        throw new IllegalStateException("The adapter position is not a parent type: " + i2);
    }

    public final int childItemPosition(int i2) {
        int childItemCount;
        int parentItemCount = parentItemCount();
        int i3 = 0;
        for (int i4 = 0; i4 < parentItemCount; i4++) {
            i3++;
            if (isExpanded(i4) && i2 < (i3 = i3 + (childItemCount = childItemCount(i4)))) {
                return childItemCount - (i3 - i2);
            }
        }
        throw new IllegalStateException("The adapter position is invalid: " + i2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public final VH onCreateViewHolder(ViewGroup viewGroup, int i2) {
        return this.mParentViewType.contains(Integer.valueOf(i2)) ? createParentHolder(viewGroup, i2) : createChildHolder(viewGroup, i2);
    }

    public final void onBindViewHolder(VH vh, int i2, List<Object> list) {
        int parentItemPosition = parentItemPosition(i2);
        if (isParentItem(i2)) {
            bindParentHolder(vh, parentItemPosition, list);
        } else {
            bindChildHolder(vh, parentItemPosition, childItemPosition(i2), list);
        }
    }

    public void bindParentHolder(VH vh, int i2, List<Object> list) {
        bindParentHolder(vh, i2);
    }

    public void bindChildHolder(VH vh, int i2, int i3, List<Object> list) {
        bindChildHolder(vh, i2, i3);
    }

    public static abstract class ViewHolder extends RecyclerView.ViewHolder {
        private ExpandableAdapter mAdapter;

        public ViewHolder(View view, ExpandableAdapter expandableAdapter) {
            super(view);
            this.mAdapter = expandableAdapter;
        }

        public final boolean isParentItem() {
            return this.mAdapter.isParentItem(getAdapterPosition());
        }

        public final int parentItemPosition() {
            return this.mAdapter.parentItemPosition(getAdapterPosition());
        }

        public final int childItemPosition() {
            if (isParentItem()) {
                throw new IllegalStateException("This item is not a child item.");
            }
            return this.mAdapter.childItemPosition(getAdapterPosition());
        }

        public final boolean isParentExpanded() {
            return this.mAdapter.isExpanded(parentItemPosition());
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onAttachedToRecyclerView(RecyclerView recyclerView) {
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        if (layoutManager instanceof GridLayoutManager) {
            final GridLayoutManager gridLayoutManager = (GridLayoutManager) layoutManager;
            final GridLayoutManager.SpanSizeLookup spanSizeLookup = gridLayoutManager.getSpanSizeLookup();
            gridLayoutManager.setSpanSizeLookup(new GridLayoutManager.SpanSizeLookup() { // from class: com.yanzhenjie.recyclerview.ExpandableAdapter.1
                @Override // androidx.recyclerview.widget.GridLayoutManager.SpanSizeLookup
                public int getSpanSize(int i2) {
                    if (ExpandableAdapter.this.isParentItem(i2)) {
                        return gridLayoutManager.getSpanCount();
                    }
                    GridLayoutManager.SpanSizeLookup spanSizeLookup2 = spanSizeLookup;
                    if (spanSizeLookup2 != null) {
                        return spanSizeLookup2.getSpanSize(i2);
                    }
                    return 1;
                }
            });
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onViewAttachedToWindow(VH vh) {
        if (isParentItem(vh.getAdapterPosition())) {
            ViewGroup.LayoutParams layoutParams = vh.itemView.getLayoutParams();
            if (layoutParams instanceof StaggeredGridLayoutManager.LayoutParams) {
                ((StaggeredGridLayoutManager.LayoutParams) layoutParams).setFullSpan(true);
            }
        }
    }
}
