package com.yucheng.smarthealthpro.customchart.charts;

import android.animation.ValueAnimator;
import android.content.ContentValues;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.RectF;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.os.Environment;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import com.yucheng.smarthealthpro.customchart.animation.ChartAnimator;
import com.yucheng.smarthealthpro.customchart.animation.Easing;
import com.yucheng.smarthealthpro.customchart.components.Description;
import com.yucheng.smarthealthpro.customchart.components.IMarker;
import com.yucheng.smarthealthpro.customchart.components.Legend;
import com.yucheng.smarthealthpro.customchart.components.XAxis;
import com.yucheng.smarthealthpro.customchart.data.ChartData;
import com.yucheng.smarthealthpro.customchart.data.Entry;
import com.yucheng.smarthealthpro.customchart.formatter.DefaultValueFormatter;
import com.yucheng.smarthealthpro.customchart.formatter.IValueFormatter;
import com.yucheng.smarthealthpro.customchart.highlight.ChartHighlighter;
import com.yucheng.smarthealthpro.customchart.highlight.Highlight;
import com.yucheng.smarthealthpro.customchart.highlight.IHighlighter;
import com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface;
import com.yucheng.smarthealthpro.customchart.interfaces.datasets.IDataSet;
import com.yucheng.smarthealthpro.customchart.klinechart.BloodPressureBean;
import com.yucheng.smarthealthpro.customchart.listener.ChartTouchListener;
import com.yucheng.smarthealthpro.customchart.listener.OnChartGestureListener;
import com.yucheng.smarthealthpro.customchart.listener.OnChartValueSelectedListener;
import com.yucheng.smarthealthpro.customchart.renderer.DataRenderer;
import com.yucheng.smarthealthpro.customchart.renderer.LegendRenderer;
import com.yucheng.smarthealthpro.customchart.temperature.NearestUtils;
import com.yucheng.smarthealthpro.customchart.temperature.TemperBean;
import com.yucheng.smarthealthpro.customchart.utils.MPPointF;
import com.yucheng.smarthealthpro.customchart.utils.Utils;
import com.yucheng.smarthealthpro.customchart.utils.ViewPortHandler;
import com.yucheng.smarthealthpro.home.activity.phy.bean.PhyDayInfo;
import com.yucheng.smarthealthpro.home.activity.running.bean.StepBean;
import com.yucheng.smarthealthpro.home.activity.sleep.bean.SleepDayInfo;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/* loaded from: classes3.dex */
public abstract class Chart<T extends ChartData<? extends IDataSet<? extends Entry>>> extends ViewGroup implements ChartInterface {
    public static final String LOG_TAG = "MPAndroidChart";
    public static final int PAINT_CENTER_TEXT = 14;
    public static final int PAINT_DESCRIPTION = 11;
    public static final int PAINT_GRID_BACKGROUND = 4;
    public static final int PAINT_HOLE = 13;
    public static final int PAINT_INFO = 7;
    public static final int PAINT_LEGEND_LABEL = 18;
    protected ChartAnimator mAnimator;
    private List<BloodPressureBean> mBloodPressureBean;
    protected ChartTouchListener mChartTouchListener;
    protected T mData;
    protected DefaultValueFormatter mDefaultValueFormatter;
    protected Paint mDescPaint;
    protected Description mDescription;
    private boolean mDragDecelerationEnabled;
    private float mDragDecelerationFrictionCoef;
    protected boolean mDrawMarkers;
    private float mExtraBottomOffset;
    private float mExtraLeftOffset;
    private float mExtraRightOffset;
    private float mExtraTopOffset;
    private OnChartGestureListener mGestureListener;
    protected boolean mHighLightPerTapEnabled;
    protected IHighlighter mHighlighter;
    protected Highlight[] mIndicesToHighlight;
    protected Paint mInfoPaint;
    protected ArrayList<Runnable> mJobs;
    protected Legend mLegend;
    protected LegendRenderer mLegendRenderer;
    protected boolean mLogEnabled;
    protected IMarker mMarker;
    private MarkerLabel mMarkerLabel;
    protected float mMaxHighlightDistance;
    private String mNoDataText;
    private boolean mOffsetsCalculated;
    private List<PhyDayInfo> mPhyInfo;
    protected DataRenderer mRenderer;
    protected OnChartValueSelectedListener mSelectionListener;
    private List<SleepDayInfo> mSleepInfo;
    private List<StepBean> mStepBean;
    protected boolean mTouchEnabled;
    private boolean mUnbind;
    protected ViewPortHandler mViewPortHandler;
    protected XAxis mXAxis;
    private List<TemperBean> temperBeans;

    public enum MarkerLabel {
        TEMPER_CHART,
        TEMPER_WEEK_MONTH_CHART,
        BLOOD_OXYGEN_DAY_CHART,
        BLOOD_OXYGEN_WEEK_MONTH_CHART,
        BLOOD_SUGAR_DAY_CHART,
        BLOOD_SUGAR_WEEK_MONTH_CHART,
        URIC_ACID_DAY_CHART,
        URIC_ACID_WEEK_MONTH_CHART,
        HEART_RATE_DAY_CHART,
        HEART_RATE_WEEK_MONTH_CHART,
        RESPIRATORY_RATE_DAY_CHART,
        RESPIRATORY_WEEK_MONTH_CHART,
        BLOOD_PRESSURE_DAY_CHART,
        BLOOD_PRESSURE_WEEK_MONTH_CHART,
        STEP_CHART,
        SLEEP_DAY_CHART,
        SLEEP_WEEK_CHART,
        SLEEP_MONTH_CHART
    }

    protected abstract void calcMinMax();

    protected abstract void calculateOffsets();

    public abstract void notifyDataSetChanged();

    public Chart(Context context) {
        super(context);
        this.mLogEnabled = false;
        this.mData = null;
        this.mHighLightPerTapEnabled = true;
        this.mDragDecelerationEnabled = true;
        this.mDragDecelerationFrictionCoef = 0.9f;
        this.mDefaultValueFormatter = new DefaultValueFormatter(0);
        this.mTouchEnabled = true;
        this.mNoDataText = "No chart data available.";
        this.mViewPortHandler = new ViewPortHandler();
        this.mExtraTopOffset = 0.0f;
        this.mExtraRightOffset = 0.0f;
        this.mExtraBottomOffset = 0.0f;
        this.mExtraLeftOffset = 0.0f;
        this.mOffsetsCalculated = false;
        this.mMaxHighlightDistance = 0.0f;
        this.mDrawMarkers = true;
        this.mJobs = new ArrayList<>();
        this.mUnbind = false;
        init();
    }

    public Chart(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.mLogEnabled = false;
        this.mData = null;
        this.mHighLightPerTapEnabled = true;
        this.mDragDecelerationEnabled = true;
        this.mDragDecelerationFrictionCoef = 0.9f;
        this.mDefaultValueFormatter = new DefaultValueFormatter(0);
        this.mTouchEnabled = true;
        this.mNoDataText = "No chart data available.";
        this.mViewPortHandler = new ViewPortHandler();
        this.mExtraTopOffset = 0.0f;
        this.mExtraRightOffset = 0.0f;
        this.mExtraBottomOffset = 0.0f;
        this.mExtraLeftOffset = 0.0f;
        this.mOffsetsCalculated = false;
        this.mMaxHighlightDistance = 0.0f;
        this.mDrawMarkers = true;
        this.mJobs = new ArrayList<>();
        this.mUnbind = false;
        init();
    }

    public Chart(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mLogEnabled = false;
        this.mData = null;
        this.mHighLightPerTapEnabled = true;
        this.mDragDecelerationEnabled = true;
        this.mDragDecelerationFrictionCoef = 0.9f;
        this.mDefaultValueFormatter = new DefaultValueFormatter(0);
        this.mTouchEnabled = true;
        this.mNoDataText = "No chart data available.";
        this.mViewPortHandler = new ViewPortHandler();
        this.mExtraTopOffset = 0.0f;
        this.mExtraRightOffset = 0.0f;
        this.mExtraBottomOffset = 0.0f;
        this.mExtraLeftOffset = 0.0f;
        this.mOffsetsCalculated = false;
        this.mMaxHighlightDistance = 0.0f;
        this.mDrawMarkers = true;
        this.mJobs = new ArrayList<>();
        this.mUnbind = false;
        init();
    }

    protected void init() {
        setWillNotDraw(false);
        this.mAnimator = new ChartAnimator(new ValueAnimator.AnimatorUpdateListener() { // from class: com.yucheng.smarthealthpro.customchart.charts.Chart.1
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                Chart.this.postInvalidate();
            }
        });
        Utils.init(getContext());
        this.mMaxHighlightDistance = Utils.convertDpToPixel(500.0f);
        this.mDescription = new Description();
        this.mLegend = new Legend();
        this.mLegendRenderer = new LegendRenderer(this.mViewPortHandler, this.mLegend);
        this.mXAxis = new XAxis();
        this.mDescPaint = new Paint(1);
        Paint paint = new Paint(1);
        this.mInfoPaint = paint;
        paint.setColor(Color.rgb(247, 189, 51));
        this.mInfoPaint.setTextAlign(Paint.Align.CENTER);
        this.mInfoPaint.setTextSize(Utils.convertDpToPixel(12.0f));
        if (this.mLogEnabled) {
            Log.i("", "Chart.init()");
        }
    }

    public void setData(T t) {
        this.mData = t;
        this.mOffsetsCalculated = false;
        if (t == null) {
            return;
        }
        setupDefaultFormatter(t.getYMin(), t.getYMax());
        for (IDataSet iDataSet : this.mData.getDataSets()) {
            if (iDataSet.needsFormatter() || iDataSet.getValueFormatter() == this.mDefaultValueFormatter) {
                iDataSet.setValueFormatter(this.mDefaultValueFormatter);
            }
        }
        notifyDataSetChanged();
        if (this.mLogEnabled) {
            Log.i(LOG_TAG, "Data is set.");
        }
    }

    public void clear() {
        this.mData = null;
        this.mOffsetsCalculated = false;
        this.mIndicesToHighlight = null;
        this.mChartTouchListener.setLastHighlighted(null);
        invalidate();
    }

    public void clearValues() {
        this.mData.clearValues();
        invalidate();
    }

    public boolean isEmpty() {
        T t = this.mData;
        return t == null || t.getEntryCount() <= 0;
    }

    protected void setupDefaultFormatter(float f2, float f3) {
        float max;
        T t = this.mData;
        if (t == null || t.getEntryCount() < 2) {
            max = Math.max(Math.abs(f2), Math.abs(f3));
        } else {
            max = Math.abs(f3 - f2);
        }
        this.mDefaultValueFormatter.setup(Utils.getDecimals(max));
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        if (this.mData == null) {
            if (!TextUtils.isEmpty(this.mNoDataText)) {
                MPPointF center = getCenter();
                int i2 = AnonymousClass2.$SwitchMap$android$graphics$Paint$Align[this.mInfoPaint.getTextAlign().ordinal()];
                if (i2 == 1) {
                    center.x = 0.0f;
                    canvas.drawText(this.mNoDataText, center.x, center.y, this.mInfoPaint);
                    return;
                } else if (i2 == 2) {
                    center.x = (float) (center.x * 2.0d);
                    canvas.drawText(this.mNoDataText, center.x, center.y, this.mInfoPaint);
                    return;
                } else {
                    canvas.drawText(this.mNoDataText, center.x, center.y, this.mInfoPaint);
                    return;
                }
            }
            return;
        }
        if (this.mOffsetsCalculated) {
            return;
        }
        calculateOffsets();
        this.mOffsetsCalculated = true;
    }

    protected void drawDescription(Canvas canvas) {
        float f2;
        float f3;
        Description description = this.mDescription;
        if (description == null || !description.isEnabled()) {
            return;
        }
        MPPointF position = this.mDescription.getPosition();
        this.mDescPaint.setTypeface(this.mDescription.getTypeface());
        this.mDescPaint.setTextSize(this.mDescription.getTextSize());
        this.mDescPaint.setColor(this.mDescription.getTextColor());
        this.mDescPaint.setTextAlign(this.mDescription.getTextAlign());
        if (position == null) {
            f3 = (getWidth() - this.mViewPortHandler.offsetRight()) - this.mDescription.getXOffset();
            f2 = (getHeight() - this.mViewPortHandler.offsetBottom()) - this.mDescription.getYOffset();
        } else {
            float f4 = position.x;
            f2 = position.y;
            f3 = f4;
        }
        canvas.drawText(this.mDescription.getText(), f3, f2, this.mDescPaint);
    }

    @Override // com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface
    public float getMaxHighlightDistance() {
        return this.mMaxHighlightDistance;
    }

    public void setMaxHighlightDistance(float f2) {
        this.mMaxHighlightDistance = Utils.convertDpToPixel(f2);
    }

    public Highlight[] getHighlighted() {
        return this.mIndicesToHighlight;
    }

    public boolean isHighlightPerTapEnabled() {
        return this.mHighLightPerTapEnabled;
    }

    public void setHighlightPerTapEnabled(boolean z) {
        this.mHighLightPerTapEnabled = z;
    }

    public boolean valuesToHighlight() {
        Highlight[] highlightArr = this.mIndicesToHighlight;
        return (highlightArr == null || highlightArr.length <= 0 || highlightArr[0] == null) ? false : true;
    }

    protected void setLastHighlighted(Highlight[] highlightArr) {
        Highlight highlight;
        if (highlightArr == null || highlightArr.length <= 0 || (highlight = highlightArr[0]) == null) {
            this.mChartTouchListener.setLastHighlighted(null);
        } else {
            this.mChartTouchListener.setLastHighlighted(highlight);
        }
    }

    public void highlightValues(Highlight[] highlightArr) {
        this.mIndicesToHighlight = highlightArr;
        setLastHighlighted(highlightArr);
        invalidate();
    }

    public void highlightValue(float f2, int i2, int i3) {
        highlightValue(f2, i2, i3, true);
    }

    public void highlightValue(float f2, int i2) {
        highlightValue(f2, i2, -1, true);
    }

    public void highlightValue(float f2, float f3, int i2, int i3) {
        highlightValue(f2, f3, i2, i3, true);
    }

    public void highlightValue(float f2, float f3, int i2) {
        highlightValue(f2, f3, i2, -1, true);
    }

    public void highlightValue(float f2, int i2, int i3, boolean z) {
        highlightValue(f2, Float.NaN, i2, i3, z);
    }

    public void highlightValue(float f2, int i2, boolean z) {
        highlightValue(f2, Float.NaN, i2, -1, z);
    }

    public void highlightValue(float f2, float f3, int i2, int i3, boolean z) {
        if (i2 < 0 || i2 >= this.mData.getDataSetCount()) {
            highlightValue((Highlight) null, z);
        } else {
            highlightValue(new Highlight(f2, f3, i2, i3), z);
        }
    }

    public void highlightValue(float f2, float f3, int i2, boolean z) {
        highlightValue(f2, f3, i2, -1, z);
    }

    public void highlightValue(Highlight highlight) {
        highlightValue(highlight, false);
    }

    public void highlightValue(Highlight highlight, boolean z) {
        Entry entry = null;
        if (highlight == null) {
            this.mIndicesToHighlight = null;
        } else {
            if (this.mLogEnabled) {
                Log.i(LOG_TAG, "Highlighted: " + highlight.toString());
            }
            Entry entryForHighlight = this.mData.getEntryForHighlight(highlight);
            if (entryForHighlight == null) {
                this.mIndicesToHighlight = null;
                highlight = null;
            } else {
                this.mIndicesToHighlight = new Highlight[]{highlight};
            }
            entry = entryForHighlight;
        }
        setLastHighlighted(this.mIndicesToHighlight);
        if (z && this.mSelectionListener != null) {
            if (!valuesToHighlight()) {
                this.mSelectionListener.onNothingSelected();
            } else {
                this.mSelectionListener.onValueSelected(entry, highlight);
            }
        }
        invalidate();
    }

    public Highlight getHighlightByTouchPoint(float f2, float f3) {
        if (this.mData == null) {
            Log.e(LOG_TAG, "Can't select by touch. No data set.");
            return null;
        }
        return getHighlighter().getHighlight(f2, f3);
    }

    public void setOnTouchListener(ChartTouchListener chartTouchListener) {
        this.mChartTouchListener = chartTouchListener;
    }

    public ChartTouchListener getOnTouchListener() {
        return this.mChartTouchListener;
    }

    protected void drawMarkers(Canvas canvas) {
        if (this.mMarker == null || !isDrawMarkersEnabled() || !valuesToHighlight()) {
            return;
        }
        int i2 = 0;
        while (true) {
            Highlight[] highlightArr = this.mIndicesToHighlight;
            if (i2 >= highlightArr.length) {
                return;
            }
            Highlight highlight = highlightArr[i2];
            IDataSet dataSetByIndex = this.mData.getDataSetByIndex(highlight.getDataSetIndex());
            Entry entryForHighlight = this.mData.getEntryForHighlight(this.mIndicesToHighlight[i2]);
            int entryIndex = dataSetByIndex.getEntryIndex(entryForHighlight);
            if (entryForHighlight != null && entryIndex <= dataSetByIndex.getEntryCount() * this.mAnimator.getPhaseX()) {
                float[] markerPosition = getMarkerPosition(highlight);
                if (this.mViewPortHandler.isInBounds(markerPosition[0], markerPosition[1])) {
                    if (this.mMarkerLabel == MarkerLabel.TEMPER_CHART) {
                        List<TemperBean> list = this.temperBeans;
                        if (list != null) {
                            int size = list.size();
                            int[] iArr = new int[size];
                            for (int i3 = 0; i3 < size; i3++) {
                                iArr[i3] = this.temperBeans.get(i3).getTime();
                            }
                            for (int i4 = 0; i4 < this.temperBeans.size(); i4++) {
                                if (entryForHighlight.getX() == new BigDecimal(this.temperBeans.get(i4).getTime()).setScale(1, 4).floatValue()) {
                                    this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                } else {
                                    int numberThree = NearestUtils.getNumberThree(iArr, Integer.valueOf((int) entryForHighlight.getX()));
                                    float f2 = numberThree;
                                    if (Math.abs((int) (f2 - entryForHighlight.getX())) < 60 && this.temperBeans.get(i4).getTime() == numberThree) {
                                        Entry entry = new Entry();
                                        entry.setX(f2);
                                        entry.setY(this.temperBeans.get(i4).getTemper());
                                        if (entryForHighlight.getY() != 0.0f) {
                                            this.mMarker.refreshContentTemp(entry, highlight, this.temperBeans);
                                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                        }
                                    }
                                }
                            }
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.TEMPER_WEEK_MONTH_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentTempWeekMohth(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.BLOOD_OXYGEN_DAY_CHART) {
                        List<TemperBean> list2 = this.temperBeans;
                        if (list2 != null) {
                            int size2 = list2.size();
                            int[] iArr2 = new int[size2];
                            for (int i5 = 0; i5 < size2; i5++) {
                                iArr2[i5] = this.temperBeans.get(i5).getTime();
                            }
                            for (int i6 = 0; i6 < this.temperBeans.size(); i6++) {
                                if (entryForHighlight.getX() == new BigDecimal(this.temperBeans.get(i6).getTime()).setScale(1, 4).floatValue()) {
                                    this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                } else {
                                    int numberThree2 = NearestUtils.getNumberThree(iArr2, Integer.valueOf((int) entryForHighlight.getX()));
                                    float f3 = numberThree2;
                                    if (Math.abs((int) (f3 - entryForHighlight.getX())) < 60 && this.temperBeans.get(i6).getTime() == numberThree2) {
                                        Entry entry2 = new Entry();
                                        entry2.setX(f3);
                                        entry2.setY(this.temperBeans.get(i6).getTemper());
                                        if (entryForHighlight.getY() != 0.0f) {
                                            this.mMarker.refreshContentDayBloodOxygen(entry2, highlight, this.temperBeans);
                                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                        }
                                    }
                                }
                            }
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.BLOOD_OXYGEN_WEEK_MONTH_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentWeekMonthBloodOxygen(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.BLOOD_SUGAR_DAY_CHART) {
                        List<TemperBean> list3 = this.temperBeans;
                        if (list3 != null) {
                            int size3 = list3.size();
                            int[] iArr3 = new int[size3];
                            for (int i7 = 0; i7 < size3; i7++) {
                                iArr3[i7] = this.temperBeans.get(i7).getTime();
                            }
                            for (int i8 = 0; i8 < this.temperBeans.size(); i8++) {
                                if (entryForHighlight.getX() == new BigDecimal(this.temperBeans.get(i8).getTime()).setScale(1, 4).floatValue()) {
                                    this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                } else {
                                    int numberThree3 = NearestUtils.getNumberThree(iArr3, Integer.valueOf((int) entryForHighlight.getX()));
                                    float f4 = numberThree3;
                                    if (Math.abs((int) (f4 - entryForHighlight.getX())) < 60 && this.temperBeans.get(i8).getTime() == numberThree3) {
                                        Entry entry3 = new Entry();
                                        entry3.setX(f4);
                                        entry3.setY(this.temperBeans.get(i8).getTemper());
                                        if (entryForHighlight.getY() != 0.0f) {
                                            this.mMarker.refreshContentDayBloodSugar(entry3, highlight, this.temperBeans);
                                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                        }
                                    }
                                }
                            }
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.BLOOD_SUGAR_WEEK_MONTH_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentWeekMonthBloodSugar(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.URIC_ACID_DAY_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentDayUricAcid(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.URIC_ACID_WEEK_MONTH_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentWeekMonthUricAcid(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.HEART_RATE_DAY_CHART) {
                        List<TemperBean> list4 = this.temperBeans;
                        if (list4 != null) {
                            int size4 = list4.size();
                            int[] iArr4 = new int[size4];
                            for (int i9 = 0; i9 < size4; i9++) {
                                iArr4[i9] = this.temperBeans.get(i9).getTime();
                            }
                            for (int i10 = 0; i10 < this.temperBeans.size(); i10++) {
                                if (entryForHighlight.getX() == new BigDecimal(this.temperBeans.get(i10).getTime()).setScale(1, 4).floatValue()) {
                                    this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                } else {
                                    int numberThree4 = NearestUtils.getNumberThree(iArr4, Integer.valueOf((int) entryForHighlight.getX()));
                                    float f5 = numberThree4;
                                    if (Math.abs((int) (f5 - entryForHighlight.getX())) < 60 && this.temperBeans.get(i10).getTime() == numberThree4) {
                                        Entry entry4 = new Entry();
                                        entry4.setX(f5);
                                        entry4.setY(this.temperBeans.get(i10).getTemper());
                                        if (entryForHighlight.getY() != 0.0f) {
                                            this.mMarker.refreshContentDayHeartRate(entry4, highlight, this.temperBeans);
                                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                        }
                                    }
                                }
                            }
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.HEART_RATE_WEEK_MONTH_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentWeekMonthHeartRate(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.RESPIRATORY_RATE_DAY_CHART) {
                        List<TemperBean> list5 = this.temperBeans;
                        if (list5 != null) {
                            int size5 = list5.size();
                            int[] iArr5 = new int[size5];
                            for (int i11 = 0; i11 < size5; i11++) {
                                iArr5[i11] = this.temperBeans.get(i11).getTime();
                            }
                            for (int i12 = 0; i12 < this.temperBeans.size(); i12++) {
                                if (entryForHighlight.getX() == new BigDecimal(this.temperBeans.get(i12).getTime()).setScale(1, 4).floatValue()) {
                                    this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                } else {
                                    int numberThree5 = NearestUtils.getNumberThree(iArr5, Integer.valueOf((int) entryForHighlight.getX()));
                                    float f6 = numberThree5;
                                    if (Math.abs((int) (f6 - entryForHighlight.getX())) < 60 && this.temperBeans.get(i12).getTime() == numberThree5) {
                                        Entry entry5 = new Entry();
                                        entry5.setX(f6);
                                        entry5.setY(this.temperBeans.get(i12).getTemper());
                                        if (entryForHighlight.getY() != 0.0f) {
                                            this.mMarker.refreshContentDayRespiratoryRate(entry5, highlight, this.temperBeans);
                                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                                        }
                                    }
                                }
                            }
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.RESPIRATORY_WEEK_MONTH_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentWeekMonthRespiratoryRate(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.BLOOD_PRESSURE_DAY_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentDayBloodPressure(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.BLOOD_PRESSURE_WEEK_MONTH_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentWeekMonthBloodPressure(entryForHighlight, highlight, this.temperBeans);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.SLEEP_DAY_CHART) {
                        if (entryForHighlight.getY() != 25.0f) {
                            this.mMarker.refreshContentSleep(entryForHighlight, highlight, this.mSleepInfo);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.STEP_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentStep(entryForHighlight, highlight, this.mStepBean);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel == MarkerLabel.SLEEP_WEEK_CHART) {
                        if (entryForHighlight.getY() != 0.0f) {
                            this.mMarker.refreshContentSleepWeekMonth(entryForHighlight, highlight, MarkerLabel.SLEEP_WEEK_CHART);
                            this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                        }
                    } else if (this.mMarkerLabel != MarkerLabel.SLEEP_MONTH_CHART) {
                        this.mMarker.refreshContent(entryForHighlight, highlight);
                        this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                    } else if (entryForHighlight.getY() != 0.0f) {
                        this.mMarker.refreshContentSleepWeekMonth(entryForHighlight, highlight, MarkerLabel.SLEEP_MONTH_CHART);
                        this.mMarker.draw(canvas, markerPosition[0], markerPosition[1]);
                    }
                }
            }
            i2++;
        }
    }

    protected float[] getMarkerPosition(Highlight highlight) {
        return new float[]{highlight.getDrawX(), highlight.getDrawY()};
    }

    public ChartAnimator getAnimator() {
        return this.mAnimator;
    }

    public boolean isDragDecelerationEnabled() {
        return this.mDragDecelerationEnabled;
    }

    public void setDragDecelerationEnabled(boolean z) {
        this.mDragDecelerationEnabled = z;
    }

    public float getDragDecelerationFrictionCoef() {
        return this.mDragDecelerationFrictionCoef;
    }

    public void setDragDecelerationFrictionCoef(float f2) {
        if (f2 < 0.0f) {
            f2 = 0.0f;
        }
        if (f2 >= 1.0f) {
            f2 = 0.999f;
        }
        this.mDragDecelerationFrictionCoef = f2;
    }

    public void animateXY(int i2, int i3, Easing.EasingFunction easingFunction, Easing.EasingFunction easingFunction2) {
        this.mAnimator.animateXY(i2, i3, easingFunction, easingFunction2);
    }

    public void animateXY(int i2, int i3, Easing.EasingFunction easingFunction) {
        this.mAnimator.animateXY(i2, i3, easingFunction);
    }

    public void animateX(int i2, Easing.EasingFunction easingFunction) {
        this.mAnimator.animateX(i2, easingFunction);
    }

    public void animateY(int i2, Easing.EasingFunction easingFunction) {
        this.mAnimator.animateY(i2, easingFunction);
    }

    public void animateX(int i2) {
        this.mAnimator.animateX(i2);
    }

    public void animateY(int i2) {
        this.mAnimator.animateY(i2);
    }

    public void animateXY(int i2, int i3) {
        this.mAnimator.animateXY(i2, i3);
    }

    public XAxis getXAxis() {
        return this.mXAxis;
    }

    @Override // com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface
    public IValueFormatter getDefaultValueFormatter() {
        return this.mDefaultValueFormatter;
    }

    public void setOnChartValueSelectedListener(OnChartValueSelectedListener onChartValueSelectedListener) {
        this.mSelectionListener = onChartValueSelectedListener;
    }

    public void setOnChartGestureListener(OnChartGestureListener onChartGestureListener) {
        this.mGestureListener = onChartGestureListener;
    }

    public OnChartGestureListener getOnChartGestureListener() {
        return this.mGestureListener;
    }

    public float getYMax() {
        return this.mData.getYMax();
    }

    public float getYMin() {
        return this.mData.getYMin();
    }

    @Override // com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface
    public float getXChartMax() {
        return this.mXAxis.mAxisMaximum;
    }

    @Override // com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface
    public float getXChartMin() {
        return this.mXAxis.mAxisMinimum;
    }

    @Override // com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface
    public float getXRange() {
        return this.mXAxis.mAxisRange;
    }

    public MPPointF getCenter() {
        return MPPointF.getInstance(getWidth() / 2.0f, getHeight() / 2.0f);
    }

    @Override // com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface
    public MPPointF getCenterOffsets() {
        return this.mViewPortHandler.getContentCenter();
    }

    public void setExtraOffsets(float f2, float f3, float f4, float f5) {
        setExtraLeftOffset(f2);
        setExtraTopOffset(f3);
        setExtraRightOffset(f4);
        setExtraBottomOffset(f5);
    }

    public void setExtraTopOffset(float f2) {
        this.mExtraTopOffset = Utils.convertDpToPixel(f2);
    }

    public float getExtraTopOffset() {
        return this.mExtraTopOffset;
    }

    public void setExtraRightOffset(float f2) {
        this.mExtraRightOffset = Utils.convertDpToPixel(f2);
    }

    public float getExtraRightOffset() {
        return this.mExtraRightOffset;
    }

    public void setExtraBottomOffset(float f2) {
        this.mExtraBottomOffset = Utils.convertDpToPixel(f2);
    }

    public float getExtraBottomOffset() {
        return this.mExtraBottomOffset;
    }

    public void setExtraLeftOffset(float f2) {
        this.mExtraLeftOffset = Utils.convertDpToPixel(f2);
    }

    public float getExtraLeftOffset() {
        return this.mExtraLeftOffset;
    }

    public void setLogEnabled(boolean z) {
        this.mLogEnabled = z;
    }

    public boolean isLogEnabled() {
        return this.mLogEnabled;
    }

    public void setNoDataText(String str) {
        this.mNoDataText = str;
    }

    public void setNoDataTextColor(int i2) {
        this.mInfoPaint.setColor(i2);
    }

    public void setNoDataTextTypeface(Typeface typeface) {
        this.mInfoPaint.setTypeface(typeface);
    }

    public void setNoDataTextAlignment(Paint.Align align) {
        this.mInfoPaint.setTextAlign(align);
    }

    public void setTouchEnabled(boolean z) {
        this.mTouchEnabled = z;
    }

    public void setMarker(IMarker iMarker, List<TemperBean> list, List<BloodPressureBean> list2, List<SleepDayInfo> list3, List<StepBean> list4, MarkerLabel markerLabel) {
        this.temperBeans = list;
        this.mBloodPressureBean = list2;
        this.mSleepInfo = list3;
        this.mStepBean = list4;
        this.mMarkerLabel = markerLabel;
        this.mMarker = iMarker;
    }

    public void setMarker(IMarker iMarker, List<TemperBean> list, List<BloodPressureBean> list2, List<SleepDayInfo> list3, List<StepBean> list4, List<PhyDayInfo> list5, MarkerLabel markerLabel) {
        this.temperBeans = list;
        this.mBloodPressureBean = list2;
        this.mSleepInfo = list3;
        this.mStepBean = list4;
        this.mMarkerLabel = markerLabel;
        this.mPhyInfo = list5;
        this.mMarker = iMarker;
    }

    public IMarker getMarker() {
        return this.mMarker;
    }

    @Deprecated
    public void setMarkerView(IMarker iMarker) {
        setMarker(iMarker, this.temperBeans, this.mBloodPressureBean, this.mSleepInfo, this.mStepBean, this.mMarkerLabel);
    }

    @Deprecated
    public IMarker getMarkerView() {
        return getMarker();
    }

    public void setDescription(Description description) {
        this.mDescription = description;
    }

    public Description getDescription() {
        return this.mDescription;
    }

    public Legend getLegend() {
        return this.mLegend;
    }

    public LegendRenderer getLegendRenderer() {
        return this.mLegendRenderer;
    }

    @Override // com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface
    public RectF getContentRect() {
        return this.mViewPortHandler.getContentRect();
    }

    public void disableScroll() {
        ViewParent parent = getParent();
        if (parent != null) {
            parent.requestDisallowInterceptTouchEvent(true);
        }
    }

    public void enableScroll() {
        ViewParent parent = getParent();
        if (parent != null) {
            parent.requestDisallowInterceptTouchEvent(false);
        }
    }

    public void setPaint(Paint paint, int i2) {
        if (i2 == 7) {
            this.mInfoPaint = paint;
        } else {
            if (i2 != 11) {
                return;
            }
            this.mDescPaint = paint;
        }
    }

    public Paint getPaint(int i2) {
        if (i2 == 7) {
            return this.mInfoPaint;
        }
        if (i2 != 11) {
            return null;
        }
        return this.mDescPaint;
    }

    @Deprecated
    public boolean isDrawMarkerViewsEnabled() {
        return isDrawMarkersEnabled();
    }

    @Deprecated
    public void setDrawMarkerViews(boolean z) {
        setDrawMarkers(z);
    }

    public boolean isDrawMarkersEnabled() {
        return this.mDrawMarkers;
    }

    public void setDrawMarkers(boolean z) {
        this.mDrawMarkers = z;
    }

    public T getData() {
        return this.mData;
    }

    public ViewPortHandler getViewPortHandler() {
        return this.mViewPortHandler;
    }

    public DataRenderer getRenderer() {
        return this.mRenderer;
    }

    public void setRenderer(DataRenderer dataRenderer) {
        if (dataRenderer != null) {
            this.mRenderer = dataRenderer;
        }
    }

    public IHighlighter getHighlighter() {
        return this.mHighlighter;
    }

    public void setHighlighter(ChartHighlighter chartHighlighter) {
        this.mHighlighter = chartHighlighter;
    }

    @Override // com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface
    public MPPointF getCenterOfView() {
        return getCenter();
    }

    public Bitmap getChartBitmap() {
        Bitmap createBitmap = Bitmap.createBitmap(getWidth(), getHeight(), Bitmap.Config.RGB_565);
        Canvas canvas = new Canvas(createBitmap);
        Drawable background = getBackground();
        if (background != null) {
            background.draw(canvas);
        } else {
            canvas.drawColor(-1);
        }
        draw(canvas);
        return createBitmap;
    }

    public boolean saveToPath(String str, String str2) {
        Bitmap chartBitmap = getChartBitmap();
        try {
            FileOutputStream fileOutputStream = new FileOutputStream(Environment.getExternalStorageDirectory().getPath() + str2 + "/" + str + ".png");
            chartBitmap.compress(Bitmap.CompressFormat.PNG, 40, fileOutputStream);
            fileOutputStream.close();
            return true;
        } catch (Exception e2) {
            e2.printStackTrace();
            return false;
        }
    }

    public boolean saveToGallery(String str, String str2, String str3, Bitmap.CompressFormat compressFormat, int i2) {
        String str4;
        if (i2 < 0 || i2 > 100) {
            i2 = 50;
        }
        long currentTimeMillis = System.currentTimeMillis();
        File file = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + "/DCIM/" + str2);
        if (!file.exists() && !file.mkdirs()) {
            return false;
        }
        int i3 = AnonymousClass2.$SwitchMap$android$graphics$Bitmap$CompressFormat[compressFormat.ordinal()];
        if (i3 == 1) {
            str4 = "image/png";
            if (!str.endsWith(".png")) {
                str = str + ".png";
            }
        } else if (i3 == 2) {
            str4 = "image/webp";
            if (!str.endsWith(".webp")) {
                str = str + ".webp";
            }
        } else {
            str4 = "image/jpeg";
            if (!str.endsWith(".jpg") && !str.endsWith(".jpeg")) {
                str = str + ".jpg";
            }
        }
        String str5 = file.getAbsolutePath() + "/" + str;
        try {
            FileOutputStream fileOutputStream = new FileOutputStream(str5);
            getChartBitmap().compress(compressFormat, i2, fileOutputStream);
            fileOutputStream.flush();
            fileOutputStream.close();
            long length = new File(str5).length();
            ContentValues contentValues = new ContentValues(8);
            contentValues.put("title", str);
            contentValues.put("_display_name", str);
            contentValues.put("date_added", Long.valueOf(currentTimeMillis));
            contentValues.put("mime_type", str4);
            contentValues.put("description", str3);
            contentValues.put("orientation", (Integer) 0);
            contentValues.put("_data", str5);
            contentValues.put("_size", Long.valueOf(length));
            return getContext().getContentResolver().insert(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, contentValues) != null;
        } catch (IOException e2) {
            e2.printStackTrace();
            return false;
        }
    }

    /* renamed from: com.yucheng.smarthealthpro.customchart.charts.Chart$2, reason: invalid class name */
    static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$android$graphics$Bitmap$CompressFormat;
        static final /* synthetic */ int[] $SwitchMap$android$graphics$Paint$Align;

        static {
            int[] iArr = new int[Bitmap.CompressFormat.values().length];
            $SwitchMap$android$graphics$Bitmap$CompressFormat = iArr;
            try {
                iArr[Bitmap.CompressFormat.PNG.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$android$graphics$Bitmap$CompressFormat[Bitmap.CompressFormat.WEBP.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$android$graphics$Bitmap$CompressFormat[Bitmap.CompressFormat.JPEG.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr2 = new int[Paint.Align.values().length];
            $SwitchMap$android$graphics$Paint$Align = iArr2;
            try {
                iArr2[Paint.Align.LEFT.ordinal()] = 1;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                $SwitchMap$android$graphics$Paint$Align[Paint.Align.RIGHT.ordinal()] = 2;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    public boolean saveToGallery(String str, int i2) {
        return saveToGallery(str, "", "MPAndroidChart-Library Save", Bitmap.CompressFormat.PNG, i2);
    }

    public boolean saveToGallery(String str) {
        return saveToGallery(str, "", "MPAndroidChart-Library Save", Bitmap.CompressFormat.PNG, 40);
    }

    public void removeViewportJob(Runnable runnable) {
        this.mJobs.remove(runnable);
    }

    public void clearAllViewportJobs() {
        this.mJobs.clear();
    }

    public void addViewportJob(Runnable runnable) {
        if (this.mViewPortHandler.hasChartDimens()) {
            post(runnable);
        } else {
            this.mJobs.add(runnable);
        }
    }

    public ArrayList<Runnable> getJobs() {
        return this.mJobs;
    }

    @Override // android.view.ViewGroup, android.view.View
    protected void onLayout(boolean z, int i2, int i3, int i4, int i5) {
        for (int i6 = 0; i6 < getChildCount(); i6++) {
            getChildAt(i6).layout(i2, i3, i4, i5);
        }
    }

    @Override // android.view.View
    protected void onMeasure(int i2, int i3) {
        super.onMeasure(i2, i3);
        int convertDpToPixel = (int) Utils.convertDpToPixel(50.0f);
        setMeasuredDimension(Math.max(getSuggestedMinimumWidth(), resolveSize(convertDpToPixel, i2)), Math.max(getSuggestedMinimumHeight(), resolveSize(convertDpToPixel, i3)));
    }

    @Override // android.view.View
    protected void onSizeChanged(int i2, int i3, int i4, int i5) {
        if (this.mLogEnabled) {
            Log.i(LOG_TAG, "OnSizeChanged()");
        }
        if (i2 > 0 && i3 > 0 && i2 < 10000 && i3 < 10000) {
            if (this.mLogEnabled) {
                Log.i(LOG_TAG, "Setting chart dimens, width: " + i2 + ", height: " + i3);
            }
            this.mViewPortHandler.setChartDimens(i2, i3);
        } else if (this.mLogEnabled) {
            Log.w(LOG_TAG, "*Avoiding* setting chart dimens! width: " + i2 + ", height: " + i3);
        }
        notifyDataSetChanged();
        Iterator<Runnable> it2 = this.mJobs.iterator();
        while (it2.hasNext()) {
            post(it2.next());
        }
        this.mJobs.clear();
        super.onSizeChanged(i2, i3, i4, i5);
    }

    public void setHardwareAccelerationEnabled(boolean z) {
        if (z) {
            setLayerType(2, null);
        } else {
            setLayerType(1, null);
        }
    }

    @Override // android.view.ViewGroup, android.view.View
    protected void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        if (this.mUnbind) {
            unbindDrawables(this);
        }
    }

    private void unbindDrawables(View view) {
        if (view.getBackground() != null) {
            view.getBackground().setCallback(null);
        }
        if (!(view instanceof ViewGroup)) {
            return;
        }
        int i2 = 0;
        while (true) {
            ViewGroup viewGroup = (ViewGroup) view;
            if (i2 < viewGroup.getChildCount()) {
                unbindDrawables(viewGroup.getChildAt(i2));
                i2++;
            } else {
                viewGroup.removeAllViews();
                return;
            }
        }
    }

    public void setUnbindEnabled(boolean z) {
        this.mUnbind = z;
    }
}
