package com.yucheng.smarthealthpro.customchart.klinechart;

import android.content.Context;
import android.graphics.Paint;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;
import androidx.core.widget.NestedScrollView;
import com.facebook.internal.security.CertificateUtil;
import com.google.android.gms.common.ConnectionResult;
import com.google.android.material.timepicker.TimeModel;
import com.yucheng.HealthWear.R;
import com.yucheng.smarthealthpro.customchart.MyBpDayCustomXAxisValueFormatter;
import com.yucheng.smarthealthpro.customchart.MyMarkerView;
import com.yucheng.smarthealthpro.customchart.MyMonthCustomXAxisValueFormatter;
import com.yucheng.smarthealthpro.customchart.MyWeekCustomXAxisValueFormatter;
import com.yucheng.smarthealthpro.customchart.charts.CandleStickChart;
import com.yucheng.smarthealthpro.customchart.charts.Chart;
import com.yucheng.smarthealthpro.customchart.components.XAxis;
import com.yucheng.smarthealthpro.customchart.components.YAxis;
import com.yucheng.smarthealthpro.customchart.data.CandleData;
import com.yucheng.smarthealthpro.customchart.data.CandleDataSet;
import com.yucheng.smarthealthpro.customchart.data.CandleEntry;
import com.yucheng.smarthealthpro.customchart.renderer.MyXAxisRenderer;
import com.yucheng.smarthealthpro.customchart.utils.HourToMinute;
import com.yucheng.smarthealthpro.home.activity.bloodpressure.bean.BloodPressureHisListBean;
import com.yucheng.smarthealthpro.utils.AppDateMgr;
import com.yucheng.smarthealthpro.utils.TimeStampUtils;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.List;

/* loaded from: classes3.dex */
public class BpCandleStickChartUtils {
    private static List<CandleEntry> dayValues;
    private static BpCandleStickChartUtils mBpCandleStickChartUtils;
    private static List<CandleEntry> monthValues;
    private static List<CandleEntry> weekValues;

    public enum FORMATTER {
        DAY,
        WEEK,
        MONTH
    }

    private BpCandleStickChartUtils() {
    }

    public static synchronized BpCandleStickChartUtils getInstance() {
        BpCandleStickChartUtils bpCandleStickChartUtils;
        synchronized (BpCandleStickChartUtils.class) {
            if (mBpCandleStickChartUtils == null) {
                mBpCandleStickChartUtils = new BpCandleStickChartUtils();
            }
            bpCandleStickChartUtils = mBpCandleStickChartUtils;
        }
        return bpCandleStickChartUtils;
    }

    public static void initCandleStickChart(CandleStickChart candleStickChart, Context context, List<BloodPressureHisListBean> list, String str, final NestedScrollView nestedScrollView, float f2, float f3, float f4, float f5, int i2, int i3, FORMATTER formatter) {
        candleStickChart.setBackgroundColor(-1);
        candleStickChart.getDescription().setEnabled(false);
        candleStickChart.setMaxVisibleValueCount(60);
        candleStickChart.setDrawGridBackground(false);
        candleStickChart.getAxisRight().setEnabled(false);
        candleStickChart.getLegend().setEnabled(false);
        candleStickChart.setDragEnabled(true);
        candleStickChart.setScaleEnabled(false);
        candleStickChart.setPinchZoom(false);
        candleStickChart.animateX(ConnectionResult.DRIVE_EXTERNAL_STORAGE_REQUIRED);
        candleStickChart.setOnTouchListener(new View.OnTouchListener() { // from class: com.yucheng.smarthealthpro.customchart.klinechart.BpCandleStickChartUtils.1
            @Override // android.view.View.OnTouchListener
            public boolean onTouch(View view, MotionEvent motionEvent) {
                if (motionEvent.getAction() == 1) {
                    NestedScrollView.this.requestDisallowInterceptTouchEvent(false);
                } else {
                    NestedScrollView.this.requestDisallowInterceptTouchEvent(true);
                }
                return false;
            }
        });
        YAxis axisLeft = candleStickChart.getAxisLeft();
        axisLeft.setEnabled(true);
        axisLeft.setLabelCount(i3, false);
        axisLeft.setDrawAxisLine(false);
        axisLeft.setDrawGridLines(false);
        if (list.size() > 0) {
            int i4 = 0;
            for (int i5 = 0; i5 < list.size(); i5++) {
                int bloodSBP = list.get(i5).getBloodSBP();
                if (bloodSBP > i4) {
                    i4 = bloodSBP;
                }
            }
            axisLeft.setAxisMaximum(i4 > 300 ? 400.0f : i4 > 200 ? 300.0f : i4 > 100 ? 200.0f : i4 / 0.8f);
        } else {
            axisLeft.setAxisMaximum(f2);
        }
        axisLeft.setAxisMinimum(f3);
        XAxis xAxis = candleStickChart.getXAxis();
        xAxis.setPosition(XAxis.XAxisPosition.BOTTOM);
        xAxis.setDrawGridLines(false);
        xAxis.setDrawAxisLine(true);
        xAxis.setAxisMaximum(f4);
        if (formatter == FORMATTER.DAY) {
            xAxis.setLabelCount(i2, true);
            xAxis.setValueFormatter(new MyBpDayCustomXAxisValueFormatter(true));
            xAxis.setAvoidFirstLastClipping(true);
            candleStickChart.setXAxisRenderer(new MyXAxisRenderer(candleStickChart.getViewPortHandler(), candleStickChart.getXAxis(), candleStickChart.getTransformer(YAxis.AxisDependency.LEFT)));
            setDayData(candleStickChart, list, context);
            setCandleStickChart(candleStickChart, dayValues, context, FORMATTER.DAY);
            return;
        }
        if (formatter == FORMATTER.WEEK) {
            xAxis.setLabelCount(i2, false);
            xAxis.setValueFormatter(new MyWeekCustomXAxisValueFormatter(true));
            setWeekData(candleStickChart, list, str, context);
            setCandleStickChart(candleStickChart, weekValues, context, FORMATTER.WEEK);
            return;
        }
        xAxis.setLabelCount(i2, true);
        xAxis.setValueFormatter(new MyMonthCustomXAxisValueFormatter(true, 30));
        xAxis.setAvoidFirstLastClipping(true);
        candleStickChart.setXAxisRenderer(new MyXAxisRenderer(candleStickChart.getViewPortHandler(), candleStickChart.getXAxis(), candleStickChart.getTransformer(YAxis.AxisDependency.LEFT)));
        setMonthData(candleStickChart, list, str, context);
        setCandleStickChart(candleStickChart, monthValues, context, FORMATTER.MONTH);
    }

    public static void setDayData(CandleStickChart candleStickChart, List<BloodPressureHisListBean> list, Context context) {
        candleStickChart.resetTracking();
        dayValues = new ArrayList();
        ArrayList arrayList = new ArrayList();
        for (int i2 = 0; i2 <= 288; i2++) {
            dayValues.add(new CandleEntry(i2, 0.0f, 0.0f, 0.0f, 0.0f, ""));
        }
        if (list.size() != 0) {
            Collections.reverse(list);
            for (int i3 = 0; i3 < list.size(); i3++) {
                arrayList.add(new BloodPressureBean(list.get(i3).getBpStartTime(), HourToMinute.timeToMinute(list.get(i3).getTime()), 0.0f, 0.0f, list.get(i3).getBloodDBP(), list.get(i3).getBloodSBP(), list.get(i3).getBloodDBP(), list.get(i3).getBloodSBP()));
            }
        } else {
            arrayList.add(new BloodPressureBean("", 0, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f));
        }
        for (int i4 = 0; i4 < arrayList.size(); i4++) {
            int time = ((BloodPressureBean) arrayList.get(i4)).getTime();
            int i5 = time / 5;
            dayValues.remove(i5);
            dayValues.add(i5, new CandleEntry(i5, ((BloodPressureBean) arrayList.get(i4)).getmShadowHigh(), ((BloodPressureBean) arrayList.get(i4)).getmShadowLow(), ((BloodPressureBean) arrayList.get(i4)).getmOpen(), ((BloodPressureBean) arrayList.get(i4)).getmClose(), String.format(TimeModel.ZERO_LEADING_NUMBER_FORMAT, Integer.valueOf(time / 60)) + CertificateUtil.DELIMITER + String.format(TimeModel.ZERO_LEADING_NUMBER_FORMAT, Integer.valueOf(time % 60))));
        }
        for (int i6 = 0; i6 < dayValues.size(); i6++) {
            Log.i("Values---", "Time-" + dayValues.get(i6).getmTime() + "High" + dayValues.get(i6).getHigh() + "Low-" + dayValues.get(i6).getLow() + "Open-" + dayValues.get(i6).getOpen() + "Close-" + dayValues.get(i6).getClose());
        }
        MyMarkerView myMarkerView = new MyMarkerView(context, R.layout.layout_for_custom_marker_view, null, arrayList, null, null);
        myMarkerView.setChartView(candleStickChart);
        candleStickChart.setMarker(myMarkerView, null, arrayList, null, null, Chart.MarkerLabel.BLOOD_PRESSURE_DAY_CHART);
    }

    public static void setWeekData(CandleStickChart candleStickChart, List<BloodPressureHisListBean> list, String str, Context context) {
        candleStickChart.resetTracking();
        weekValues = new ArrayList();
        ArrayList arrayList = new ArrayList();
        if (list == null || list.size() == 0) {
            for (int i2 = 0; i2 < 7; i2++) {
                arrayList.add(new BloodPressureBean("", i2, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f));
            }
        } else {
            for (int i3 = 0; i3 < list.size(); i3++) {
                arrayList.add(new BloodPressureBean(list.get(i3).getBpStartTime(), i3, 0.0f, 0.0f, list.get(i3).getBloodSBP(), list.get(i3).getBloodDBP(), list.get(i3).getBloodSBP(), list.get(i3).getBloodDBP()));
            }
        }
        for (int i4 = 0; i4 < arrayList.size(); i4++) {
            weekValues.add(new CandleEntry(i4, 0.0f, 0.0f, 0.0f, 0.0f, ""));
        }
        ArrayList<String> pastDay = pastDay(str);
        for (int i5 = 0; i5 < arrayList.size(); i5++) {
            weekValues.remove(i5);
            weekValues.add(i5, new CandleEntry(((BloodPressureBean) arrayList.get(i5)).getTime(), ((BloodPressureBean) arrayList.get(i5)).getmShadowHigh(), ((BloodPressureBean) arrayList.get(i5)).getmShadowLow(), ((BloodPressureBean) arrayList.get(i5)).getmOpen(), ((BloodPressureBean) arrayList.get(i5)).getmClose(), TimeStampUtils.dateForStringDates(TimeStampUtils.stringForDateDay(pastDay.get(i5)))));
        }
        MyMarkerView myMarkerView = new MyMarkerView(context, R.layout.layout_for_custom_marker_view, null, arrayList, null, null);
        myMarkerView.setChartView(candleStickChart);
        candleStickChart.setMarker(myMarkerView, null, arrayList, null, null, Chart.MarkerLabel.BLOOD_PRESSURE_WEEK_MONTH_CHART);
    }

    public static void setMonthData(CandleStickChart candleStickChart, List<BloodPressureHisListBean> list, String str, Context context) {
        candleStickChart.resetTracking();
        monthValues = new ArrayList();
        ArrayList arrayList = new ArrayList();
        if (list == null || list.size() == 0) {
            for (int i2 = 0; i2 < 30; i2++) {
                arrayList.add(new BloodPressureBean("", i2, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f));
            }
        } else {
            for (int i3 = 0; i3 < list.size(); i3++) {
                arrayList.add(new BloodPressureBean(list.get(i3).getBpStartTime(), i3, 0.0f, 0.0f, list.get(i3).getBloodSBP(), list.get(i3).getBloodDBP(), list.get(i3).getBloodSBP(), list.get(i3).getBloodDBP()));
            }
        }
        for (int i4 = 0; i4 < arrayList.size(); i4++) {
            monthValues.add(new CandleEntry(i4, 0.0f, 0.0f, 0.0f, 0.0f, ""));
        }
        ArrayList<String> pastThirtyDay = pastThirtyDay(str);
        for (int i5 = 0; i5 < arrayList.size(); i5++) {
            monthValues.remove(i5);
            monthValues.add(i5, new CandleEntry(((BloodPressureBean) arrayList.get(i5)).getTime(), ((BloodPressureBean) arrayList.get(i5)).getmShadowHigh(), ((BloodPressureBean) arrayList.get(i5)).getmShadowLow(), ((BloodPressureBean) arrayList.get(i5)).getmOpen(), ((BloodPressureBean) arrayList.get(i5)).getmClose(), TimeStampUtils.dateForStringDates(TimeStampUtils.stringForDateDay(pastThirtyDay.get(i5)))));
        }
        MyMarkerView myMarkerView = new MyMarkerView(context, R.layout.layout_for_custom_marker_view, null, arrayList, null, null);
        myMarkerView.setChartView(candleStickChart);
        candleStickChart.setMarker(myMarkerView, null, arrayList, null, null, Chart.MarkerLabel.BLOOD_PRESSURE_WEEK_MONTH_CHART);
    }

    public static void setCandleStickChart(CandleStickChart candleStickChart, List<CandleEntry> list, Context context, FORMATTER formatter) {
        CandleDataSet candleDataSet = new CandleDataSet(list, "Data Set");
        candleDataSet.setDrawIcons(false);
        candleDataSet.setAxisDependency(YAxis.AxisDependency.LEFT);
        candleDataSet.setShadowColor(-16776961);
        if (formatter == FORMATTER.DAY) {
            candleDataSet.setShadowWidth(0.7f);
            candleDataSet.setBarSpace(0.05f);
        } else if (formatter == FORMATTER.WEEK) {
            candleDataSet.setShadowWidth(3.0f);
            candleDataSet.setBarSpace(0.4f);
        } else {
            candleDataSet.setShadowWidth(0.7f);
            candleDataSet.setBarSpace(0.05f);
        }
        candleDataSet.setDecreasingColor(context.getColor(R.color.blood_presure_bar_color_1));
        candleDataSet.setDecreasingPaintStyle(Paint.Style.FILL);
        candleDataSet.setIncreasingColor(context.getColor(R.color.blood_presure_bar_color_2));
        candleDataSet.setIncreasingPaintStyle(Paint.Style.FILL);
        candleDataSet.setNeutralColor(-16776961);
        candleDataSet.setDrawValues(!candleDataSet.isDrawValuesEnabled());
        candleDataSet.setDrawHorizontalHighlightIndicator(false);
        candleDataSet.setDrawVerticalHighlightIndicator(true);
        candleStickChart.setData(new CandleData(candleDataSet));
        candleStickChart.invalidate();
    }

    public static ArrayList<String> pastDay(String str) {
        ArrayList<String> arrayList = new ArrayList<>();
        try {
            Date parse = new SimpleDateFormat(AppDateMgr.DF_YYYY_MM_DD).parse(str);
            for (int i2 = 6; i2 >= 0; i2--) {
                arrayList.add(getPastDate(i2, parse));
            }
        } catch (ParseException e2) {
            e2.printStackTrace();
        }
        return arrayList;
    }

    public static ArrayList<String> pastThirtyDay(String str) {
        ArrayList<String> arrayList = new ArrayList<>();
        try {
            Date parse = new SimpleDateFormat(AppDateMgr.DF_YYYY_MM_DD).parse(str);
            for (int i2 = 29; i2 >= 0; i2--) {
                arrayList.add(getPastDate(i2, parse));
            }
        } catch (ParseException e2) {
            e2.printStackTrace();
        }
        return arrayList;
    }

    public static String getPastDate(int i2, Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(5, calendar.get(5) - i2);
        return new SimpleDateFormat(AppDateMgr.DF_YYYY_MM_DD).format(calendar.getTime());
    }
}
