package com.yucheng.smarthealthpro.customchart.renderer;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import com.tencent.connect.common.Constants;
import com.yucheng.smarthealthpro.customchart.animation.ChartAnimator;
import com.yucheng.smarthealthpro.customchart.buffer.BarBuffer;
import com.yucheng.smarthealthpro.customchart.buffer.HorizontalBarBuffer;
import com.yucheng.smarthealthpro.customchart.data.BarData;
import com.yucheng.smarthealthpro.customchart.data.BarEntry;
import com.yucheng.smarthealthpro.customchart.formatter.IValueFormatter;
import com.yucheng.smarthealthpro.customchart.highlight.Highlight;
import com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.BarDataProvider;
import com.yucheng.smarthealthpro.customchart.interfaces.dataprovider.ChartInterface;
import com.yucheng.smarthealthpro.customchart.interfaces.datasets.IBarDataSet;
import com.yucheng.smarthealthpro.customchart.utils.Fill;
import com.yucheng.smarthealthpro.customchart.utils.MPPointF;
import com.yucheng.smarthealthpro.customchart.utils.Transformer;
import com.yucheng.smarthealthpro.customchart.utils.Utils;
import com.yucheng.smarthealthpro.customchart.utils.ViewPortHandler;
import java.util.List;

/* loaded from: classes3.dex */
public class HorizontalBarChartRenderer extends BarChartRenderer {
    private RectF mBarShadowRectBuffer;

    public HorizontalBarChartRenderer(BarDataProvider barDataProvider, ChartAnimator chartAnimator, ViewPortHandler viewPortHandler, Context context) {
        super(barDataProvider, chartAnimator, viewPortHandler, context);
        this.mBarShadowRectBuffer = new RectF();
        this.mValuePaint.setTextAlign(Paint.Align.LEFT);
    }

    @Override // com.yucheng.smarthealthpro.customchart.renderer.BarChartRenderer, com.yucheng.smarthealthpro.customchart.renderer.DataRenderer
    public void initBuffers() {
        BarData barData = this.mChart.getBarData();
        this.mBarBuffers = new HorizontalBarBuffer[barData.getDataSetCount()];
        for (int i2 = 0; i2 < this.mBarBuffers.length; i2++) {
            IBarDataSet iBarDataSet = (IBarDataSet) barData.getDataSetByIndex(i2);
            this.mBarBuffers[i2] = new HorizontalBarBuffer(iBarDataSet.getEntryCount() * 4 * (iBarDataSet.isStacked() ? iBarDataSet.getStackSize() : 1), barData.getDataSetCount(), iBarDataSet.isStacked());
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.yucheng.smarthealthpro.customchart.renderer.BarChartRenderer
    protected void drawDataSet(Canvas canvas, IBarDataSet iBarDataSet, int i2) {
        Transformer transformer = this.mChart.getTransformer(iBarDataSet.getAxisDependency());
        this.mBarBorderPaint.setColor(iBarDataSet.getBarBorderColor());
        this.mBarBorderPaint.setStrokeWidth(Utils.convertDpToPixel(iBarDataSet.getBarBorderWidth()));
        int i3 = 0;
        boolean z = iBarDataSet.getBarBorderWidth() > 0.0f;
        float phaseX = this.mAnimator.getPhaseX();
        float phaseY = this.mAnimator.getPhaseY();
        if (this.mChart.isDrawBarShadowEnabled()) {
            this.mShadowPaint.setColor(iBarDataSet.getBarShadowColor());
            float barWidth = this.mChart.getBarData().getBarWidth() / 2.0f;
            int min = Math.min((int) Math.ceil(iBarDataSet.getEntryCount() * phaseX), iBarDataSet.getEntryCount());
            for (int i4 = 0; i4 < min; i4++) {
                float x = ((BarEntry) iBarDataSet.getEntryForIndex(i4)).getX();
                this.mBarShadowRectBuffer.top = x - barWidth;
                this.mBarShadowRectBuffer.bottom = x + barWidth;
                transformer.rectValueToPixel(this.mBarShadowRectBuffer);
                if (this.mViewPortHandler.isInBoundsTop(this.mBarShadowRectBuffer.bottom)) {
                    if (!this.mViewPortHandler.isInBoundsBottom(this.mBarShadowRectBuffer.top)) {
                        break;
                    }
                    this.mBarShadowRectBuffer.left = this.mViewPortHandler.contentLeft();
                    this.mBarShadowRectBuffer.right = this.mViewPortHandler.contentRight();
                    canvas.drawRect(this.mBarShadowRectBuffer, this.mShadowPaint);
                }
            }
        }
        BarBuffer barBuffer = this.mBarBuffers[i2];
        barBuffer.setPhases(phaseX, phaseY);
        barBuffer.setDataSet(i2);
        barBuffer.setInverted(this.mChart.isInverted(iBarDataSet.getAxisDependency()));
        barBuffer.setBarWidth(this.mChart.getBarData().getBarWidth());
        barBuffer.feed(iBarDataSet);
        transformer.pointValuesToPixel(barBuffer.buffer);
        boolean z2 = (iBarDataSet.getFills() == null || iBarDataSet.getFills().isEmpty()) ? false : true;
        boolean z3 = iBarDataSet.getColors().size() == 1;
        boolean isInverted = this.mChart.isInverted(iBarDataSet.getAxisDependency());
        if (z3) {
            this.mRenderPaint.setColor(iBarDataSet.getColor());
        }
        int i5 = 0;
        while (i3 < barBuffer.size()) {
            int i6 = i3 + 3;
            if (!this.mViewPortHandler.isInBoundsTop(barBuffer.buffer[i6])) {
                return;
            }
            int i7 = i3 + 1;
            if (this.mViewPortHandler.isInBoundsBottom(barBuffer.buffer[i7])) {
                if (!z3) {
                    this.mRenderPaint.setColor(iBarDataSet.getColor(i3 / 4));
                }
                if (z2) {
                    iBarDataSet.getFill(i5).fillRect(canvas, this.mRenderPaint, barBuffer.buffer[i3], barBuffer.buffer[i7], barBuffer.buffer[i3 + 2], barBuffer.buffer[i6], isInverted ? Fill.Direction.LEFT : Fill.Direction.RIGHT);
                } else {
                    canvas.drawRect(barBuffer.buffer[i3], barBuffer.buffer[i7], barBuffer.buffer[i3 + 2], barBuffer.buffer[i6], this.mRenderPaint);
                }
                if (z) {
                    canvas.drawRect(barBuffer.buffer[i3], barBuffer.buffer[i7], barBuffer.buffer[i3 + 2], barBuffer.buffer[i6], this.mBarBorderPaint);
                }
            }
            i3 += 4;
            i5++;
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.yucheng.smarthealthpro.customchart.renderer.BarChartRenderer, com.yucheng.smarthealthpro.customchart.renderer.DataRenderer
    public void drawValues(Canvas canvas) {
        List list;
        float f2;
        MPPointF mPPointF;
        int i2;
        float[] fArr;
        float f3;
        int i3;
        float[] fArr2;
        float f4;
        float f5;
        BarEntry barEntry;
        List list2;
        float f6;
        float f7;
        float f8;
        int i4;
        float f9;
        float f10;
        MPPointF mPPointF2;
        IValueFormatter iValueFormatter;
        float f11;
        BarBuffer barBuffer;
        if (isDrawingValuesAllowed(this.mChart)) {
            List dataSets = this.mChart.getBarData().getDataSets();
            float convertDpToPixel = Utils.convertDpToPixel(5.0f);
            boolean isDrawValueAboveBarEnabled = this.mChart.isDrawValueAboveBarEnabled();
            int i5 = 0;
            while (i5 < this.mChart.getBarData().getDataSetCount()) {
                IBarDataSet iBarDataSet = (IBarDataSet) dataSets.get(i5);
                if (shouldDrawValues(iBarDataSet)) {
                    boolean isInverted = this.mChart.isInverted(iBarDataSet.getAxisDependency());
                    applyValueTextStyle(iBarDataSet);
                    float f12 = 2.0f;
                    float calcTextHeight = Utils.calcTextHeight(this.mValuePaint, Constants.VIA_REPORT_TYPE_SHARE_TO_QQ) / 2.0f;
                    IValueFormatter valueFormatter = iBarDataSet.getValueFormatter();
                    BarBuffer barBuffer2 = this.mBarBuffers[i5];
                    float phaseY = this.mAnimator.getPhaseY();
                    MPPointF mPPointF3 = MPPointF.getInstance(iBarDataSet.getIconsOffset());
                    mPPointF3.x = Utils.convertDpToPixel(mPPointF3.x);
                    mPPointF3.y = Utils.convertDpToPixel(mPPointF3.y);
                    if (iBarDataSet.isStacked()) {
                        list = dataSets;
                        f2 = convertDpToPixel;
                        mPPointF = mPPointF3;
                        Transformer transformer = this.mChart.getTransformer(iBarDataSet.getAxisDependency());
                        int i6 = 0;
                        int i7 = 0;
                        while (i6 < iBarDataSet.getEntryCount() * this.mAnimator.getPhaseX()) {
                            BarEntry barEntry2 = (BarEntry) iBarDataSet.getEntryForIndex(i6);
                            int valueTextColor = iBarDataSet.getValueTextColor(i6);
                            float[] yVals = barEntry2.getYVals();
                            if (yVals == null) {
                                int i8 = i7 + 1;
                                if (!this.mViewPortHandler.isInBoundsTop(barBuffer2.buffer[i8])) {
                                    break;
                                }
                                if (this.mViewPortHandler.isInBoundsX(barBuffer2.buffer[i7]) && this.mViewPortHandler.isInBoundsBottom(barBuffer2.buffer[i8])) {
                                    String formattedValue = valueFormatter.getFormattedValue(barEntry2.getY(), barEntry2, i5, this.mViewPortHandler);
                                    float calcTextWidth = Utils.calcTextWidth(this.mValuePaint, formattedValue);
                                    float f13 = isDrawValueAboveBarEnabled ? f2 : -(calcTextWidth + f2);
                                    float f14 = isDrawValueAboveBarEnabled ? -(calcTextWidth + f2) : f2;
                                    if (isInverted) {
                                        f13 = (-f13) - calcTextWidth;
                                        f14 = (-f14) - calcTextWidth;
                                    }
                                    float f15 = f13;
                                    float f16 = f14;
                                    if (iBarDataSet.isDrawValuesEnabled()) {
                                        i2 = i6;
                                        fArr = yVals;
                                        barEntry = barEntry2;
                                        drawValue(canvas, formattedValue, barBuffer2.buffer[i7 + 2] + (barEntry2.getY() >= 0.0f ? f15 : f16), barBuffer2.buffer[i8] + calcTextHeight, valueTextColor);
                                    } else {
                                        barEntry = barEntry2;
                                        i2 = i6;
                                        fArr = yVals;
                                    }
                                    if (barEntry.getIcon() != null && iBarDataSet.isDrawIconsEnabled()) {
                                        Drawable icon = barEntry.getIcon();
                                        float f17 = barBuffer2.buffer[i7 + 2];
                                        if (barEntry.getY() < 0.0f) {
                                            f15 = f16;
                                        }
                                        Utils.drawImage(canvas, icon, (int) (f17 + f15 + mPPointF.x), (int) (barBuffer2.buffer[i8] + mPPointF.y), icon.getIntrinsicWidth(), icon.getIntrinsicHeight());
                                    }
                                }
                            } else {
                                i2 = i6;
                                fArr = yVals;
                                int length = fArr.length * 2;
                                float[] fArr3 = new float[length];
                                float f18 = -barEntry2.getNegativeSum();
                                float f19 = 0.0f;
                                int i9 = 0;
                                int i10 = 0;
                                while (i9 < length) {
                                    float f20 = fArr[i10];
                                    if (f20 == 0.0f && (f19 == 0.0f || f18 == 0.0f)) {
                                        float f21 = f18;
                                        f18 = f20;
                                        f5 = f21;
                                    } else if (f20 >= 0.0f) {
                                        f19 += f20;
                                        f5 = f18;
                                        f18 = f19;
                                    } else {
                                        f5 = f18 - f20;
                                    }
                                    fArr3[i9] = f18 * phaseY;
                                    i9 += 2;
                                    i10++;
                                    f18 = f5;
                                }
                                transformer.pointValuesToPixel(fArr3);
                                int i11 = 0;
                                while (i11 < length) {
                                    float f22 = fArr[i11 / 2];
                                    String formattedValue2 = valueFormatter.getFormattedValue(f22, barEntry2, i5, this.mViewPortHandler);
                                    float calcTextWidth2 = Utils.calcTextWidth(this.mValuePaint, formattedValue2);
                                    float f23 = isDrawValueAboveBarEnabled ? f2 : -(calcTextWidth2 + f2);
                                    int i12 = length;
                                    float f24 = isDrawValueAboveBarEnabled ? -(calcTextWidth2 + f2) : f2;
                                    if (isInverted) {
                                        f23 = (-f23) - calcTextWidth2;
                                        f24 = (-f24) - calcTextWidth2;
                                    }
                                    boolean z = (f22 == 0.0f && f18 == 0.0f && f19 > 0.0f) || f22 < 0.0f;
                                    float f25 = fArr3[i11];
                                    if (z) {
                                        f23 = f24;
                                    }
                                    float f26 = f25 + f23;
                                    float f27 = (barBuffer2.buffer[i7 + 1] + barBuffer2.buffer[i7 + 3]) / 2.0f;
                                    if (!this.mViewPortHandler.isInBoundsTop(f27)) {
                                        break;
                                    }
                                    if (this.mViewPortHandler.isInBoundsX(f26) && this.mViewPortHandler.isInBoundsBottom(f27)) {
                                        if (iBarDataSet.isDrawValuesEnabled()) {
                                            f3 = f27;
                                            i3 = i11;
                                            fArr2 = fArr3;
                                            f4 = f26;
                                            drawValue(canvas, formattedValue2, f26, f27 + calcTextHeight, valueTextColor);
                                        } else {
                                            f3 = f27;
                                            i3 = i11;
                                            fArr2 = fArr3;
                                            f4 = f26;
                                        }
                                        if (barEntry2.getIcon() != null && iBarDataSet.isDrawIconsEnabled()) {
                                            Drawable icon2 = barEntry2.getIcon();
                                            Utils.drawImage(canvas, icon2, (int) (f4 + mPPointF.x), (int) (f3 + mPPointF.y), icon2.getIntrinsicWidth(), icon2.getIntrinsicHeight());
                                        }
                                    } else {
                                        i3 = i11;
                                        fArr2 = fArr3;
                                    }
                                    i11 = i3 + 2;
                                    length = i12;
                                    fArr3 = fArr2;
                                }
                            }
                            i7 = fArr == null ? i7 + 4 : i7 + (fArr.length * 4);
                            i6 = i2 + 1;
                        }
                    } else {
                        int i13 = 0;
                        while (i13 < barBuffer2.buffer.length * this.mAnimator.getPhaseX()) {
                            int i14 = i13 + 1;
                            float f28 = (barBuffer2.buffer[i14] + barBuffer2.buffer[i13 + 3]) / f12;
                            if (!this.mViewPortHandler.isInBoundsTop(barBuffer2.buffer[i14])) {
                                break;
                            }
                            if (this.mViewPortHandler.isInBoundsX(barBuffer2.buffer[i13]) && this.mViewPortHandler.isInBoundsBottom(barBuffer2.buffer[i14])) {
                                BarEntry barEntry3 = (BarEntry) iBarDataSet.getEntryForIndex(i13 / 4);
                                float y = barEntry3.getY();
                                String formattedValue3 = valueFormatter.getFormattedValue(y, barEntry3, i5, this.mViewPortHandler);
                                MPPointF mPPointF4 = mPPointF3;
                                float calcTextWidth3 = Utils.calcTextWidth(this.mValuePaint, formattedValue3);
                                float f29 = isDrawValueAboveBarEnabled ? convertDpToPixel : -(calcTextWidth3 + convertDpToPixel);
                                IValueFormatter iValueFormatter2 = valueFormatter;
                                if (isDrawValueAboveBarEnabled) {
                                    f6 = -(calcTextWidth3 + convertDpToPixel);
                                    list2 = dataSets;
                                } else {
                                    list2 = dataSets;
                                    f6 = convertDpToPixel;
                                }
                                int i15 = i13 + 2;
                                f7 = convertDpToPixel;
                                float f30 = f6 - (barBuffer2.buffer[i15] - barBuffer2.buffer[i13]);
                                if (isInverted) {
                                    f29 = (-f29) - calcTextWidth3;
                                    f30 = (-f30) - calcTextWidth3;
                                }
                                float f31 = f29;
                                float f32 = f30;
                                if (iBarDataSet.isDrawValuesEnabled()) {
                                    float f33 = barBuffer2.buffer[i15];
                                    float f34 = y >= 0.0f ? f31 : f32;
                                    f8 = y;
                                    i4 = i13;
                                    f9 = f31;
                                    mPPointF2 = mPPointF4;
                                    f11 = f32;
                                    barBuffer = barBuffer2;
                                    f10 = calcTextHeight;
                                    iValueFormatter = iValueFormatter2;
                                    drawValue(canvas, formattedValue3, f34 + f33, f28 + calcTextHeight, iBarDataSet.getValueTextColor(i13 / 2));
                                } else {
                                    f8 = y;
                                    i4 = i13;
                                    f9 = f31;
                                    f10 = calcTextHeight;
                                    mPPointF2 = mPPointF4;
                                    iValueFormatter = iValueFormatter2;
                                    f11 = f32;
                                    barBuffer = barBuffer2;
                                }
                                if (barEntry3.getIcon() != null && iBarDataSet.isDrawIconsEnabled()) {
                                    Drawable icon3 = barEntry3.getIcon();
                                    float f35 = barBuffer.buffer[i15];
                                    if (f8 < 0.0f) {
                                        f9 = f11;
                                    }
                                    Utils.drawImage(canvas, icon3, (int) (f35 + f9 + mPPointF2.x), (int) (f28 + mPPointF2.y), icon3.getIntrinsicWidth(), icon3.getIntrinsicHeight());
                                }
                            } else {
                                i4 = i13;
                                list2 = dataSets;
                                f7 = convertDpToPixel;
                                f10 = calcTextHeight;
                                mPPointF2 = mPPointF3;
                                barBuffer = barBuffer2;
                                iValueFormatter = valueFormatter;
                            }
                            i13 = i4 + 4;
                            mPPointF3 = mPPointF2;
                            barBuffer2 = barBuffer;
                            valueFormatter = iValueFormatter;
                            dataSets = list2;
                            convertDpToPixel = f7;
                            calcTextHeight = f10;
                            f12 = 2.0f;
                        }
                        list = dataSets;
                        f2 = convertDpToPixel;
                        mPPointF = mPPointF3;
                    }
                    MPPointF.recycleInstance(mPPointF);
                } else {
                    list = dataSets;
                    f2 = convertDpToPixel;
                }
                i5++;
                dataSets = list;
                convertDpToPixel = f2;
            }
        }
    }

    protected void drawValue(Canvas canvas, String str, float f2, float f3, int i2) {
        this.mValuePaint.setColor(i2);
        canvas.drawText(str, f2, f3, this.mValuePaint);
    }

    @Override // com.yucheng.smarthealthpro.customchart.renderer.BarChartRenderer
    protected void prepareBarHighlight(float f2, float f3, float f4, float f5, Transformer transformer) {
        this.mBarRect.set(f3, f2 - f5, f4, f2 + f5);
        transformer.rectToPixelPhaseHorizontal(this.mBarRect, this.mAnimator.getPhaseY());
    }

    @Override // com.yucheng.smarthealthpro.customchart.renderer.BarChartRenderer
    protected void setHighlightDrawPos(Highlight highlight, RectF rectF) {
        highlight.setDraw(rectF.centerY(), rectF.right);
    }

    @Override // com.yucheng.smarthealthpro.customchart.renderer.DataRenderer
    protected boolean isDrawingValuesAllowed(ChartInterface chartInterface) {
        return ((float) chartInterface.getData().getEntryCount()) < ((float) chartInterface.getMaxVisibleCount()) * this.mViewPortHandler.getScaleY();
    }
}
