package com.yucheng.smarthealthpro.greendao;

import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;
import org.greenrobot.greendao.AbstractDaoMaster;
import org.greenrobot.greendao.database.Database;
import org.greenrobot.greendao.database.DatabaseOpenHelper;
import org.greenrobot.greendao.database.StandardDatabase;
import org.greenrobot.greendao.identityscope.IdentityScopeType;

/* loaded from: classes3.dex */
public class DaoMaster extends AbstractDaoMaster {
    public static final int SCHEMA_VERSION = 38;

    public static void createAllTables(Database database, boolean z) {
        AllDbDao.createTable(database, z);
        BloodDbDao.createTable(database, z);
        BloodFatDbDao.createTable(database, z);
        EcgMeasureDbDao.createTable(database, z);
        HeartDbDao.createTable(database, z);
        MotionPatternDbDao.createTable(database, z);
        PhysiotherapyDbDao.createTable(database, z);
        RunDbDao.createTable(database, z);
        SleepDbDao.createTable(database, z);
        StepDpDao.createTable(database, z);
        UricAcidDbDao.createTable(database, z);
    }

    public static void dropAllTables(Database database, boolean z) {
        AllDbDao.dropTable(database, z);
        BloodDbDao.dropTable(database, z);
        BloodFatDbDao.dropTable(database, z);
        EcgMeasureDbDao.dropTable(database, z);
        HeartDbDao.dropTable(database, z);
        MotionPatternDbDao.dropTable(database, z);
        PhysiotherapyDbDao.dropTable(database, z);
        RunDbDao.dropTable(database, z);
        SleepDbDao.dropTable(database, z);
        StepDpDao.dropTable(database, z);
        UricAcidDbDao.dropTable(database, z);
    }

    public static DaoSession newDevSession(Context context, String str) {
        return new DaoMaster(new DevOpenHelper(context, str).getWritableDb()).newSession();
    }

    public DaoMaster(SQLiteDatabase sQLiteDatabase) {
        this(new StandardDatabase(sQLiteDatabase));
    }

    public DaoMaster(Database database) {
        super(database, 38);
        registerDaoClass(AllDbDao.class);
        registerDaoClass(BloodDbDao.class);
        registerDaoClass(BloodFatDbDao.class);
        registerDaoClass(EcgMeasureDbDao.class);
        registerDaoClass(HeartDbDao.class);
        registerDaoClass(MotionPatternDbDao.class);
        registerDaoClass(PhysiotherapyDbDao.class);
        registerDaoClass(RunDbDao.class);
        registerDaoClass(SleepDbDao.class);
        registerDaoClass(StepDpDao.class);
        registerDaoClass(UricAcidDbDao.class);
    }

    @Override // org.greenrobot.greendao.AbstractDaoMaster
    public DaoSession newSession() {
        return new DaoSession(this.db, IdentityScopeType.Session, this.daoConfigMap);
    }

    @Override // org.greenrobot.greendao.AbstractDaoMaster
    public DaoSession newSession(IdentityScopeType identityScopeType) {
        return new DaoSession(this.db, identityScopeType, this.daoConfigMap);
    }

    public static abstract class OpenHelper extends DatabaseOpenHelper {
        public OpenHelper(Context context, String str) {
            super(context, str, 38);
        }

        public OpenHelper(Context context, String str, SQLiteDatabase.CursorFactory cursorFactory) {
            super(context, str, cursorFactory, 38);
        }

        @Override // org.greenrobot.greendao.database.DatabaseOpenHelper
        public void onCreate(Database database) {
            Log.i("greenDAO", "Creating tables for schema version 38");
            DaoMaster.createAllTables(database, false);
        }
    }

    public static class DevOpenHelper extends OpenHelper {
        public DevOpenHelper(Context context, String str) {
            super(context, str);
        }

        public DevOpenHelper(Context context, String str, SQLiteDatabase.CursorFactory cursorFactory) {
            super(context, str, cursorFactory);
        }

        @Override // org.greenrobot.greendao.database.DatabaseOpenHelper
        public void onUpgrade(Database database, int i2, int i3) {
            Log.i("greenDAO", "Upgrading schema from version " + i2 + " to " + i3 + " by dropping all tables");
            DaoMaster.dropAllTables(database, true);
            onCreate(database);
        }
    }
}
