package com.yucheng.smarthealthpro.greendao;

import android.database.Cursor;
import android.database.sqlite.SQLiteStatement;
import com.yucheng.smarthealthpro.greendao.bean.EcgMeasureDb;
import com.yucheng.smarthealthpro.utils.Constant;
import com.yucheng.ycbtsdk.Constants;
import org.greenrobot.greendao.AbstractDao;
import org.greenrobot.greendao.Property;
import org.greenrobot.greendao.database.Database;
import org.greenrobot.greendao.database.DatabaseStatement;
import org.greenrobot.greendao.internal.DaoConfig;

/* loaded from: classes3.dex */
public class EcgMeasureDbDao extends AbstractDao<EcgMeasureDb, Long> {
    public static final String TABLENAME = "ECG_MEASURE_DB";

    public static class Properties {
        public static final Property Id = new Property(0, Long.class, "id", true, "_id");
        public static final Property QueryID = new Property(1, Integer.TYPE, "queryID", false, "QUERY_ID");
        public static final Property UserId = new Property(2, String.class, "userId", false, "USER_ID");
        public static final Property Time = new Property(3, Long.TYPE, "time", false, "TIME");
        public static final Property TimeYearToDate = new Property(4, String.class, "timeYearToDate", false, "TIME_YEAR_TO_DATE");
        public static final Property Hrv = new Property(5, Integer.TYPE, "hrv", false, "HRV");
        public static final Property Heart = new Property(6, Integer.TYPE, "heart", false, "HEART");
        public static final Property MaxBp = new Property(7, Integer.TYPE, "maxBp", false, "MAX_BP");
        public static final Property MinBp = new Property(8, Integer.TYPE, "minBp", false, "MIN_BP");
        public static final Property MeasureData = new Property(9, String.class, "measureData", false, "MEASURE_DATA");
        public static final Property Age = new Property(10, Integer.TYPE, Constant.SpConstKey.AGE, false, "AGE");
        public static final Property Sex = new Property(11, Integer.TYPE, Constant.SpConstKey.SEX, false, "SEX");
        public static final Property IsAfib = new Property(12, Boolean.TYPE, "isAfib", false, "IS_AFIB");
        public static final Property DiagnoseType = new Property(13, Integer.TYPE, "diagnoseType", false, "DIAGNOSE_TYPE");
        public static final Property DeviceType = new Property(14, String.class, Constants.FunctionConstant.DEVICETYPE, false, "DEVICE_TYPE");
        public static final Property DeviceMac = new Property(15, String.class, "deviceMac", false, "DEVICE_MAC");
        public static final Property IsUpload = new Property(16, Boolean.TYPE, "isUpload", false, "IS_UPLOAD");
        public static final Property IsOtherUpload = new Property(17, Boolean.TYPE, "isOtherUpload", false, "IS_OTHER_UPLOAD");
        public static final Property HealthNorm = new Property(18, String.class, "healthNorm", false, "HEALTH_NORM");
        public static final Property BelongDataGroupId = new Property(19, String.class, "belongDataGroupId", false, "BELONG_DATA_GROUP_ID");
    }

    @Override // org.greenrobot.greendao.AbstractDao
    protected final boolean isEntityUpdateable() {
        return true;
    }

    public EcgMeasureDbDao(DaoConfig daoConfig) {
        super(daoConfig);
    }

    public EcgMeasureDbDao(DaoConfig daoConfig, DaoSession daoSession) {
        super(daoConfig, daoSession);
    }

    public static void createTable(Database database, boolean z) {
        String str = z ? "IF NOT EXISTS " : "";
        database.execSQL("CREATE TABLE " + str + "\"ECG_MEASURE_DB\" (\"_id\" INTEGER PRIMARY KEY AUTOINCREMENT ,\"QUERY_ID\" INTEGER NOT NULL ,\"USER_ID\" TEXT,\"TIME\" INTEGER NOT NULL ,\"TIME_YEAR_TO_DATE\" TEXT,\"HRV\" INTEGER NOT NULL ,\"HEART\" INTEGER NOT NULL ,\"MAX_BP\" INTEGER NOT NULL ,\"MIN_BP\" INTEGER NOT NULL ,\"MEASURE_DATA\" TEXT,\"AGE\" INTEGER NOT NULL ,\"SEX\" INTEGER NOT NULL ,\"IS_AFIB\" INTEGER NOT NULL ,\"DIAGNOSE_TYPE\" INTEGER NOT NULL ,\"DEVICE_TYPE\" TEXT,\"DEVICE_MAC\" TEXT,\"IS_UPLOAD\" INTEGER NOT NULL ,\"IS_OTHER_UPLOAD\" INTEGER NOT NULL ,\"HEALTH_NORM\" TEXT,\"BELONG_DATA_GROUP_ID\" TEXT);");
        database.execSQL("CREATE UNIQUE INDEX " + str + "IDX_ECG_MEASURE_DB_TIME ON \"ECG_MEASURE_DB\" (\"TIME\" ASC);");
    }

    public static void dropTable(Database database, boolean z) {
        StringBuilder sb = new StringBuilder("DROP TABLE ");
        sb.append(z ? "IF EXISTS " : "");
        sb.append("\"ECG_MEASURE_DB\"");
        database.execSQL(sb.toString());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.greenrobot.greendao.AbstractDao
    public final void bindValues(DatabaseStatement databaseStatement, EcgMeasureDb ecgMeasureDb) {
        databaseStatement.clearBindings();
        Long id = ecgMeasureDb.getId();
        if (id != null) {
            databaseStatement.bindLong(1, id.longValue());
        }
        databaseStatement.bindLong(2, ecgMeasureDb.getQueryID());
        String userId = ecgMeasureDb.getUserId();
        if (userId != null) {
            databaseStatement.bindString(3, userId);
        }
        databaseStatement.bindLong(4, ecgMeasureDb.getTime());
        String timeYearToDate = ecgMeasureDb.getTimeYearToDate();
        if (timeYearToDate != null) {
            databaseStatement.bindString(5, timeYearToDate);
        }
        databaseStatement.bindLong(6, ecgMeasureDb.getHrv());
        databaseStatement.bindLong(7, ecgMeasureDb.getHeart());
        databaseStatement.bindLong(8, ecgMeasureDb.getMaxBp());
        databaseStatement.bindLong(9, ecgMeasureDb.getMinBp());
        String measureData = ecgMeasureDb.getMeasureData();
        if (measureData != null) {
            databaseStatement.bindString(10, measureData);
        }
        databaseStatement.bindLong(11, ecgMeasureDb.getAge());
        databaseStatement.bindLong(12, ecgMeasureDb.getSex());
        databaseStatement.bindLong(13, ecgMeasureDb.getIsAfib() ? 1L : 0L);
        databaseStatement.bindLong(14, ecgMeasureDb.getDiagnoseType());
        String deviceType = ecgMeasureDb.getDeviceType();
        if (deviceType != null) {
            databaseStatement.bindString(15, deviceType);
        }
        String deviceMac = ecgMeasureDb.getDeviceMac();
        if (deviceMac != null) {
            databaseStatement.bindString(16, deviceMac);
        }
        databaseStatement.bindLong(17, ecgMeasureDb.getIsUpload() ? 1L : 0L);
        databaseStatement.bindLong(18, ecgMeasureDb.getIsOtherUpload() ? 1L : 0L);
        String healthNorm = ecgMeasureDb.getHealthNorm();
        if (healthNorm != null) {
            databaseStatement.bindString(19, healthNorm);
        }
        String belongDataGroupId = ecgMeasureDb.getBelongDataGroupId();
        if (belongDataGroupId != null) {
            databaseStatement.bindString(20, belongDataGroupId);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.greenrobot.greendao.AbstractDao
    public final void bindValues(SQLiteStatement sQLiteStatement, EcgMeasureDb ecgMeasureDb) {
        sQLiteStatement.clearBindings();
        Long id = ecgMeasureDb.getId();
        if (id != null) {
            sQLiteStatement.bindLong(1, id.longValue());
        }
        sQLiteStatement.bindLong(2, ecgMeasureDb.getQueryID());
        String userId = ecgMeasureDb.getUserId();
        if (userId != null) {
            sQLiteStatement.bindString(3, userId);
        }
        sQLiteStatement.bindLong(4, ecgMeasureDb.getTime());
        String timeYearToDate = ecgMeasureDb.getTimeYearToDate();
        if (timeYearToDate != null) {
            sQLiteStatement.bindString(5, timeYearToDate);
        }
        sQLiteStatement.bindLong(6, ecgMeasureDb.getHrv());
        sQLiteStatement.bindLong(7, ecgMeasureDb.getHeart());
        sQLiteStatement.bindLong(8, ecgMeasureDb.getMaxBp());
        sQLiteStatement.bindLong(9, ecgMeasureDb.getMinBp());
        String measureData = ecgMeasureDb.getMeasureData();
        if (measureData != null) {
            sQLiteStatement.bindString(10, measureData);
        }
        sQLiteStatement.bindLong(11, ecgMeasureDb.getAge());
        sQLiteStatement.bindLong(12, ecgMeasureDb.getSex());
        sQLiteStatement.bindLong(13, ecgMeasureDb.getIsAfib() ? 1L : 0L);
        sQLiteStatement.bindLong(14, ecgMeasureDb.getDiagnoseType());
        String deviceType = ecgMeasureDb.getDeviceType();
        if (deviceType != null) {
            sQLiteStatement.bindString(15, deviceType);
        }
        String deviceMac = ecgMeasureDb.getDeviceMac();
        if (deviceMac != null) {
            sQLiteStatement.bindString(16, deviceMac);
        }
        sQLiteStatement.bindLong(17, ecgMeasureDb.getIsUpload() ? 1L : 0L);
        sQLiteStatement.bindLong(18, ecgMeasureDb.getIsOtherUpload() ? 1L : 0L);
        String healthNorm = ecgMeasureDb.getHealthNorm();
        if (healthNorm != null) {
            sQLiteStatement.bindString(19, healthNorm);
        }
        String belongDataGroupId = ecgMeasureDb.getBelongDataGroupId();
        if (belongDataGroupId != null) {
            sQLiteStatement.bindString(20, belongDataGroupId);
        }
    }

    /* JADX WARN: Can't rename method to resolve collision */
    @Override // org.greenrobot.greendao.AbstractDao
    public Long readKey(Cursor cursor, int i2) {
        int i3 = i2 + 0;
        if (cursor.isNull(i3)) {
            return null;
        }
        return Long.valueOf(cursor.getLong(i3));
    }

    /* JADX WARN: Can't rename method to resolve collision */
    @Override // org.greenrobot.greendao.AbstractDao
    public EcgMeasureDb readEntity(Cursor cursor, int i2) {
        int i3 = i2 + 0;
        Long valueOf = cursor.isNull(i3) ? null : Long.valueOf(cursor.getLong(i3));
        int i4 = cursor.getInt(i2 + 1);
        int i5 = i2 + 2;
        String string = cursor.isNull(i5) ? null : cursor.getString(i5);
        long j2 = cursor.getLong(i2 + 3);
        int i6 = i2 + 4;
        String string2 = cursor.isNull(i6) ? null : cursor.getString(i6);
        int i7 = cursor.getInt(i2 + 5);
        int i8 = cursor.getInt(i2 + 6);
        int i9 = cursor.getInt(i2 + 7);
        int i10 = cursor.getInt(i2 + 8);
        int i11 = i2 + 9;
        String string3 = cursor.isNull(i11) ? null : cursor.getString(i11);
        int i12 = cursor.getInt(i2 + 10);
        int i13 = cursor.getInt(i2 + 11);
        boolean z = cursor.getShort(i2 + 12) != 0;
        int i14 = cursor.getInt(i2 + 13);
        int i15 = i2 + 14;
        String string4 = cursor.isNull(i15) ? null : cursor.getString(i15);
        int i16 = i2 + 15;
        String string5 = cursor.isNull(i16) ? null : cursor.getString(i16);
        boolean z2 = cursor.getShort(i2 + 16) != 0;
        boolean z3 = cursor.getShort(i2 + 17) != 0;
        int i17 = i2 + 18;
        String string6 = cursor.isNull(i17) ? null : cursor.getString(i17);
        int i18 = i2 + 19;
        return new EcgMeasureDb(valueOf, i4, string, j2, string2, i7, i8, i9, i10, string3, i12, i13, z, i14, string4, string5, z2, z3, string6, cursor.isNull(i18) ? null : cursor.getString(i18));
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public void readEntity(Cursor cursor, EcgMeasureDb ecgMeasureDb, int i2) {
        int i3 = i2 + 0;
        ecgMeasureDb.setId(cursor.isNull(i3) ? null : Long.valueOf(cursor.getLong(i3)));
        ecgMeasureDb.setQueryID(cursor.getInt(i2 + 1));
        int i4 = i2 + 2;
        ecgMeasureDb.setUserId(cursor.isNull(i4) ? null : cursor.getString(i4));
        ecgMeasureDb.setTime(cursor.getLong(i2 + 3));
        int i5 = i2 + 4;
        ecgMeasureDb.setTimeYearToDate(cursor.isNull(i5) ? null : cursor.getString(i5));
        ecgMeasureDb.setHrv(cursor.getInt(i2 + 5));
        ecgMeasureDb.setHeart(cursor.getInt(i2 + 6));
        ecgMeasureDb.setMaxBp(cursor.getInt(i2 + 7));
        ecgMeasureDb.setMinBp(cursor.getInt(i2 + 8));
        int i6 = i2 + 9;
        ecgMeasureDb.setMeasureData(cursor.isNull(i6) ? null : cursor.getString(i6));
        ecgMeasureDb.setAge(cursor.getInt(i2 + 10));
        ecgMeasureDb.setSex(cursor.getInt(i2 + 11));
        ecgMeasureDb.setIsAfib(cursor.getShort(i2 + 12) != 0);
        ecgMeasureDb.setDiagnoseType(cursor.getInt(i2 + 13));
        int i7 = i2 + 14;
        ecgMeasureDb.setDeviceType(cursor.isNull(i7) ? null : cursor.getString(i7));
        int i8 = i2 + 15;
        ecgMeasureDb.setDeviceMac(cursor.isNull(i8) ? null : cursor.getString(i8));
        ecgMeasureDb.setIsUpload(cursor.getShort(i2 + 16) != 0);
        ecgMeasureDb.setIsOtherUpload(cursor.getShort(i2 + 17) != 0);
        int i9 = i2 + 18;
        ecgMeasureDb.setHealthNorm(cursor.isNull(i9) ? null : cursor.getString(i9));
        int i10 = i2 + 19;
        ecgMeasureDb.setBelongDataGroupId(cursor.isNull(i10) ? null : cursor.getString(i10));
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.greenrobot.greendao.AbstractDao
    public final Long updateKeyAfterInsert(EcgMeasureDb ecgMeasureDb, long j2) {
        ecgMeasureDb.setId(Long.valueOf(j2));
        return Long.valueOf(j2);
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public Long getKey(EcgMeasureDb ecgMeasureDb) {
        if (ecgMeasureDb != null) {
            return ecgMeasureDb.getId();
        }
        return null;
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public boolean hasKey(EcgMeasureDb ecgMeasureDb) {
        return ecgMeasureDb.getId() != null;
    }
}
