package com.yucheng.smarthealthpro.greendao;

import android.database.Cursor;
import android.database.sqlite.SQLiteStatement;
import androidx.constraintlayout.core.motion.utils.TypedValues;
import com.yucheng.smarthealthpro.greendao.bean.PhysiotherapyDb;
import com.yucheng.ycbtsdk.Constants;
import org.greenrobot.greendao.AbstractDao;
import org.greenrobot.greendao.Property;
import org.greenrobot.greendao.database.Database;
import org.greenrobot.greendao.database.DatabaseStatement;
import org.greenrobot.greendao.internal.DaoConfig;

/* loaded from: classes3.dex */
public class PhysiotherapyDbDao extends AbstractDao<PhysiotherapyDb, Long> {
    public static final String TABLENAME = "PHYSIOTHERAPY_DB";

    public static class Properties {
        public static final Property Id = new Property(0, Long.class, "id", true, "_id");
        public static final Property QueryId = new Property(1, Integer.TYPE, "queryId", false, "QUERY_ID");
        public static final Property StartTime = new Property(2, Long.TYPE, "startTime", false, "START_TIME");
        public static final Property Duration = new Property(3, Long.TYPE, TypedValues.TransitionType.S_DURATION, false, "DURATION");
        public static final Property Type = new Property(4, Integer.TYPE, "type", false, "TYPE");
        public static final Property StartType = new Property(5, Integer.TYPE, "startType", false, "START_TYPE");
        public static final Property PowerLevel = new Property(6, Integer.TYPE, "powerLevel", false, "POWER_LEVEL");
        public static final Property DurationLevel = new Property(7, Integer.TYPE, "durationLevel", false, "DURATION_LEVEL");
        public static final Property IsUpload = new Property(8, Boolean.TYPE, "isUpload", false, "IS_UPLOAD");
        public static final Property UserId = new Property(9, String.class, "userId", false, "USER_ID");
        public static final Property DeviceType = new Property(10, String.class, Constants.FunctionConstant.DEVICETYPE, false, "DEVICE_TYPE");
        public static final Property DeviceMac = new Property(11, String.class, "deviceMac", false, "DEVICE_MAC");
        public static final Property BelongDataGroupId = new Property(12, String.class, "belongDataGroupId", false, "BELONG_DATA_GROUP_ID");
    }

    @Override // org.greenrobot.greendao.AbstractDao
    protected final boolean isEntityUpdateable() {
        return true;
    }

    public PhysiotherapyDbDao(DaoConfig daoConfig) {
        super(daoConfig);
    }

    public PhysiotherapyDbDao(DaoConfig daoConfig, DaoSession daoSession) {
        super(daoConfig, daoSession);
    }

    public static void createTable(Database database, boolean z) {
        String str = z ? "IF NOT EXISTS " : "";
        database.execSQL("CREATE TABLE " + str + "\"PHYSIOTHERAPY_DB\" (\"_id\" INTEGER PRIMARY KEY AUTOINCREMENT ,\"QUERY_ID\" INTEGER NOT NULL ,\"START_TIME\" INTEGER NOT NULL ,\"DURATION\" INTEGER NOT NULL ,\"TYPE\" INTEGER NOT NULL ,\"START_TYPE\" INTEGER NOT NULL ,\"POWER_LEVEL\" INTEGER NOT NULL ,\"DURATION_LEVEL\" INTEGER NOT NULL ,\"IS_UPLOAD\" INTEGER NOT NULL ,\"USER_ID\" TEXT,\"DEVICE_TYPE\" TEXT,\"DEVICE_MAC\" TEXT,\"BELONG_DATA_GROUP_ID\" TEXT);");
        database.execSQL("CREATE INDEX " + str + "IDX_PHYSIOTHERAPY_DB_QUERY_ID ON \"PHYSIOTHERAPY_DB\" (\"QUERY_ID\" ASC);");
        database.execSQL("CREATE UNIQUE INDEX " + str + "IDX_PHYSIOTHERAPY_DB_START_TIME ON \"PHYSIOTHERAPY_DB\" (\"START_TIME\" ASC);");
    }

    public static void dropTable(Database database, boolean z) {
        StringBuilder sb = new StringBuilder("DROP TABLE ");
        sb.append(z ? "IF EXISTS " : "");
        sb.append("\"PHYSIOTHERAPY_DB\"");
        database.execSQL(sb.toString());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.greenrobot.greendao.AbstractDao
    public final void bindValues(DatabaseStatement databaseStatement, PhysiotherapyDb physiotherapyDb) {
        databaseStatement.clearBindings();
        Long id = physiotherapyDb.getId();
        if (id != null) {
            databaseStatement.bindLong(1, id.longValue());
        }
        databaseStatement.bindLong(2, physiotherapyDb.getQueryId());
        databaseStatement.bindLong(3, physiotherapyDb.getStartTime());
        databaseStatement.bindLong(4, physiotherapyDb.getDuration());
        databaseStatement.bindLong(5, physiotherapyDb.getType());
        databaseStatement.bindLong(6, physiotherapyDb.getStartType());
        databaseStatement.bindLong(7, physiotherapyDb.getPowerLevel());
        databaseStatement.bindLong(8, physiotherapyDb.getDurationLevel());
        databaseStatement.bindLong(9, physiotherapyDb.getIsUpload() ? 1L : 0L);
        String userId = physiotherapyDb.getUserId();
        if (userId != null) {
            databaseStatement.bindString(10, userId);
        }
        String deviceType = physiotherapyDb.getDeviceType();
        if (deviceType != null) {
            databaseStatement.bindString(11, deviceType);
        }
        String deviceMac = physiotherapyDb.getDeviceMac();
        if (deviceMac != null) {
            databaseStatement.bindString(12, deviceMac);
        }
        String belongDataGroupId = physiotherapyDb.getBelongDataGroupId();
        if (belongDataGroupId != null) {
            databaseStatement.bindString(13, belongDataGroupId);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.greenrobot.greendao.AbstractDao
    public final void bindValues(SQLiteStatement sQLiteStatement, PhysiotherapyDb physiotherapyDb) {
        sQLiteStatement.clearBindings();
        Long id = physiotherapyDb.getId();
        if (id != null) {
            sQLiteStatement.bindLong(1, id.longValue());
        }
        sQLiteStatement.bindLong(2, physiotherapyDb.getQueryId());
        sQLiteStatement.bindLong(3, physiotherapyDb.getStartTime());
        sQLiteStatement.bindLong(4, physiotherapyDb.getDuration());
        sQLiteStatement.bindLong(5, physiotherapyDb.getType());
        sQLiteStatement.bindLong(6, physiotherapyDb.getStartType());
        sQLiteStatement.bindLong(7, physiotherapyDb.getPowerLevel());
        sQLiteStatement.bindLong(8, physiotherapyDb.getDurationLevel());
        sQLiteStatement.bindLong(9, physiotherapyDb.getIsUpload() ? 1L : 0L);
        String userId = physiotherapyDb.getUserId();
        if (userId != null) {
            sQLiteStatement.bindString(10, userId);
        }
        String deviceType = physiotherapyDb.getDeviceType();
        if (deviceType != null) {
            sQLiteStatement.bindString(11, deviceType);
        }
        String deviceMac = physiotherapyDb.getDeviceMac();
        if (deviceMac != null) {
            sQLiteStatement.bindString(12, deviceMac);
        }
        String belongDataGroupId = physiotherapyDb.getBelongDataGroupId();
        if (belongDataGroupId != null) {
            sQLiteStatement.bindString(13, belongDataGroupId);
        }
    }

    /* JADX WARN: Can't rename method to resolve collision */
    @Override // org.greenrobot.greendao.AbstractDao
    public Long readKey(Cursor cursor, int i2) {
        int i3 = i2 + 0;
        if (cursor.isNull(i3)) {
            return null;
        }
        return Long.valueOf(cursor.getLong(i3));
    }

    /* JADX WARN: Can't rename method to resolve collision */
    @Override // org.greenrobot.greendao.AbstractDao
    public PhysiotherapyDb readEntity(Cursor cursor, int i2) {
        int i3 = i2 + 0;
        int i4 = i2 + 9;
        int i5 = i2 + 10;
        int i6 = i2 + 11;
        int i7 = i2 + 12;
        return new PhysiotherapyDb(cursor.isNull(i3) ? null : Long.valueOf(cursor.getLong(i3)), cursor.getInt(i2 + 1), cursor.getLong(i2 + 2), cursor.getLong(i2 + 3), cursor.getInt(i2 + 4), cursor.getInt(i2 + 5), cursor.getInt(i2 + 6), cursor.getInt(i2 + 7), cursor.getShort(i2 + 8) != 0, cursor.isNull(i4) ? null : cursor.getString(i4), cursor.isNull(i5) ? null : cursor.getString(i5), cursor.isNull(i6) ? null : cursor.getString(i6), cursor.isNull(i7) ? null : cursor.getString(i7));
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public void readEntity(Cursor cursor, PhysiotherapyDb physiotherapyDb, int i2) {
        int i3 = i2 + 0;
        physiotherapyDb.setId(cursor.isNull(i3) ? null : Long.valueOf(cursor.getLong(i3)));
        physiotherapyDb.setQueryId(cursor.getInt(i2 + 1));
        physiotherapyDb.setStartTime(cursor.getLong(i2 + 2));
        physiotherapyDb.setDuration(cursor.getLong(i2 + 3));
        physiotherapyDb.setType(cursor.getInt(i2 + 4));
        physiotherapyDb.setStartType(cursor.getInt(i2 + 5));
        physiotherapyDb.setPowerLevel(cursor.getInt(i2 + 6));
        physiotherapyDb.setDurationLevel(cursor.getInt(i2 + 7));
        physiotherapyDb.setIsUpload(cursor.getShort(i2 + 8) != 0);
        int i4 = i2 + 9;
        physiotherapyDb.setUserId(cursor.isNull(i4) ? null : cursor.getString(i4));
        int i5 = i2 + 10;
        physiotherapyDb.setDeviceType(cursor.isNull(i5) ? null : cursor.getString(i5));
        int i6 = i2 + 11;
        physiotherapyDb.setDeviceMac(cursor.isNull(i6) ? null : cursor.getString(i6));
        int i7 = i2 + 12;
        physiotherapyDb.setBelongDataGroupId(cursor.isNull(i7) ? null : cursor.getString(i7));
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.greenrobot.greendao.AbstractDao
    public final Long updateKeyAfterInsert(PhysiotherapyDb physiotherapyDb, long j2) {
        physiotherapyDb.setId(Long.valueOf(j2));
        return Long.valueOf(j2);
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public Long getKey(PhysiotherapyDb physiotherapyDb) {
        if (physiotherapyDb != null) {
            return physiotherapyDb.getId();
        }
        return null;
    }

    @Override // org.greenrobot.greendao.AbstractDao
    public boolean hasKey(PhysiotherapyDb physiotherapyDb) {
        return physiotherapyDb.getId() != null;
    }
}
