package com.yucheng.smarthealthpro.greendao.utils;

import android.content.Context;
import android.util.Log;
import com.yucheng.smarthealthpro.greendao.HeartDbDao;
import com.yucheng.smarthealthpro.greendao.bean.HeartDb;
import com.yucheng.smarthealthpro.login.normal.util.UserInfoUtil;
import com.yucheng.smarthealthpro.utils.AppDateMgr;
import java.util.Iterator;
import java.util.List;
import org.greenrobot.greendao.query.WhereCondition;

/* loaded from: classes3.dex */
public class HeartDbUtils {
    private static final String TAG = "HeartDbUtils";
    private static DaoManager daoManager;

    public HeartDbUtils(Context context) {
        daoManager = DaoManager.getInstance();
    }

    public HeartDbUtils() {
        daoManager = DaoManager.getInstance();
    }

    public boolean insertMsgModel(HeartDb heartDb) {
        return daoManager.getDaoSession().getHeartDbDao().insert(heartDb) != -1;
    }

    public boolean insertMultMsgModel(final List<HeartDb> list) {
        try {
            daoManager.getDaoSession().runInTx(new Runnable() { // from class: com.yucheng.smarthealthpro.greendao.utils.HeartDbUtils.1
                @Override // java.lang.Runnable
                public void run() {
                    Iterator it2 = list.iterator();
                    while (it2.hasNext()) {
                        HeartDbUtils.daoManager.getDaoSession().insertOrReplace((HeartDb) it2.next());
                    }
                }
            });
            return true;
        } catch (Exception e2) {
            e2.printStackTrace();
            return false;
        }
    }

    public boolean updateMsgModel(HeartDb heartDb) {
        try {
            daoManager.getDaoSession().update(heartDb);
            return true;
        } catch (Exception e2) {
            e2.printStackTrace();
            return false;
        }
    }

    public boolean deleteMsgModel(HeartDb heartDb) {
        try {
            daoManager.getDaoSession().delete(heartDb);
            return true;
        } catch (Exception e2) {
            e2.printStackTrace();
            return false;
        }
    }

    public boolean deleteAll() {
        try {
            daoManager.getDaoSession().deleteAll(HeartDb.class);
            return true;
        } catch (Exception e2) {
            e2.printStackTrace();
            return false;
        }
    }

    public List<HeartDb> queryAllMsgModel() {
        try {
            return daoManager.getDaoSession().queryBuilder(HeartDb.class).whereOr(HeartDbDao.Properties.UserId.eq(UserInfoUtil.getUserName()), HeartDbDao.Properties.UserId.isNull(), HeartDbDao.Properties.UserId.eq("")).list();
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public HeartDb queryMsgModelById(long j2) {
        return (HeartDb) daoManager.getDaoSession().load(HeartDb.class, Long.valueOf(j2));
    }

    public HeartDb queryMsgModelByQueryBuilder(long j2) {
        try {
            return (HeartDb) daoManager.getDaoSession().queryBuilder(HeartDb.class).where(HeartDbDao.Properties.Id.eq(Long.valueOf(j2)), new WhereCondition[0]).unique();
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public List<HeartDb> queryId(long j2) {
        try {
            return daoManager.getDaoSession().queryBuilder(HeartDb.class).where(HeartDbDao.Properties.HeartStartTime.eq(Long.valueOf(j2)), new WhereCondition[0]).list();
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public List<HeartDb> queryIdYearToDay(String str) {
        try {
            return daoManager.getDaoSession().queryBuilder(HeartDb.class).where(HeartDbDao.Properties.TimeYearToDate.eq(str), new WhereCondition[0]).whereOr(HeartDbDao.Properties.UserId.eq(UserInfoUtil.getUserName()), HeartDbDao.Properties.UserId.isNull(), HeartDbDao.Properties.UserId.eq("")).orderDesc(HeartDbDao.Properties.HeartStartTime).list();
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public List<HeartDb> queryGeTimeYearToDay(String str) {
        try {
            return daoManager.getDaoSession().queryBuilder(HeartDb.class).where(HeartDbDao.Properties.TimeYearToDate.ge(str), new WhereCondition[0]).whereOr(HeartDbDao.Properties.UserId.eq(UserInfoUtil.getUserName()), HeartDbDao.Properties.UserId.isNull(), HeartDbDao.Properties.UserId.eq("")).list();
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public List<HeartDb> queryByTimeRange(long j2, long j3) {
        try {
            return daoManager.getDaoSession().queryBuilder(HeartDb.class).where(HeartDbDao.Properties.HeartStartTime.between(Long.valueOf(j2), Long.valueOf(j3)), new WhereCondition[0]).whereOr(HeartDbDao.Properties.UserId.eq(UserInfoUtil.getUserName()), HeartDbDao.Properties.UserId.isNull(), HeartDbDao.Properties.UserId.eq("")).list();
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public boolean queryIdDelete(int i2) {
        HeartDb heartDb = (HeartDb) daoManager.getDaoSession().queryBuilder(HeartDb.class).where(HeartDbDao.Properties.QueryID.eq(Integer.valueOf(i2)), new WhereCondition[0]).unique();
        if (heartDb != null) {
            try {
                daoManager.getDaoSession().delete(heartDb);
                return true;
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
        return false;
    }

    public boolean setDataGroupId(String str, long j2, long j3) {
        try {
            Log.d("ltf", "查询时间起始:" + AppDateMgr.timeStampToDateTime2(Long.valueOf(j2)) + " 结束:" + AppDateMgr.timeStampToDateTime2(Long.valueOf(j3)) + " 设置id:" + str);
            List list = daoManager.getDaoSession().queryBuilder(HeartDb.class).where(HeartDbDao.Properties.HeartStartTime.between(Long.valueOf(j2), Long.valueOf(j3)), new WhereCondition[0]).whereOr(HeartDbDao.Properties.UserId.eq(UserInfoUtil.getUserName()), HeartDbDao.Properties.UserId.isNull(), HeartDbDao.Properties.UserId.eq("")).list();
            for (int i2 = 0; i2 < list.size(); i2++) {
                HeartDb heartDb = (HeartDb) list.get(i2);
                Log.d("ltf", "心率时间:" + AppDateMgr.timeStampToDateTime2(Long.valueOf(heartDb.getHeartStartTime())));
                heartDb.setBelongDataGroupId(str);
            }
            daoManager.getDaoSession().getHeartDbDao().updateInTx(list);
            return true;
        } catch (Exception e2) {
            e2.printStackTrace();
            return false;
        }
    }
}
