package com.yucheng.smarthealthpro.me.setting.contacts.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.recyclerview.widget.RecyclerView;
import com.yucheng.HealthWear.R;
import com.yucheng.smarthealthpro.framework.util.ToastUtil;
import com.yucheng.smarthealthpro.me.setting.contacts.bean.MyContacts;
import com.yucheng.smarthealthpro.me.setting.contacts.utils.ColorGenerator;
import com.yucheng.smarthealthpro.me.setting.contacts.utils.TextDrawable;
import com.yucheng.ycbtsdk.YCBTClient;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/* loaded from: classes2.dex */
public class ContactAdapter extends RecyclerView.Adapter<MyRecycleHolder> {
    private List<MyContacts> contactBeanList;
    private List<String> list;
    private Context mContext;
    private ColorGenerator mColorGenerator = ColorGenerator.MATERIAL;
    private TextDrawable.IBuilder mDrawableBuilder = TextDrawable.builder().round();
    private int maxSize = 10;
    private int currSize = 0;

    static /* synthetic */ int access$008(ContactAdapter contactAdapter) {
        int i2 = contactAdapter.currSize;
        contactAdapter.currSize = i2 + 1;
        return i2;
    }

    static /* synthetic */ int access$010(ContactAdapter contactAdapter) {
        int i2 = contactAdapter.currSize;
        contactAdapter.currSize = i2 - 1;
        return i2;
    }

    public ContactAdapter(Context context, List<MyContacts> list) {
        this.mContext = context;
        if (list == null) {
            this.contactBeanList = new ArrayList();
        } else {
            this.contactBeanList = list;
        }
        initMax();
    }

    private void initMax() {
        if (YCBTClient.getChipScheme() == 3) {
            this.maxSize = 10;
        } else {
            this.maxSize = 30;
        }
    }

    public void addAll(List<MyContacts> list) {
        if (list != null) {
            this.contactBeanList = list;
        }
        this.currSize = 0;
        Iterator<MyContacts> it2 = this.contactBeanList.iterator();
        while (it2.hasNext()) {
            if (it2.next().isChecked) {
                this.currSize++;
            }
        }
        notifyDataSetChanged();
    }

    public void add(MyContacts myContacts, int i2) {
        this.contactBeanList.add(i2, myContacts);
        notifyItemInserted(i2);
    }

    public void add(MyContacts myContacts) {
        this.contactBeanList.add(myContacts);
        notifyItemChanged(this.contactBeanList.size() - 1);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public MyRecycleHolder onCreateViewHolder(ViewGroup viewGroup, int i2) {
        return new MyRecycleHolder(LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.item_contacts_layout, viewGroup, false));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onBindViewHolder(final MyRecycleHolder myRecycleHolder, int i2) {
        final MyContacts myContacts;
        List<MyContacts> list = this.contactBeanList;
        if (list == null || list.size() == 0 || this.contactBeanList.size() <= i2 || (myContacts = this.contactBeanList.get(i2)) == null) {
            return;
        }
        myRecycleHolder.tv_name.setText(myContacts.getName());
        myRecycleHolder.iv_img.setImageDrawable(this.mDrawableBuilder.build(String.valueOf(myContacts.getName().charAt(0)), this.mColorGenerator.getColor(myContacts.getName())));
        myRecycleHolder.check_box.setChecked(myContacts.isChecked);
        myRecycleHolder.check_box.setOnClickListener(new View.OnClickListener() { // from class: com.yucheng.smarthealthpro.me.setting.contacts.adapter.ContactAdapter.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                if (!myContacts.isChecked) {
                    if (ContactAdapter.this.currSize >= ContactAdapter.this.maxSize) {
                        myRecycleHolder.check_box.setChecked(false);
                        ToastUtil.getInstance(ContactAdapter.this.mContext).toast(ContactAdapter.this.mContext.getString(R.string.contacts_limit_reached));
                        return;
                    } else {
                        myContacts.isChecked = true;
                        ContactAdapter.access$008(ContactAdapter.this);
                        return;
                    }
                }
                myContacts.isChecked = false;
                ContactAdapter.access$010(ContactAdapter.this);
            }
        });
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        List<MyContacts> list = this.contactBeanList;
        if (list != null) {
            return list.size();
        }
        return 0;
    }

    public static class MyRecycleHolder extends RecyclerView.ViewHolder {
        public final CheckBox check_box;
        public final ImageView iv_img;
        public final TextView tv_name;

        public MyRecycleHolder(View view) {
            super(view);
            this.tv_name = (TextView) view.findViewById(R.id.tv_name);
            this.iv_img = (ImageView) view.findViewById(R.id.iv_img);
            this.check_box = (CheckBox) view.findViewById(R.id.check_box);
        }
    }
}
