package com.yucheng.smarthealthpro.sport.utils;

/* loaded from: classes2.dex */
public class GPSConverterUtils {
    public static final String BAIDU_LBS_TYPE = "bd09ll";

    /* renamed from: a, reason: collision with root package name */
    public static double f5551a = 6378245.0d;
    public static double ee = 0.006693421622965943d;
    public static double pi = 3.141592653589793d;

    public static boolean outOfChina(double d2, double d3) {
        return d3 < 72.004d || d3 > 137.8347d || d2 < 0.8293d || d2 > 55.8271d;
    }

    public static GPS gps84_To_Gcj02(double d2, double d3) {
        if (outOfChina(d2, d3)) {
            return null;
        }
        double d4 = d3 - 105.0d;
        double d5 = d2 - 35.0d;
        double transformLat = transformLat(d4, d5);
        double transformLon = transformLon(d4, d5);
        double d6 = (d2 / 180.0d) * pi;
        double sin = Math.sin(d6);
        double d7 = 1.0d - ((ee * sin) * sin);
        double sqrt = Math.sqrt(d7);
        double d8 = f5551a;
        return new GPS(d2 + ((transformLat * 180.0d) / ((((1.0d - ee) * d8) / (d7 * sqrt)) * pi)), d3 + ((transformLon * 180.0d) / (((d8 / sqrt) * Math.cos(d6)) * pi)));
    }

    public static GPS gcj_To_Gps84(double d2, double d3) {
        GPS transform = transform(d2, d3);
        return new GPS((d2 * 2.0d) - transform.getLat(), (d3 * 2.0d) - transform.getLon());
    }

    public static GPS gcj02_To_Bd09(double d2, double d3) {
        double sqrt = Math.sqrt((d3 * d3) + (d2 * d2)) + (Math.sin(pi * d2) * 2.0E-5d);
        double atan2 = Math.atan2(d2, d3) + (Math.cos(d3 * pi) * 3.0E-6d);
        return new GPS((sqrt * Math.sin(atan2)) + 0.006d, (Math.cos(atan2) * sqrt) + 0.0065d);
    }

    public static GPS bd09_To_Gcj02(double d2, double d3) {
        double d4 = d3 - 0.0065d;
        double d5 = d2 - 0.006d;
        double sqrt = Math.sqrt((d4 * d4) + (d5 * d5)) - (Math.sin(pi * d5) * 2.0E-5d);
        double atan2 = Math.atan2(d5, d4) - (Math.cos(d4 * pi) * 3.0E-6d);
        return new GPS(sqrt * Math.sin(atan2), Math.cos(atan2) * sqrt);
    }

    public static GPS bd09_To_Gps84(double d2, double d3) {
        GPS bd09_To_Gcj02 = bd09_To_Gcj02(d2, d3);
        return gcj_To_Gps84(bd09_To_Gcj02.getLat(), bd09_To_Gcj02.getLon());
    }

    public static GPS transform(double d2, double d3) {
        if (outOfChina(d2, d3)) {
            return new GPS(d2, d3);
        }
        double d4 = d3 - 105.0d;
        double d5 = d2 - 35.0d;
        double transformLat = transformLat(d4, d5);
        double transformLon = transformLon(d4, d5);
        double d6 = (d2 / 180.0d) * pi;
        double sin = Math.sin(d6);
        double d7 = 1.0d - ((ee * sin) * sin);
        double sqrt = Math.sqrt(d7);
        double d8 = f5551a;
        return new GPS(d2 + ((transformLat * 180.0d) / ((((1.0d - ee) * d8) / (d7 * sqrt)) * pi)), d3 + ((transformLon * 180.0d) / (((d8 / sqrt) * Math.cos(d6)) * pi)));
    }

    public static double transformLat(double d2, double d3) {
        double d4 = d2 * 2.0d;
        return (-100.0d) + d4 + (d3 * 3.0d) + (d3 * 0.2d * d3) + (0.1d * d2 * d3) + (Math.sqrt(Math.abs(d2)) * 0.2d) + ((((Math.sin((d2 * 6.0d) * pi) * 20.0d) + (Math.sin(d4 * pi) * 20.0d)) * 2.0d) / 3.0d) + ((((Math.sin(pi * d3) * 20.0d) + (Math.sin((d3 / 3.0d) * pi) * 40.0d)) * 2.0d) / 3.0d) + ((((Math.sin((d3 / 12.0d) * pi) * 160.0d) + (Math.sin((d3 * pi) / 30.0d) * 320.0d)) * 2.0d) / 3.0d);
    }

    public static double transformLon(double d2, double d3) {
        double d4 = d2 * 0.1d;
        return d2 + 300.0d + (d3 * 2.0d) + (d4 * d2) + (d4 * d3) + (Math.sqrt(Math.abs(d2)) * 0.1d) + ((((Math.sin((6.0d * d2) * pi) * 20.0d) + (Math.sin((d2 * 2.0d) * pi) * 20.0d)) * 2.0d) / 3.0d) + ((((Math.sin(pi * d2) * 20.0d) + (Math.sin((d2 / 3.0d) * pi) * 40.0d)) * 2.0d) / 3.0d) + ((((Math.sin((d2 / 12.0d) * pi) * 150.0d) + (Math.sin((d2 / 30.0d) * pi) * 300.0d)) * 2.0d) / 3.0d);
    }
}
