package com.yucheng.smarthealthpro.sport.utils;

import android.content.Context;
import android.content.Intent;
import android.location.Address;
import android.location.Geocoder;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.util.Log;
import androidx.core.app.ActivityCompat;
import com.amap.api.services.geocoder.GeocodeSearch;
import com.google.firebase.analytics.FirebaseAnalytics;
import com.orhanobut.logger.Logger;
import com.yanzhenjie.permission.Permission;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

/* loaded from: classes2.dex */
public class LocationUtils {
    private static double EARTH_RADIUS = 6378.137d;
    private static ArrayList<AddressCallback> addressCallbacks;
    private static Location location;
    private static volatile LocationUtils uniqueInstance;
    private AddressCallback addressCallback;
    private boolean isInit = false;
    private LocationListener locationListener = new LocationListener() { // from class: com.yucheng.smarthealthpro.sport.utils.LocationUtils.1
        @Override // android.location.LocationListener
        public void onProviderDisabled(String str) {
        }

        @Override // android.location.LocationListener
        public void onProviderEnabled(String str) {
        }

        @Override // android.location.LocationListener
        public void onStatusChanged(String str, int i2, Bundle bundle) {
        }

        @Override // android.location.LocationListener
        public void onLocationChanged(Location location2) {
            Logger.d("==LocationUtils==onLocationChanged==" + location2.toString());
        }
    };
    private LocationManager locationManager;
    private Context mContext;

    public interface AddressCallback {
        void onGetAddress(Address address);

        void onGetLocation(double d2, double d3);
    }

    private static double rad(double d2) {
        return (d2 * 3.141592653589793d) / 180.0d;
    }

    public AddressCallback getAddressCallback() {
        return this.addressCallback;
    }

    public void setAddressCallback(AddressCallback addressCallback) {
        this.addressCallback = addressCallback;
        if (this.isInit) {
            showLocation();
        } else {
            this.isInit = true;
        }
    }

    private LocationUtils(Context context) {
        this.mContext = context;
        getLocation();
    }

    public static LocationUtils getInstance(Context context) {
        if (uniqueInstance == null) {
            synchronized (LocationUtils.class) {
                if (uniqueInstance == null) {
                    addressCallbacks = new ArrayList<>();
                    uniqueInstance = new LocationUtils(context);
                }
            }
        }
        return uniqueInstance;
    }

    private void addAddressCallback(AddressCallback addressCallback) {
        addressCallbacks.add(addressCallback);
        if (this.isInit) {
            showLocation();
        }
    }

    public void removeAddressCallback(AddressCallback addressCallback) {
        if (addressCallbacks.contains(addressCallback)) {
            addressCallbacks.remove(addressCallback);
        }
    }

    public void cleareAddressCallback() {
        removeLocationUpdatesListener();
        addressCallbacks.clear();
    }

    private void getLocation() {
        this.locationManager = (LocationManager) this.mContext.getSystemService(FirebaseAnalytics.Param.LOCATION);
        if (ActivityCompat.checkSelfPermission(this.mContext, Permission.ACCESS_FINE_LOCATION) == 0 || ActivityCompat.checkSelfPermission(this.mContext, Permission.ACCESS_COARSE_LOCATION) == 0) {
            List<String> providers = this.locationManager.getProviders(true);
            String str = GeocodeSearch.GPS;
            if (providers.contains(GeocodeSearch.GPS)) {
                Logger.d("=====GPS_PROVIDER=====");
            } else {
                str = "network";
                if (providers.contains("network")) {
                    Logger.d("=====NETWORK_PROVIDER=====");
                } else {
                    Logger.d("=====NO_PROVIDER=====");
                    Intent intent = new Intent();
                    intent.setAction("android.settings.LOCATION_SOURCE_SETTINGS");
                    this.mContext.startActivity(intent);
                    return;
                }
            }
            String str2 = str;
            Location lastKnownLocation = this.locationManager.getLastKnownLocation(str2);
            location = lastKnownLocation;
            if (lastKnownLocation != null) {
                Logger.d("==显示当前设备的位置信息==");
                showLocation();
            } else {
                Logger.d("==Google服务被墙的解决办法==");
                getLngAndLatWithNetwork();
            }
            this.locationManager.requestLocationUpdates(str2, 1000L, 0.0f, this.locationListener);
        }
    }

    private void showLocation() {
        Location location2 = location;
        if (location2 == null) {
            getLocation();
            return;
        }
        double latitude = location2.getLatitude();
        double longitude = location.getLongitude();
        Log.i("定位经纬度", "--latitude--" + latitude + "--longitude--" + longitude);
        AddressCallback addressCallback = this.addressCallback;
        if (addressCallback != null) {
            addressCallback.onGetLocation(latitude, longitude);
        }
        getAddress(latitude, longitude);
    }

    private void getAddress(double d2, double d3) {
        try {
            List<Address> fromLocation = new Geocoder(this.mContext, Locale.getDefault()).getFromLocation(d2, d3, 1);
            if (fromLocation != null) {
                Address address = fromLocation.get(0);
                address.getCountryName();
                address.getCountryCode();
                address.getAdminArea();
                address.getLocality();
                address.getSubLocality();
                address.getFeatureName();
                for (int i2 = 0; address.getAddressLine(i2) != null; i2++) {
                    Logger.d("addressLine=====" + address.getAddressLine(i2));
                }
                AddressCallback addressCallback = this.addressCallback;
                if (addressCallback != null) {
                    addressCallback.onGetAddress(address);
                }
            }
        } catch (IOException e2) {
            e2.printStackTrace();
        }
    }

    private void removeLocationUpdatesListener() {
        if (this.locationManager != null) {
            uniqueInstance = null;
            this.locationManager.removeUpdates(this.locationListener);
        }
    }

    private void getLngAndLatWithNetwork() {
        if (ActivityCompat.checkSelfPermission(this.mContext, Permission.ACCESS_FINE_LOCATION) == 0 || ActivityCompat.checkSelfPermission(this.mContext, Permission.ACCESS_COARSE_LOCATION) == 0) {
            LocationManager locationManager = (LocationManager) this.mContext.getSystemService(FirebaseAnalytics.Param.LOCATION);
            locationManager.requestLocationUpdates("network", 1000L, 0.0f, this.locationListener);
            location = locationManager.getLastKnownLocation("network");
            showLocation();
        }
    }

    public static double getDistance(double d2, double d3, double d4, double d5) {
        double rad = rad(d2);
        double rad2 = rad(d4);
        return (Math.round(((Math.asin(Math.sqrt(Math.pow(Math.sin((rad - rad2) / 2.0d), 2.0d) + ((Math.cos(rad) * Math.cos(rad2)) * Math.pow(Math.sin((rad(d3) - rad(d5)) / 2.0d), 2.0d)))) * 2.0d) * EARTH_RADIUS) * 10000.0d) / 10000.0d) * 1000.0d;
    }
}
