package com.yucheng.smarthealthpro.utils;

import androidx.core.view.MotionEventCompat;
import androidx.core.view.ViewCompat;
import com.dd.plist.ASCIIPropertyListParser;
import com.google.firebase.crashlytics.buildtools.reloc.com.google.common.base.Ascii;
import com.yucheng.smarthealthpro.customchart.utils.Utils;

/* loaded from: classes2.dex */
public class ConvertUtils {
    private static final char[] DIGITS_LOWER = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
    private static final char[] DIGITS_UPPER = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', ASCIIPropertyListParser.DATA_GSBOOL_BEGIN_TOKEN, 'C', ASCIIPropertyListParser.DATA_GSDATE_BEGIN_TOKEN, 'E', 'F'};

    public static byte[] intToByte(int i2) {
        return new byte[]{(byte) (i2 & 255), (byte) ((i2 >> 8) & 255), (byte) ((i2 >> 16) & 255), (byte) (i2 >>> 24)};
    }

    public static String nullOfString(String str) {
        return str == null ? "" : str;
    }

    private ConvertUtils() {
        throw new UnsupportedOperationException("cannot be instantiated");
    }

    public static byte[] hexStringToBytes(String str) {
        if (str == null || str.equals("")) {
            return null;
        }
        String upperCase = str.toUpperCase();
        int length = upperCase.length() / 2;
        char[] charArray = upperCase.toCharArray();
        byte[] bArr = new byte[length];
        for (int i2 = 0; i2 < length; i2++) {
            int i3 = i2 * 2;
            bArr[i2] = (byte) (charToByte(charArray[i3 + 1]) | (charToByte(charArray[i3]) << 4));
        }
        return bArr;
    }

    public static byte charToByte(char c2) {
        return (byte) "0123456789ABCDEF".indexOf(c2);
    }

    private static int toDigit(char c2, int i2) throws Exception {
        int digit = Character.digit(c2, 16);
        if (digit != -1) {
            return digit;
        }
        throw new Exception("Illegal hexadecimal character " + c2 + " at index " + i2);
    }

    private static String bytes2Hex(byte[] bArr, char[] cArr) {
        char[] cArr2 = new char[bArr.length << 1];
        int i2 = 0;
        for (byte b2 : bArr) {
            int i3 = i2 + 1;
            cArr2[i2] = cArr[(b2 & 240) >>> 4];
            i2 = i3 + 1;
            cArr2[i3] = cArr[b2 & 15];
        }
        return new String(cArr2);
    }

    public static String bytesToHexString(byte[] bArr) {
        if (bArr.length == 0) {
            return null;
        }
        StringBuilder sb = new StringBuilder("");
        for (byte b2 : bArr) {
            String hexString = Integer.toHexString(b2 & 255);
            if (hexString.length() < 2) {
                sb.append(0);
            }
            sb.append(hexString);
        }
        return sb.toString();
    }

    public static int byteToInt(byte[] bArr) {
        return ((bArr[0] << Ascii.CAN) & ViewCompat.MEASURED_STATE_MASK) | (bArr[3] & 255) | ((bArr[2] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | ((bArr[1] << 16) & 16711680);
    }

    public static String saveDecimals(int i2, double d2) {
        return i2 == 2 ? String.format("%.02f", Double.valueOf(d2)) : i2 == 1 ? String.format("%.01f", Double.valueOf(d2)) : String.format("%.0f", Double.valueOf(d2));
    }

    public static byte stringToByte(String str) {
        if (str != null) {
            try {
                return Byte.parseByte(str);
            } catch (Exception unused) {
            }
        }
        return (byte) 0;
    }

    public static boolean stringToBoolean(String str) {
        if (str == null) {
            return false;
        }
        if (str.equals("1")) {
            return true;
        }
        if (str.equals("0")) {
            return false;
        }
        try {
            return Boolean.parseBoolean(str);
        } catch (Exception unused) {
            return false;
        }
    }

    public static int stringToInt(String str) {
        if (str == null) {
            return 0;
        }
        try {
            return Integer.parseInt(str.trim());
        } catch (Exception unused) {
            return 0;
        }
    }

    public static short stringToShort(String str) {
        if (str == null) {
            return (short) 0;
        }
        try {
            return Short.parseShort(str.trim());
        } catch (Exception unused) {
            return (short) 0;
        }
    }

    public static double stringToDouble(String str) {
        if (str == null) {
            return Utils.DOUBLE_EPSILON;
        }
        try {
            return Double.parseDouble(str.trim());
        } catch (Exception unused) {
            return Utils.DOUBLE_EPSILON;
        }
    }

    public static String intToString(int i2) {
        try {
            return String.valueOf(i2);
        } catch (Exception unused) {
            return "";
        }
    }

    public static long doubleToLong(double d2) {
        try {
            return Long.parseLong(String.valueOf(d2).substring(0, String.valueOf(d2).lastIndexOf(".")));
        } catch (Exception unused) {
            return 0L;
        }
    }

    public static int doubleToInt(double d2) {
        try {
            return Integer.parseInt(String.valueOf(d2).substring(0, String.valueOf(d2).lastIndexOf(".")));
        } catch (Exception unused) {
            return 0;
        }
    }

    public static double longToDouble(long j2) {
        try {
            return Double.parseDouble(String.valueOf(j2));
        } catch (Exception unused) {
            return Utils.DOUBLE_EPSILON;
        }
    }

    public static int longToInt(long j2) {
        try {
            return Integer.parseInt(String.valueOf(j2));
        } catch (Exception unused) {
            return 0;
        }
    }

    public static long stringToLong(String str) {
        Long l = new Long(0L);
        try {
            l = Long.valueOf(str);
        } catch (Exception unused) {
        }
        return l.longValue();
    }

    public static String longToString(long j2) {
        try {
            return String.valueOf(j2);
        } catch (Exception unused) {
            return "";
        }
    }
}
