package com.yucheng.smarthealthpro.utils;

import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.wifi.WifiManager;
import android.provider.Settings;
import com.facebook.internal.ServerProtocol;

/* loaded from: classes2.dex */
public class NetworkManager {
    private static NetworkManager networkManager;
    private ConnectivityManager connManager;
    private Context context;

    public static synchronized NetworkManager getInstance(Context context) {
        NetworkManager networkManager2;
        synchronized (NetworkManager.class) {
            if (networkManager == null) {
                networkManager = new NetworkManager(context);
            }
            networkManager2 = networkManager;
        }
        return networkManager2;
    }

    private NetworkManager(Context context) {
        this.context = context;
        this.connManager = (ConnectivityManager) context.getSystemService("connectivity");
    }

    public boolean isNetworkConnected() {
        NetworkInfo activeNetworkInfo = this.connManager.getActiveNetworkInfo();
        if (activeNetworkInfo != null) {
            return activeNetworkInfo.isConnected();
        }
        return false;
    }

    public boolean isWifiConnected() {
        NetworkInfo networkInfo = this.connManager.getNetworkInfo(1);
        if (networkInfo != null) {
            return networkInfo.isConnected();
        }
        return false;
    }

    public boolean isMobileConnected() {
        NetworkInfo networkInfo = this.connManager.getNetworkInfo(0);
        if (networkInfo != null) {
            return networkInfo.isConnected();
        }
        return false;
    }

    public void toggleGprs(boolean z) throws Exception {
        this.connManager.getClass().getMethod("setMobileDataEnabled", Boolean.TYPE).invoke(this.connManager, Boolean.valueOf(z));
    }

    public boolean toggleWiFi(boolean z) {
        return ((WifiManager) this.context.getSystemService(AppNetworkMgr.NETWORK_TYPE_WIFI)).setWifiEnabled(z);
    }

    public boolean isAirplaneModeOn() {
        return Settings.System.getInt(this.context.getContentResolver(), "airplane_mode_on", 0) == 1;
    }

    public void toggleAirplaneMode(boolean z) {
        Settings.System.putInt(this.context.getContentResolver(), "airplane_mode_on", z ? 1 : 0);
        Intent intent = new Intent("android.intent.action.AIRPLANE_MODE");
        intent.putExtra(ServerProtocol.DIALOG_PARAM_STATE, z);
        this.context.sendBroadcast(intent);
    }

    public String getInternetState() {
        try {
            return isNetworkConnected() ? isWifiConnected() ? "WIFI" : isMobileConnected() ? "4/5G" : "No network" : "No network";
        } catch (SecurityException e2) {
            e2.printStackTrace();
            return "No network";
        }
    }
}
