package com.yucheng.ycbtsdk.utils;

import android.content.Context;
import android.os.Build;
import android.os.Environment;
import android.text.format.Formatter;
import android.util.Log;
import com.google.firebase.crashlytics.buildtools.reloc.org.apache.commons.io.IOUtils;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.text.SimpleDateFormat;
import java.util.Date;

/* loaded from: classes2.dex */
public class LogToFileUtils {
    private static final int LOG_MAX_SIZE = 10485760;
    private static final String MY_TAG = "LogToFileUtils";
    private static LogToFileUtils instance;
    private static File logFile;
    private static SimpleDateFormat logSDF = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS");
    private static Context mContext;
    private static String tag;

    public static void clearLog() {
        File file;
        if (mContext == null || instance == null || (file = logFile) == null || !file.exists()) {
            Log.e(MY_TAG, "Initialization failure !!!");
            return;
        }
        try {
            BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(logFile, false));
            bufferedWriter.write("");
            bufferedWriter.flush();
        } catch (Exception e2) {
            Log.e(tag, "Write failure !!! " + e2.toString());
        }
    }

    public static boolean deleteLogFile(String str) {
        File file;
        if (Environment.getExternalStorageState().equals("mounted")) {
            file = new File(mContext.getExternalFilesDir("YCLog").getPath() + "/");
        } else {
            file = new File(mContext.getFilesDir().getPath() + "/YCLog/");
        }
        if (!file.exists()) {
            file.mkdir();
        }
        File file2 = new File(file.getPath() + "/" + str);
        if (file2.exists()) {
            return file2.delete();
        }
        return false;
    }

    public static long getFileSize(File file) {
        if (file.exists()) {
            try {
                return new FileInputStream(file).available();
            } catch (Exception e2) {
                Log.e(MY_TAG, e2.toString());
            }
        }
        return 0L;
    }

    private static String getFunctionInfo() {
        StackTraceElement[] stackTrace = Thread.currentThread().getStackTrace();
        if (stackTrace == null) {
            return null;
        }
        for (StackTraceElement stackTraceElement : stackTrace) {
            if (!stackTraceElement.isNativeMethod() && !stackTraceElement.getClassName().equals(Thread.class.getName()) && !stackTraceElement.getClassName().equals(instance.getClass().getName())) {
                tag = stackTraceElement.getFileName();
                return "[" + logSDF.format(new Date()) + "]";
            }
        }
        return null;
    }

    public static File getLogFile(String str) {
        File file;
        if (Environment.getExternalStorageState().equals("mounted")) {
            file = new File(mContext.getExternalFilesDir("YCLog").getPath() + "/");
        } else {
            file = new File(mContext.getFilesDir().getPath() + "/YCLog/");
        }
        if (!file.exists()) {
            file.mkdir();
        }
        File file2 = new File(file.getPath() + "/" + str);
        if (!file2.exists()) {
            try {
                file2.createNewFile();
            } catch (Exception e2) {
                Log.e(MY_TAG, "Create log file failure !!! " + e2.toString());
            }
        }
        return file2;
    }

    public static String getSDPath(Context context) {
        return (Environment.getExternalStorageState().equals("mounted") ? Build.VERSION.SDK_INT >= 29 ? context.getExternalFilesDir(null) : Environment.getExternalStorageDirectory() : Environment.getRootDirectory()).toString();
    }

    public static String getYCFilePath() {
        File file;
        String sDPath = getSDPath(mContext);
        if (sDPath != null) {
            file = new File(sDPath + "/yc_file/");
        } else if (Environment.getExternalStorageState().equals("mounted")) {
            file = new File(mContext.getExternalFilesDir("YCLog").getPath() + "/");
        } else {
            file = new File(mContext.getFilesDir().getPath() + "/YCLog/");
        }
        if (!file.exists()) {
            file.mkdir();
        }
        return file.getAbsolutePath() + "/";
    }

    public static void init(Context context) {
        File file;
        Log.i(MY_TAG, "init ...");
        if (mContext != null && instance != null && (file = logFile) != null && file.exists()) {
            Log.i(MY_TAG, "LogToFileUtils has been init ...");
            return;
        }
        mContext = context;
        instance = new LogToFileUtils();
        logFile = getLogFile("yclogs.txt");
        Log.i(MY_TAG, "LogFilePath is: " + logFile.getPath());
        long fileSize = getFileSize(logFile);
        Log.d(MY_TAG, "Log max size is: " + Formatter.formatFileSize(context, 10485760L));
        Log.i(MY_TAG, "log now size is: " + Formatter.formatFileSize(context, fileSize));
        if (10485760 < fileSize) {
            resetLogFile();
        }
    }

    private static void resetLogFile() {
        Log.i(MY_TAG, "Reset Log File ... ");
        File file = new File(logFile.getParent() + "/lastLog.txt");
        if (file.exists()) {
            file.delete();
        }
        logFile.renameTo(file);
        try {
            logFile.createNewFile();
        } catch (Exception e2) {
            Log.e(MY_TAG, "Create log file failure !!! " + e2.toString());
        }
    }

    public static void write(Object obj) {
        File file;
        if (mContext == null || instance == null || (file = logFile) == null || !file.exists()) {
            Log.e(MY_TAG, "Initialization failure !!!");
            return;
        }
        String str = getFunctionInfo() + " - " + obj.toString();
        try {
            BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(logFile, true));
            bufferedWriter.write(str);
            bufferedWriter.write(IOUtils.LINE_SEPARATOR_WINDOWS);
            bufferedWriter.flush();
        } catch (Exception e2) {
            Log.e(tag, "Write failure !!! " + e2.toString());
        }
    }

    public static void write(String str, String str2) {
        write(str, str2, false);
    }

    public static void write(String str, String str2, boolean z) {
        String str3;
        File file;
        Context context = mContext;
        if (context != null && instance != null) {
            String sDPath = getSDPath(context);
            if (sDPath == null) {
                file = getLogFile(str);
            } else {
                file = new File(sDPath + "/yc_file/" + str);
            }
            if (!file.exists()) {
                File file2 = new File(file.getParent());
                if (!file2.exists()) {
                    file2.mkdirs();
                }
                try {
                    file.createNewFile();
                } catch (Exception e2) {
                    str3 = "create file(yc_file) failure !!! " + e2.toString();
                }
            }
            try {
                BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(file, z));
                bufferedWriter.write(str2);
                bufferedWriter.write(IOUtils.LINE_SEPARATOR_WINDOWS);
                bufferedWriter.flush();
                return;
            } catch (Exception e3) {
                YCBTLog.e("Write failure !!! " + e3.toString());
                return;
            }
        }
        str3 = "Initialization failure !!!";
        YCBTLog.e(str3);
    }
}
