package it.sephiroth.android.library.easing;

import android.os.Handler;
import android.os.SystemClock;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

/* loaded from: classes2.dex */
public final class EasingManager {
    static final int FPS = 60;
    static final int FRAME_TIME = 16;
    static final Handler mHandler = new Handler();
    long mBase;
    int mDuration;
    Easing mEasing;
    EasingCallback mEasingCallback;
    double mEndValue;
    boolean mInverted;
    Method mMethod;
    boolean mRunning;
    double mStartValue;
    Ticker mTicker;
    String mToken = String.valueOf(System.currentTimeMillis());
    double mValue;

    public enum EaseType {
        EaseIn,
        EaseOut,
        EaseInOut,
        EaseNone
    }

    public interface EasingCallback {
        void onEasingFinished(double d2);

        void onEasingStarted(double d2);

        void onEasingValueChanged(double d2, double d3);
    }

    public EasingManager(EasingCallback easingCallback) {
        this.mEasingCallback = easingCallback;
    }

    public void start(Class<? extends Easing> cls, EaseType easeType, double d2, double d3, int i2) {
        start(cls, easeType, d2, d3, i2, 0L);
    }

    public void start(Class<? extends Easing> cls, EaseType easeType, double d2, double d3, int i2, long j2) {
        if (this.mRunning) {
            return;
        }
        Easing createInstance = createInstance(cls);
        this.mEasing = createInstance;
        if (createInstance == null) {
            return;
        }
        Method easingMethod = getEasingMethod(createInstance, easeType);
        this.mMethod = easingMethod;
        if (easingMethod == null) {
            return;
        }
        boolean z = d2 > d3;
        this.mInverted = z;
        if (z) {
            this.mStartValue = d3;
            this.mEndValue = d2;
        } else {
            this.mStartValue = d2;
            this.mEndValue = d3;
        }
        this.mValue = this.mStartValue;
        this.mDuration = i2;
        this.mBase = SystemClock.uptimeMillis() + j2;
        this.mRunning = true;
        this.mTicker = new Ticker();
        long uptimeMillis = SystemClock.uptimeMillis() + 16 + j2;
        if (j2 == 0) {
            this.mEasingCallback.onEasingStarted(d2);
        } else {
            mHandler.postAtTime(new TickerStart(d2), this.mToken, uptimeMillis - 16);
        }
        mHandler.postAtTime(this.mTicker, this.mToken, uptimeMillis);
    }

    public void stop() {
        this.mRunning = false;
        mHandler.removeCallbacks(this.mTicker, this.mToken);
    }

    Easing createInstance(Class<? extends Easing> cls) {
        try {
            return cls.newInstance();
        } catch (IllegalAccessException e2) {
            e2.printStackTrace();
            return null;
        } catch (InstantiationException e3) {
            e3.printStackTrace();
            return null;
        }
    }

    Method getEasingMethod(Easing easing, EaseType easeType) {
        String methodName = getMethodName(easeType);
        if (methodName != null) {
            try {
                return easing.getClass().getMethod(methodName, Double.TYPE, Double.TYPE, Double.TYPE, Double.TYPE);
            } catch (NoSuchMethodException e2) {
                e2.printStackTrace();
                return null;
            } catch (SecurityException e3) {
                e3.printStackTrace();
            }
        }
        return null;
    }

    /* renamed from: it.sephiroth.android.library.easing.EasingManager$1, reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$it$sephiroth$android$library$easing$EasingManager$EaseType;

        static {
            int[] iArr = new int[EaseType.values().length];
            $SwitchMap$it$sephiroth$android$library$easing$EasingManager$EaseType = iArr;
            try {
                iArr[EaseType.EaseIn.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$it$sephiroth$android$library$easing$EasingManager$EaseType[EaseType.EaseInOut.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$it$sephiroth$android$library$easing$EasingManager$EaseType[EaseType.EaseNone.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                $SwitchMap$it$sephiroth$android$library$easing$EasingManager$EaseType[EaseType.EaseOut.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
        }
    }

    String getMethodName(EaseType easeType) {
        int i2 = AnonymousClass1.$SwitchMap$it$sephiroth$android$library$easing$EasingManager$EaseType[easeType.ordinal()];
        if (i2 == 1) {
            return "easeIn";
        }
        if (i2 == 2) {
            return "easeInOut";
        }
        if (i2 == 3) {
            return "easeNone";
        }
        if (i2 != 4) {
            return null;
        }
        return "easeOut";
    }

    class TickerStart implements Runnable {
        double mValue;

        public TickerStart(double d2) {
            this.mValue = d2;
        }

        @Override // java.lang.Runnable
        public void run() {
            EasingManager.this.mEasingCallback.onEasingStarted(this.mValue);
        }
    }

    class Ticker implements Runnable {
        Ticker() {
        }

        @Override // java.lang.Runnable
        public void run() {
            long j2 = EasingManager.this.mBase;
            long uptimeMillis = SystemClock.uptimeMillis() - j2;
            double d2 = EasingManager.this.mValue;
            try {
                double doubleValue = ((Double) EasingManager.this.mMethod.invoke(EasingManager.this.mEasing, Long.valueOf(uptimeMillis), Double.valueOf(EasingManager.this.mStartValue), Double.valueOf(EasingManager.this.mEndValue), Integer.valueOf(EasingManager.this.mDuration))).doubleValue();
                EasingManager.this.mValue = doubleValue;
                long j3 = j2 + ((((int) (uptimeMillis / 16)) + 1) * 16);
                if (uptimeMillis < EasingManager.this.mDuration) {
                    EasingCallback easingCallback = EasingManager.this.mEasingCallback;
                    if (EasingManager.this.mInverted) {
                        doubleValue = EasingManager.this.mEndValue - doubleValue;
                    }
                    easingCallback.onEasingValueChanged(doubleValue, d2);
                    EasingManager.mHandler.postAtTime(this, EasingManager.this.mToken, j3);
                    return;
                }
                EasingManager.this.mEasingCallback.onEasingFinished(EasingManager.this.mInverted ? EasingManager.this.mEndValue : EasingManager.this.mStartValue);
                EasingManager.this.mRunning = false;
            } catch (IllegalAccessException e2) {
                e2.printStackTrace();
            } catch (IllegalArgumentException e3) {
                e3.printStackTrace();
            } catch (InvocationTargetException e4) {
                e4.printStackTrace();
            }
        }
    }
}
