package jsc.kit.wheel.base;

import android.animation.Animator;
import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Camera;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.text.TextPaint;
import android.util.AttributeSet;
import android.util.Log;
import android.util.TypedValue;
import android.view.VelocityTracker;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.animation.LinearInterpolator;
import android.widget.OverScroller;
import androidx.core.view.ViewCompat;
import jsc.kit.wheel.R;

/* loaded from: classes2.dex */
public class WheelView extends View implements IWheelViewSetting {
    private static final long CLICK_EVENT_INTERNAL_TIME = 1000;
    private static final float DEFAULT_ROTATION_X = 45.0f;
    private static final int DEFAULT_VELOCITY_UNITS = 600;
    private final String TAG;
    private ValueAnimator animator;
    private float averageShowTextLength;
    private int[] calculateResult;
    private Camera camera;
    private Rect[] defaultRectArray;
    private int drawCount;
    private Rect[] drawRectArray;
    private int flingDirection;
    private boolean isAnimatorCanceledForwardly;
    private boolean isRight;
    private boolean isScrolling;
    private int itemHeight;
    private int itemVerticalSpace;
    private IWheel[] items;
    private float lastX;
    private float lastY;
    private int mMaximumVelocity;
    private int mMinimumVelocity;
    private OverScroller mOverScroller;
    private VelocityTracker mVelocityTracker;
    private Matrix matrix;
    private int offsetY;
    private OnSelectedListener onSelectedListener;
    private RectF rectF;
    private int scaledTouchSlop;
    private int selectedIndex;
    private int showCount;
    private float textBaseLine;
    private int textColor;
    private TextPaint textPaint;
    private float textSize;
    private int totalMoveY;
    private int totalOffsetX;
    private long touchDownTimeStamp;
    private String unit;
    private int velocityUnits;
    private float wheelRotationX;

    public interface OnSelectedListener {
        void onSelected(Context context, int i2);
    }

    public WheelView(Context context) {
        super(context);
        this.TAG = "WheelView";
        this.textPaint = new TextPaint(1);
        this.camera = new Camera();
        this.matrix = new Matrix();
        this.textBaseLine = 0.0f;
        this.items = null;
        this.textColor = ViewCompat.MEASURED_STATE_MASK;
        this.textSize = 0.0f;
        this.totalOffsetX = 0;
        this.averageShowTextLength = 0.0f;
        this.showCount = 5;
        this.drawCount = 5 + 2;
        this.defaultRectArray = null;
        this.drawRectArray = null;
        this.offsetY = 0;
        this.totalMoveY = 0;
        this.wheelRotationX = 0.0f;
        this.velocityUnits = 0;
        this.itemVerticalSpace = 0;
        this.itemHeight = 0;
        this.lastX = 0.0f;
        this.lastY = 0.0f;
        this.calculateResult = new int[2];
        this.selectedIndex = 0;
        this.onSelectedListener = null;
        this.animator = null;
        this.isScrolling = false;
        this.isAnimatorCanceledForwardly = false;
        this.rectF = new RectF();
        this.touchDownTimeStamp = 0L;
        this.mVelocityTracker = null;
        this.flingDirection = 0;
        initAttr(context, null, 0);
    }

    public WheelView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.TAG = "WheelView";
        this.textPaint = new TextPaint(1);
        this.camera = new Camera();
        this.matrix = new Matrix();
        this.textBaseLine = 0.0f;
        this.items = null;
        this.textColor = ViewCompat.MEASURED_STATE_MASK;
        this.textSize = 0.0f;
        this.totalOffsetX = 0;
        this.averageShowTextLength = 0.0f;
        this.showCount = 5;
        this.drawCount = 5 + 2;
        this.defaultRectArray = null;
        this.drawRectArray = null;
        this.offsetY = 0;
        this.totalMoveY = 0;
        this.wheelRotationX = 0.0f;
        this.velocityUnits = 0;
        this.itemVerticalSpace = 0;
        this.itemHeight = 0;
        this.lastX = 0.0f;
        this.lastY = 0.0f;
        this.calculateResult = new int[2];
        this.selectedIndex = 0;
        this.onSelectedListener = null;
        this.animator = null;
        this.isScrolling = false;
        this.isAnimatorCanceledForwardly = false;
        this.rectF = new RectF();
        this.touchDownTimeStamp = 0L;
        this.mVelocityTracker = null;
        this.flingDirection = 0;
        initAttr(context, attributeSet, 0);
    }

    public WheelView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.TAG = "WheelView";
        this.textPaint = new TextPaint(1);
        this.camera = new Camera();
        this.matrix = new Matrix();
        this.textBaseLine = 0.0f;
        this.items = null;
        this.textColor = ViewCompat.MEASURED_STATE_MASK;
        this.textSize = 0.0f;
        this.totalOffsetX = 0;
        this.averageShowTextLength = 0.0f;
        this.showCount = 5;
        this.drawCount = 5 + 2;
        this.defaultRectArray = null;
        this.drawRectArray = null;
        this.offsetY = 0;
        this.totalMoveY = 0;
        this.wheelRotationX = 0.0f;
        this.velocityUnits = 0;
        this.itemVerticalSpace = 0;
        this.itemHeight = 0;
        this.lastX = 0.0f;
        this.lastY = 0.0f;
        this.calculateResult = new int[2];
        this.selectedIndex = 0;
        this.onSelectedListener = null;
        this.animator = null;
        this.isScrolling = false;
        this.isAnimatorCanceledForwardly = false;
        this.rectF = new RectF();
        this.touchDownTimeStamp = 0L;
        this.mVelocityTracker = null;
        this.flingDirection = 0;
        initAttr(context, attributeSet, i2);
    }

    public void initAttr(Context context, AttributeSet attributeSet, int i2) {
        this.mOverScroller = new OverScroller(context);
        ViewConfiguration viewConfiguration = ViewConfiguration.get(context);
        this.mMinimumVelocity = viewConfiguration.getScaledMinimumFlingVelocity();
        this.mMaximumVelocity = viewConfiguration.getScaledMaximumFlingVelocity();
        this.scaledTouchSlop = viewConfiguration.getScaledTouchSlop();
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.WheelView, i2, 0);
        float applyDimension = TypedValue.applyDimension(1, 14.0f, getResources().getDisplayMetrics());
        this.textColor = obtainStyledAttributes.getColor(R.styleable.WheelView_wheelTextColor, -13421773);
        this.textSize = obtainStyledAttributes.getDimension(R.styleable.WheelView_wheelTextSize, applyDimension);
        this.showCount = obtainStyledAttributes.getInt(R.styleable.WheelView_wheelShowCount, 5);
        this.totalOffsetX = obtainStyledAttributes.getDimensionPixelSize(R.styleable.WheelView_wheelTotalOffsetX, 0);
        this.itemVerticalSpace = obtainStyledAttributes.getDimensionPixelSize(R.styleable.WheelView_wheelItemVerticalSpace, 32);
        this.wheelRotationX = obtainStyledAttributes.getFloat(R.styleable.WheelView_wheelRotationX, DEFAULT_ROTATION_X);
        int integer = obtainStyledAttributes.getInteger(R.styleable.WheelView_wheelRotationX, 600);
        this.velocityUnits = integer;
        if (integer < 0) {
            this.velocityUnits = Math.abs(integer);
        }
        obtainStyledAttributes.recycle();
        initConfig();
        if (isInEditMode()) {
            IWheel[] iWheelArr = new IWheel[50];
            for (int i3 = 0; i3 < 50; i3++) {
                StringBuilder sb = new StringBuilder("菜单选项");
                sb.append(i3 < 10 ? "0" + i3 : String.valueOf(i3));
                iWheelArr[i3] = new WheelItem(sb.toString());
            }
            setItems(iWheelArr);
        }
    }

    private void initConfig() {
        this.textPaint.setColor(this.textColor);
        this.textPaint.setTextSize(this.textSize);
        Paint.FontMetrics fontMetrics = this.textPaint.getFontMetrics();
        Rect rect = new Rect();
        this.textPaint.getTextBounds("菜单选项", 0, 4, rect);
        int height = rect.height() + this.itemVerticalSpace;
        this.itemHeight = height;
        this.textBaseLine = (((-height) / 2.0f) + (((height - fontMetrics.bottom) + fontMetrics.top) / 2.0f)) - fontMetrics.top;
        System.out.println("chong-------textsize==" + this.textSize + "--itemheight==" + this.itemHeight);
        if (this.showCount < 5) {
            this.showCount = 5;
        }
        int i2 = this.showCount;
        if (i2 % 2 == 0) {
            this.showCount = i2 + 1;
        }
        int i3 = this.showCount + 2;
        this.drawCount = i3;
        this.defaultRectArray = new Rect[i3];
        this.drawRectArray = new Rect[i3];
        for (int i4 = 0; i4 < this.drawCount; i4++) {
            this.defaultRectArray[i4] = new Rect();
            this.drawRectArray[i4] = new Rect();
        }
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setTextSize(float f2) {
        this.textSize = f2;
        initConfig();
        requestLayout();
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setTextColor(int i2) {
        this.textColor = i2;
        this.textPaint.setColor(i2);
        invalidate();
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setShowCount(int i2) {
        this.showCount = i2;
        initConfig();
        requestLayout();
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setTotalOffsetX(int i2) {
        this.totalOffsetX = i2;
        invalidate();
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setItemVerticalSpace(int i2) {
        this.itemVerticalSpace = i2;
        initConfig();
        requestLayout();
    }

    public void setVelocityUnits(int i2) {
        this.velocityUnits = Math.abs(i2);
    }

    @Override // android.view.View
    protected void onMeasure(int i2, int i3) {
        int i4 = 0 - this.itemHeight;
        for (int i5 = 0; i5 < this.drawCount; i5++) {
            this.defaultRectArray[i5].set(0, i4, 0, this.itemHeight + i4);
            i4 += this.itemHeight;
        }
        super.onMeasure(i2, View.MeasureSpec.makeMeasureSpec(this.itemHeight * this.showCount, 1073741824));
    }

    /* JADX WARN: Code restructure failed: missing block: B:12:0x001f, code lost:
    
        if (r1 != 3) goto L41;
     */
    @Override // android.view.View
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public boolean onTouchEvent(android.view.MotionEvent r19) {
        /*
            Method dump skipped, instructions count: 294
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: jsc.kit.wheel.base.WheelView.onTouchEvent(android.view.MotionEvent):boolean");
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setOnSelectedListener(OnSelectedListener onSelectedListener) {
        this.onSelectedListener = onSelectedListener;
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setItems(IWheel[] iWheelArr) {
        this.items = iWheelArr;
        if (isEmpty()) {
            return;
        }
        this.averageShowTextLength = calAverageShowTextLength();
        invalidate();
    }

    public int getItemHeight() {
        return this.itemHeight;
    }

    public int getShowCount() {
        return this.showCount;
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public int getSelectedIndex() {
        return this.selectedIndex;
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setSelectedIndex(int i2) {
        setSelectedIndex(i2, true);
    }

    public void setWheelRotationX(float f2) {
        if (this.wheelRotationX != f2) {
            this.wheelRotationX = f2;
            invalidate();
        }
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public void setSelectedIndex(int i2, boolean z) {
        if (i2 < 0 || i2 >= getItemCount()) {
            throw new IndexOutOfBoundsException("Out of array bounds.");
        }
        if (z) {
            executeAnimation(this.totalMoveY, 0 - (this.itemHeight * i2));
            return;
        }
        this.totalMoveY = 0 - (this.itemHeight * i2);
        this.selectedIndex = i2;
        this.offsetY = 0;
        invalidate();
        OnSelectedListener onSelectedListener = this.onSelectedListener;
        if (onSelectedListener != null) {
            onSelectedListener.onSelected(getContext(), this.selectedIndex);
        }
    }

    @Override // jsc.kit.wheel.base.IWheelViewSetting
    public boolean isScrolling() {
        return this.isScrolling;
    }

    private float calAverageShowTextLength() {
        float f2 = 0.0f;
        for (IWheel iWheel : this.items) {
            String showText = iWheel.getShowText();
            if (showText != null && showText.length() != 0) {
                f2 += this.textPaint.measureText(showText);
            }
        }
        return f2 / getItemCount();
    }

    private void executeClickEvent(float f2, float f3) {
        int i2 = this.selectedIndex - (this.drawCount / 2);
        boolean z = false;
        int i3 = 0;
        while (true) {
            if (i3 >= this.drawCount) {
                break;
            }
            this.rectF.set(this.drawRectArray[i3]);
            if (this.rectF.contains(f2, f3)) {
                z = true;
                break;
            } else {
                i2++;
                i3++;
            }
        }
        if (!z || i2 < 0 || i2 >= getItemCount()) {
            return;
        }
        setSelectedIndex(i2);
    }

    private int getItemCount() {
        IWheel[] iWheelArr = this.items;
        if (iWheelArr == null) {
            return 0;
        }
        return iWheelArr.length;
    }

    private IWheel getItemAt(int i2) {
        if (isEmpty() || i2 < 0 || i2 >= getItemCount()) {
            return null;
        }
        return this.items[i2];
    }

    private boolean isEmpty() {
        return getItemCount() == 0;
    }

    private void executeAnimation(int... iArr) {
        if (invalidAnimation(iArr)) {
            OnSelectedListener onSelectedListener = this.onSelectedListener;
            if (onSelectedListener != null) {
                onSelectedListener.onSelected(getContext(), this.selectedIndex);
                return;
            }
            return;
        }
        int i2 = 0;
        for (int i3 = 0; i3 < iArr.length; i3++) {
            if (i3 > 0) {
                i2 += Math.abs(iArr[i3] - iArr[i3 - 1]);
            }
        }
        if (i2 == 0) {
            OnSelectedListener onSelectedListener2 = this.onSelectedListener;
            if (onSelectedListener2 != null) {
                onSelectedListener2.onSelected(getContext(), this.selectedIndex);
                return;
            }
            return;
        }
        createAnimatorIfNecessary();
        if (this.animator.isRunning()) {
            this.isAnimatorCanceledForwardly = true;
            this.animator.cancel();
        }
        this.animator.setIntValues(iArr);
        this.animator.setDuration(calSuitableDuration(i2));
        this.animator.start();
    }

    private boolean invalidAnimation(int... iArr) {
        if (iArr != null && iArr.length >= 2) {
            int i2 = iArr[0];
            for (int i3 : iArr) {
                if (i2 != i3) {
                    return false;
                }
            }
        }
        return true;
    }

    private int calSuitableDuration(int i2) {
        while (i2 > 1200) {
            i2 /= 2;
        }
        return i2;
    }

    private void createAnimatorIfNecessary() {
        if (this.animator == null) {
            ValueAnimator valueAnimator = new ValueAnimator();
            this.animator = valueAnimator;
            valueAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: jsc.kit.wheel.base.WheelView.1
                @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                public void onAnimationUpdate(ValueAnimator valueAnimator2) {
                    WheelView.this.updateByTotalMoveY(((Integer) valueAnimator2.getAnimatedValue()).intValue(), 0);
                }
            });
            this.animator.setInterpolator(new LinearInterpolator());
            this.animator.addListener(new Animator.AnimatorListener() { // from class: jsc.kit.wheel.base.WheelView.2
                @Override // android.animation.Animator.AnimatorListener
                public void onAnimationCancel(Animator animator) {
                }

                @Override // android.animation.Animator.AnimatorListener
                public void onAnimationRepeat(Animator animator) {
                }

                @Override // android.animation.Animator.AnimatorListener
                public void onAnimationStart(Animator animator) {
                    WheelView.this.isScrolling = true;
                }

                @Override // android.animation.Animator.AnimatorListener
                public void onAnimationEnd(Animator animator) {
                    WheelView.this.isScrolling = false;
                    if (WheelView.this.isAnimatorCanceledForwardly) {
                        WheelView.this.isAnimatorCanceledForwardly = false;
                    } else if (WheelView.this.onSelectedListener != null) {
                        WheelView.this.onSelectedListener.onSelected(WheelView.this.getContext(), WheelView.this.selectedIndex);
                    }
                }
            });
        }
    }

    public int getTotalMoveY() {
        return this.totalMoveY;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void updateByTotalMoveY(int i2, int i3) {
        calculateSelectedIndex(i2, i3);
        this.totalMoveY = i2;
        int[] iArr = this.calculateResult;
        this.selectedIndex = iArr[0];
        this.offsetY = iArr[1];
        invalidate();
    }

    private void calculateSelectedIndex(int i2, int i3) {
        int i4 = this.itemHeight;
        int i5 = i2 / (0 - i4);
        int i6 = i2 % (0 - i4);
        if (i3 > 0 && i6 != 0) {
            i5++;
            i6 = i4 - Math.abs(i6);
        }
        if (i3 < 0 && Math.abs(i6) >= this.itemHeight / 4) {
            i5++;
        }
        if (i3 > 0 && Math.abs(i6) >= this.itemHeight / 4) {
            i5--;
        }
        int min = Math.min(Math.max(i5, 0), getItemCount() - 1);
        int i7 = (0 - (this.itemHeight * min)) - i2;
        int[] iArr = this.calculateResult;
        iArr[0] = min;
        iArr[1] = i7;
    }

    @Override // android.view.View
    public void computeScroll() {
        if (this.mOverScroller.computeScrollOffset()) {
            int currY = this.mOverScroller.getCurrY();
            this.totalMoveY = currY;
            updateByTotalMoveY(currY, 0);
            invalidate();
            return;
        }
        int i2 = this.flingDirection;
        if (i2 != 0) {
            this.flingDirection = 0;
            calculateSelectedIndex(this.totalMoveY, i2);
            int[] iArr = this.calculateResult;
            int i3 = iArr[0];
            this.selectedIndex = i3;
            this.offsetY = iArr[1];
            executeAnimation(this.totalMoveY, 0 - (i3 * this.itemHeight));
        }
    }

    public void setUnit(String str, boolean z) {
        this.unit = str;
        this.isRight = z;
        invalidate();
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        if (isEmpty()) {
            return;
        }
        int i2 = this.selectedIndex - (this.drawCount / 2);
        for (int i3 = 0; i3 < this.drawCount; i3++) {
            Rect rect = this.drawRectArray[i3];
            rect.set(this.defaultRectArray[i3]);
            rect.left = 0;
            rect.right = getWidth();
            if (i2 >= 0 && i2 < getItemCount()) {
                drawItem(canvas, rect, getItemAt(i2) == null ? "" : getItemAt(i2).getShowText(), -this.offsetY, this.textPaint, getSelectedIndex() == i2);
            }
            i2++;
        }
        computeScroll();
    }

    private void drawItem(Canvas canvas, Rect rect, String str, int i2, TextPaint textPaint, boolean z) {
        float width;
        float f2;
        if (str == null || str.trim().length() == 0) {
            return;
        }
        rect.offset(0, i2);
        textPaint.setAlpha(calAlpha(rect));
        int i3 = this.totalOffsetX;
        int calOffsetX = i3 != 0 ? calOffsetX(i3, rect) : 0;
        float measureText = textPaint.measureText(str);
        int i4 = this.totalOffsetX;
        if (i4 > 0) {
            f2 = ((getWidth() + this.averageShowTextLength) / 2.0f) - measureText;
        } else {
            if (i4 < 0) {
                width = getWidth() - this.averageShowTextLength;
            } else {
                width = getWidth() - measureText;
            }
            f2 = width / 2.0f;
        }
        float f3 = f2 + calOffsetX;
        float width2 = getWidth() / 2.0f;
        float exactCenterY = rect.exactCenterY();
        float f4 = this.textBaseLine + exactCenterY;
        Log.d("WheelView", "centerY=" + exactCenterY + "  textBaseLine=" + this.textBaseLine + "  baseLine=" + f4);
        this.matrix.reset();
        this.camera.save();
        this.camera.rotateX(calRotationX(rect, this.wheelRotationX));
        this.camera.getMatrix(this.matrix);
        this.camera.restore();
        this.matrix.preTranslate(-width2, -exactCenterY);
        this.matrix.postTranslate(width2, exactCenterY);
        int i5 = this.totalOffsetX;
        if (i5 > 0) {
            this.matrix.setSkew(0.0f - calSkewX(rect), 0.0f, (measureText + f3) / 2.0f, exactCenterY);
        } else if (i5 < 0) {
            this.matrix.setSkew(calSkewX(rect), 0.0f, (measureText + f3) / 2.0f, exactCenterY);
        }
        canvas.save();
        canvas.concat(this.matrix);
        canvas.drawText(str, f3, f4, textPaint);
        if (z) {
            if (this.isRight) {
                canvas.drawText(this.unit, f3 + textPaint.measureText(str) + (getContext().getResources().getDisplayMetrics().density * 10.0f), f4, textPaint);
            } else {
                String str2 = this.unit;
                canvas.drawText(str2, (f3 - textPaint.measureText(str2)) - (getContext().getResources().getDisplayMetrics().density * 10.0f), f4, textPaint);
            }
        }
        canvas.restore();
    }

    private int calAlpha(Rect rect) {
        return (int) ((1.0f - ((Math.abs((getHeight() / 2) - rect.centerY()) * 0.6f) / (this.itemHeight * (this.showCount / 2)))) * 255.0f);
    }

    private float calRotationX(Rect rect, float f2) {
        return ((f2 * ((getHeight() / 2) - rect.centerY())) * 1.0f) / (this.itemHeight * (this.showCount / 2));
    }

    private float calSkewX(Rect rect) {
        return (((getHeight() / 2) - rect.centerY()) * 0.3f) / (this.itemHeight * (this.showCount / 2));
    }

    private int calOffsetX(int i2, Rect rect) {
        return (i2 * Math.abs((getHeight() / 2) - rect.centerY())) / (this.itemHeight * (this.showCount / 2));
    }

    private void initVelocityTrackerIfNotExists() {
        if (this.mVelocityTracker == null) {
            this.mVelocityTracker = VelocityTracker.obtain();
        }
    }

    private void recycleVelocityTracker() {
        VelocityTracker velocityTracker = this.mVelocityTracker;
        if (velocityTracker != null) {
            velocityTracker.recycle();
            this.mVelocityTracker = null;
        }
    }
}
