package no.nordicsemi.android.dfu;

import android.os.SystemClock;

/* loaded from: classes4.dex */
class DfuProgressInfo {
    private int bytesReceived;
    private int bytesSent;
    private int currentPart;
    private int imageSizeInBytes;
    private int initialBytesSent;
    private int lastBytesSent;
    private long lastProgressTime;
    private final ProgressListener mListener;
    private int maxObjectSizeInBytes;
    private int progress;
    private long timeStart;
    private int totalParts;

    interface ProgressListener {
        void updateProgressNotification();
    }

    DfuProgressInfo(ProgressListener progressListener) {
        this.mListener = progressListener;
    }

    void init(int i2, int i3, int i4) {
        this.imageSizeInBytes = i2;
        this.maxObjectSizeInBytes = Integer.MAX_VALUE;
        this.currentPart = i3;
        this.totalParts = i4;
    }

    DfuProgressInfo setTotalPart(int i2) {
        this.totalParts = i2;
        return this;
    }

    void setProgress(int i2) {
        this.progress = i2;
        this.mListener.updateProgressNotification();
    }

    void setBytesSent(int i2) {
        if (this.timeStart == 0) {
            this.timeStart = SystemClock.elapsedRealtime();
            this.initialBytesSent = i2;
        }
        this.bytesSent = i2;
        this.progress = (int) ((i2 * 100.0f) / this.imageSizeInBytes);
        this.mListener.updateProgressNotification();
    }

    void addBytesSent(int i2) {
        setBytesSent(this.bytesSent + i2);
    }

    void setBytesReceived(int i2) {
        this.bytesReceived = i2;
    }

    void setMaxObjectSizeInBytes(int i2) {
        this.maxObjectSizeInBytes = i2;
    }

    boolean isComplete() {
        return this.bytesSent == this.imageSizeInBytes;
    }

    boolean isObjectComplete() {
        return this.bytesSent % this.maxObjectSizeInBytes == 0;
    }

    int getAvailableObjectSizeIsBytes() {
        int i2 = this.imageSizeInBytes;
        int i3 = this.bytesSent;
        int i4 = this.maxObjectSizeInBytes;
        return Math.min(i2 - i3, i4 - (i3 % i4));
    }

    int getProgress() {
        return this.progress;
    }

    int getBytesSent() {
        return this.bytesSent;
    }

    int getBytesReceived() {
        return this.bytesReceived;
    }

    int getImageSizeInBytes() {
        return this.imageSizeInBytes;
    }

    float getSpeed() {
        long elapsedRealtime = SystemClock.elapsedRealtime();
        float f2 = elapsedRealtime - this.timeStart != 0 ? (this.bytesSent - this.lastBytesSent) / (elapsedRealtime - this.lastProgressTime) : 0.0f;
        this.lastProgressTime = elapsedRealtime;
        this.lastBytesSent = this.bytesSent;
        return f2;
    }

    float getAverageSpeed() {
        if (SystemClock.elapsedRealtime() - this.timeStart != 0) {
            return (this.bytesSent - this.initialBytesSent) / (r0 - r2);
        }
        return 0.0f;
    }

    int getCurrentPart() {
        return this.currentPart;
    }

    int getTotalParts() {
        return this.totalParts;
    }

    boolean isLastPart() {
        return this.currentPart == this.totalParts;
    }
}
