package no.nordicsemi.android.error;

import com.google.firebase.crashlytics.buildtools.ndk.internal.elf.EMachine;
import com.jieli.jl_rcsp.model.SportHealthConfigure;

/* loaded from: classes4.dex */
public class GattError {
    public static String parseConnectionError(int i2) {
        if (i2 == 0) {
            return "SUCCESS";
        }
        if (i2 == 1) {
            return "GATT CONN L2C FAILURE";
        }
        if (i2 == 8) {
            return "GATT CONN TIMEOUT";
        }
        if (i2 == 19) {
            return "GATT CONN TERMINATE PEER USER";
        }
        if (i2 == 22) {
            return "GATT CONN TERMINATE LOCAL HOST";
        }
        if (i2 == 34) {
            return "GATT CONN LMP TIMEOUT";
        }
        if (i2 == 62) {
            return "GATT CONN FAIL ESTABLISH";
        }
        if (i2 == 133) {
            return "GATT ERROR";
        }
        if (i2 == 256) {
            return "GATT CONN CANCEL ";
        }
        return "UNKNOWN (" + i2 + ")";
    }

    public static String parse(int i2) {
        if (i2 == 26) {
            return "HCI ERROR UNSUPPORTED REMOTE FEATURE";
        }
        if (i2 == 30) {
            return "HCI ERROR INVALID LMP PARAM";
        }
        if (i2 == 34) {
            return "GATT CONN LMP TIMEOUT";
        }
        if (i2 == 42) {
            return "HCI ERROR DIFF TRANSACTION COLLISION";
        }
        if (i2 == 257) {
            return "TOO MANY OPEN CONNECTIONS";
        }
        if (i2 == 58) {
            return "GATT CONTROLLER BUSY";
        }
        if (i2 == 59) {
            return "GATT UNACCEPT CONN INTERVAL";
        }
        switch (i2) {
            case 1:
                return "GATT INVALID HANDLE";
            case 2:
                return "GATT READ NOT PERMIT";
            case 3:
                return "GATT WRITE NOT PERMIT";
            case 4:
                return "GATT INVALID PDU";
            case 5:
                return "GATT INSUF AUTHENTICATION";
            case 6:
                return "GATT REQ NOT SUPPORTED";
            case 7:
                return "GATT INVALID OFFSET";
            case 8:
                return "GATT INSUF AUTHORIZATION";
            case 9:
                return "GATT PREPARE Q FULL";
            case 10:
                return "GATT NOT FOUND";
            case 11:
                return "GATT NOT LONG";
            case 12:
                return "GATT INSUF KEY SIZE";
            case 13:
                return "GATT INVALID ATTR LEN";
            case 14:
                return "GATT ERR UNLIKELY";
            case 15:
                return "GATT INSUF ENCRYPTION";
            case 16:
                return "GATT UNSUPPORT GRP TYPE";
            case 17:
                return "GATT INSUF RESOURCE";
            default:
                switch (i2) {
                    case 128:
                        return "GATT NO RESOURCES";
                    case 129:
                        return "GATT INTERNAL ERROR";
                    case 130:
                        return "GATT WRONG STATE";
                    case EMachine.EM_TSK3000 /* 131 */:
                        return "GATT DB FULL";
                    case 132:
                        return "GATT BUSY";
                    case 133:
                        return "GATT ERROR";
                    case EMachine.EM_ECOG2 /* 134 */:
                        return "GATT CMD STARTED";
                    case EMachine.EM_SCORE7 /* 135 */:
                        return "GATT ILLEGAL PARAMETER";
                    case EMachine.EM_DSP24 /* 136 */:
                        return "GATT PENDING";
                    case EMachine.EM_VIDEOCORE3 /* 137 */:
                        return "GATT AUTH FAIL";
                    case EMachine.EM_LATTICEMICO32 /* 138 */:
                        return "GATT MORE";
                    case EMachine.EM_SE_C17 /* 139 */:
                        return "GATT INVALID CFG";
                    case 140:
                        return "GATT SERVICE STARTED";
                    case EMachine.EM_TI_C2000 /* 141 */:
                        return "GATT ENCRYPTED NO MITM";
                    case EMachine.EM_TI_C5500 /* 142 */:
                        return "GATT NOT ENCRYPTED";
                    case 143:
                        return "GATT CONGESTED";
                    default:
                        switch (i2) {
                            case 253:
                                return "GATT CCCD CFG ERROR";
                            case SportHealthConfigure.CONFIGURE_TYPE_SPORT_MODE /* 254 */:
                                return "GATT PROCEDURE IN PROGRESS";
                            case 255:
                                return "GATT VALUE OUT OF RANGE";
                            default:
                                switch (i2) {
                                    case 4096:
                                        return "DFU DEVICE DISCONNECTED";
                                    case 4097:
                                        return "DFU FILE NOT FOUND";
                                    case 4098:
                                        return "DFU FILE ERROR";
                                    case 4099:
                                        return "DFU NOT A VALID HEX FILE";
                                    case 4100:
                                        return "DFU IO EXCEPTION";
                                    case 4101:
                                        return "DFU SERVICE DISCOVERY NOT STARTED";
                                    case 4102:
                                        return "DFU CHARACTERISTICS NOT FOUND";
                                    default:
                                        switch (i2) {
                                            case 4104:
                                                return "DFU INVALID RESPONSE";
                                            case 4105:
                                                return "DFU FILE TYPE NOT SUPPORTED";
                                            case 4106:
                                                return "BLUETOOTH ADAPTER DISABLED";
                                            case 4107:
                                            case 4108:
                                                return "DFU INIT PACKET REQUIRED";
                                            case 4109:
                                                return "DFU CRC ERROR";
                                            case 4110:
                                                return "DFU DEVICE NOT BONDED";
                                            default:
                                                return "UNKNOWN (" + i2 + ")";
                                        }
                                }
                        }
                }
        }
    }

    public static String parseDfuRemoteError(int i2) {
        int i3 = i2 & 3840;
        if (i3 == 256) {
            return LegacyDfuError.parse(i2);
        }
        if (i3 == 512) {
            return SecureDfuError.parse(i2);
        }
        if (i3 == 1024) {
            return SecureDfuError.parseExtendedError(i2);
        }
        if (i3 == 2048) {
            return SecureDfuError.parseButtonlessError(i2);
        }
        return "UNKNOWN (" + i2 + ")";
    }
}
