package org.apache.commons.lang3;

/* loaded from: classes4.dex */
public class CharSequenceUtils {
    private static final int NOT_FOUND = -1;
    static final int TO_STRING_LIMIT = 16;

    public static CharSequence subSequence(CharSequence charSequence, int i2) {
        if (charSequence == null) {
            return null;
        }
        return charSequence.subSequence(i2, charSequence.length());
    }

    static int indexOf(CharSequence charSequence, int i2, int i3) {
        if (charSequence instanceof String) {
            return ((String) charSequence).indexOf(i2, i3);
        }
        int length = charSequence.length();
        if (i3 < 0) {
            i3 = 0;
        }
        if (i2 < 65536) {
            for (int i4 = i3; i4 < length; i4++) {
                if (charSequence.charAt(i4) == i2) {
                    return i4;
                }
            }
        }
        if (i2 > 1114111) {
            return -1;
        }
        char[] chars = Character.toChars(i2);
        while (i3 < length - 1) {
            char charAt = charSequence.charAt(i3);
            int i5 = i3 + 1;
            char charAt2 = charSequence.charAt(i5);
            if (charAt == chars[0] && charAt2 == chars[1]) {
                return i3;
            }
            i3 = i5;
        }
        return -1;
    }

    static int indexOf(CharSequence charSequence, CharSequence charSequence2, int i2) {
        if (charSequence instanceof String) {
            return ((String) charSequence).indexOf(charSequence2.toString(), i2);
        }
        if (charSequence instanceof StringBuilder) {
            return ((StringBuilder) charSequence).indexOf(charSequence2.toString(), i2);
        }
        if (charSequence instanceof StringBuffer) {
            return ((StringBuffer) charSequence).indexOf(charSequence2.toString(), i2);
        }
        return charSequence.toString().indexOf(charSequence2.toString(), i2);
    }

    static int lastIndexOf(CharSequence charSequence, int i2, int i3) {
        if (charSequence instanceof String) {
            return ((String) charSequence).lastIndexOf(i2, i3);
        }
        int length = charSequence.length();
        if (i3 < 0) {
            return -1;
        }
        if (i3 >= length) {
            i3 = length - 1;
        }
        if (i2 < 65536) {
            for (int i4 = i3; i4 >= 0; i4--) {
                if (charSequence.charAt(i4) == i2) {
                    return i4;
                }
            }
        }
        if (i2 <= 1114111) {
            char[] chars = Character.toChars(i2);
            if (i3 == length - 1) {
                return -1;
            }
            while (i3 >= 0) {
                char charAt = charSequence.charAt(i3);
                char charAt2 = charSequence.charAt(i3 + 1);
                if (chars[0] == charAt && chars[1] == charAt2) {
                    return i3;
                }
                i3--;
            }
        }
        return -1;
    }

    static int lastIndexOf(CharSequence charSequence, CharSequence charSequence2, int i2) {
        if (charSequence2 instanceof String) {
            if (charSequence instanceof String) {
                return ((String) charSequence).lastIndexOf((String) charSequence2, i2);
            }
            if (charSequence instanceof StringBuilder) {
                return ((StringBuilder) charSequence).lastIndexOf((String) charSequence2, i2);
            }
            if (charSequence instanceof StringBuffer) {
                return ((StringBuffer) charSequence).lastIndexOf((String) charSequence2, i2);
            }
        }
        int length = charSequence.length();
        int length2 = charSequence2.length();
        if (i2 > length) {
            i2 = length;
        }
        if (i2 >= 0 && length2 >= 0 && length2 <= length) {
            if (length2 == 0) {
                return i2;
            }
            if (length2 <= 16) {
                if (charSequence instanceof String) {
                    return ((String) charSequence).lastIndexOf(charSequence2.toString(), i2);
                }
                if (charSequence instanceof StringBuilder) {
                    return ((StringBuilder) charSequence).lastIndexOf(charSequence2.toString(), i2);
                }
                if (charSequence instanceof StringBuffer) {
                    return ((StringBuffer) charSequence).lastIndexOf(charSequence2.toString(), i2);
                }
            }
            if (i2 + length2 > length) {
                i2 = length - length2;
            }
            char charAt = charSequence2.charAt(0);
            while (true) {
                if (charSequence.charAt(i2) != charAt) {
                    i2--;
                    if (i2 < 0) {
                        return -1;
                    }
                } else {
                    if (checkLaterThan1(charSequence, charSequence2, length2, i2)) {
                        return i2;
                    }
                    i2--;
                    if (i2 < 0) {
                        break;
                    }
                }
            }
        }
        return -1;
    }

    private static boolean checkLaterThan1(CharSequence charSequence, CharSequence charSequence2, int i2, int i3) {
        int i4 = 1;
        for (int i5 = i2 - 1; i4 <= i5; i5--) {
            if (charSequence.charAt(i3 + i4) != charSequence2.charAt(i4) || charSequence.charAt(i3 + i5) != charSequence2.charAt(i5)) {
                return false;
            }
            i4++;
        }
        return true;
    }

    public static char[] toCharArray(CharSequence charSequence) {
        int length = StringUtils.length(charSequence);
        if (length == 0) {
            return ArrayUtils.EMPTY_CHAR_ARRAY;
        }
        if (charSequence instanceof String) {
            return ((String) charSequence).toCharArray();
        }
        char[] cArr = new char[length];
        for (int i2 = 0; i2 < length; i2++) {
            cArr[i2] = charSequence.charAt(i2);
        }
        return cArr;
    }

    static boolean regionMatches(CharSequence charSequence, boolean z, int i2, CharSequence charSequence2, int i3, int i4) {
        if ((charSequence instanceof String) && (charSequence2 instanceof String)) {
            return ((String) charSequence).regionMatches(z, i2, (String) charSequence2, i3, i4);
        }
        int length = charSequence.length() - i2;
        int length2 = charSequence2.length() - i3;
        if (i2 < 0 || i3 < 0 || i4 < 0 || length < i4 || length2 < i4) {
            return false;
        }
        while (true) {
            int i5 = i4 - 1;
            if (i4 <= 0) {
                return true;
            }
            int i6 = i2 + 1;
            char charAt = charSequence.charAt(i2);
            int i7 = i3 + 1;
            char charAt2 = charSequence2.charAt(i3);
            if (charAt != charAt2) {
                if (!z) {
                    return false;
                }
                char upperCase = Character.toUpperCase(charAt);
                char upperCase2 = Character.toUpperCase(charAt2);
                if (upperCase != upperCase2 && Character.toLowerCase(upperCase) != Character.toLowerCase(upperCase2)) {
                    return false;
                }
            }
            i2 = i6;
            i4 = i5;
            i3 = i7;
        }
    }
}
