package org.apache.commons.lang3;

import com.tencent.connect.common.Constants;
import org.apache.commons.lang3.math.NumberUtils;

/* loaded from: classes4.dex */
public enum JavaVersion {
    JAVA_0_9(1.5f, "0.9"),
    JAVA_1_1(1.1f, "1.1"),
    JAVA_1_2(1.2f, "1.2"),
    JAVA_1_3(1.3f, "1.3"),
    JAVA_1_4(1.4f, "1.4"),
    JAVA_1_5(1.5f, "1.5"),
    JAVA_1_6(1.6f, "1.6"),
    JAVA_1_7(1.7f, "1.7"),
    JAVA_1_8(1.8f, "1.8"),
    JAVA_1_9(9.0f, Constants.VIA_SHARE_TYPE_MINI_PROGRAM),
    JAVA_9(9.0f, Constants.VIA_SHARE_TYPE_MINI_PROGRAM),
    JAVA_10(10.0f, Constants.VIA_REPORT_TYPE_SHARE_TO_QQ),
    JAVA_11(11.0f, Constants.VIA_REPORT_TYPE_SHARE_TO_QZONE),
    JAVA_12(12.0f, Constants.VIA_REPORT_TYPE_SET_AVATAR),
    JAVA_13(13.0f, Constants.VIA_REPORT_TYPE_JOININ_GROUP),
    JAVA_14(14.0f, Constants.VIA_REPORT_TYPE_MAKE_FRIEND),
    JAVA_15(15.0f, Constants.VIA_REPORT_TYPE_WPA_STATE),
    JAVA_16(16.0f, Constants.VIA_REPORT_TYPE_START_WAP),
    JAVA_RECENT(maxVersion(), Float.toString(maxVersion()));

    private final String name;
    private final float value;

    JavaVersion(float f2, String str) {
        this.value = f2;
        this.name = str;
    }

    public boolean atLeast(JavaVersion javaVersion) {
        return this.value >= javaVersion.value;
    }

    public boolean atMost(JavaVersion javaVersion) {
        return this.value <= javaVersion.value;
    }

    static JavaVersion getJavaVersion(String str) {
        return get(str);
    }

    static JavaVersion get(String str) {
        if (str == null) {
            return null;
        }
        if ("0.9".equals(str)) {
            return JAVA_0_9;
        }
        if ("1.1".equals(str)) {
            return JAVA_1_1;
        }
        if ("1.2".equals(str)) {
            return JAVA_1_2;
        }
        if ("1.3".equals(str)) {
            return JAVA_1_3;
        }
        if ("1.4".equals(str)) {
            return JAVA_1_4;
        }
        if ("1.5".equals(str)) {
            return JAVA_1_5;
        }
        if ("1.6".equals(str)) {
            return JAVA_1_6;
        }
        if ("1.7".equals(str)) {
            return JAVA_1_7;
        }
        if ("1.8".equals(str)) {
            return JAVA_1_8;
        }
        if (Constants.VIA_SHARE_TYPE_MINI_PROGRAM.equals(str)) {
            return JAVA_9;
        }
        if (Constants.VIA_REPORT_TYPE_SHARE_TO_QQ.equals(str)) {
            return JAVA_10;
        }
        if (Constants.VIA_REPORT_TYPE_SHARE_TO_QZONE.equals(str)) {
            return JAVA_11;
        }
        if (Constants.VIA_REPORT_TYPE_SET_AVATAR.equals(str)) {
            return JAVA_12;
        }
        if (Constants.VIA_REPORT_TYPE_JOININ_GROUP.equals(str)) {
            return JAVA_13;
        }
        if (Constants.VIA_REPORT_TYPE_MAKE_FRIEND.equals(str)) {
            return JAVA_14;
        }
        if (Constants.VIA_REPORT_TYPE_WPA_STATE.equals(str)) {
            return JAVA_15;
        }
        if (Constants.VIA_REPORT_TYPE_START_WAP.equals(str)) {
            return JAVA_16;
        }
        float floatVersion = toFloatVersion(str);
        if (floatVersion - 1.0d < 1.0d) {
            int max = Math.max(str.indexOf(46), str.indexOf(44));
            if (Float.parseFloat(str.substring(max + 1, Math.max(str.length(), str.indexOf(44, max)))) > 0.9f) {
                return JAVA_RECENT;
            }
        } else if (floatVersion > 10.0f) {
            return JAVA_RECENT;
        }
        return null;
    }

    @Override // java.lang.Enum
    public String toString() {
        return this.name;
    }

    private static float maxVersion() {
        float floatVersion = toFloatVersion(System.getProperty("java.specification.version", "99.0"));
        if (floatVersion > 0.0f) {
            return floatVersion;
        }
        return 99.0f;
    }

    private static float toFloatVersion(String str) {
        if (str.contains(".")) {
            String[] split = str.split("\\.");
            if (split.length < 2) {
                return -1.0f;
            }
            return NumberUtils.toFloat(split[0] + '.' + split[1], -1.0f);
        }
        return NumberUtils.toFloat(str, -1.0f);
    }
}
