package org.apache.commons.text.matcher;

import java.util.Arrays;
import org.apache.commons.lang3.CharSequenceUtils;
import org.apache.commons.text.matcher.StringMatcher;

/* loaded from: classes4.dex */
abstract class AbstractStringMatcher implements StringMatcher {
    @Override // org.apache.commons.text.matcher.StringMatcher
    public /* synthetic */ StringMatcher andThen(StringMatcher stringMatcher) {
        StringMatcher andMatcher;
        andMatcher = StringMatcherFactory.INSTANCE.andMatcher(this, stringMatcher);
        return andMatcher;
    }

    @Override // org.apache.commons.text.matcher.StringMatcher
    public /* synthetic */ int isMatch(CharSequence charSequence, int i2) {
        int isMatch;
        isMatch = isMatch(charSequence, i2, 0, charSequence.length());
        return isMatch;
    }

    @Override // org.apache.commons.text.matcher.StringMatcher
    public /* synthetic */ int isMatch(CharSequence charSequence, int i2, int i3, int i4) {
        int isMatch;
        isMatch = isMatch(CharSequenceUtils.toCharArray(charSequence), i2, i4, i4);
        return isMatch;
    }

    @Override // org.apache.commons.text.matcher.StringMatcher
    public /* synthetic */ int isMatch(char[] cArr, int i2) {
        int isMatch;
        isMatch = isMatch(cArr, i2, 0, cArr.length);
        return isMatch;
    }

    @Override // org.apache.commons.text.matcher.StringMatcher
    public /* synthetic */ int size() {
        return StringMatcher.CC.$default$size(this);
    }

    static final class AndStringMatcher extends AbstractStringMatcher {
        private final StringMatcher[] stringMatchers;

        AndStringMatcher(StringMatcher... stringMatcherArr) {
            this.stringMatchers = (StringMatcher[]) stringMatcherArr.clone();
        }

        @Override // org.apache.commons.text.matcher.StringMatcher
        public int isMatch(char[] cArr, int i2, int i3, int i4) {
            int i5 = 0;
            for (StringMatcher stringMatcher : this.stringMatchers) {
                if (stringMatcher != null) {
                    int isMatch = stringMatcher.isMatch(cArr, i2, i3, i4);
                    if (isMatch == 0) {
                        return 0;
                    }
                    i5 += isMatch;
                    i2 += isMatch;
                }
            }
            return i5;
        }

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int isMatch(CharSequence charSequence, int i2, int i3, int i4) {
            int i5 = 0;
            for (StringMatcher stringMatcher : this.stringMatchers) {
                if (stringMatcher != null) {
                    int isMatch = stringMatcher.isMatch(charSequence, i2, i3, i4);
                    if (isMatch == 0) {
                        return 0;
                    }
                    i5 += isMatch;
                    i2 += isMatch;
                }
            }
            return i5;
        }

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int size() {
            int i2 = 0;
            for (StringMatcher stringMatcher : this.stringMatchers) {
                if (stringMatcher != null) {
                    i2 += stringMatcher.size();
                }
            }
            return i2;
        }
    }

    static final class CharArrayMatcher extends AbstractStringMatcher {
        private final char[] chars;
        private final String string;

        CharArrayMatcher(char... cArr) {
            this.string = String.valueOf(cArr);
            this.chars = (char[]) cArr.clone();
        }

        @Override // org.apache.commons.text.matcher.StringMatcher
        public int isMatch(char[] cArr, int i2, int i3, int i4) {
            int size = size();
            if (i2 + size > i4) {
                return 0;
            }
            int i5 = 0;
            while (i5 < size) {
                if (this.chars[i5] != cArr[i2]) {
                    return 0;
                }
                i5++;
                i2++;
            }
            return size;
        }

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int isMatch(CharSequence charSequence, int i2, int i3, int i4) {
            int size = size();
            if (i2 + size > i4) {
                return 0;
            }
            int i5 = 0;
            while (i5 < size) {
                if (this.chars[i5] != charSequence.charAt(i2)) {
                    return 0;
                }
                i5++;
                i2++;
            }
            return size;
        }

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int size() {
            return this.chars.length;
        }

        public String toString() {
            return super.toString() + "[\"" + this.string + "\"]";
        }
    }

    static final class CharMatcher extends AbstractStringMatcher {
        private final char ch;

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int size() {
            return 1;
        }

        CharMatcher(char c2) {
            this.ch = c2;
        }

        @Override // org.apache.commons.text.matcher.StringMatcher
        public int isMatch(char[] cArr, int i2, int i3, int i4) {
            return this.ch == cArr[i2] ? 1 : 0;
        }

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int isMatch(CharSequence charSequence, int i2, int i3, int i4) {
            return this.ch == charSequence.charAt(i2) ? 1 : 0;
        }

        public String toString() {
            return super.toString() + "['" + this.ch + "']";
        }
    }

    static final class CharSetMatcher extends AbstractStringMatcher {
        private final char[] chars;

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int size() {
            return 1;
        }

        CharSetMatcher(char[] cArr) {
            char[] cArr2 = (char[]) cArr.clone();
            this.chars = cArr2;
            Arrays.sort(cArr2);
        }

        @Override // org.apache.commons.text.matcher.StringMatcher
        public int isMatch(char[] cArr, int i2, int i3, int i4) {
            return Arrays.binarySearch(this.chars, cArr[i2]) >= 0 ? 1 : 0;
        }

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int isMatch(CharSequence charSequence, int i2, int i3, int i4) {
            return Arrays.binarySearch(this.chars, charSequence.charAt(i2)) >= 0 ? 1 : 0;
        }

        public String toString() {
            return super.toString() + Arrays.toString(this.chars);
        }
    }

    static final class NoneMatcher extends AbstractStringMatcher {
        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int isMatch(CharSequence charSequence, int i2, int i3, int i4) {
            return 0;
        }

        @Override // org.apache.commons.text.matcher.StringMatcher
        public int isMatch(char[] cArr, int i2, int i3, int i4) {
            return 0;
        }

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int size() {
            return 0;
        }

        NoneMatcher() {
        }
    }

    static final class TrimMatcher extends AbstractStringMatcher {
        private static final int SPACE_INT = 32;

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int size() {
            return 1;
        }

        TrimMatcher() {
        }

        @Override // org.apache.commons.text.matcher.StringMatcher
        public int isMatch(char[] cArr, int i2, int i3, int i4) {
            return cArr[i2] <= ' ' ? 1 : 0;
        }

        @Override // org.apache.commons.text.matcher.AbstractStringMatcher, org.apache.commons.text.matcher.StringMatcher
        public int isMatch(CharSequence charSequence, int i2, int i3, int i4) {
            return charSequence.charAt(i2) <= ' ' ? 1 : 0;
        }
    }

    protected AbstractStringMatcher() {
    }
}
