package org.apache.commons.text.similarity;

import java.util.Arrays;

/* loaded from: classes4.dex */
public class LevenshteinDistance implements EditDistance<Integer> {
    private static final LevenshteinDistance DEFAULT_INSTANCE = new LevenshteinDistance();
    private final Integer threshold;

    public LevenshteinDistance() {
        this(null);
    }

    public LevenshteinDistance(Integer num) {
        if (num != null && num.intValue() < 0) {
            throw new IllegalArgumentException("Threshold must not be negative");
        }
        this.threshold = num;
    }

    @Override // org.apache.commons.text.similarity.EditDistance, org.apache.commons.text.similarity.SimilarityScore
    public Integer apply(CharSequence charSequence, CharSequence charSequence2) {
        Integer num = this.threshold;
        if (num != null) {
            return Integer.valueOf(limitedCompare(charSequence, charSequence2, num.intValue()));
        }
        return Integer.valueOf(unlimitedCompare(charSequence, charSequence2));
    }

    public static LevenshteinDistance getDefaultInstance() {
        return DEFAULT_INSTANCE;
    }

    public Integer getThreshold() {
        return this.threshold;
    }

    private static int limitedCompare(CharSequence charSequence, CharSequence charSequence2, int i2) {
        int i3;
        int i4;
        CharSequence charSequence3;
        CharSequence charSequence4;
        if (charSequence == null || charSequence2 == null) {
            throw new IllegalArgumentException("CharSequences must not be null");
        }
        if (i2 < 0) {
            throw new IllegalArgumentException("Threshold must not be negative");
        }
        int length = charSequence.length();
        int length2 = charSequence2.length();
        if (length == 0) {
            if (length2 <= i2) {
                return length2;
            }
            return -1;
        }
        if (length2 == 0) {
            if (length <= i2) {
                return length;
            }
            return -1;
        }
        if (length > length2) {
            i4 = charSequence.length();
            i3 = length2;
            charSequence4 = charSequence;
            charSequence3 = charSequence2;
        } else {
            i3 = length;
            i4 = length2;
            charSequence3 = charSequence;
            charSequence4 = charSequence2;
        }
        if (i4 - i3 > i2) {
            return -1;
        }
        int i5 = i3 + 1;
        int[] iArr = new int[i5];
        int[] iArr2 = new int[i5];
        int min = Math.min(i3, i2) + 1;
        char c2 = 0;
        for (int i6 = 0; i6 < min; i6++) {
            iArr[i6] = i6;
        }
        int i7 = Integer.MAX_VALUE;
        Arrays.fill(iArr, min, i5, Integer.MAX_VALUE);
        Arrays.fill(iArr2, Integer.MAX_VALUE);
        int i8 = 1;
        while (i8 <= i4) {
            char charAt = charSequence4.charAt(i8 - 1);
            iArr2[c2] = i8;
            int max = Math.max(1, i8 - i2);
            int min2 = i8 > i7 - i2 ? i3 : Math.min(i3, i8 + i2);
            if (max > 1) {
                iArr2[max - 1] = i7;
            }
            while (max <= min2) {
                int i9 = max - 1;
                if (charSequence3.charAt(i9) == charAt) {
                    iArr2[max] = iArr[i9];
                } else {
                    iArr2[max] = Math.min(Math.min(iArr2[i9], iArr[max]), iArr[i9]) + 1;
                }
                max++;
            }
            i8++;
            c2 = 0;
            i7 = Integer.MAX_VALUE;
            int[] iArr3 = iArr2;
            iArr2 = iArr;
            iArr = iArr3;
        }
        int i10 = iArr[i3];
        if (i10 <= i2) {
            return i10;
        }
        return -1;
    }

    private static int unlimitedCompare(CharSequence charSequence, CharSequence charSequence2) {
        if (charSequence == null || charSequence2 == null) {
            throw new IllegalArgumentException("CharSequences must not be null");
        }
        int length = charSequence.length();
        int length2 = charSequence2.length();
        if (length == 0) {
            return length2;
        }
        if (length2 == 0) {
            return length;
        }
        if (length > length2) {
            length2 = charSequence.length();
            length = length2;
        } else {
            charSequence2 = charSequence;
            charSequence = charSequence2;
        }
        int[] iArr = new int[length + 1];
        for (int i2 = 0; i2 <= length; i2++) {
            iArr[i2] = i2;
        }
        for (int i3 = 1; i3 <= length2; i3++) {
            int i4 = iArr[0];
            char charAt = charSequence.charAt(i3 - 1);
            iArr[0] = i3;
            int i5 = 1;
            while (i5 <= length) {
                int i6 = iArr[i5];
                int i7 = i5 - 1;
                iArr[i5] = Math.min(Math.min(iArr[i7] + 1, iArr[i5] + 1), i4 + (charSequence2.charAt(i7) == charAt ? 0 : 1));
                i5++;
                i4 = i6;
            }
        }
        return iArr[length];
    }
}
