package org.apache.commons.text.translate;

import com.dd.plist.ASCIIPropertyListParser;
import java.io.IOException;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Locale;
import org.apache.commons.lang3.Validate;

/* loaded from: classes4.dex */
public abstract class CharSequenceTranslator {
    static final char[] HEX_DIGITS = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', ASCIIPropertyListParser.DATA_GSBOOL_BEGIN_TOKEN, 'C', ASCIIPropertyListParser.DATA_GSDATE_BEGIN_TOKEN, 'E', 'F'};

    public abstract int translate(CharSequence charSequence, int i2, Writer writer) throws IOException;

    public final String translate(CharSequence charSequence) {
        if (charSequence == null) {
            return null;
        }
        try {
            StringWriter stringWriter = new StringWriter(charSequence.length() * 2);
            translate(charSequence, stringWriter);
            return stringWriter.toString();
        } catch (IOException e2) {
            throw new RuntimeException(e2);
        }
    }

    public final void translate(CharSequence charSequence, Writer writer) throws IOException {
        Validate.isTrue(writer != null, "The Writer must not be null", new Object[0]);
        if (charSequence == null) {
            return;
        }
        int length = charSequence.length();
        int i2 = 0;
        while (i2 < length) {
            int translate = translate(charSequence, i2, writer);
            if (translate == 0) {
                char charAt = charSequence.charAt(i2);
                writer.write(charAt);
                i2++;
                if (Character.isHighSurrogate(charAt) && i2 < length) {
                    char charAt2 = charSequence.charAt(i2);
                    if (Character.isLowSurrogate(charAt2)) {
                        writer.write(charAt2);
                        i2++;
                    }
                }
            } else {
                for (int i3 = 0; i3 < translate; i3++) {
                    i2 += Character.charCount(Character.codePointAt(charSequence, i2));
                }
            }
        }
    }

    public final CharSequenceTranslator with(CharSequenceTranslator... charSequenceTranslatorArr) {
        CharSequenceTranslator[] charSequenceTranslatorArr2 = new CharSequenceTranslator[charSequenceTranslatorArr.length + 1];
        charSequenceTranslatorArr2[0] = this;
        System.arraycopy(charSequenceTranslatorArr, 0, charSequenceTranslatorArr2, 1, charSequenceTranslatorArr.length);
        return new AggregateTranslator(charSequenceTranslatorArr2);
    }

    public static String hex(int i2) {
        return Integer.toHexString(i2).toUpperCase(Locale.ENGLISH);
    }
}
