package org.joda.time.tz;

import org.joda.time.DateTimeZone;

/* loaded from: classes4.dex */
public class CachedDateTimeZone extends DateTimeZone {
    private static final int cInfoCacheMask;
    private static final long serialVersionUID = 5472298452022250685L;
    private final transient Info[] iInfoCache;
    private final DateTimeZone iZone;

    static {
        Integer num;
        int i2;
        try {
            num = Integer.getInteger("org.joda.time.tz.CachedDateTimeZone.size");
        } catch (SecurityException unused) {
            num = null;
        }
        if (num == null) {
            i2 = 512;
        } else {
            int i3 = 0;
            for (int intValue = num.intValue() - 1; intValue > 0; intValue >>= 1) {
                i3++;
            }
            i2 = 1 << i3;
        }
        cInfoCacheMask = i2 - 1;
    }

    public static CachedDateTimeZone forZone(DateTimeZone dateTimeZone) {
        if (dateTimeZone instanceof CachedDateTimeZone) {
            return (CachedDateTimeZone) dateTimeZone;
        }
        return new CachedDateTimeZone(dateTimeZone);
    }

    private CachedDateTimeZone(DateTimeZone dateTimeZone) {
        super(dateTimeZone.getID());
        this.iInfoCache = new Info[cInfoCacheMask + 1];
        this.iZone = dateTimeZone;
    }

    public DateTimeZone getUncachedZone() {
        return this.iZone;
    }

    @Override // org.joda.time.DateTimeZone
    public String getNameKey(long j2) {
        return getInfo(j2).getNameKey(j2);
    }

    @Override // org.joda.time.DateTimeZone
    public int getOffset(long j2) {
        return getInfo(j2).getOffset(j2);
    }

    @Override // org.joda.time.DateTimeZone
    public int getStandardOffset(long j2) {
        return getInfo(j2).getStandardOffset(j2);
    }

    @Override // org.joda.time.DateTimeZone
    public boolean isFixed() {
        return this.iZone.isFixed();
    }

    @Override // org.joda.time.DateTimeZone
    public long nextTransition(long j2) {
        return this.iZone.nextTransition(j2);
    }

    @Override // org.joda.time.DateTimeZone
    public long previousTransition(long j2) {
        return this.iZone.previousTransition(j2);
    }

    @Override // org.joda.time.DateTimeZone
    public int hashCode() {
        return this.iZone.hashCode();
    }

    @Override // org.joda.time.DateTimeZone
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof CachedDateTimeZone) {
            return this.iZone.equals(((CachedDateTimeZone) obj).iZone);
        }
        return false;
    }

    private Info getInfo(long j2) {
        int i2 = (int) (j2 >> 32);
        Info[] infoArr = this.iInfoCache;
        int i3 = cInfoCacheMask & i2;
        Info info = infoArr[i3];
        if (info != null && ((int) (info.iPeriodStart >> 32)) == i2) {
            return info;
        }
        Info createInfo = createInfo(j2);
        infoArr[i3] = createInfo;
        return createInfo;
    }

    private Info createInfo(long j2) {
        long j3 = j2 & (-4294967296L);
        Info info = new Info(this.iZone, j3);
        long j4 = 4294967295L | j3;
        Info info2 = info;
        while (true) {
            long nextTransition = this.iZone.nextTransition(j3);
            if (nextTransition == j3 || nextTransition > j4) {
                break;
            }
            Info info3 = new Info(this.iZone, nextTransition);
            info2.iNextInfo = info3;
            info2 = info3;
            j3 = nextTransition;
        }
        return info;
    }

    private static final class Info {
        private String iNameKey;
        Info iNextInfo;
        public final long iPeriodStart;
        public final DateTimeZone iZoneRef;
        private int iOffset = Integer.MIN_VALUE;
        private int iStandardOffset = Integer.MIN_VALUE;

        Info(DateTimeZone dateTimeZone, long j2) {
            this.iPeriodStart = j2;
            this.iZoneRef = dateTimeZone;
        }

        public String getNameKey(long j2) {
            Info info = this.iNextInfo;
            if (info == null || j2 < info.iPeriodStart) {
                if (this.iNameKey == null) {
                    this.iNameKey = this.iZoneRef.getNameKey(this.iPeriodStart);
                }
                return this.iNameKey;
            }
            return info.getNameKey(j2);
        }

        public int getOffset(long j2) {
            Info info = this.iNextInfo;
            if (info == null || j2 < info.iPeriodStart) {
                if (this.iOffset == Integer.MIN_VALUE) {
                    this.iOffset = this.iZoneRef.getOffset(this.iPeriodStart);
                }
                return this.iOffset;
            }
            return info.getOffset(j2);
        }

        public int getStandardOffset(long j2) {
            Info info = this.iNextInfo;
            if (info == null || j2 < info.iPeriodStart) {
                if (this.iStandardOffset == Integer.MIN_VALUE) {
                    this.iStandardOffset = this.iZoneRef.getStandardOffset(this.iPeriodStart);
                }
                return this.iStandardOffset;
            }
            return info.getStandardOffset(j2);
        }
    }
}
